@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownMassiveAction.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownMassiveAction.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,26 +36,23 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
 if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemtype"])) {
 
-   if (!class_exists($_POST['itemtype']) ) {
+   if (!($item = getItemForItemtype($_POST['itemtype']))) {
       exit();
    }
 
    if (isset($_POST['sub_type'])) {
-      if (!class_exists($_POST['sub_type']) ) {
+      if (!($item = getItemForItemtype($_POST['sub_type']))) {
          exit();
       }
-      $item = new $_POST["sub_type"]();
-   } else {
-      $item = new $_POST["itemtype"]();
    }
 
    if (in_array($_POST["itemtype"],$CFG_GLPI["infocom_types"])) {
-      checkSeveralRightsOr(array($_POST["itemtype"] => "w",
-                                 "infocom"          => "w"));
+      Session::checkSeveralRightsOr(array($_POST["itemtype"] => "w",
+                                          "infocom"          => "w"));
    } else {
       $item->checkGlobal("w");
    }
@@ -63,7 +60,6 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
    echo "<input type='hidden' name='action' value='".$_POST["action"]."'>";
    echo "<input type='hidden' name='itemtype' value='".$_POST["itemtype"]."'>";
    echo '&nbsp;';
-
    switch($_POST["action"]) {
       case "activate_rule" :
          Dropdown::showYesNo("activate_rule");
@@ -87,8 +83,8 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
 
       case "move_rule" :
          echo "<select name='move_type'>";
-         echo "<option value='after' selected>".$LANG['buttons'][47]."</option>";
-         echo "<option value='before'>".$LANG['buttons'][46]."</option>";
+         echo "<option value='after' selected>".Toolbox::ucfirst($LANG['search'][24])."</option>";
+         echo "<option value='before'>".Toolbox::ucfirst($LANG['search'][23])."</option>";
          echo "</select>&nbsp;";
 
          if (isset($_POST['entity_restrict'])) {
@@ -108,21 +104,23 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
          break;
 
       case "add_task" :
-         TicketTask::showFormMassiveAction();
+         $tasktype = $_POST['itemtype']."Task";
+         $ttype = new $tasktype();
+         $ttype->showFormMassiveAction();
          break;
 
       case "add_actor" :
-         $types            = array(0                 => DROPDOWN_EMPTY_VALUE,
-                                   Ticket::REQUESTER => $LANG['job'][4],
-                                   Ticket::OBSERVER  => $LANG['common'][104],
-                                   Ticket::ASSIGN    => $LANG['job'][5]);
+         $types            = array(0                           => Dropdown::EMPTY_VALUE,
+                                   CommonITILObject::REQUESTER => $LANG['job'][4],
+                                   CommonITILObject::OBSERVER  => $LANG['common'][104],
+                                   CommonITILObject::ASSIGN    => $LANG['job'][5]);
          $rand             = Dropdown::showFromArray('actortype', $types);
 
          $paramsmassaction = array('actortype' => '__VALUE__');
 
-         ajaxUpdateItemOnSelectEvent("dropdown_actortype$rand", "show_massiveaction_field",
-                                     $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionAddActor.php",
-                                     $paramsmassaction);
+         Ajax::updateItemOnSelectEvent("dropdown_actortype$rand", "show_massiveaction_field",
+                                       $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionAddActor.php",
+                                       $paramsmassaction);
          echo "<span id='show_massiveaction_field'>&nbsp;</span>\n";
 
          break;
@@ -144,9 +142,9 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
          $rand             = Auth::dropdown(array('name' => 'authtype'));
          $paramsmassaction = array('authtype' => '__VALUE__');
 
-         ajaxUpdateItemOnSelectEvent("dropdown_authtype$rand", "show_massiveaction_field",
-                                     $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionAuthMethods.php",
-                                     $paramsmassaction);
+         Ajax::updateItemOnSelectEvent("dropdown_authtype$rand", "show_massiveaction_field",
+                                       $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionAuthMethods.php",
+                                       $paramsmassaction);
          echo "<span id='show_massiveaction_field'>";
          echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
                       $LANG['buttons'][2]."'></span>\n";
@@ -212,7 +210,7 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
          break;
 
       case "add_group" :
-         Dropdown::show('Group');
+         Dropdown::show('Group', array('condition' => '`is_usergroup`'));
          echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
                       $LANG['buttons'][2]."'>";
          break;
@@ -234,19 +232,19 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
          break;
 
       case "add_contract" :
-         Contract::dropdown(array('name' => "conID"));
+         Contract::dropdown(array('name' => "contractID"));
          echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
                       $LANG['buttons'][2]."'>";
          break;
 
       case "add_contact" :
-         Dropdown::show('Contact', array('name' => "conID"));
+         Dropdown::show('Contact', array('name' => "contactID"));
          echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
                       $LANG['buttons'][2]."'>";
          break;
 
       case "add_enterprise" :
-         Dropdown::show('Supplier', array('name' => "entID"));
+         Dropdown::show('Supplier', array('name' => "supplierID"));
          echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
                       $LANG['buttons'][2]."'>";
          break;
@@ -257,12 +255,6 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
                       $LANG['buttons'][2]."'>";
          break;
 
-      case "add_user_to_email" :
-         User::dropdown();
-         echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
-                      $LANG['buttons'][2]."'>";
-         break;
-
       case "duplicate" :
          if ($item->isEntityAssign()) {
             Dropdown::show('Entity');
@@ -288,7 +280,7 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
          $searchopt = Search::getCleanedOptions($_POST["itemtype"], 'w');
 
          echo "<select name='id_field' id='massiveaction_field'>";
-         echo "<option value='0' selected>".DROPDOWN_EMPTY_VALUE."</option>";
+         echo "<option value='0' selected>".Dropdown::EMPTY_VALUE."</option>";
 
          foreach ($searchopt as $key => $val) {
             if (!is_array($val)) {
@@ -348,11 +340,11 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
                $paramsmassaction[$key] = $val;
             }
          }
-         ajaxUpdateItemOnSelectEvent("massiveaction_field", "show_massiveaction_field",
-                                     $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionField.php",
-                                     $paramsmassaction);
+         Ajax::updateItemOnSelectEvent("massiveaction_field", "show_massiveaction_field",
+                                       $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionField.php",
+                                       $paramsmassaction);
 
-         echo "<span id='show_massiveaction_field'>&nbsp;</span>\n";
+         echo "&nbsp;<span id='show_massiveaction_field'>&nbsp;</span>\n";
          break;
 
       default :
@@ -362,14 +354,15 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
          if ($split[0]=='plugin' && isset($split[1])) {
             // Normalized name plugin_name_action
             // Allow hook from any plugin on any (core or plugin) type
-            doOneHook($split[1], 'MassiveActionsDisplay', array('itemtype' => $_POST["itemtype"],
-                                                                'action'   => $_POST["action"]));
+            Plugin::doOneHook($split[1], 'MassiveActionsDisplay',
+                              array('itemtype' => $_POST["itemtype"],
+                                    'action'   => $_POST["action"]));
 
          } else if ($plug=isPluginItemType($_POST["itemtype"])) {
             // non-normalized name
             // hook from the plugin defining the type
-            doOneHook($plug['plugin'], 'MassiveActionsDisplay', $_POST["itemtype"],
-                      $_POST["action"]);
+            Plugin::doOneHook($plug['plugin'], 'MassiveActionsDisplay', $_POST["itemtype"],
+                              $_POST["action"]);
          }
    }
 }
