@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleactionvalue.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ruleactionvalue.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,17 +37,16 @@ if (strpos($_SERVER['PHP_SELF'],"ruleactionvalue.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
 if (!defined('GLPI_ROOT')) {
    die("Can not acces directly to this file");
 }
 
-checkLoginUser();
+Session::checkLoginUser();
 $display = false;
 
 $ra = new RuleAction();
 $ra->displayActionSelectPattern($_POST);
-
-?>
+?>
\ No newline at end of file
