@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: updateMetaSearch.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: updateMetaSearch.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,13 +35,12 @@
 define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-if (!class_exists($_POST["itemtype"])) {
+if (!($item = getItemForItemtype($_POST['itemtype']))) {
    exit();
 }
 
-$item = new $_POST["itemtype"];
 $item->checkGlobal('r');
 
 $first_group    = true;
@@ -70,12 +69,12 @@ foreach ($searchopt as $key => $val) {
       // No search on plugins
       echo $key."--";
       if (!isPluginItemType($key) && !isset($val["nometa"])) {
-         $newgroup .= "<option value='$key' title=\"".cleanInputText($val["name"])."\"";
+         $newgroup .= "<option value='$key' title=\"".Html::cleanInputText($val["name"])."\"";
          if ($key == $_POST["field"]) {
             $newgroup .= "selected";
          }
-         $newgroup .= ">". utf8_substr($val["name"], 0,
-                                       $_SESSION['glpidropdown_chars_limit']) ."</option>\n";
+         $newgroup .= ">". Toolbox::substr($val["name"], 0,
+                                           $_SESSION['glpidropdown_chars_limit']) ."</option>\n";
          $items_in_group++;
       }
    }
@@ -110,9 +109,9 @@ $params = array('field'       => '__VALUE__',
                  'searchtype' => $_POST["searchtype2"],
                  'meta'       => 1);
 
-ajaxUpdateItemOnSelectEvent("Search2".$_POST["itemtype"].$_POST["num"],
-                            "Search2Span".$_POST["itemtype"].$_POST["num"],
-                            $CFG_GLPI["root_doc"]."/ajax/searchoption.php", $params, false);
+Ajax::updateItemOnSelectEvent("Search2".$_POST["itemtype"].$_POST["num"],
+                              "Search2Span".$_POST["itemtype"].$_POST["num"],
+                              $CFG_GLPI["root_doc"]."/ajax/searchoption.php", $params);
 echo '</td></tr></table>';
 
 ?>
