@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: define.php 17459 2012-02-09 20:17:17Z moyo $
+ * @version $Id: define.php 17288 2012-01-31 10:35:07Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -28,7 +28,7 @@
 */
 
 // Current version of GLPI
-define("GLPI_VERSION","0.80.7");
+define("GLPI_VERSION","0.83");
 define("GLPI_DEMO_MODE","0");
 
 
@@ -42,7 +42,9 @@ $CFG_GLPI['languages'] =  //| NAME in native lang    |LANG FILE  |extjs| tinymce
             'dk_DK' => array('Dansk',                'dk_DK.php','da',    'da','danish'),
             'ee_ET' => array('Eesti',                'ee_ET.php','en',    'et','estonian'),
             'en_GB' => array('English',              'en_GB.php','en',    'en','english'),
+            'en_US' => array('English (US)',         'en_US.php','en',    'en','english'),
             'es_AR' => array('Español (Argentina)',  'es_AR.php','es',    'es','spanish'),
+            'es_CO' => array('Español (Colombia)',   'es_CO.php','es',    'es','spanish'),
             'es_ES' => array('Español (España)',     'es_ES.php','es',    'es','spanish'),
             'es_MX' => array('Español (Mexico)',     'es_MX.php','es',    'es','spanish'),
             'es_VE' => array('Español (Venezuela)',  'es_VE.php','es',    'es','spanish'),
@@ -91,8 +93,6 @@ define("DAY_TIMESTAMP",86400);
 define("WEEK_TIMESTAMP",604800);
 define("MONTH_TIMESTAMP",2592000);
 
-//Empty value displayed in a dropdown
-define("DROPDOWN_EMPTY_VALUE","-----");
 
 // ITEMS TYPE
 /// Temporary definition for test
@@ -146,36 +146,11 @@ if (!strstr($_SERVER['PHP_SELF'],"/install/")) {
 }
 
 
-// GLPI MODE
-define("NORMAL_MODE",0);
-define("TRANSLATION_MODE",1);
-define("DEBUG_MODE",2);
 
 //Management modes
 define("MANAGEMENT_UNITARY",0);
 define("MANAGEMENT_GLOBAL",1);
 
-// DEVICE INTERNAL ACTION
-define("HISTORY_ADD_DEVICE",1);
-define("HISTORY_UPDATE_DEVICE",2);
-define("HISTORY_DELETE_DEVICE",3);
-define("HISTORY_INSTALL_SOFTWARE",4);
-define("HISTORY_UNINSTALL_SOFTWARE",5);
-define("HISTORY_DISCONNECT_DEVICE",6);
-define("HISTORY_CONNECT_DEVICE",7);
-define("HISTORY_OCS_IMPORT",8);
-define("HISTORY_OCS_DELETE",9);
-define("HISTORY_OCS_IDCHANGED",10);
-define("HISTORY_OCS_LINK",11);
-define("HISTORY_LOG_SIMPLE_MESSAGE",12);
-define("HISTORY_DELETE_ITEM",13);
-define("HISTORY_RESTORE_ITEM",14);
-define("HISTORY_ADD_RELATION",15);
-define("HISTORY_DEL_RELATION",16);
-define("HISTORY_ADD_SUBITEM",17);
-define("HISTORY_UPDATE_SUBITEM",18);
-define("HISTORY_DELETE_SUBITEM",19);
-define("HISTORY_CREATE_ITEM",20);
 
 // EXPORT TYPE
 define("GLOBAL_SEARCH",-1);
@@ -205,92 +180,110 @@ define("MAIL_SMTP",1);
 define("MAIL_SMTPSSL",2);
 define("MAIL_SMTPTLS",3);
 
-// Auto assign mode for tickets
-define("NO_AUTO_ASSIGN",0);
-define("AUTO_ASSIGN_HARDWARE_CATEGORY",1);
-define("AUTO_ASSIGN_CATEGORY_HARDWARE",2);
-
 
 // MESSAGE TYPE
 define("INFO",0);
 define("ERROR",1);
 
-//Bookmark types
-define("BOOKMARK_SEARCH",1); //SEARCH SYSTEM bookmark
-define("BOOKMARK_URI",2); //bookmark without controls
 
-$CFG_GLPI["unicity_types"] = array('Budget', 'Computer', 'Contact', 'Contract', 'Infocom', 'Monitor',
-                                   'NetworkEquipment', 'Peripheral', 'Phone', 'Printer', 'Software',
-                                   'SoftwareLicense', 'Supplier','User');
+// For plugins
+$PLUGIN_HOOKS     = array();
+$CFG_GLPI_PLUGINS = array();
 
-$CFG_GLPI["state_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral', 'Phone',
-                                 'Printer');
 
-$CFG_GLPI["document_types"]= array('Budget', 'CartridgeItem', 'Computer', 'ConsumableItem',
-                                   'Contact', 'Contract', 'Entity', 'Monitor', 'NetworkEquipment',
-                                   'Peripheral', 'Phone', 'Printer', 'Software', 'SoftwareLicense',
-                                   'Supplier', 'Ticket','User');
+$CFG_GLPI["unicity_types"]                = array('Budget', 'Computer', 'Contact', 'Contract',
+                                                  'Infocom', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software',
+                                                  'SoftwareLicense', 'Supplier','User');
 
-$CFG_GLPI["contract_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
-                                    'Phone', 'Printer', 'Software');
+$CFG_GLPI["state_types"]                  = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer');
 
-$CFG_GLPI["infocom_types"] = array('Cartridge', 'CartridgeItem', 'Computer', 'Consumable',
-                                   'ConsumableItem', 'Monitor', 'NetworkEquipment', 'Peripheral',
-                                   'Phone', 'Printer', 'Software', 'SoftwareLicense');
+$CFG_GLPI["document_types"]               = array('Budget', 'CartridgeItem', /*'Change',*/ 'Computer',
+                                                  'ConsumableItem', 'Contact', 'Contract',
+                                                  'Document', 'Entity', 'KnowbaseItem', 'Monitor',
+                                                  'NetworkEquipment', 'Peripheral', 'Phone',
+                                                  'Printer', 'Problem', 'Reminder', 'Software',
+                                                  'SoftwareLicense', 'Supplier', 'Ticket','User');
 
-$CFG_GLPI["reservation_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
-                                       'Phone', 'Printer', 'Software');
+$CFG_GLPI["consumables_types"]            = array('Group', 'User');
 
-$CFG_GLPI["linkuser_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
-                                    'Phone', 'Printer', 'Software');
+$CFG_GLPI["contract_types"]               = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software',
+                                                  'SoftwareLicense');
 
-$CFG_GLPI["linkgroup_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
-                                     'Phone', 'Printer', 'Software');
+$CFG_GLPI["infocom_types"]                = array('Cartridge', 'CartridgeItem', 'Computer',
+                                                  'Consumable', 'ConsumableItem', 'Monitor',
+                                                  'NetworkEquipment', 'Peripheral', 'Phone',
+                                                  'Printer', 'Software', 'SoftwareLicense');
 
-$CFG_GLPI["ticket_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral', 'Phone',
-                                  'Printer', 'Software');
+$CFG_GLPI["reservation_types"]            = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["link_types"] = array('Budget', 'CartridgeItem', 'Computer', 'ConsumableItem', 'Contact',
-                                'Contract', 'Monitor', 'NetworkEquipment', 'Peripheral', 'Phone',
-                                'Printer', 'Software', 'Supplier');
+$CFG_GLPI["linkuser_types"]               = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["dictionnary_types"] = array('ComputerModel', 'ComputerType', 'Manufacturer',
-                                       'MonitorModel', 'MonitorType', 'NetworkEquipmentModel',
-                                       'NetworkEquipmentType', 'OperatingSystem',
-                                       'OperatingSystemServicePack', 'OperatingSystemVersion',
-                                       'PeripheralModel', 'PeripheralType', 'PhoneModel',
-                                       'PhoneType', 'Printer', 'PrinterModel', 'PrinterType',
-                                       'Software');
+$CFG_GLPI["linkgroup_types"]              = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["helpdesk_visible_types"] = array('Software');
+$CFG_GLPI["linkuser_tech_types"]          = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["networkport_types"] = array('Computer', 'NetworkEquipment', 'Peripheral', 'Phone',
-                                       'Printer');
+$CFG_GLPI["linkgroup_tech_types"]         = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software');
+
+$CFG_GLPI["ticket_types"]                 = array('Computer', 'Monitor', 'NetworkEquipment',
+                                                  'Peripheral', 'Phone', 'Printer', 'Software');
+
+$CFG_GLPI["link_types"]                   = array('Budget', 'CartridgeItem', 'Computer',
+                                                  'ConsumableItem', 'Contact', 'Contract', 'Monitor',
+                                                  'NetworkEquipment', 'Peripheral', 'Phone',
+                                                  'Printer', 'Software', 'Supplier');
+
+$CFG_GLPI["dictionnary_types"]            = array('ComputerModel', 'ComputerType', 'Manufacturer',
+                                                  'MonitorModel', 'MonitorType',
+                                                  'NetworkEquipmentModel', 'NetworkEquipmentType',
+                                                  'OperatingSystem', 'OperatingSystemServicePack',
+                                                  'OperatingSystemVersion', 'PeripheralModel',
+                                                  'PeripheralType', 'PhoneModel', 'PhoneType',
+                                                  'Printer', 'PrinterModel', 'PrinterType',
+                                                  'Software');
+
+$CFG_GLPI["helpdesk_visible_types"]       = array('Software');
+
+$CFG_GLPI["networkport_types"]            = array('Computer', 'NetworkEquipment', 'Peripheral',
+                                                  'Phone', 'Printer');
 
 $CFG_GLPI["massiveaction_noupdate_types"] = array('Entity', 'OcsServer', 'Profile',
                                                   'TicketValidation');
 
 $CFG_GLPI["massiveaction_nodelete_types"] = array('CronTask', 'Entity', 'NotImportedEmail');
 
-$CFG_GLPI["notificationtemplates_types"] = array('Cartridge', 'Consumable', 'Contract', 'Crontask',
-                                                 'DBConnection', 'FieldUnicity', 'Infocom',
-                                                 'Reservation', 'SoftwareLicense', 'Ticket', 'User');
+$CFG_GLPI["notificationtemplates_types"]  = array('Cartridge', 'Consumable', 'Contract', 'Crontask',
+                                                  'DBConnection', 'FieldUnicity', 'Infocom',
+                                                  'Problem', 'Reservation', 'SoftwareLicense',
+                                                  'Ticket', 'User');
 
-$CFG_GLPI["notificationmethods_types"] = array('NotificationMail');
+$CFG_GLPI["notificationmethods_types"]    = array('NotificationMail');
 
-$CFG_GLPI["union_search_type"] = array('ReservationItem' => "reservation_types",
-                                       'States'          => "state_types");
+$CFG_GLPI["union_search_type"]            = array('ReservationItem' => "reservation_types",
+                                                  'States'          => "state_types");
 
-$CFG_GLPI["systeminformations_types"] = array('AuthLDAP', 'DBConnection', 'MailCollector',
-                                              'OcsServer', 'Plugin');
+$CFG_GLPI["systeminformations_types"]     = array('AuthLDAP', 'DBConnection', 'MailCollector',
+                                                  'OcsServer', 'Plugin');
 
-$CFG_GLPI["rulecollections_types"] = array('RuleImportComputerCollection',
-                                           'RuleMailCollectorCollection', 'RuleOcsCollection',
-                                           'RuleRightCollection', 'RuleSoftwareCategoryCollection',
-                                           'RuleTicketCollection');
+$CFG_GLPI["rulecollections_types"]        = array('RuleImportComputerCollection',
+                                                  'RuleMailCollectorCollection', 'RuleOcsCollection',
+                                                  'RuleRightCollection',
+                                                  'RuleSoftwareCategoryCollection',
+                                                  'RuleTicketCollection');
 
 // Items which can planned something
-$CFG_GLPI['planning_types'] = array('Reminder','TicketPlanning');
+$CFG_GLPI['planning_types']               = array('ProblemTask', 'Reminder', 'TicketTask');
+
+$CFG_GLPI["globalsearch_types"]           = array('Computer', 'Contact', 'Document',  'Monitor',
+                                                  'NetworkEquipment', 'Peripheral', 'Phone',
+                                                  'Printer', 'Software', 'Supplier', 'Ticket');
 
 // New config options which can be missing during migration
 $CFG_GLPI["number_format"]  = 0;
@@ -308,7 +301,8 @@ $CFG_GLPI['user_pref_field'] = array('csv_delimiter', 'date_format', 'default_re
                                      'is_not_categorized_soft_expanded', 'language', 'list_limit',
                                      'names_format', 'number_format', 'priority_1', 'priority_2',
                                      'priority_3', 'priority_4', 'priority_5', 'priority_6',
-                                     'show_jobs_at_login', 'task_private','use_flat_dropdowntree');
+                                     'refresh_ticket_list', 'set_default_tech', 'show_count_on_tabs',
+                                     'show_jobs_at_login', 'task_private', 'use_flat_dropdowntree');
 
 /// TODO need this array be empty
 // Itemtypes not implements : need to create class to avoid warning on autoload
@@ -342,5 +336,5 @@ $CFG_GLPI['missingclasses'] = array('cartridgeitem_printermodel',
                                     'rulecacheprintermodel',
                                     'rulecacheprinter',
                                     'rulecacheprintertype',
-                                    'rulecachesoftware',);
+                                    'rulecachesoftware');
 ?>
