@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: authldap.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: authldap.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,7 +36,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("config", "w");
+Session::checkRight("config", "w");
 
 $config = new Config();
 $config_ldap = new AuthLDAP();
@@ -45,31 +45,31 @@ if (!isset($_GET['id'])) {
    $_GET['id'] = "";
 }
 //LDAP Server add/update/delete
-if (isset ($_POST["update"])) {
+if (isset($_POST["update"])) {
    $config_ldap->update($_POST);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
-} else if (isset ($_POST["add"])) {
+} else if (isset($_POST["add"])) {
    //If no name has been given to this configuration, then go back to the page without adding
    if ($_POST["name"] != "") {
       if ($newID = $config_ldap->add($_POST)) {
          if (AuthLdap::testLDAPConnection($newID)) {
-            addMessageAfterRedirect($LANG['login'][22]);
+            Session::addMessageAfterRedirect($LANG['login'][22]);
          } else {
-            addMessageAfterRedirect($LANG['login'][23],false,ERROR);
+            Session::addMessageAfterRedirect($LANG['login'][23], false, ERROR);
          }
-         glpi_header($CFG_GLPI["root_doc"] . "/front/authldap.php?next=extauth_ldap&id=".$newID);
+         Html::redirect($CFG_GLPI["root_doc"] . "/front/authldap.php?next=extauth_ldap&id=".$newID);
       }
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
-} else if (isset ($_POST["delete"])) {
+} else if (isset($_POST["delete"])) {
    $config_ldap->delete($_POST);
    $_SESSION['glpi_authconfig'] = 1;
    $config_ldap->redirectToList();
 
-} else if (isset ($_POST["test_ldap"])) {
-   $ldap = new AuthLDAP;
+} else if (isset($_POST["test_ldap"])) {
+   $ldap = new AuthLDAP();
    $ldap->getFromDB($_POST["id"]);
 
    if (AuthLdap::testLDAPConnection($_POST["id"])) {
@@ -79,11 +79,11 @@ if (isset ($_POST["update"])) {
       $_SESSION["LDAP_TEST_MESSAGE"] = $LANG['login'][23].
                                        " (".$LANG['ldap'][21]." : ".$ldap->fields["name"].")";
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
-} else if (isset ($_POST["test_ldap_replicate"])) {
+} else if (isset($_POST["test_ldap_replicate"])) {
    foreach ($_POST["test_ldap_replicate"] as $replicate_id => $value) {
-      $replicate = new AuthLdapReplicate;
+      $replicate = new AuthLdapReplicate();
       $replicate->getFromDB($replicate_id);
 
       if (AuthLdap::testLDAPConnection($_POST["id"],$replicate_id)) {
@@ -94,26 +94,25 @@ if (isset ($_POST["update"])) {
                                           " (".$LANG['ldap'][19]." : ".$replicate->fields["name"].")";
       }
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete_replicate"])) {
-   $replicate = new AuthLdapReplicate;
+   $replicate = new AuthLdapReplicate();
    foreach ($_POST["item"] as $index=>$val) {
       $replicate->delete(array("id" => $index));
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["add_replicate"])) {
-   $replicate = new AuthLdapReplicate;
+   $replicate = new AuthLdapReplicate();
    unset($_POST["next"]);
    unset($_POST["id"]);
    $replicate->add($_POST);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 }
 
-commonHeader($LANG['login'][2], $_SERVER['PHP_SELF'],"config","extauth","ldap");
+Html::header(AuthLDAP::getTypeName(1), $_SERVER['PHP_SELF'], 'config', 'extauth', 'ldap');
 $config_ldap->showForm($_GET["id"]);
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
