@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: bookmark.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: bookmark.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -44,7 +44,7 @@ if (!isset($_GET["url"])) {
    $_GET["url"] = "";
 }
 
-$bookmark = new Bookmark;
+$bookmark = new Bookmark();
 
 if (isset($_POST["add"])) {
    $bookmark->check(-1, 'w', $_POST);
@@ -105,19 +105,9 @@ if ($_GET["action"] == "edit") {
    }
 } else {
    echo '<br>';
-   $tabs[1] = array('title'  => $LANG['common'][88],
-                    'url'    => $CFG_GLPI['root_doc']."/ajax/bookmark.tabs.php",
-                    'params' => "target=".$_SERVER['PHP_SELF']."&glpi_tab=1&itemtype=Bookmark");
 
-   if (haveRight('bookmark_public','r')) {
-      $tabs[0] = array('title'  => $LANG['common'][76],
-                       'url'    => $CFG_GLPI['root_doc']."/ajax/bookmark.tabs.php",
-                       'params' => "target=".$_SERVER['PHP_SELF']."&glpi_tab=0&itemtype=Bookmark");
-   }
-   echo "<div id='tabspanel' class='center-h'></div>";
-   createAjaxTabs('tabspanel', 'tabcontent', $tabs, 'Bookmark', Bookmark::WIDTH);
+   $bookmark->showTabs();
    echo "<div id='tabcontent'>&nbsp;</div>";
    echo "<script type='text/javascript'>loadDefaultTab();</script>";
 }
-
 ?>
\ No newline at end of file
