@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: find_num.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: find_num.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,10 +36,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-if ($CFG_GLPI["use_anonymous_helpdesk"]) {
-   $auth = new Auth();
-   $auth->initSession();
-} else {
+if (!$CFG_GLPI["use_anonymous_helpdesk"]) {
    exit();
 }
 
