@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: graph.send.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: graph.send.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -32,27 +32,24 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkLoginUser();
+Session ::checkLoginUser();
 
 if (isset($_GET["switchto"])) {
-   $_SESSION['glpigraphtype']=$_GET["switchto"];
-   glpi_header($_SERVER['HTTP_REFERER']);
+   $_SESSION['glpigraphtype'] = $_GET["switchto"];
+   Html::back();
 }
 
-if ($uid=getLoginUserID(false) && isset($_GET["file"])) {
+if ($uid=Session::getLoginUserID(false) && isset($_GET["file"])) {
    list($userID,$filename)=explode("_",$_GET["file"]);
    if ($userID==$uid && file_exists(GLPI_GRAPH_DIR."/".$_GET["file"])) {
       list($fname,$extension)=explode(".",$filename);
 
-      sendFile(GLPI_GRAPH_DIR."/".$_GET["file"],'glpi.'.$extension);
+      Toolbox::sendFile(GLPI_GRAPH_DIR."/".$_GET["file"], 'glpi.'.$extension);
    } else {
-      displayErrorAndDie($LANG['document'][45],true);
+      Html::displayErrorAndDie($LANG['document'][45],true);
    }
 }
-
-
-?>
+?>
\ No newline at end of file
