@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: helpdesk.public.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: helpdesk.public.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,18 +37,18 @@ define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 // Change profile system
-if (isset ($_POST['newprofile'])) {
-   if (isset ($_SESSION["glpiprofiles"][$_POST['newprofile']])) {
-      changeProfile($_POST['newprofile']);
+if (isset($_POST['newprofile'])) {
+   if (isset($_SESSION["glpiprofiles"][$_POST['newprofile']])) {
+      Session::changeProfile($_POST['newprofile']);
 
       if ($_SESSION["glpiactiveprofile"]["interface"] == "central") {
-         glpi_header($CFG_GLPI['root_doc']."/front/central.php");
+         Html::redirect($CFG_GLPI['root_doc']."/front/central.php");
       } else {
-         glpi_header($_SERVER['PHP_SELF']);
+         Html::redirect($_SERVER['PHP_SELF']);
       }
 
    } else {
-      glpi_header(preg_replace("/entities_id=.*/","",$_SERVER['HTTP_REFERER']));
+      Html::redirect(preg_replace("/entities_id=.*/","",$_SERVER['HTTP_REFERER']));
    }
 }
 
@@ -57,47 +57,47 @@ if (isset($_GET["active_entity"])) {
    if (!isset($_GET["is_recursive"])) {
       $_GET["is_recursive"] = 0;
    }
-   if (changeActiveEntities($_GET["active_entity"],$_GET["is_recursive"])) {
+   if (Session::changeActiveEntities($_GET["active_entity"],$_GET["is_recursive"])) {
       if ($_GET["active_entity"] == $_SESSION["glpiactive_entity"]) {
-         glpi_header(preg_replace("/entities_id.*/","",$_SERVER['HTTP_REFERER']));
+         Html::redirect(preg_replace("/entities_id.*/","",$_SERVER['HTTP_REFERER']));
       }
    }
 }
 
 // Redirect management
 if (isset($_GET["redirect"])) {
-   manageRedirect($_GET["redirect"]);
+   Toolbox::manageRedirect($_GET["redirect"]);
 }
 
 // redirect if no create ticket right
-if (!haveRight('create_ticket',1)) {
-   if (haveRight('observe_ticket',1) || haveRight('validate_ticket',1)) {
-      glpi_header($CFG_GLPI['root_doc']."/front/ticket.php");
-   } else if (haveRight('reservation_helpdesk',1)) {
-      glpi_header($CFG_GLPI['root_doc']."/front/reservationitem.php");
-   } else if (haveRight('faq','r')) {
-      glpi_header($CFG_GLPI['root_doc']."/front/helpdesk.faq.php");
+if (!Session::haveRight('create_ticket',1)) {
+   if (Session::haveRight('observe_ticket',1) || Session::haveRight('validate_ticket',1)) {
+      Html::redirect($CFG_GLPI['root_doc']."/front/ticket.php");
+   } else if (Session::haveRight('reservation_helpdesk',1)) {
+      Html::redirect($CFG_GLPI['root_doc']."/front/reservationitem.php");
+   } else if (Session::haveRight('faq','r')) {
+      Html::redirect($CFG_GLPI['root_doc']."/front/helpdesk.faq.php");
    }
 }
 
-checkHelpdeskAccess();
+Session::checkHelpdeskAccess();
 
-helpHeader($LANG['job'][13],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
+Html::helpHeader($LANG['job'][13],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
 
 if (isset($_GET['create_ticket'])) {
-   printHelpDesk(getLoginUserID(),1);
+   Ticket::showFormHelpdesk(Session::getLoginUserID());
 
 } else {
    echo "<table class='tab_cadre_central'><tr>";
    echo "<td class='top'><br>";
    echo "<table>";
-   if (haveRight('create_ticket',1)) {
+   if (Session::haveRight('create_ticket',1)) {
       echo "<tr><td class='top' width='450px'>";
       Ticket::showCentralCount(true);
       echo "</td></tr>";
    }
 
-   if (haveRight("reminder_public","r")) {
+   if (Session::haveRight("reminder_public","r")) {
       echo "<tr><td class='top' width='450px'>";
       Reminder::showListForCentral($_SESSION["glpiactive_entity"]);
       $entities = array_reverse(getAncestorsOf("glpi_entities", $_SESSION["glpiactive_entity"]));
@@ -120,7 +120,7 @@ if (isset($_GET['create_ticket'])) {
    echo "<table>";
 
    // Show KB items
-   if (haveRight("faq","r")) {
+   if (Session::haveRight("faq","r")) {
       echo "<tr><td class='top' width='450px'>";
       KnowbaseItem::showRecentPopular($CFG_GLPI['root_doc'].'/front/helpdesk.faq.php', "popular", 1);
       echo "</td></tr>";
@@ -136,6 +136,5 @@ if (isset($_GET['create_ticket'])) {
 
 }
 
-helpFooter();
-
-?>
+Html::helpFooter();
+?>
\ No newline at end of file
