@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ocsng.link.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ocsng.link.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,9 +35,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("ocsng","w");
+Session::checkRight("ocsng", "w");
 
-commonHeader($LANG['ocsng'][0],$_SERVER['PHP_SELF'], "utils", "ocsng", "link");
+Html::header($LANG['ocsng'][0],$_SERVER['PHP_SELF'], "utils", "ocsng", "link");
 
 $CFG_GLPI["use_ajax"] = 1;
 
@@ -61,17 +61,17 @@ if (isset($_SESSION["ocs_link"])) {
       $percent = min(100,
                      round(100*($_SESSION["ocs_link_count"]-$count)/$_SESSION["ocs_link_count"], 0));
 
-      displayProgressBar(400,$percent);
+      Html::displayProgressBar(400, $percent);
 
       $key = array_pop($_SESSION["ocs_link"]);
       OcsServer::linkComputer($key["ocsid"], $_SESSION["ocsservers_id"], $key["computers_id"]);
-      glpi_header($_SERVER['PHP_SELF']);
+      Html::redirect($_SERVER['PHP_SELF']);
 
    } else {
-      displayProgressBar(400,100);
+      Html::displayProgressBar(400, 100);
 
       unset($_SESSION["ocs_link"]);
-      echo "<div class='center b'>".$LANG['ocsng'][8]."<br>";
+      echo "<div class='center b'>".$LANG['ldap'][10]."<br>";
       echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a></div>";
    }
 }
@@ -100,9 +100,8 @@ if (!isset($_POST["import_ok"])) {
          }
       }
    }
-   glpi_header($_SERVER['PHP_SELF']);
+   Html::redirect($_SERVER['PHP_SELF']);
 }
 
-commonFooter();
-
+Html::footer();
 ?>
\ No newline at end of file
