@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.contract.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: report.contract.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,16 +35,18 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("reports","r");
+Session::checkRight("reports", "r");
 
-commonHeader($LANG['Menu'][6], $_SERVER['PHP_SELF'], "utils", "report");
+Html::header($LANG['Menu'][6], $_SERVER['PHP_SELF'], "utils", "report");
+
+Report::title();
 
 # Titre
 
 echo "<form name='form' method='post' action='report.contract.list.php'>";
 
 echo "<table class='tab_cadre' >";
-echo "<tr><th colspan='2'><big><b>".$LANG['reports'][11]." </b></big></th></tr>";
+echo "<tr><th colspan='2'><span class='big'>".$LANG['reports'][11]." </span></th></tr>";
 
 # 3. Selection d'affichage pour generer la liste
 echo "<tr class='tab_bg_1'>";
@@ -80,6 +82,5 @@ echo "<p><input type='submit' value=\"".$LANG['reports'][15]."\" class='submit'>
 echo "</table>";
 echo "</form>";
 
-commonFooter();
-
+Html::footer();
 ?>
\ No newline at end of file
