@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.infocom.conso.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: report.infocom.conso.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,9 +35,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("reports","r");
+Session::checkRight("reports", "r");
 
-commonHeader($LANG['Menu'][6], $_SERVER['PHP_SELF'], "utils", "report");
+Html::header($LANG['Menu'][6], $_SERVER['PHP_SELF'], "utils", "report");
 
 if (empty($_POST["date1"]) && empty($_POST["date2"])) {
    $year = date("Y")-1;
@@ -54,14 +54,16 @@ if (!empty($_POST["date1"])
    $_POST["date2"] = $tmp;
 }
 
+Report::title();
+
 echo "\n<form method='post' name='form' action='".$_SERVER['PHP_SELF']."'>";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
 echo "<td class='right'>".$LANG['search'][8]."&nbsp;:&nbsp;</td><td>";
-showDateFormItem("date1", $_POST["date1"]);
+Html::showDateFormItem("date1", $_POST["date1"]);
 echo "</td><td rowspan='2' class='center'>";
 echo "<input type='submit' class='button' name='submit' value=\"".$LANG['buttons'][7]."\"></td></tr>\n";
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;:&nbsp;</td><td>";
-showDateFormItem("date2", $_POST["date2"]);
+Html::showDateFormItem("date2", $_POST["date2"]);
 echo "</td></tr>";
 echo "</table></form>\n";
 
@@ -252,8 +254,8 @@ if (($i%2)==0) {
 echo "&nbsp;</td></tr></table>";
 
 echo "<div class='center'><h3>".$LANG['common'][33]."&nbsp;: ".
-      $LANG['financial'][21]." = ".formatNumber($valeurtot)." - ".
-      $LANG['financial'][81]." = ".formatNumber($valeurnettetot)."</h3></div>\n";
+      $LANG['financial'][21]." = ".Html::formatNumber($valeurtot)." - ".
+      $LANG['financial'][81]." = ".Html::formatNumber($valeurnettetot)."</h3></div>\n";
 
 if (count($valeurnettegraphtot) >0) {
    $valeurnettegraphtotdisplay = array_map('round', $valeurnettegraphtot);
@@ -267,6 +269,5 @@ if (count($valeurgraphtot) >0) {
                    array('title' => $LANG['financial'][21]));
 }
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
