@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.infocom.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: report.infocom.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,9 +36,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("reports","r");
+Session::checkRight("reports", "r");
 
-commonHeader($LANG['Menu'][6], $_SERVER['PHP_SELF'], "utils", "report");
+Html::header($LANG['Menu'][6], $_SERVER['PHP_SELF'], "utils", "report");
 
 if (empty($_POST["date1"]) && empty($_POST["date2"])) {
    $year = date("Y")-1;
@@ -55,14 +55,16 @@ if (!empty($_POST["date1"])
    $_POST["date2"] = $tmp;
 }
 
+Report::title();
+
 echo "<div class='center'><form method='post' name='form' action='".$_SERVER['PHP_SELF']."'>";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
 echo "<td class='right'>".$LANG['search'][8]."&nbsp;:&nbsp;</td><td>";
-showDateFormItem("date1", $_POST["date1"]);
+Html::showDateFormItem("date1", $_POST["date1"]);
 echo "</td><td rowspan='2' class='center'>";
 echo "<input type='submit' class='button' name='submit' value=\"".$LANG['buttons'][7]."\"></td></tr>";
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;:&nbsp;</td><td>";
-showDateFormItem("date2" ,$_POST["date2"]);
+Html::showDateFormItem("date2" ,$_POST["date2"]);
 echo "</td></tr>";
 echo "</table></form></div>";
 
@@ -107,7 +109,7 @@ function display_infocoms_report($itemtype, $begin, $end) {
 
    $query .= " ORDER BY entname ASC, `buy_date`, `use_date`";
 
-   $display_entity = isMultiEntitiesMode();
+   $display_entity = Session::isMultiEntitiesMode();
 
    $result = $DB->query($query);
    if ($DB->numrows($result)>0) {
@@ -177,19 +179,20 @@ function display_infocoms_report($itemtype, $begin, $end) {
             }
          }
 
-         echo "<td class='right'>".formatNumber($line["value"])."</td><td class='right'>".
-               formatNumber($valeurnette)."</td><td class='right'>".
+         echo "<td class='right'>".Html::formatNumber($line["value"])."</td><td class='right'>".
+               Html::formatNumber($valeurnette)."</td><td class='right'>".
                Infocom::showTco($line["ticket_tco"],$line["value"])."</td><td>".
-               convDate($line["buy_date"])."</td><td>".convDate($line["use_date"])."</td><td>".
-               getWarrantyExpir($line["buy_date"],$line["warranty_duration"])."</td></tr>";
+               Html::convDate($line["buy_date"])."</td><td>".Html::convDate($line["use_date"]).
+               "</td><td>".Infocom::getWarrantyExpir($line["buy_date"], $line["warranty_duration"]).
+               "</td></tr>";
       }
 
       $valeurtot += $valeursoustot;
       $valeurnettetot += $valeurnettesoustot;
 
       echo "<tr><td colspan='6' class='center'><h3>".$LANG['common'][33]."&nbsp;: ".
-            $LANG['financial'][21]."=".formatNumber($valeursoustot)." - ".
-            $LANG['financial'][81]."=".formatNumber($valeurnettesoustot)."</h3></td></tr>";
+            $LANG['financial'][21]."=".Html::formatNumber($valeursoustot)." - ".
+            $LANG['financial'][81]."=".Html::formatNumber($valeurnettesoustot)."</h3></td></tr>";
 
       if (count($valeurnettegraph)>0) {
          echo "<tr><td colspan='5' class='center'>";
@@ -261,8 +264,8 @@ echo "</td></tr></table>";
 
 
 echo "<div class='center'><h3>".$LANG['common'][33]."&nbsp;: ".
-      $LANG['financial'][21]."=".formatNumber($valeurtot)." - ".
-      $LANG['financial'][81]."=".formatNumber($valeurnettetot)."</h3></div>";
+      $LANG['financial'][21]."=".Html::formatNumber($valeurtot)." - ".
+      $LANG['financial'][81]."=".Html::formatNumber($valeurnettetot)."</h3></div>";
 
 if (count($valeurnettegraphtot)>0) {
    $valeurnettegraphtotdisplay = array_map('round', $valeurnettegraphtot);
@@ -275,5 +278,5 @@ if (count($valeurgraphtot)>0) {
                    array('title' => $LANG['financial'][21]));
 }
 
-commonFooter();
-?>
+Html::footer();
+?>
\ No newline at end of file
