@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.reservation.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: report.reservation.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,14 +35,16 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("reports","r");
+Session::checkRight("reports", "r");
 
-commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
+Html::header($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 if (!isset($_GET["id"])) {
    $_GET["id"] = 0;
 }
 
+Report::title();
+
 echo "<form method='get' name='form' action='report.reservation.php'>";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
 echo "<td rowspan='2' class='center'>";
@@ -58,6 +60,5 @@ echo "</table></form>";
 if ($_GET["id"] > 0) {
    Reservation::showForUser($_GET["id"]);
 }
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
