@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.year.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: report.year.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -34,10 +34,11 @@
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
-checkRight("reports","r");
+Session::checkRight("reports", "r");
 
-commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
+Html::header($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
+Report::title();
 
 # Titre
 
@@ -76,6 +77,5 @@ echo "<input type='submit' value=\"".$LANG['reports'][15]."\" class='submit'></t
 
 echo "</table></form>";
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
