@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.global.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: stat.global.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,9 +35,10 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-commonHeader($LANG['Menu'][13], $_SERVER['PHP_SELF'], "maintain", "stat");
+Html::header($LANG['Menu'][13], $_SERVER['PHP_SELF'], "maintain", "stat");
+
+Session::checkRight("statistic", "1");
 
-checkRight("statistic", "1");
 
 if (empty($_REQUEST["date1"]) && empty($_REQUEST["date2"])) {
    $year              = date("Y")-1;
@@ -54,30 +55,36 @@ if (!empty($_REQUEST["date1"])
    $_REQUEST["date2"] = $tmp;
 }
 
+Stat::title();
+
+$item = new $_REQUEST['itemtype']();
+
 echo "<form method='get' name='form' action='stat.global.php'><div class='center'>";
 echo "<table class='tab_cadre'>";
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][8]."&nbsp;: </td><td>";
-showDateFormItem("date1", $_REQUEST["date1"]);
+Html::showDateFormItem("date1", $_REQUEST["date1"]);
 echo "</td><td rowspan='2' class='center'>";
+echo "<input type='hidden' name='itemtype' value=\"".$_REQUEST['itemtype']."\">";
+
 echo "<input type='submit' class='button' value=\"". $LANG['buttons'][7] ."\"></td></tr>";
 
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;: </td><td>";
-showDateFormItem("date2",$_REQUEST["date2"]);
+Html::showDateFormItem("date2",$_REQUEST["date2"]);
 echo "</td></tr>";
 echo "</table></div>";
 
 ///////// Stats nombre intervention
 // Total des interventions
-$values['total']   = Stat::constructEntryValues("inter_total", $_REQUEST["date1"],
+$values['total']   = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_total", $_REQUEST["date1"],
                                                 $_REQUEST["date2"]);
 // Total des interventions résolues
-$values['solved']  = Stat::constructEntryValues("inter_solved", $_REQUEST["date1"],
+$values['solved']  = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_solved", $_REQUEST["date1"],
                                                 $_REQUEST["date2"]);
 // Total des interventions closes
-$values['closed']  = Stat::constructEntryValues("inter_closed", $_REQUEST["date1"],
+$values['closed']  = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_closed", $_REQUEST["date1"],
                                                 $_REQUEST["date2"]);
 // Total des interventions closes
-$values['late']    = Stat::constructEntryValues("inter_solved_late", $_REQUEST["date1"],
+$values['late']    = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_solved_late", $_REQUEST["date1"],
                                                 $_REQUEST["date2"]);
 
 $available = array('total'  => $LANG['job'][14],
@@ -106,43 +113,55 @@ foreach ($available as $key => $name) {
    }
 }
 
-Stat::showGraph($toprint, array('title'     =>$LANG['stats'][13],
+Stat::showGraph($toprint, array('title'     => $LANG['tracking'][29],
                                 'showtotal' => 1,
-                                'unit'      => $LANG['stats'][35]));
+                                'unit'      => $item->getTypeName(2)));
 
 //Temps moyen de resolution d'intervention
-$values2['avgsolved']     = Stat::constructEntryValues("inter_avgsolvedtime", $_REQUEST["date1"],
+$values2['avgsolved']     = Stat::constructEntryValues($_REQUEST['itemtype'],"inter_avgsolvedtime", $_REQUEST["date1"],
                                                        $_REQUEST["date2"]);
-//Temps moyen de cloture d'intervention
-$values2['avgclosed']     = Stat::constructEntryValues("inter_avgclosedtime", $_REQUEST["date1"],
-                                                       $_REQUEST["date2"]);
-//Temps moyen d'intervention reel
-$values2['avgactiontime'] = Stat::constructEntryValues("inter_avgactiontime", $_REQUEST["date1"],
-                                                       $_REQUEST["date2"]);
-//Temps moyen de prise en compte de l'intervention
-$values2['avgtaketime']   = Stat::constructEntryValues("inter_avgtakeaccount", $_REQUEST["date1"],
-                                                       $_REQUEST["date2"]);
-
 // Pass to hour values
 foreach ($values2['avgsolved'] as $key => $val) {
    $values2['avgsolved'][$key] /= HOUR_TIMESTAMP;
 }
+
+//Temps moyen de cloture d'intervention
+$values2['avgclosed']     = Stat::constructEntryValues($_REQUEST['itemtype'],"inter_avgclosedtime", $_REQUEST["date1"],
+                                                       $_REQUEST["date2"]);
+// Pass to hour values
 foreach ($values2['avgclosed'] as $key => $val) {
    $values2['avgclosed'][$key] /= HOUR_TIMESTAMP;
 }
+//Temps moyen d'intervention reel
+$values2['avgactiontime'] = Stat::constructEntryValues($_REQUEST['itemtype'],"inter_avgactiontime", $_REQUEST["date1"],
+                                                       $_REQUEST["date2"]);
+
+// Pass to hour values
 foreach ($values2['avgactiontime'] as $key => $val) {
    $values2['avgactiontime'][$key]/=HOUR_TIMESTAMP;
 }
-foreach ($values2['avgtaketime'] as $key => $val) {
-   $values2['avgtaketime'][$key] /= HOUR_TIMESTAMP;
-}
+
 
 $available = array('avgclosed'      => $LANG['stats'][10],
                    'avgsolved'      => $LANG['stats'][9],
-                   'avgtaketime'    => $LANG['stats'][12],
                    'avgactiontime'  => $LANG['stats'][14]);
 
 
+if ($_REQUEST['itemtype']=='Ticket') {
+   $available['avgtaketime'] = $LANG['stats'][12];
+   
+   //Temps moyen de prise en compte de l'intervention
+   $values2['avgtaketime']   = Stat::constructEntryValues($_REQUEST['itemtype'],"inter_avgtakeaccount", $_REQUEST["date1"],
+                                                         $_REQUEST["date2"]);
+   
+   // Pass to hour values
+   foreach ($values2['avgtaketime'] as $key => $val) {
+      $values2['avgtaketime'][$key] /= HOUR_TIMESTAMP;
+   }
+}
+
+
+
 echo "<div class='center'>";
 
 $show_all2 = false;
@@ -166,63 +185,65 @@ foreach ($available as $key => $name) {
 }
 
 Stat::showGraph($toprint, array('title'     => $LANG['stats'][8],
-                                'unit'      => $LANG['job'][21],
+                                'unit'      => Toolbox::ucfirst($LANG['gmt'][1]),
                                 'showtotal' => 1,
                                 'datatype'  => 'average'));
 
 
-///////// Satisfaction
-$values['opensatisfaction']   = Stat::constructEntryValues("inter_opensatisfaction",
-                                                           $_REQUEST["date1"], $_REQUEST["date2"]);
+if ($_REQUEST['itemtype']=='Ticket') {
 
-$values['answersatisfaction'] = Stat::constructEntryValues("inter_answersatisfaction",
-                                                           $_REQUEST["date1"], $_REQUEST["date2"]);
-
-
-$available = array('opensatisfaction'   => $LANG['satisfaction'][13],
-                   'answersatisfaction' => $LANG['satisfaction'][14]);
-echo "<div class='center'>";
-
-foreach ($available as $key => $name) {
-   echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
-          ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
-}
-echo "</div>";
-
-$toprint = array();
-foreach ($available as $key => $name) {
-   if ($show_all || isset($_REQUEST['graph'][$key])) {
-      $toprint[$name] = $values[$key];
+   ///////// Satisfaction
+   $values['opensatisfaction']   = Stat::constructEntryValues($_REQUEST['itemtype'],"inter_opensatisfaction",
+                                                            $_REQUEST["date1"], $_REQUEST["date2"]);
+   
+   $values['answersatisfaction'] = Stat::constructEntryValues($_REQUEST['itemtype'],"inter_answersatisfaction",
+                                                            $_REQUEST["date1"], $_REQUEST["date2"]);
+   
+   
+   $available = array('opensatisfaction'   => $LANG['satisfaction'][13],
+                     'answersatisfaction' => $LANG['satisfaction'][14]);
+   echo "<div class='center'>";
+   
+   foreach ($available as $key => $name) {
+      echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
+            ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
    }
-}
-
-Stat::showGraph($toprint, array('title'     => $LANG['satisfaction'][3],
-                                'showtotal' => 1,
-                                'unit'      => $LANG['stats'][35]));
-
-$values['avgsatisfaction'] = Stat::constructEntryValues("inter_avgsatisfaction", $_REQUEST["date1"],
-                                                        $_REQUEST["date2"]);
-
-$available = array('avgsatisfaction' => $LANG['satisfaction'][7]);
-echo "<div class='center'>";
-
-foreach ($available as $key => $name) {
-   echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
-          ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
-}
-echo "</div>";
-
-$toprint = array();
-foreach ($available as $key => $name) {
-   if ($show_all || isset($_REQUEST['graph'][$key])) {
-      $toprint[$name] = $values[$key];
+   echo "</div>";
+   
+   $toprint = array();
+   foreach ($available as $key => $name) {
+      if ($show_all || isset($_REQUEST['graph'][$key])) {
+         $toprint[$name] = $values[$key];
+      }
    }
+   
+   Stat::showGraph($toprint, array('title'     => $LANG['satisfaction'][3],
+                                 'showtotal' => 1,
+                                 'unit'      => $LANG['stats'][35]));
+
+
+   $values['avgsatisfaction'] = Stat::constructEntryValues($_REQUEST['itemtype'],"inter_avgsatisfaction", $_REQUEST["date1"],
+                                                         $_REQUEST["date2"]);
+   
+   $available = array('avgsatisfaction' => $LANG['satisfaction'][7]);
+   echo "<div class='center'>";
+   
+   foreach ($available as $key => $name) {
+      echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
+            ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
+   }
+   echo "</div>";
+   
+   $toprint = array();
+   foreach ($available as $key => $name) {
+      if ($show_all || isset($_REQUEST['graph'][$key])) {
+         $toprint[$name] = $values[$key];
+      }
+   }
+   
+   Stat::showGraph($toprint, array('title' => $LANG['satisfaction'][7]));
 }
 
-Stat::showGraph($toprint, array('title' => $LANG['satisfaction'][7]));
-
-
 echo "</form>";
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
