@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.graph.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: stat.graph.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,9 +35,11 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-commonHeader($LANG['Menu'][13], $_SERVER['PHP_SELF'], "maintain", "stat");
+Html::header($LANG['Menu'][13], $_SERVER['PHP_SELF'], "maintain", "stat");
 
-checkRight("statistic", "1");
+Session::checkRight("statistic", "1");
+
+$item  = new $_REQUEST['itemtype'];
 
 if (empty($_POST["date1"]) && empty($_POST["date2"])) {
    if (isset($_GET["date1"])) {
@@ -64,6 +66,7 @@ $cleantarget = preg_replace("/&/","&amp;",$cleantarget);
 $next  = 0;
 $prev  = 0;
 $title = "";
+$cond  = '';
 
 switch($_GET["type"]) {
    case "technicien" :
@@ -71,7 +74,7 @@ switch($_GET["type"]) {
       $val2  = "";
       $next  = getNextItem("glpi_users", $_GET["id"]);
       $prev  = getPreviousItem("glpi_users", $_GET["id"]);
-      $title = $LANG['stats'][16]."&nbsp;: ".Ticket::getAssignName($_GET["id"], 'User', 1);
+      $title = $LANG['stats'][16]."&nbsp;: ".$item->getAssignName($_GET["id"], 'User', 1);
       break;
 
    case "technicien_followup" :
@@ -79,7 +82,7 @@ switch($_GET["type"]) {
       $val2  = "";
       $next  = getNextItem("glpi_users", $_GET["id"]);
       $prev  = getPreviousItem("glpi_users", $_GET["id"]);
-      $title = $LANG['stats'][16]."&nbsp;: ".Ticket::getAssignName($_GET["id"], 'User', 1);
+      $title = $LANG['stats'][16]."&nbsp;: ".$item->getAssignName($_GET["id"], 'User', 1);
       break;
 
    case "enterprise" :
@@ -87,7 +90,7 @@ switch($_GET["type"]) {
       $val2  = "";
       $next  = getNextItem("glpi_suppliers", $_GET["id"]);
       $prev  = getPreviousItem("glpi_suppliers", $_GET["id"]);
-      $title = $LANG['stats'][44]."&nbsp;: ".Ticket::getAssignName($_GET["id"], 'Supplier', 1);
+      $title = $LANG['stats'][44]."&nbsp;: ".$item->getAssignName($_GET["id"], 'Supplier', 1);
       break;
 
    case "user" :
@@ -106,12 +109,16 @@ switch($_GET["type"]) {
       $title = $LANG['stats'][20]."&nbsp;: ".getUserName($_GET["id"],1);
       break;
 
-   case "ticketcategories_id" :
+   case "itilcategories_tree" :
+      $parent = (isset($_REQUEST['champ']) ? $_REQUEST['champ'] : 0);
+      $cond = "(`id`='$parent' OR `itilcategories_id`='$parent')";
+      // nobreak;
+   case "itilcategories_id" :
       $val1  = $_GET["id"];
       $val2  = "";
-      $next  = getNextItem("glpi_ticketcategories", $_GET["id"], '', 'completename');
-      $prev  = getPreviousItem("glpi_ticketcategories", $_GET["id"], '', 'completename');
-      $title = $LANG['common'][36]."&nbsp;: ".Dropdown::getDropdownName("glpi_ticketcategories",
+      $next  = getNextItem("glpi_itilcategories", $_GET["id"], $cond, 'completename');
+      $prev  = getPreviousItem("glpi_itilcategories", $_GET["id"], $cond, 'completename');
+      $title = $LANG['common'][36]."&nbsp;: ".Dropdown::getDropdownName("glpi_itilcategories",
                                                                         $_GET["id"]);
       break;
 
@@ -125,11 +132,17 @@ switch($_GET["type"]) {
       $title = $LANG['common'][17]."&nbsp;: ".Ticket::getTicketTypeName($_GET["id"]);
       break;
 
+   case 'group_tree' :
+   case 'groups_tree_assign' :
+      $parent = (isset($_REQUEST['champ']) ? $_REQUEST['champ'] : 0);
+      $cond = "(`id`='$parent' OR `groups_id`='$parent') AND ".
+              ($_GET["type"]=='group_tree' ? '`is_requester`' : '`is_assign`');
+      // nobreak;
    case "group" :
       $val1  = $_GET["id"];
       $val2  = "";
-      $next  = getNextItem("glpi_groups", $_GET["id"]);
-      $prev  = getPreviousItem("glpi_groups", $_GET["id"]);
+      $next  = getNextItem("glpi_groups", $_GET["id"], $cond);
+      $prev  = getPreviousItem("glpi_groups", $_GET["id"], $cond);
       $title = $LANG['common'][35]."&nbsp;: ".Dropdown::getDropdownName("glpi_groups", $_GET["id"]);
       break;
 
@@ -151,7 +164,7 @@ switch($_GET["type"]) {
       if ($val1 > 1) {
          $prev = $val1-1;
       }
-      $title = $LANG['joblist'][2]."&nbsp;: ".Ticket::getPriorityName($_GET["id"]);
+      $title = $LANG['joblist'][2]."&nbsp;: ".$item->getPriorityName($_GET["id"]);
       break;
 
    case "urgency" :
@@ -164,7 +177,7 @@ switch($_GET["type"]) {
       if ($val1 > 1) {
          $prev = $val1-1;
       }
-      $title = $LANG['joblist'][29]."&nbsp;: ".Ticket::getUrgencyName($_GET["id"]);
+      $title = $LANG['joblist'][29]."&nbsp;: ".$item->getUrgencyName($_GET["id"]);
       break;
 
    case "impact" :
@@ -177,7 +190,7 @@ switch($_GET["type"]) {
       if ($val1 > 1) {
          $prev = $val1-1;
       }
-      $title = $LANG['joblist'][30]."&nbsp;: ".Ticket::getImpactName($_GET["id"]);
+      $title = $LANG['joblist'][30]."&nbsp;: ".$item->getImpactName($_GET["id"]);
       break;
 
    case "usertitles_id" :
@@ -190,13 +203,13 @@ switch($_GET["type"]) {
                                                                       $_GET["id"]);
       break;
 
-   case "ticketsolutiontypes_id" :
+   case "solutiontypes_id" :
       $val1  = $_GET["id"];
       $val2  = "";
       $next  = $prev = 0;
-      $next  = getNextItem("glpi_ticketsolutiontypes", $_GET["id"]);
-      $prev  = getPreviousItem("glpi_ticketsolutiontypes", $_GET["id"]);
-      $title = $LANG['job'][48]."&nbsp;: ".Dropdown::getDropdownName("glpi_ticketsolutiontypes",
+      $next  = getNextItem("glpi_solutiontypes", $_GET["id"]);
+      $prev  = getPreviousItem("glpi_solutiontypes", $_GET["id"]);
+      $title = $LANG['job'][48]."&nbsp;: ".Dropdown::getDropdownName("glpi_solutiontypes",
                                                                       $_GET["id"]);
       break;
 
@@ -279,64 +292,17 @@ $target = preg_replace("/&/","&amp;",$_SERVER["REQUEST_URI"]);
 echo "<form method='post' name='form' action='$target'><div class='center'>";
 echo "<table class='tab_cadre'>";
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][8]."&nbsp;: </td><td>";
-showDateFormItem("date1", $_POST["date1"]);
+Html::showDateFormItem("date1", $_POST["date1"]);
 echo "</td><td rowspan='2' class='center'>";
+echo "<input type='hidden' name='itemtype' value=\"".$_REQUEST['itemtype']."\">";
 echo "<input type='submit' class='button' value=\"".$LANG['buttons'][7]."\"></td></tr>";
 
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;: </td><td>";
-showDateFormItem("date2", $_POST["date2"]);
+Html::showDateFormItem("date2", $_POST["date2"]);
 echo "</td></tr>";
 echo "</table></div>";
 
 
-/*
-///////// Stats nombre intervention
-// Total des interventions
-$entrees_total = Stat::constructEntryValues("inter_total",$_POST["date1"],$_POST["date2"],$_GET["type"],$val1,$val2);
-// Total des interventions résolues
-$entrees_solved = Stat::constructEntryValues("inter_solved",$_POST["date1"],$_POST["date2"],$_GET["type"],$val1,$val2);
-// Total des interventions closes
-$entrees_closed = Stat::constructEntryValues("inter_closed",$_POST["date1"],$_POST["date2"],$_GET["type"],$val1,$val2);
-//Temps moyen de resolution d'intervention
-$entrees_avgsolvedtime = Stat::constructEntryValues("inter_avgsolvedtime",$_POST["date1"],$_POST["date2"],$_GET["type"],$val1,$val2);
-//Temps moyen de cloture d'intervention
-$entrees_avgclosedtime = Stat::constructEntryValues("inter_avgclosedtime",$_POST["date1"],$_POST["date2"],$_GET["type"],$val1,$val2);
-//Temps moyen d'intervention reel
-$entrees_avgactiontime = Stat::constructEntryValues("inter_avgactiontime",$_POST["date1"],$_POST["date2"],$_GET["type"],$val1,$val2);
-//Temps moyen de prise en compte de l'intervention
-$entrees_avgtaketime = Stat::constructEntryValues("inter_avgtakeaccount",$_POST["date1"],$_POST["date2"],$_GET["type"],$val1,$val2);
-
-
-Stat::showGraph(array($LANG['job'][14] => $entrees_total,
-                     $LANG['job'][15]  => $entrees_solved,
-                     $LANG['job'][16]  => $entrees_closed),
-               array('title'=>$LANG['stats'][13],
-                     'showtotal' => 1,
-                     'unit'      => $LANG['stats'][35]));
-
-// Pass to hour values
-foreach ($entrees_avgclosedtime as $key => $val) {
-   $entrees_avgclosedtime[$key]/=HOUR_TIMESTAMP;
-}
-foreach ($entrees_avgsolvedtime as $key => $val) {
-   $entrees_avgsolvedtime[$key]/=HOUR_TIMESTAMP;
-}
-foreach ($entrees_avgtaketime as $key => $val) {
-   $entrees_avgtaketime[$key]/=HOUR_TIMESTAMP;
-}
-foreach ($entrees_avgactiontime as $key => $val) {
-   $entrees_avgactiontime[$key]/=HOUR_TIMESTAMP;
-}
-
-Stat::showGraph(array($LANG['stats'][10] => $entrees_avgclosedtime,
-                        $LANG['stats'][9] => $entrees_avgsolvedtime,
-                        $LANG['stats'][12]  => $entrees_avgtaketime,
-                        $LANG['stats'][14]  => $entrees_avgactiontime),
-               array('title'   => $LANG['stats'][8],
-                     'unit'     => $LANG['job'][21],
-                     'showtotal' => 1,
-                     'datatype' => 'average'));
-*/
 
 
 $show_all = false;
@@ -347,16 +313,16 @@ if (!isset($_REQUEST['graph']) || count($_REQUEST['graph'])==0) {
 
 ///////// Stats nombre intervention
 // Total des interventions
-$values['total']  = Stat::constructEntryValues("inter_total", $_REQUEST["date1"],
+$values['total']  = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_total", $_REQUEST["date1"],
                                                $_REQUEST["date2"], $_GET["type"], $val1, $val2);
 // Total des interventions résolues
-$values['solved'] = Stat::constructEntryValues("inter_solved", $_REQUEST["date1"],
+$values['solved'] = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_solved", $_REQUEST["date1"],
                                                $_REQUEST["date2"], $_GET["type"], $val1, $val2);
 // Total des interventions closes
-$values['closed'] = Stat::constructEntryValues("inter_closed", $_REQUEST["date1"],
+$values['closed'] = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_closed", $_REQUEST["date1"],
                                                $_REQUEST["date2"], $_GET["type"], $val1, $val2);
 // Total des interventions closes
-$values['late']   = Stat::constructEntryValues("inter_solved_late", $_REQUEST["date1"],
+$values['late']   = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_solved_late", $_REQUEST["date1"],
                                                $_REQUEST["date2"], $_GET["type"], $val1, $val2);
 
 $available = array('total'  => $LANG['job'][14],
@@ -383,43 +349,51 @@ Stat::showGraph($toprint, array('title'     => $LANG['stats'][13],
                                 'unit'      => $LANG['stats'][35]));
 
 //Temps moyen de resolution d'intervention
-$values2['avgsolved']     = Stat::constructEntryValues("inter_avgsolvedtime", $_REQUEST["date1"],
+$values2['avgsolved']     = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_avgsolvedtime", $_REQUEST["date1"],
                                                        $_REQUEST["date2"], $_GET["type"], $val1,
                                                        $val2);
-//Temps moyen de cloture d'intervention
-$values2['avgclosed']     = Stat::constructEntryValues("inter_avgclosedtime", $_REQUEST["date1"],
-                                                       $_REQUEST["date2"], $_GET["type"], $val1,
-                                                       $val2);
-//Temps moyen d'intervention reel
-$values2['avgactiontime'] = Stat::constructEntryValues("inter_avgactiontime", $_REQUEST["date1"],
-                                                       $_REQUEST["date2"], $_GET["type"], $val1,
-                                                       $val2);
-//Temps moyen de prise en compte de l'intervention
-$values2['avgtaketime']   = Stat::constructEntryValues("inter_avgtakeaccount", $_REQUEST["date1"],
-                                                       $_REQUEST["date2"], $_GET["type"], $val1,
-                                                       $val2);
-
 // Pass to hour values
 foreach ($values2['avgsolved'] as $key => $val) {
    $values2['avgsolved'][$key] /= HOUR_TIMESTAMP;
 }
-
+//Temps moyen de cloture d'intervention
+$values2['avgclosed']     = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_avgclosedtime", $_REQUEST["date1"],
+                                                       $_REQUEST["date2"], $_GET["type"], $val1,
+                                                       $val2);
+// Pass to hour values
 foreach ($values2['avgclosed'] as $key => $val) {
    $values2['avgclosed'][$key] /= HOUR_TIMESTAMP;
 }
+//Temps moyen d'intervention reel
+$values2['avgactiontime'] = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_avgactiontime", $_REQUEST["date1"],
+                                                       $_REQUEST["date2"], $_GET["type"], $val1,
+                                                       $val2);
+// Pass to hour values
 foreach ($values2['avgactiontime'] as $key => $val) {
    $values2['avgactiontime'][$key] /= HOUR_TIMESTAMP;
 }
 
-foreach ($values2['avgtaketime'] as $key => $val) {
-   $values2['avgtaketime'][$key] /= HOUR_TIMESTAMP;
-}
 
 $available = array('avgclosed'     => $LANG['stats'][10],
                    'avgsolved'     => $LANG['stats'][9],
-                   'avgtaketime'   => $LANG['stats'][12],
                    'avgactiontime' => $LANG['stats'][14]);
 
+
+if ($_REQUEST['itemtype'] == 'Ticket') {
+   $available['avgtaketime'] = $LANG['stats'][12];
+   //Temps moyen de prise en compte de l'intervention
+   $values2['avgtaketime']   = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_avgtakeaccount", $_REQUEST["date1"],
+                                                         $_REQUEST["date2"], $_GET["type"], $val1,
+                                                         $val2);
+   // Pass to hour values
+   foreach ($values2['avgtaketime'] as $key => $val) {
+      $values2['avgtaketime'][$key] /= HOUR_TIMESTAMP;
+   }
+}
+
+
+
+
 echo "<div class='center'>";
 
 $show_all2 = false;
@@ -441,66 +415,66 @@ foreach ($available as $key => $name) {
 }
 
 Stat::showGraph($toprint, array('title'     => $LANG['stats'][8],
-                                'unit'      => $LANG['job'][21],
+                                'unit'      => Toolbox::ucfirst($LANG['gmt'][1]),
                                 'showtotal' => 1,
                                 'datatype'  => 'average'));
 
 
-///////// Satisfaction
-$values['opensatisfaction']   = Stat::constructEntryValues("inter_opensatisfaction",
-                                                           $_REQUEST["date1"], $_REQUEST["date2"],
-                                                           $_GET["type"], $val1, $val2);
+if ($_REQUEST['itemtype'] == 'Ticket') {
+   ///////// Satisfaction
+   $values['opensatisfaction']   = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_opensatisfaction",
+                                                            $_REQUEST["date1"], $_REQUEST["date2"],
+                                                            $_GET["type"], $val1, $val2);
 
-$values['answersatisfaction'] = Stat::constructEntryValues("inter_answersatisfaction",
-                                                           $_REQUEST["date1"], $_REQUEST["date2"],
-                                                           $_GET["type"], $val1, $val2);
+   $values['answersatisfaction'] = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_answersatisfaction",
+                                                            $_REQUEST["date1"], $_REQUEST["date2"],
+                                                            $_GET["type"], $val1, $val2);
 
 
-$available = array('opensatisfaction'   => $LANG['satisfaction'][13],
-                   'answersatisfaction' => $LANG['satisfaction'][14]);
-echo "<div class='center'>";
+   $available = array('opensatisfaction'   => $LANG['satisfaction'][13],
+                     'answersatisfaction' => $LANG['satisfaction'][14]);
+   echo "<div class='center'>";
 
-foreach ($available as $key => $name) {
-   echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
-          ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
-}
-echo "</div>";
-
-$toprint = array();
-foreach ($available as $key => $name) {
-   if ($show_all || isset($_REQUEST['graph'][$key])) {
-      $toprint[$name] = $values[$key];
+   foreach ($available as $key => $name) {
+      echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
+            ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
    }
-}
+   echo "</div>";
 
-Stat::showGraph($toprint, array('title'     => $LANG['satisfaction'][3],
-                                'showtotal' => 1,
-                                'unit'      => $LANG['stats'][35]));
-
-$values['avgsatisfaction'] = Stat::constructEntryValues("inter_avgsatisfaction", $_REQUEST["date1"],
-                                                        $_REQUEST["date2"], $_GET["type"], $val1,
-                                                        $val2);
-
-$available = array('avgsatisfaction' => $LANG['satisfaction'][7]);
-echo "<div class='center'>";
-
-foreach ($available as $key => $name) {
-   echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
-          ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
-}
-echo "</div>";
-
-$toprint = array();
-foreach ($available as $key => $name) {
-   if ($show_all || isset($_REQUEST['graph'][$key])) {
-      $toprint[$name] = $values[$key];
+   $toprint = array();
+   foreach ($available as $key => $name) {
+      if ($show_all || isset($_REQUEST['graph'][$key])) {
+         $toprint[$name] = $values[$key];
+      }
    }
+
+   Stat::showGraph($toprint, array('title'     => $LANG['satisfaction'][3],
+                                 'showtotal' => 1,
+                                 'unit'      => $LANG['stats'][35]));
+
+   $values['avgsatisfaction'] = Stat::constructEntryValues($_REQUEST['itemtype'], "inter_avgsatisfaction", $_REQUEST["date1"],
+                                                         $_REQUEST["date2"], $_GET["type"], $val1,
+                                                         $val2);
+
+   $available = array('avgsatisfaction' => $LANG['satisfaction'][7]);
+   echo "<div class='center'>";
+
+   foreach ($available as $key => $name) {
+      echo "<input type='checkbox' onchange='submit()' name='graph[$key]' ".
+            ($show_all||isset($_REQUEST['graph'][$key])?"checked":"")."> ".$name."&nbsp;";
+   }
+   echo "</div>";
+
+   $toprint = array();
+   foreach ($available as $key => $name) {
+      if ($show_all || isset($_REQUEST['graph'][$key])) {
+         $toprint[$name] = $values[$key];
+      }
+   }
+
+   Stat::showGraph($toprint, array('title' => $LANG['satisfaction'][7]));
+
 }
-
-Stat::showGraph($toprint, array('title' => $LANG['satisfaction'][7]));
-
-
 echo "</form>";
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
