@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.item.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: stat.item.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,9 +35,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-commonHeader($LANG['Menu'][13],'',"maintain","stat");
+Html::header($LANG['Menu'][13],'',"maintain","stat");
 
-checkRight("statistic","1");
+Session::checkRight("statistic", "1");
 
 if (isset($_GET["date1"])) {
    $_POST["date1"] = $_GET["date1"];
@@ -65,19 +65,20 @@ if (!isset($_GET["start"])) {
    $_GET["start"] = 0;
 }
 
+Stat::title();
+
 echo "<div class='center'><form method='post' name='form' action='stat.item.php'>";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
 echo "<td class='right'>".$LANG['search'][8]."&nbsp;:</td><td>";
-showDateFormItem("date1",$_POST["date1"]);
+Html::showDateFormItem("date1",$_POST["date1"]);
 echo "</td><td rowspan='2' class='center'>";
 echo "<input type='submit' class='button' name='submit' value='". $LANG['buttons'][7] ."'></td></tr>";
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;:</td><td>";
-showDateFormItem("date2",$_POST["date2"]);
+Html::showDateFormItem("date2",$_POST["date2"]);
 echo "</td></tr>";
 echo "</table></form></div>";
 
 Stat::showItems($_SERVER['PHP_SELF'],$_POST["date1"],$_POST["date2"],$_GET['start']);
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
