@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ticketfollowup.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ticketfollowup.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,7 +36,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkLoginUser();
+Session::checkLoginUser();
 
 $fup = new TicketFollowup();
 
@@ -46,7 +46,7 @@ if (isset($_POST["add"])) {
 
    Event::log($fup->getField('tickets_id'), "ticket", 4, "tracking",
               $_SESSION["glpiname"]."  ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST['add_close']) || isset($_POST['add_reopen'])) {
    $ticket = new Ticket();
@@ -55,7 +55,7 @@ if (isset($_POST["add"])) {
 
       Event::log($fup->getField('tickets_id'), "ticket", 4, "tracking",
                  $_SESSION["glpiname"]."  ".$LANG['log'][29]);
-      glpi_header($_SERVER['HTTP_REFERER']);
+      Html::back();
    }
 
 } else if (isset($_POST["update"])) {
@@ -64,7 +64,7 @@ if (isset($_POST["add"])) {
 
    Event::log($fup->getField('tickets_id'), "ticket", 4, "tracking",
               $_SESSION["glpiname"]."  ".$LANG['log'][21]);
-   glpi_header(getItemTypeFormURL('Ticket')."?id=".$fup->getField('tickets_id'));
+   Html::redirect(Toolbox::getItemTypeFormURL('Ticket')."?id=".$fup->getField('tickets_id'));
 
 } else if (isset($_POST["delete"])) {
    $fup->check($_POST['id'], 'w');
@@ -72,9 +72,8 @@ if (isset($_POST["add"])) {
 
    Event::log($fup->getField('tickets_id'), "ticket", 4, "tracking",
               $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header(getItemTypeFormURL('Ticket')."?id=".$fup->getField('tickets_id'));
+   Html::redirect(Toolbox::getItemTypeFormURL('Ticket')."?id=".$fup->getField('tickets_id'));
 }
 
-displayErrorAndDie('Lost');
-
-?>
+Html::displayErrorAndDie('Lost');
+?>
\ No newline at end of file
