@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: user.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: user.form.php 17820 2012-03-13 12:06:48Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -56,7 +56,7 @@ $groupuser = new Group_User();
 if (empty($_GET["id"]) && isset($_GET["name"])) {
 
    $user->getFromDBbyName($_GET["name"]);
-   glpi_header($CFG_GLPI["root_doc"]."/front/user.form.php?id=".$user->fields['id']);
+   Html::redirect($CFG_GLPI["root_doc"]."/front/user.form.php?id=".$user->fields['id']);
 }
 
 if (empty($_GET["name"])) {
@@ -65,7 +65,7 @@ if (empty($_GET["name"])) {
 
 if (isset($_REQUEST['getvcard'])) {
    if (empty($_GET["id"])) {
-      glpi_header($CFG_GLPI["root_doc"]."/front/user.php");
+      Html::redirect($CFG_GLPI["root_doc"]."/front/user.php");
    }
    $user->check($_GET['id'], 'r');
    $user->generateVcard($_GET["id"]);
@@ -78,7 +78,7 @@ if (isset($_REQUEST['getvcard'])) {
       Event::log($newID, "users", 4, "setup",
                  $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete"])) {
    $user->check($_POST['id'], 'w');
@@ -99,22 +99,21 @@ if (isset($_REQUEST['getvcard'])) {
    Event::log($_POST["id"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][24]);
    $user->redirectToList();
 
-} else if (isset ($_POST["force_ldap_resynch"])) {
-   checkRight('user_authtype', 'w');
-   $user->check($_POST['id'], 'w');
+} else if (isset($_POST["force_ldap_resynch"])) {
+   Session::checkRight('user_authtype', 'w');
 
    $user->getFromDB($_POST["id"]);
    AuthLdap::ldapImportUserByServerId(array('method' => AuthLDAP::IDENTIFIER_LOGIN,
                                             'value'  => $user->fields["name"]),
                                       true, $user->fields["auths_id"], true);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["update"])) {
    $user->check($_POST['id'], 'w');
    $user->update($_POST);
    Event::log(0, "users", 5, "setup",
               $_SESSION["glpiname"]."  ".$LANG['log'][21]."  ".$user->fields["name"].".");
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["addgroup"])) {
    $groupuser->check(-1,'w',$_POST);
@@ -122,7 +121,7 @@ if (isset($_REQUEST['getvcard'])) {
       Event::log($_POST["users_id"], "users", 4, "setup",
                  $_SESSION["glpiname"]." ".$LANG['log'][48]);
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["deletegroup"])) {
    if (count($_POST["item"])) {
@@ -133,32 +132,31 @@ if (isset($_REQUEST['getvcard'])) {
       }
    }
    Event::log($_POST["users_id"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][49]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["change_auth_method"])) {
-   checkRight('user_authtype', 'w');
-   $user->check($_POST['id'], 'w');
+   Session::checkRight('user_authtype', 'w');
 
    if (isset($_POST["auths_id"])) {
       User::changeAuthMethod(array($_POST["id"]), $_POST["authtype"], $_POST["auths_id"]);
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else {
    if (!isset($_GET["ext_auth"])) {
-      checkRight("user", "r");
-      commonHeader($LANG['title'][13], '', "admin", "user");
+      Session::checkRight("user", "r");
+      Html::header($LANG['title'][13], '', "admin", "user");
       $user->showForm($_GET["id"]);
-      commonFooter();
+      Html::footer();
 
    } else {
-      checkRight("import_externalauth_users", "w");
+      Session::checkRight("import_externalauth_users", "w");
 
       if (isset($_GET['add_ext_auth_ldap'])) {
          if (isset($_GET['login']) && !empty($_GET['login'])) {
             AuthLdap::importUserFromServers(array('name' => $_GET['login']));
          }
-         glpi_header($_SERVER['HTTP_REFERER']);
+         Html::back();
       }
       if (isset($_GET['add_ext_auth_simple'])) {
          if (isset($_GET['login']) && !empty($_GET['login'])) {
@@ -170,13 +168,12 @@ if (isset($_REQUEST['getvcard'])) {
             Event::log($newID, "users", 4, "setup",
                        $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_GET['login'].".");
          }
-         glpi_header($_SERVER['HTTP_REFERER']);
+         Html::back();
       }
 
-      commonHeader($LANG['title'][13], '', "admin", "user");
+      Html::header($LANG['title'][13], '', "admin", "user");
       User::showAddExtAuthForm();
-      commonFooter();
+      Html::footer();
    }
 }
-
-?>
+?>
\ No newline at end of file
