@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: auth.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: auth.class.php 17758 2012-03-08 09:33:53Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -91,6 +91,7 @@ class Auth {
 
       $query = "SELECT *
                 FROM `glpi_users`
+                LEFT JOIN `glpi_useremails` ON (`glpi_users`.`id` = `glpi_useremails`.`users_id`)
                 WHERE ";
       $first = true;
       foreach ($options as $key => $value) {
@@ -110,7 +111,7 @@ class Auth {
       } else {
          $pwd = $DB->result($result, 0, "password");
 
-         if (empty ($pwd)) {
+         if (empty($pwd)) {
             //If the user has an LDAP DN, then store it in the Auth object
             $user_dn = $DB->result($result, 0, "user_dn");
             if ($user_dn) {
@@ -137,7 +138,7 @@ class Auth {
    function connection_imap($host, $login, $pass) {
 
       // we prevent some delay...
-      if (empty ($host)) {
+      if (empty($host)) {
          return false;
       }
 
@@ -168,7 +169,7 @@ class Auth {
       global $LANG;
 
       // we prevent some delay...
-      if (empty ($ldap_method['host'])) {
+      if (empty($ldap_method['host'])) {
          return false;
       }
 
@@ -191,7 +192,7 @@ class Auth {
          if (!empty($dn) && @ldap_bind($this->ldap_connection, $dn, $password)) {
 
             //Hook to implement to restrict access by checking the ldap directory
-            if (doHookFunction("restrict_ldap_auth", $dn)) {
+            if (Plugin::doHookFunction("restrict_ldap_auth", $dn)) {
                return $dn;
             } else {
                $this->addToError($LANG['login'][11]);
@@ -235,7 +236,7 @@ class Auth {
       global $DB, $LANG;
 
       // sanity check... we prevent empty passwords...
-      if (empty ($password)) {
+      if (empty($password)) {
          $this->addToError($LANG['login'][13]);
          return false;
       }
@@ -318,7 +319,7 @@ class Auth {
                   $login = substr($login, 0, $pos);
                }
             }
-            if (isValidLogin($login)) {
+            if (self::isValidLogin($login)) {
                $this->user->fields['name'] = $login;
                return true;
             }
@@ -335,7 +336,7 @@ class Auth {
             }
             if (isset($sslattributes[$CFG_GLPI["x509_email_field"]])
                 && NotificationMail::isUserAddressValid($sslattributes[$CFG_GLPI["x509_email_field"]])
-                && isValidLogin($sslattributes[$CFG_GLPI["x509_email_field"]])) {
+                && self::isValidLogin($sslattributes[$CFG_GLPI["x509_email_field"]])) {
 
                $this->user->fields['name'] = $sslattributes[$CFG_GLPI["x509_email_field"]];
 
@@ -350,113 +351,6 @@ class Auth {
    }
 
 
-   /**
-    * Init session for the user is defined
-    *
-    * @return nothing
-   **/
-   function initSession() {
-      global $CFG_GLPI, $LANG;
-
-      if ($this->auth_succeded) {
-         // Restart GLPi session : complete destroy to prevent lost datas
-         $tosave = array('glpi_plugins', 'glpicookietest', 'phpCAS');
-         $save   = array();
-         foreach ($tosave as $t) {
-            if (isset($_SESSION[$t])) {
-               $save[$t] = $_SESSION[$t];
-            }
-         }
-         $this->destroySession();
-         startGlpiSession();
-         $_SESSION = $save;
-
-         // Normal mode for this request
-         $_SESSION["glpi_use_mode"] = NORMAL_MODE;
-         // Check ID exists and load complete user from DB (plugins...)
-         if (isset($this->user->fields['id'])
-             && $this->user->getFromDB($this->user->fields['id'])) {
-
-            if (!$this->user->fields['is_deleted'] && $this->user->fields['is_active']) {
-               $_SESSION["glpiID"]              = $this->user->fields['id'];
-               $_SESSION["glpiname"]            = $this->user->fields['name'];
-               $_SESSION["glpirealname"]        = $this->user->fields['realname'];
-               $_SESSION["glpifirstname"]       = $this->user->fields['firstname'];
-               $_SESSION["glpidefault_entity"]  = $this->user->fields['entities_id'];
-               $_SESSION["glpiusers_idisation"] = true;
-               $_SESSION["glpiextauth"]         = $this->extauth;
-               $_SESSION["glpiauthtype"]        = $this->user->fields['authtype'];
-               $_SESSION["glpisearchcount"]     = array();
-               $_SESSION["glpisearchcount2"]    = array();
-               $_SESSION["glpiroot"]            = $CFG_GLPI["root_doc"];
-               $_SESSION["glpi_use_mode"]       = $this->user->fields['use_mode'];
-               $_SESSION["glpicrontimer"]       = time();
-               // Default tab
-//               $_SESSION['glpi_tab']=1;
-               $_SESSION['glpi_tabs']           = array();
-               $this->user->computePreferences();
-               foreach ($CFG_GLPI['user_pref_field'] as $field) {
-                  if (isset($this->user->fields[$field])) {
-                     $_SESSION["glpi$field"] = $this->user->fields[$field];
-                  }
-               }
-               // Do it here : do not reset on each page, cause export issue
-               if ($_SESSION["glpilist_limit"] > $CFG_GLPI['list_limit_max']) {
-                  $_SESSION["glpilist_limit"] = $CFG_GLPI['list_limit_max'];
-               }
-               // Init not set value for language
-               if (empty($_SESSION["glpilanguage"])) {
-                  $_SESSION["glpilanguage"] = $CFG_GLPI['language'];
-               }
-               loadLanguage();
-
-               // glpiprofiles -> other available profile with link to the associated entities
-               doHook("init_session");
-
-               initEntityProfiles(getLoginUserID());
-
-               // Use default profile if exist
-               if (isset($_SESSION['glpiprofiles'][$this->user->fields['profiles_id']])) {
-                  changeProfile($this->user->fields['profiles_id']);
-
-               } else { // Else use first
-                  changeProfile(key($_SESSION['glpiprofiles']));
-               }
-
-               if (!isset($_SESSION["glpiactiveprofile"]["interface"])) {
-                  $this->auth_succeded = false;
-                  $this->addToError($LANG['login'][25]);
-               }
-
-            } else {
-               $this->auth_succeded = false;
-               $this->addToError($LANG['login'][20]);
-            }
-
-         } else {
-            $this->auth_succeded = false;
-            $this->addToError($LANG['login'][25]);
-         }
-      }
-   }
-
-
-   /**
-    * Destroy the current session
-    *
-    * @return nothing
-   **/
-   function destroySession() {
-
-      startGlpiSession();
-      // Unset all of the session variables.
-      session_unset();
-      // destroy may cause problems (no login / back to login page)
-      $_SESSION = array();
-      // write_close may cause troubles (no login / back to login page)
-   }
-
-
    /**
     * Get the current identification error
     *
@@ -538,13 +432,15 @@ class Auth {
             $this->user->fields['authtype'] = $authtype;
             // if LDAP enabled too, get user's infos from LDAP
             $this->user->fields["auths_id"] = $CFG_GLPI['authldaps_id_extra'];
-            if (canUseLdap()) {
-               if (isset($this->authtypes["ldap"][$this->user->fields["auths_id"]])) {
+            if (Toolbox::canUseLdap()) {
+               if (isset($this->authtypes["ldap"][$this->user->fields["auths_id"]])
+                  && $this->authtypes["ldap"][$this->user->fields["auths_id"]]['is_active']) {
                   $ldap_method = $this->authtypes["ldap"][$this->user->fields["auths_id"]];
                   $ds = AuthLdap::connectToServer($ldap_method["host"],
                                                   $ldap_method["port"],
                                                   $ldap_method["rootdn"],
-                                                  decrypt($ldap_method["rootdn_passwd"],GLPIKEY),
+                                                  Toolbox::decrypt($ldap_method["rootdn_passwd"],
+                                                                   GLPIKEY),
                                                   $ldap_method["use_tls"],
                                                   $ldap_method["deref_option"]);
 
@@ -613,7 +509,7 @@ class Auth {
                   case self::CAS :
                   case self::EXTERNAL :
                   case self::LDAP :
-                     if (canUseLdap()) {
+                     if (Toolbox::canUseLdap()) {
                         AuthLdap::tryLdapAuth($this, $login_name, $login_password,
                                               $this->user->fields["auths_id"],
                                               $this->user->fields["user_dn"]);
@@ -624,7 +520,7 @@ class Auth {
                      break;
 
                   case self::MAIL :
-                     if (canUseImapPop()) {
+                     if (Toolbox::canUseImapPop()) {
                         AuthMail::tryMailAuth($this, $login_name, $login_password,
                                               $this->user->fields["auths_id"]);
                      }
@@ -636,12 +532,12 @@ class Auth {
 
             } else if (!$exists) {
                //test all ldap servers only is user is not present in glpi's DB
-               if (!$this->auth_succeded && canUseLdap()) {
+               if (!$this->auth_succeded && Toolbox::canUseLdap()) {
                   AuthLdap::tryLdapAuth($this, $login_name, $login_password, 0, false, false);
                }
 
                //test all imap/pop servers
-               if (!$this->auth_succeded && canUseImapPop()) {
+               if (!$this->auth_succeded && Toolbox::canUseImapPop()) {
                   AuthMail::tryMailAuth($this, $login_name, $login_password, 0, false);
                }
             }
@@ -703,7 +599,7 @@ class Auth {
          }
       }
 
-      $this->initSession();
+      Session::init($this);
 
       if ($noauto) {
          $_SESSION["noAUTO"] = 1;
@@ -734,11 +630,12 @@ class Auth {
          }
       }
 
-      $methods[0] = DROPDOWN_EMPTY_VALUE;
+      $methods[0]             = Dropdown::EMPTY_VALUE;
       $methods[self::DB_GLPI] = $LANG['login'][32];
 
       $sql = "SELECT count(*) AS cpt
-              FROM `glpi_authldaps`";
+              FROM `glpi_authldaps`
+              WHERE `is_active` = 1";
       $result = $DB->query($sql);
 
       if ($DB->result($result, 0, "cpt") > 0) {
@@ -747,7 +644,8 @@ class Auth {
       }
 
       $sql = "SELECT count(*) AS cpt
-              FROM `glpi_authmails`";
+              FROM `glpi_authmails`
+              WHERE `is_active` = 1";
       $result = $DB->query($sql);
 
       if ($DB->result($result,0,"cpt") > 0) {
@@ -775,7 +673,7 @@ class Auth {
          case self::LDAP :
             $auth = new AuthLdap();
             if ($auth->getFromDB($auths_id)) {
-               return $auth->getTypeName() . "&nbsp;" . $auth->getLink();
+               return $auth->getTypeName(1) . "&nbsp;" . $auth->getLink();
             }
             return $LANG['login'][2]."&nbsp;$name";
 
@@ -895,26 +793,26 @@ class Auth {
    /**
     * Is an alternate auth ?
     *
-    * @param $auths_id auth type
+    * @param $authtype auth type
     *
     * @return boolean
    **/
-   static function isAlternateAuth($auths_id) {
-      return in_array($auths_id, array(self::X509, self::CAS, self::EXTERNAL));
+   static function isAlternateAuth($authtype) {
+      return in_array($authtype, array(self::X509, self::CAS, self::EXTERNAL));
    }
 
 
    /**
     * Is an alternate auth wich used LDAP extra server?
     *
-    * @param $auths_id auth type
+    * @param $authtype auth type
     *
     * @return boolean
    **/
-   static function isAlternateAuthWithLdap($auths_id) {
+   static function isAlternateAuthWithLdap($authtype) {
       global $CFG_GLPI;
 
-      return (self::isAlternateAuth($auths_id) && $CFG_GLPI["authldaps_id_extra"] > 0);
+      return (self::isAlternateAuth($authtype) && $CFG_GLPI["authldaps_id_extra"] > 0);
    }
 
 
@@ -942,7 +840,7 @@ class Auth {
           && strstr($_SERVER['SSL_CLIENT_S_DN'], $CFG_GLPI["x509_email_field"])) {
 
          if ($redirect) {
-            glpi_header("login.php".$redir_string);
+            Html::redirect("login.php".$redir_string);
          } else {
             return self::X509;
          }
@@ -954,7 +852,7 @@ class Auth {
           && !empty($_SERVER[$CFG_GLPI["existing_auth_server_field"]])) {
 
          if ($redirect) {
-            glpi_header("login.php".$redir_string);
+            Html::redirect("login.php".$redir_string);
          } else {
             return self::EXTERNAL;
          }
@@ -963,7 +861,7 @@ class Auth {
       // Using CAS server
       if (!empty($CFG_GLPI["cas_host"])) {
          if ($redirect) {
-            glpi_header("login.php".$redir_string);
+            Html::redirect("login.php".$redir_string);
          } else {
             return self::CAS;
          }
@@ -974,83 +872,211 @@ class Auth {
 
    /** Display refresh button in the user page
     *
-    * @param $ID ID of the user
+    * @param $user User
     *
     * @return nothing
     */
-   static function showSynchronizationForm($ID) {
+   static function showSynchronizationForm(User $user) {
       global $LANG, $DB, $CFG_GLPI;
 
-      if (haveRight("user", "w")) {
-         //Look it the user's auth method is LDAP
-         $sql = "SELECT `authtype`, `auths_id`
-                 FROM `glpi_users`
-                 WHERE `id` = '$ID'";
-         $result = $DB->query($sql);
+      if (Session::haveRight("user_authtype", "w")) {
+         echo "<form method='post' action='".Toolbox::getItemTypeFormURL('User')."'>";
+         echo "<div class='firstbloc'>";
 
-         if ($DB->numrows($result) == 1) {
-            $data = $DB->fetch_array($result);
-            echo "<form method='post' action='".getItemTypeFormURL('User')."'>";
-            echo "<div class='firstbloc'>";
+         switch($user->getField('authtype')) {
+            case self::LDAP :
+               //Look it the auth server still exists !
+               // <- Bad idea : id not exists unable to change anything
+               $sql = "SELECT `name`
+                       FROM `glpi_authldaps`
+                       WHERE `id` = '" . $user->getField('auths_id') . "'
+                           AND `is_active` = 1";
+               $result = $DB->query($sql);
+               if ($DB->numrows($result) > 0) {
+                  echo "<table class='tab_cadre'><tr class='tab_bg_2'><td>";
+                  echo "<input type='hidden' name='id' value='".$user->getID()."'>";
+                  echo "<input class=submit type='submit' name='force_ldap_resynch' value='" .
+                         $LANG['ldap'][11] . "'>";
+                  echo "</td></tr></table>";
+               }
+               break;
 
-            switch($data["authtype"]) {
-               case self::LDAP :
-                  //Look it the auth server still exists !
-                  // <- Bad idea : id not exists unable to change anything
+            case self::DB_GLPI :
+            case self::MAIL :
+               break;
+
+            case self::CAS :
+            case self::EXTERNAL :
+            case self::X509 :
+               if ($CFG_GLPI['authldaps_id_extra']) {
                   $sql = "SELECT `name`
                           FROM `glpi_authldaps`
-                          WHERE `id` = '" . $data["auths_id"]."'";
+                          WHERE `id` = '" .$CFG_GLPI['authldaps_id_extra']."'
+                           AND `is_active` = 1";
                   $result = $DB->query($sql);
+
                   if ($DB->numrows($result) > 0) {
                      echo "<table class='tab_cadre'><tr class='tab_bg_2'><td>";
-                     echo "<input type='hidden' name='id' value='$ID'>";
                      echo "<input class=submit type='submit' name='force_ldap_resynch' value='" .
-                            $LANG['ocsng'][24] . "'>";
+                            $LANG['ldap'][11] . "'>";
                      echo "</td></tr></table>";
                   }
-                  break;
-
-               case self::DB_GLPI :
-               case self::MAIL :
-                  break;
-
-               case self::CAS :
-               case self::EXTERNAL :
-               case self::X509 :
-                  if ($CFG_GLPI['authldaps_id_extra']) {
-                     $sql = "SELECT `name`
-                             FROM `glpi_authldaps`
-                             WHERE `id` = '" .$CFG_GLPI['authldaps_id_extra']."'";
-                     $result = $DB->query($sql);
-
-                     if ($DB->numrows($result) > 0) {
-                        echo "<table class='tab_cadre'><tr class='tab_bg_2'><td>";
-                        echo "<input class=submit type='submit' name='force_ldap_resynch' value='" .
-                               $LANG['ocsng'][24] . "'>";
-                        echo "</td></tr></table>";
-                     }
-                  }
-                  break;
-            }
-            echo "</div>";
-
-            echo "<div class='spaced'>";
-            echo "<table class='tab_cadre'>";
-            echo "<tr><th>".$LANG['login'][30]."&nbsp:&nbsp;</th></tr>";
-            echo "<tr class='tab_bg_2'><td class='center'>";
-            $rand             = self::dropdown(array('name' => 'authtype'));
-            $paramsmassaction = array('authtype' => '__VALUE__',
-                                      'name'     => 'change_auth_method');
-            ajaxUpdateItemOnSelectEvent("dropdown_authtype$rand", "show_massiveaction_field",
-                                        $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionAuthMethods.php",
-                                        $paramsmassaction);
-            echo "<input type='hidden' name='id' value='" . $ID . "'>";
-            echo "<span id='show_massiveaction_field'></span>";
-            echo "</td></tr></table>";
-            echo "</div></form>";
+               }
+               break;
          }
+         echo "</div>";
+
+         echo "<div class='spaced'>";
+         echo "<table class='tab_cadre'>";
+         echo "<tr><th>".$LANG['login'][30]."&nbsp:&nbsp;</th></tr>";
+         echo "<tr class='tab_bg_2'><td class='center'>";
+         $rand             = self::dropdown(array('name' => 'authtype'));
+         $paramsmassaction = array('authtype' => '__VALUE__',
+                                   'name'     => 'change_auth_method');
+         Ajax::updateItemOnSelectEvent("dropdown_authtype$rand", "show_massiveaction_field",
+                                       $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveActionAuthMethods.php",
+                                       $paramsmassaction);
+         echo "<input type='hidden' name='id' value='" . $user->getID() . "'>";
+         echo "<span id='show_massiveaction_field'></span>";
+         echo "</td></tr></table>";
+         echo "</div></form>";
       }
    }
-}
 
-?>
+
+    /**
+     * Determine if a login is valid
+     *
+     * @param $login string: login to check
+     *
+     * @return boolean
+    **/
+    static function isValidLogin($login="") {
+       return preg_match( "/^[[:alnum:]@.\-_ ]+$/i", $login);
+    }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case 'User' :
+               if (Session::haveRight("user_authtype", "w")) {
+                  return $LANG['ldap'][12];
+               }
+               break;
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='User') {
+         self::showSynchronizationForm($item);
+      }
+      return true;
+   }
+
+   /**
+    * Form for configuration authentification
+   **/
+   static function showOtherAuthList() {
+      global $DB, $LANG, $CFG_GLPI;
+
+      if (!Session::haveRight("config", "w")) {
+         return false;
+      }
+
+      echo "<form name=cas action='".$CFG_GLPI['root_doc']."/front/auth.others.php' method='post'>";
+      echo "<input type='hidden' name='id' value='" . $CFG_GLPI["id"] . "'>";
+      echo "<div class='center'>";
+      echo "<table class='tab_cadre_fixe'>";
+
+      // CAS config
+      echo "<tr><th colspan='2'>" . $LANG['setup'][177];
+      if (!empty($CFG_GLPI["cas_host"])) {
+         echo " - ".$LANG['setup'][192];
+      }
+      echo "</th></tr>\n";
+
+      if (function_exists('curl_init')
+          && (version_compare(PHP_VERSION, '5', '>=') || (function_exists("domxml_open_mem")))) {
+
+         echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['setup'][174] . "</td>";
+         echo "<td><input type='text' name='cas_host' value=\"".$CFG_GLPI["cas_host"]."\"></td></tr>\n";
+         echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['setup'][175] . "</td>";
+         echo "<td><input type='text' name='cas_port' value=\"".$CFG_GLPI["cas_port"]."\"></td></tr>\n";
+         echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['setup'][176] . "</td>";
+         echo "<td><input type='text' name='cas_uri' value=\"".$CFG_GLPI["cas_uri"]."\"></td></tr>\n";
+         echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['setup'][182] . "</td>";
+         echo "<td><input type='text' name='cas_logout' value=\"".$CFG_GLPI["cas_logout"]."\"></td>".
+              "</tr>\n";
+      } else {
+         echo "<tr class='tab_bg_2'><td class='center' colspan='2'>";
+         echo "<p class='red'>" . $LANG['setup'][178] . "</p>";
+         echo "<p>" . $LANG['setup'][179] . "</p></td></tr>\n";
+      }
+      // X509 config
+      echo "<tr><th colspan='2'>" . $LANG['setup'][190];
+      if (!empty($CFG_GLPI["x509_email_field"])) {
+         echo " - ".$LANG['setup'][192];
+      }
+      echo "</th></tr>\n";
+      echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['setup'][191] . "</td>";
+      echo "<td><input type='text' name='x509_email_field' value=\"".$CFG_GLPI["x509_email_field"]."\">";
+      echo "</td></tr>\n";
+
+      // Autres config
+      echo "<tr><th colspan='2'>" . $LANG['login'][19];
+      if (!empty($CFG_GLPI["existing_auth_server_field"])) {
+         echo " - ".$LANG['setup'][192];
+      }
+      echo "</th></tr>\n";
+      echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['setup'][193] . "</td>";
+      echo "<td><select name='existing_auth_server_field'>";
+      echo "<option value=''>&nbsp;</option>\n";
+      echo "<option value='HTTP_AUTH_USER' " .
+             ($CFG_GLPI["existing_auth_server_field"]=="HTTP_AUTH_USER" ? " selected " : "") . ">".
+             "HTTP_AUTH_USER</option>\n";
+      echo "<option value='REMOTE_USER' " .
+             ($CFG_GLPI["existing_auth_server_field"]=="REMOTE_USER" ? " selected " : "") . ">".
+             "REMOTE_USER</option>\n";
+      echo "<option value='PHP_AUTH_USER' " .
+             ($CFG_GLPI["existing_auth_server_field"]=="PHP_AUTH_USER" ? " selected " : "") . ">".
+             "PHP_AUTH_USER</option>\n";
+      echo "<option value='USERNAME' " .
+             ($CFG_GLPI["existing_auth_server_field"]=="USERNAME" ? " selected " : "") . ">".
+             "USERNAME</option>\n";
+      echo "<option value='REDIRECT_REMOTE_USER' " .
+             ($CFG_GLPI["existing_auth_server_field"]=="REDIRECT_REMOTE_USER" ? " selected " : "") .">".
+             "REDIRECT_REMOTE_USER</option>\n";
+      //For apache mod_proxy
+      echo "<option value='HTTP_REMOTE_USER' " .
+             ($CFG_GLPI["existing_auth_server_field"]=="HTTP_REMOTE_USER" ? " selected " : "") .">".
+             "HTTP_REMOTE_USER</option>\n";
+      echo "</select>";
+      echo "</td></tr>\n";
+
+      echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['setup'][199] . "</td><td>";
+      Dropdown::showYesNo('existing_auth_server_field_clean_domain',
+                          $CFG_GLPI['existing_auth_server_field_clean_domain']);
+      echo "</td></tr>\n";
+
+      echo "<tr><th colspan='2'>" . $LANG['setup'][194]."</th></tr>\n";
+      echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['ldap'][4] . "</td><td>";
+      Dropdown::show('AuthLDAP', array('name'   => 'authldaps_id_extra',
+                                       'value'  => $CFG_GLPI["authldaps_id_extra"]));
+      echo "</td></tr>\n";
+
+      echo "<tr class='tab_bg_1'><td class='center' colspan='2'>";
+      echo "<input type='submit' name='update' class='submit' value=\"".$LANG['buttons'][7]."\" >";
+      echo "</td></tr>";
+
+      echo "</table></div></form>\n";
+   }
+
+}
+?>
\ No newline at end of file
