@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: authmail.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: authmail.class.php 17891 2012-03-19 06:21:48Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -41,27 +41,30 @@ class AuthMail extends CommonDBTM {
    // From CommonDBTM
    public $dohistory = true;
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['Menu'][10];
+      }
       return $LANG['login'][3];
    }
 
 
    function canCreate() {
-      return haveRight('config', 'w');
+      return Session::haveRight('config', 'w');
    }
 
 
    function canView() {
-      return haveRight('config', 'r');
+      return Session::haveRight('config', 'r');
    }
 
 
    function prepareInputForUpdate($input) {
 
-      if (isset ($input['mail_server']) && !empty ($input['mail_server'])) {
-         $input["connect_string"] = constructMailServerConfig($input);
+      if (isset($input['mail_server']) && !empty($input['mail_server'])) {
+         $input["connect_string"] = Toolbox::constructMailServerConfig($input);
       }
       return $input;
    }
@@ -69,8 +72,8 @@ class AuthMail extends CommonDBTM {
 
    function prepareInputForAdd($input) {
 
-      if (isset ($input['mail_server']) && !empty ($input['mail_server'])) {
-         $input["connect_string"] = constructMailServerConfig($input);
+      if (isset($input['mail_server']) && !empty($input['mail_server'])) {
+         $input["connect_string"] = Toolbox::constructMailServerConfig($input);
       }
       return $input;
    }
@@ -80,11 +83,9 @@ class AuthMail extends CommonDBTM {
       global $LANG;
 
       $ong = array();
-      $ong[1] = $LANG['title'][26];
+      $this->addStandardTab('authMail', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
-      if ($this->fields['id'] > 0) {
-         $ong[12] = $LANG['title'][38];
-      }
       return $ong;
    }
 
@@ -93,7 +94,7 @@ class AuthMail extends CommonDBTM {
       global $LANG;
 
       $tab = array();
-      $tab['common'] = $LANG['login'][2];
+      $tab['common'] = $LANG['login'][3];
 
       $tab[1]['table']         = $this->getTable();
       $tab[1]['field']         = 'name';
@@ -149,11 +150,11 @@ class AuthMail extends CommonDBTM {
    function showForm($ID, $options=array()) {
       global $LANG;
 
-      if (!haveRight("config", "w")) {
+      if (!Session::haveRight("config", "w")) {
          return false;
       }
       $spotted = false;
-      if (empty ($ID)) {
+      if (empty($ID)) {
          if ($this->getEmpty()) {
             $spotted = true;
          }
@@ -163,7 +164,7 @@ class AuthMail extends CommonDBTM {
          }
       }
 
-      if (canUseImapPop()) {
+      if (Toolbox::canUseImapPop()) {
          $options['colspan']=1;
          $this->showTabs($options);
          $this->showFormHeader($options);
@@ -182,13 +183,13 @@ class AuthMail extends CommonDBTM {
          echo "<td><input size='30' type='text' name='host' value='" . $this->fields["host"] . "'>";
          echo "</td></tr>";
 
-         showMailServerConfig($this->fields["connect_string"]);
+         Toolbox::showMailServerConfig($this->fields["connect_string"]);
 
          echo "<tr class='tab_bg_1'><td>" . $LANG['common'][25] . "&nbsp;:</td>";
          echo "<td>";
          echo "<textarea cols='40' rows='4' name='comment'>".$this->fields["comment"]."</textarea>";
          if ($ID>0) {
-            echo "<br>".$LANG['common'][26]."&nbsp;: ".convDateTime($this->fields["date_mod"]);
+            echo "<br>".$LANG['common'][26]."&nbsp;: ".Html::convDateTime($this->fields["date_mod"]);
          }
 
          echo "</td></tr>";
@@ -207,9 +208,11 @@ class AuthMail extends CommonDBTM {
    }
 
 
-   function showFormTestMail ($ID) {
+   function showFormTestMail() {
       global $LANG;
 
+      $ID = $this->getField('id');
+
       if ($this->getFromDB($ID)) {
          echo "<form method='post' action='".$this->getFormURL()."'>";
          echo "<input type='hidden' name='imap_string' value=\"".$this->fields['connect_string']."\">";
@@ -223,7 +226,7 @@ class AuthMail extends CommonDBTM {
          echo "<td><input size='30' type='password' name='imap_password' value=''
                     autocomplete='off'></td></tr>";
 
-         echo "<tr class='tab_bg_2'><td class='center' colspan=2>";
+         echo "<tr class='tab_bg_2'><td class='center' colspan='2'>";
          echo "<input type='submit' name='test' class='submit' value=\"".$LANG['buttons'][2]."\"></td>";
          echo "</tr></table></div></form>";
       }
@@ -236,17 +239,7 @@ class AuthMail extends CommonDBTM {
     * @return boolean
    **/
    static function useAuthMail() {
-      global $DB;
-
-      //Get all the pop/imap servers
-      $sql = "SELECT count(*)
-              FROM `glpi_authmails`";
-      $result = $DB->query($sql);
-
-      if ($DB->result($result, 0, 0) > 0) {
-         return true;
-      }
-      return false;
+      return (countElementsInTable('glpi_authmails', "`is_active`") > 0);
    }
 
 
@@ -261,8 +254,8 @@ class AuthMail extends CommonDBTM {
    static function testAuth($connect_string, $login, $password) {
 
       $auth = new Auth();
-      return $auth->connection_imap($connect_string, decodeFromUtf8($login),
-                                    decodeFromUtf8($password));
+      return $auth->connection_imap($connect_string, Toolbox::decodeFromUtf8($login),
+                                    Toolbox::decodeFromUtf8($password));
    }
 
 
@@ -277,14 +270,14 @@ class AuthMail extends CommonDBTM {
    **/
    static function mailAuth($auth, $login, $password, $mail_method) {
 
-      if (isset($mail_method["connect_string"]) && !empty ($mail_method["connect_string"])) {
+      if (isset($mail_method["connect_string"]) && !empty($mail_method["connect_string"])) {
          $auth->auth_succeded = $auth->connection_imap($mail_method["connect_string"],
-                                                       decodeFromUtf8($login),
-                                                       decodeFromUtf8($password));
+                                                       Toolbox::decodeFromUtf8($login),
+                                                       Toolbox::decodeFromUtf8($password));
          if ($auth->auth_succeded) {
             $auth->extauth = 1;
             $auth->user_present = $auth->user->getFromDBbyName(addslashes($login));
-            $auth->user->getFromIMAP($mail_method, decodeFromUtf8($login));
+            $auth->user->getFromIMAP($mail_method, Toolbox::decodeFromUtf8($login));
             //Update the authentication method for the current user
             $auth->user->fields["authtype"] = Auth::MAIL;
             $auth->user->fields["auths_id"] = $mail_method["id"];
@@ -326,9 +319,33 @@ class AuthMail extends CommonDBTM {
 
 
    function cleanDBonPurge() {
-
       Rule::cleanForItemCriteria($this, 'MAIL_SERVER');
    }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate && $item->can($item->getField('id'),'r')) {
+         $ong = array();
+         $ong[1] = $LANG['title'][26];    // test connexion
+
+         return $ong;
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      switch ($tabnum) {
+         case 1 :
+            $item->showFormTestMail();
+            break;
+      }
+      return true;
+   }
+
 }
 
 ?>
\ No newline at end of file
