@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: bookmark.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: bookmark.class.php 17768 2012-03-08 13:32:11Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,15 +39,64 @@ class Bookmark extends CommonDBTM {
 
    var $auto_message_on_action=false;
 
-   const WIDTH = 750;
+   const WIDTH  = 750;
+   const SEARCH = 1; //SEARCH SYSTEM bookmark
+   const URI    = 2;
 
    function canCreate() {
-      return haveRight('bookmark_public', 'w');
+      return Session::haveRight('bookmark_public', 'w');
    }
 
 
    function canView() {
-      return haveRight('bookmark_public', 'r');
+      return Session::haveRight('bookmark_public', 'r');
+   }
+
+
+   function isNewItem() {
+      /// For tabs management : force isNewItem
+      return false;
+   }
+
+
+   function defineTabs($options=array()) {
+      global $LANG;
+
+      $ong = array();
+      $this->addStandardTab(__CLASS__, $ong, $options);
+      $ong['no_all_tab'] = true;
+      return $ong;
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      switch ($item->getType()) {
+         case __CLASS__:
+            $ong = array();
+            $ong[1] = $LANG['common'][88]; // personal
+            if (Session::haveRight('bookmark_public','r')) {
+               $ong[2] = $LANG['common'][76]; // public
+            }
+            return $ong;
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      switch ($item->getType()) {
+         case __CLASS__ :
+            $is_private = 1;
+            if ($tabnum == 2) {
+               $is_private = 0;
+            }
+            $item->showBookmarkList($_POST['target'], $is_private);
+            return true;
+      }
+      return false;
    }
 
 
@@ -63,7 +112,8 @@ class Bookmark extends CommonDBTM {
       if (!$index) {
          $index = strpos($taburl["path"], "front");
       }
-      $input['path'] = utf8_substr($taburl["path"], $index, utf8_strlen($taburl["path"]) - $index);
+      $input['path'] = Toolbox::substr($taburl["path"], $index,
+                                       Toolbox::strlen($taburl["path"]) - $index);
 
       $query_tab = array();
 
@@ -71,8 +121,8 @@ class Bookmark extends CommonDBTM {
          parse_str($taburl["query"], $query_tab);
       }
 
-      $input['query'] = append_params($this->prepareQueryToStore($input['type'], $query_tab,
-                                                                 $input['itemtype']));
+      $input['query'] = Toolbox::append_params($this->prepareQueryToStore($input['type'],
+                                               $query_tab, $input['itemtype']));
 
       return $input;
    }
@@ -81,7 +131,7 @@ class Bookmark extends CommonDBTM {
    function pre_updateInDB() {
 
       // Set new user if initial user have been deleted
-      if ($this->fields['users_id']==0 && $uid=getLoginUserID()) {
+      if ($this->fields['users_id']==0 && $uid=Session::getLoginUserID()) {
          $this->input['users_id']  = $uid;
          $this->fields['users_id'] = $uid;
          $this->updates[]          = "users_id";
@@ -89,9 +139,9 @@ class Bookmark extends CommonDBTM {
    }
 
 
-   function post_getEmpty () {
+   function post_getEmpty() {
 
-      $this->fields["users_id"]     = getLoginUserID();
+      $this->fields["users_id"]     = Session::getLoginUserID();
       $this->fields["is_private"]   = 1;
       $this->fields["is_recursive"] = 0;
       $this->fields["entities_id"]  = $_SESSION["glpiactive_entity"];
@@ -156,13 +206,13 @@ class Bookmark extends CommonDBTM {
 
       echo "<tr><td class='tab_bg_1'>".$LANG['common'][16]."&nbsp;:</td>";
       echo "<td class='tab_bg_1'>";
-      autocompletionTextField($this, "name", array('user' => $this->fields["users_id"]));
+      Html::autocompletionTextField($this, "name", array('user' => $this->fields["users_id"]));
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_2'><td>".$LANG['common'][17]."&nbsp;:</td>";
       echo "<td>";
 
-      if (haveRight("bookmark_public","w")) {
+      if ($this->canCreate()) {
          Dropdown::showPrivatePublicSwitch($this->fields["is_private"],
                                            $this->fields["entities_id"],
                                            $this->fields["is_recursive"]);
@@ -209,7 +259,7 @@ class Bookmark extends CommonDBTM {
    function prepareQueryToStore($type, $query_tab, $itemtype=0) {
 
       switch ($type) {
-         case BOOKMARK_SEARCH :
+         case self::SEARCH :
             $fields_toclean = array('add_search_count', 'add_search_count2', 'delete_search_count',
                                     'delete_search_count2', 'glpisearchcount', 'glpisearchcount2',
                                     'start');
@@ -249,7 +299,7 @@ class Bookmark extends CommonDBTM {
       global $LANG;
 
       switch ($type) {
-         case BOOKMARK_SEARCH :
+         case self::SEARCH :
             // Check if all datas are valid
             $opt = Search::getCleanedOptions($this->fields['itemtype']);
 
@@ -316,7 +366,7 @@ class Bookmark extends CommonDBTM {
 
             // Display message
             if ($partial_load) {
-               addMessageAfterRedirect($LANG['bookmark'][2], false, ERROR);
+               Session::addMessageAfterRedirect($LANG['bookmark'][2], false, ERROR);
             }
             // add reset value
             $query_tab['reset'] = 'reset';
@@ -338,14 +388,14 @@ class Bookmark extends CommonDBTM {
 
       if ($params= $this->getParameters($ID)) {
          $url  = GLPI_ROOT."/".rawurldecode($this->fields["path"]);
-         $url .= "?".append_params($params);
+         $url .= "?".Toolbox::append_params($params);
 
          if ($opener) {
             echo "<script type='text/javascript' >\n";
             echo "window.opener.location.href='$url';";
             echo "</script>";
          } else {
-            glpi_header($url);
+            Html::redirect($url);
          }
       }
    }
@@ -380,12 +430,12 @@ class Bookmark extends CommonDBTM {
       global $DB;
 
       // Get bookmark / Only search bookmark
-      if ($this->getFromDB($ID) && $this->fields['type']=BOOKMARK_SEARCH) {
+      if ($this->getFromDB($ID) && ($this->fields['type'] == self::SEARCH)) {
          $dd = new Bookmark_User();
          // Is default view for this itemtype already exists ?
          $query = "SELECT `id`
                    FROM `glpi_bookmarks_users`
-                   WHERE `users_id` = '".getLoginUserID()."'
+                   WHERE `users_id` = '".Session::getLoginUserID()."'
                          AND `itemtype` = '".$this->fields['itemtype']."'";
 
          if ($result=$DB->query($query)) {
@@ -396,7 +446,7 @@ class Bookmark extends CommonDBTM {
                                  'bookmarks_id' => $ID));
             } else {
                $dd->add(array('bookmarks_id' => $ID,
-                              'users_id'     => getLoginUserID(),
+                              'users_id'     => Session::getLoginUserID(),
                               'itemtype'     => $this->fields['itemtype']));
             }
          }
@@ -415,12 +465,12 @@ class Bookmark extends CommonDBTM {
       global $DB;
 
       // Get bookmark / Only search bookmark
-      if ($this->getFromDB($ID) && $this->fields['type']=BOOKMARK_SEARCH) {
+      if ($this->getFromDB($ID) && $this->fields['type'] == self::SEARCH) {
          $dd = new Bookmark_User();
          // Is default view for this itemtype already exists ?
          $query = "SELECT `id`
                    FROM `glpi_bookmarks_users`
-                   WHERE `users_id` = '".getLoginUserID()."'
+                   WHERE `users_id` = '".Session::getLoginUserID()."'
                          AND `bookmarks_id` = '$ID'
                          AND `itemtype` = '".$this->fields['itemtype']."'";
 
@@ -446,7 +496,7 @@ class Bookmark extends CommonDBTM {
    function showBookmarkList($target, $is_private=1) {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!$is_private && !haveRight('bookmark_public','r')) {
+      if (!$is_private && !$this->canView()) {
          return false;
       }
 
@@ -460,7 +510,7 @@ class Bookmark extends CommonDBTM {
 
       if ($is_private) {
          $query .= "(`".$this->getTable()."`.`is_private`='1'
-                     AND `".$this->getTable()."`.`users_id`='".getLoginUserID()."') ";
+                     AND `".$this->getTable()."`.`users_id`='".Session::getLoginUserID()."') ";
       } else {
          $query .= "(`".$this->getTable()."`.`is_private`='0' ".
                      getEntitiesRestrictRequest("AND", $this->getTable(), "", "", true) . ")";
@@ -489,8 +539,7 @@ class Bookmark extends CommonDBTM {
 
                   if ($current_type=="States") {
                      $current_type_name = $LANG['state'][0];
-                  } else if (class_exists($current_type)) {
-                     $item = new $current_type();
+                  } else if ($item = getItemForItemtype($current_type)) {
                      $current_type_name = $item->getTypeName();
                   }
                }
@@ -520,7 +569,7 @@ class Bookmark extends CommonDBTM {
                   echo "<td>&nbsp;</td>";
                }
                echo "<td class='center'>";
-               if ($this->fields['type']==BOOKMARK_SEARCH) {
+               if ($this->fields['type'] == self::SEARCH) {
                   if (is_null($this->fields['IS_DEFAULT'])) {
                      echo "<a href=\"".GLPI_ROOT."/front/popup.php?popup=edit_bookmark&amp;
                             mark_default=1&amp;id=".$this->fields["id"]."\">".$LANG['choice'][0].
@@ -535,8 +584,8 @@ class Bookmark extends CommonDBTM {
             }
             echo "</table></div>";
 
-            openArrowMassive("form_load_bookmark$rand");
-            closeArrowMassive('delete_several', $LANG['buttons'][6]);
+            Html::openArrowMassives("form_load_bookmark$rand");
+            Html::closeArrowMassives(array('delete_several' => $LANG['buttons'][6]));
 
          } else {
             echo "<tr class='tab_bg_1'><td colspan='5'>".$LANG['bookmark'][3]."</td></tr></table>";
