@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: calendar_holiday.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: calendar_holiday.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -84,7 +84,7 @@ class Calendar_Holiday extends CommonDBRelation {
       $rand=mt_rand();
       echo "<form name='calendarholiday_form$rand' id='calendarholiday_form$rand' method='post'
              action='";
-      echo getItemTypeFormURL(__CLASS__)."'>";
+      echo Toolbox::getItemTypeFormURL(__CLASS__)."'>";
 
       echo "<div class='center'><table class='tab_cadre_fixehov'>";
       echo "<tr><th colspan='2'>".$LANG['common'][16]."</th>";
@@ -105,10 +105,11 @@ class Calendar_Holiday extends CommonDBRelation {
       $used = array();
 
       if ($DB->numrows($result) >0) {
-         initNavigateListItems('Holiday', $LANG['buttons'][15] ." = ". $calendar->fields["name"]);
+         Session::initNavigateListItems('Holiday',
+                                        $LANG['buttons'][15] ." = ". $calendar->fields["name"]);
 
          while ($data = $DB->fetch_array($result)) {
-            addToNavigateListItems('Holiday', $data["id"]);
+            Session::addToNavigateListItems('Holiday', $data["id"]);
             echo "<tr class='tab_bg_1'>";
             echo "<td width='10'>";
             if ($canedit) {
@@ -117,11 +118,11 @@ class Calendar_Holiday extends CommonDBRelation {
                echo "&nbsp;";
             }
             echo "</td>";
-            $used[] = $data['id'];
-            echo "<td><a href='".getItemTypeFormURL('Holiday')."?id=".$data['id']."'>".
+            $used[$data['id']] = $data['id'];
+            echo "<td><a href='".Toolbox::getItemTypeFormURL('Holiday')."?id=".$data['id']."'>".
                       $data["name"]."</a></td>";
-            echo "<td>".convDate($data["begin_date"])."</td>";
-            echo "<td>".convDate($data["end_date"])."</td>";
+            echo "<td>".Html::convDate($data["begin_date"])."</td>";
+            echo "<td>".Html::convDate($data["end_date"])."</td>";
             echo "<td>".Dropdown::getYesNo($data["is_perpetual"])."</td>";
             echo "</tr>";
          }
@@ -140,8 +141,8 @@ class Calendar_Holiday extends CommonDBRelation {
       echo "</table></div>";
 
       if ($canedit) {
-         openArrowMassive("calendarholiday_form$rand",true);
-         closeArrowMassive('delete', $LANG['buttons'][6]);
+         Html::openArrowMassives("calendarholiday_form$rand",true);
+         Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
       }
       echo "</form>";
    }
@@ -150,7 +151,7 @@ class Calendar_Holiday extends CommonDBRelation {
    /**
     * Duplicate all holidays from a calendar to his clone
    **/
-   function cloneCalendar ($oldid, $newid) {
+   function cloneCalendar($oldid, $newid) {
       global $DB;
 
       $query = "SELECT *
@@ -167,6 +168,31 @@ class Calendar_Holiday extends CommonDBRelation {
    }
 
 
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case 'Calendar' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['calendar'][11],
+                                              countElementsInTable($this->getTable(),
+                                                                   "calendars_id = '".$item->getID()."'"));
+               }
+               return $LANG['calendar'][11];
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='Calendar') {
+         self::showForCalendar($item);
+      }
+      return true;
+   }
 }
 
 ?>
\ No newline at end of file
