@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: calendarsegment.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: calendarsegment.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -47,20 +47,23 @@ class CalendarSegment extends CommonDBChild {
    public $items_id = 'calendars_id';
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['calendar'][10];
+      }
       return $LANG['calendar'][5];
    }
 
 
    function canCreate() {
-      return haveRight('calendar', 'w');
+      return Session::haveRight('calendar', 'w');
    }
 
 
    function canView() {
-      return haveRight('calendar', 'r');
+      return Session::haveRight('calendar', 'r');
    }
 
 
@@ -70,7 +73,7 @@ class CalendarSegment extends CommonDBChild {
       // Check override of segment : do not add
       if (count(self::getSegmentsBetween($input['calendars_id'], $input['day'], $input['begin'],
                                          $input['day'], $input['end'])) > 0 ) {
-         addMessageAfterRedirect($LANG['calendar'][8], false, ERROR);
+         Session::addMessageAfterRedirect($LANG['calendar'][8], false, ERROR);
          return false;
       }
       return $input;
@@ -80,7 +83,7 @@ class CalendarSegment extends CommonDBChild {
    /**
     * Duplicate all segments from a calendar to his clone
    */
-   function cloneCalendar ($oldid, $newid) {
+   function cloneCalendar($oldid, $newid) {
       global $DB;
 
       $query = "SELECT *
@@ -206,7 +209,7 @@ class CalendarSegment extends CommonDBChild {
                   list($begin_hour, $begin_minute, $begin_second) = explode(':', $data['BEGIN']);
                   $beginstamp = $begin_hour*HOUR_TIMESTAMP+$begin_minute*MINUTE_TIMESTAMP+$begin_second;
                   $endstamp   = $beginstamp+$delay;
-                  $units      = getTimestampTimeUnits($endstamp);
+                  $units      = Toolbox::getTimestampTimeUnits($endstamp);
                   return str_pad($units['hour'], 2, '0', STR_PAD_LEFT).':'.
                          str_pad($units['minute'], 2, '0', STR_PAD_LEFT).':'.
                          str_pad($units['second'], 2, '0', STR_PAD_LEFT);
@@ -291,7 +294,7 @@ class CalendarSegment extends CommonDBChild {
       $rand    = mt_rand();
       echo "<form name='calendarsegment_form$rand' id='calendarsegment_form$rand' method='post'
              action='";
-      echo getItemTypeFormURL(__CLASS__)."'>";
+      echo Toolbox::getItemTypeFormURL(__CLASS__)."'>";
 
       if ($canedit) {
          echo "<div class='spaced'>";
@@ -349,12 +352,38 @@ class CalendarSegment extends CommonDBChild {
       echo "</table></div>";
 
       if ($canedit) {
-         openArrowMassive("calendarsegment_form$rand", true);
-         closeArrowMassive('delete', $LANG['buttons'][6]);
+         Html::openArrowMassives("calendarsegment_form$rand", true);
+         Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
       }
       echo "</form>";
    }
 
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case 'Calendar' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['calendar'][10],
+                                              countElementsInTable($this->getTable(),
+                                                                   "calendars_id = '".$item->getID()."'"));
+               }
+               return $LANG['calendar'][10];
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='Calendar') {
+         self::showForCalendar($item);
+      }
+      return true;
+   }
 }
 
 ?>
