@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cartridge.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: cartridge.class.php 17956 2012-03-21 09:13:14Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -49,20 +49,23 @@ class Cartridge extends CommonDBTM {
    protected $forward_entity_to = array('Infocom');
    var $no_form_page = false;
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['Menu'][21];
+      }
       return $LANG['cartridges'][0];
    }
 
 
    function canCreate() {
-      return haveRight('cartridge', 'w');
+      return Session::haveRight('cartridge', 'w');
    }
 
 
    function canView() {
-      return haveRight('cartridge', 'r');
+      return Session::haveRight('cartridge', 'r');
    }
 
 
@@ -86,6 +89,21 @@ class Cartridge extends CommonDBTM {
    }
 
 
+   function post_updateItem($history=1) {
+
+      if (in_array('pages', $this->updates)) {
+         $printer = new Printer();
+         if ($printer->getFromDB($this->fields['printers_id'])
+             && ($this->fields['pages'] > $printer->getField('last_pages_counter')
+                 || $this->oldvalues['pages'] == $printer->getField('last_pages_counter'))) {
+
+            $printer->update(array('id'                 => $printer->getID(),
+                                   'last_pages_counter' => $this->fields['pages'] ));
+         }
+      }
+   }
+
+
    function restore($input,$history=1) {
       global $DB;
 
@@ -111,18 +129,40 @@ class Cartridge extends CommonDBTM {
    *@return boolean : true for success
    **/
    function updatePages($pages) {
-      global $DB;
 
-      $query = "UPDATE `".$this->getTable()."`
-                SET `pages` = '$pages'
-                WHERE `id` = '".$this->fields['id']."'";
-
-      if ($result = $DB->query($query) && $DB->affected_rows() > 0) {
-         return true;
-      }
-      return false;
+      return $this->update(array('id'    => $this->fields['id'],
+                                 'pages' => $pages));
    }
 
+   /**
+   * Update dates use value of a cartridge
+   *
+   *@param $date_use  date_use value
+   *
+   *@return boolean : true for success
+   **/
+   function updateCartUse($date_use) {
+      global $DB;
+
+      return $this->update(array('id'       => $this->fields['id'],
+                                 'date_use' => $date_use));
+   }
+
+  /**
+   * Update count pages and date out value of a cartridge
+   *
+   *@param $pages  count pages value
+   *@param $date_out  date_out value
+   *
+   *@return boolean : true for success
+   **/
+   function updateCartOut($pages, $date_out) {
+      global $DB;
+
+      return $this->update(array('id'       => $this->fields['id'],
+                                 'date_out' => $date_out,
+                                 'pages'    => $pages));
+   }
 
    /**
    * Link a cartridge to a printer.
@@ -157,7 +197,7 @@ class Cartridge extends CommonDBTM {
          }
 
       } else {
-         addMessageAfterRedirect($LANG['cartridges'][34], false, ERROR);
+         Session::addMessageAfterRedirect($LANG['cartridges'][34], false, ERROR);
       }
       return false;
    }
@@ -405,7 +445,7 @@ class Cartridge extends CommonDBTM {
       if (!$cartitem->can($tID,'r')) {
          return false;
       }
-      $canedit = $cartitem->can($tID,'r');
+      $canedit = $cartitem->can($tID,'w');
 
       $query = "SELECT count(*) AS COUNT
                 FROM `glpi_cartridges`
@@ -419,23 +459,26 @@ class Cartridge extends CommonDBTM {
 
          echo "<div class='spaced'><table class='tab_cadre_fixe'>";
          if (!$show_old) {
-            echo "<tr><th colspan='7'>".self::getCount($tID,-1)."</th>";
-            echo "<th colspan='2'>&nbsp;</th></tr>";
+            echo "<tr><th colspan='".($canedit?'8':'6')."'>".self::getCount($tID,-1)."</th>";
+            echo "</tr>";
          } else { // Old
-            echo "<tr><th colspan='8'>".$LANG['cartridges'][35]."</th>";
-            echo "<th colspan='2'>&nbsp;</th></tr>";
+            echo "<tr><th colspan='".($canedit?'10':'8')."'>".$LANG['cartridges'][35]."</th>";
+            echo "</tr>";
          }
          $i = 0;
          echo "<tr><th>".$LANG['common'][2]."</th><th>".$LANG['consumables'][23]."</th>";
          echo "<th>".$LANG['cartridges'][24]."</th><th>".$LANG['consumables'][26]."</th>";
-         echo "<th>".$LANG['cartridges'][27]."</th><th>".$LANG['search'][9]."</th>";
+         echo "<th>".$LANG['cartridges'][27]."</th>";
 
          if ($show_old) {
+            echo "<th>".$LANG['search'][9]."</th>";
             echo "<th>".$LANG['cartridges'][39]."</th>";
          }
 
-         echo "<th>".$LANG['financial'][3]."</th>";
-         echo "<th colspan='2'>&nbsp;</th>";
+         echo "<th width='18%'>".$LANG['financial'][3]."</th>";
+         if ($canedit) {
+            echo "<th colspan='2'>".$LANG['rulesengine'][7]."</th>";
+         }
 
          echo "</tr>";
       }
@@ -475,9 +518,9 @@ class Cartridge extends CommonDBTM {
       if ($result=$DB->query($query)) {
          $number = $DB->numrows($result);
          while ($data=$DB->fetch_array($result)) {
-            $date_in  = convDate($data["date_in"]);
-            $date_use = convDate($data["date_use"]);
-            $date_out = convDate($data["date_out"]);
+            $date_in  = Html::convDate($data["date_in"]);
+            $date_use = Html::convDate($data["date_use"]);
+            $date_out = Html::convDate($data["date_out"]);
             $printer  = $data["printers_id"];
             $page     = $data["pages"];
 
@@ -489,11 +532,11 @@ class Cartridge extends CommonDBTM {
             if (!is_null($date_use)) {
                if ($data["printID"]>0) {
                   echo "<a href='".$CFG_GLPI["root_doc"]."/front/printer.form.php?id=".
-                        $data["printID"]."'><strong>".$data["printname"];
-                  if ($_SESSION['glpiis_ids_visible']) {
+                        $data["printID"]."'><span class='b'>".$data["printname"];
+                  if ($_SESSION['glpiis_ids_visible'] || empty($data["printname"])) {
                      echo " (".$data["printID"].")";
                   }
-                  echo "</strong></a>";
+                  echo "</span></a>";
                } else {
                   echo NOT_AVAILABLE;
                }
@@ -503,9 +546,9 @@ class Cartridge extends CommonDBTM {
                                  - mktime(0, 0, 0, $tmp_dbeg[1], $tmp_dbeg[2], $tmp_dbeg[0]);
                $stock_time += $stock_time_tmp;
             }
-            echo "</td><td class='center'>";
-            echo $date_out;
             if ($show_old) {
+               echo "</td><td class='center'>";
+               echo $date_out;
                $tmp_dbeg = explode("-",$data["date_use"]);
                $tmp_dend = explode("-",$data["date_out"]);
                $use_time_tmp = mktime(0, 0, 0, $tmp_dend[1], $tmp_dend[2], $tmp_dend[0])
@@ -525,42 +568,45 @@ class Cartridge extends CommonDBTM {
                   $nb_pages_printed++;
                   echo ($data['pages']-$pages[$printer])." ".$LANG['printers'][31];
                   $pages[$printer] = $data['pages'];
-               }
+               } else if ($data['pages']!=0) {
+                  echo "<span class='tab_bg_1_2'>".$LANG['cartridges'][3]."</span>";
+  	       }
                echo "</td>";
             }
             echo "<td class='center'>";
             Infocom::showDisplayLink('Cartridge',$data["id"],1);
             echo "</td>";
-            echo "<td class='center'>";
-            if (!is_null($date_use) && $canedit) {
-               echo "<a href='".$CFG_GLPI["root_doc"]."/front/cartridge.form.php?restore=restore&amp;id=".
-                     $data["id"]."&amp;tID=$tID'>".$LANG['consumables'][37]."</a>";
-            } else {
-                echo "&nbsp;";
-            }
-            echo "</td>";
-            echo "<td class='center'>";
             if ($canedit) {
-               echo "<a href='".$CFG_GLPI["root_doc"]."/front/cartridge.form.php?delete=delete&amp;id=".
-                     $data["id"]."&amp;tID=$tID'>".$LANG['buttons'][6]."</a>";
-            } else {
-                echo "&nbsp;";
+               echo "<td class='center'>";
+               if (!is_null($date_use)) {
+                  echo "<a href='".$CFG_GLPI["root_doc"]."/front/cartridge.form.php?restore=restore&amp;id=".
+                        $data["id"]."&amp;tID=$tID'>".$LANG['consumables'][37]."</a>";
+               } else {
+                  echo "&nbsp;";
+               }
+               echo "</td>";
             }
-            echo "</td></tr>";
+            if ($canedit) {
+               echo "<td class='center'>";
+               echo "<a href='".$CFG_GLPI["root_doc"]."/front/cartridge.form.php?delete=delete&amp;id=".
+                     $data["id"]."&amp;tID=$tID'><img title=\"".$LANG['buttons'][6]."\" alt=\"".$LANG['buttons'][6]."\" src='".$CFG_GLPI["root_doc"]."/pics/delete.png'></a>";
+               echo "</td>";
+            }
+            echo "</tr>";
          }
          if ($show_old&&$number>0) {
             if ($nb_pages_printed==0) {
                 $nb_pages_printed = 1;
             }
             echo "<tr class='tab_bg_2'><td colspan='3'>&nbsp;</td>";
-            echo "<td class='center'>".$LANG['cartridges'][40]."&nbsp;:<br>";
+            echo "<td class='center b'>".$LANG['cartridges'][40]."&nbsp;:<br>";
             echo round($stock_time/$number/60/60/24/30.5,1)." ".$LANG['financial'][57]."</td>";
             echo "<td>&nbsp;</td>";
-            echo "<td class='center'>".$LANG['cartridges'][41]."&nbsp;:<br>";
+            echo "<td class='center b'>".$LANG['cartridges'][41]."&nbsp;:<br>";
             echo round($use_time/$number/60/60/24/30.5,1)." ".$LANG['financial'][57]."</td>";
-            echo "<td class='center'>".$LANG['cartridges'][42]."&nbsp;:<br>";
+            echo "<td class='center b'>".$LANG['cartridges'][42]."&nbsp;:<br>";
             echo round($pages_printed/$nb_pages_printed)."</td>";
-            echo "<td colspan='3'>&nbsp;</td></tr>";
+            echo "<td colspan='".($canedit?'3':'1')."'>&nbsp;</td></tr>";
          }
       }
       echo "</table></div>\n\n";
@@ -610,10 +656,10 @@ class Cartridge extends CommonDBTM {
       global $DB, $CFG_GLPI, $LANG;
 
       $instID = $printer->getField('id');
-      if (!haveRight("cartridge","r")) {
+      if (!Session::haveRight("cartridge","r")) {
          return false;
       }
-      $canedit = haveRight("cartridge","w");
+      $canedit = Session::haveRight("cartridge", "w");
 
       $query = "SELECT `glpi_cartridgeitems`.`id` AS tID,
                        `glpi_cartridgeitems`.`is_deleted`,
@@ -638,12 +684,14 @@ class Cartridge extends CommonDBTM {
       $i = 0;
 
       $pages = $printer->fields['init_pages_counter'];
-
+      if ($canedit) {
+         echo "<form method='post' action=\"".$CFG_GLPI["root_doc"]."/front/cartridge.form.php\">";
+      }
       echo "<div class='spaced'><table class='tab_cadre_fixe'>";
       if ($old==0) {
-         echo "<tr><th colspan='5'>".$LANG['cartridges'][33]."&nbsp;:</th></tr>";
+         echo "<tr><th colspan='".($canedit?'5':'4')."'>".$LANG['cartridges'][33]."&nbsp;:</th></tr>";
       } else {
-         echo "<tr><th colspan='7'>".$LANG['cartridges'][35]."&nbsp;:</th></tr>";
+         echo "<tr><th colspan='".($canedit?'7':'6')."'>".$LANG['cartridges'][35]."&nbsp;:</th></tr>";
       }
       echo "<tr><th>".$LANG['common'][2]."</th><th>".$LANG['cartridges'][12]."</th>";
       echo "<th>".$LANG['cartridges'][24]."</th>";
@@ -651,24 +699,33 @@ class Cartridge extends CommonDBTM {
       if ($old!=0) {
          echo "<th>".$LANG['search'][9]."</th><th>".$LANG['cartridges'][39]."</th>";
       }
-
-      echo "<th>&nbsp;</th></tr>";
+      if ($canedit) {
+         echo "<th>".$LANG['rulesengine'][7]."</th>";
+      }
+      echo "</tr>";
       $stock_time       = 0;
       $use_time         = 0;
       $pages_printed    = 0;
       $nb_pages_printed = 0;
 
       while ($data=$DB->fetch_array($result)) {
-         $date_in  = convDate($data["date_in"]);
-         $date_use = convDate($data["date_use"]);
-         $date_out = convDate($data["date_out"]);
+         $cart_id  = $data["id"];
+         $date_in  = Html::convDate($data["date_in"]);
+         $date_use = Html::convDate($data["date_use"]);
+         $date_out = Html::convDate($data["date_out"]);
          echo "<tr class='tab_bg_1".($data["is_deleted"]?"_2":"")."'>";
          echo "<td class='center'>".$data["id"]."</td>";
-         echo "<td class='center b'>";
+         echo "<td class='center'>";
          echo "<a href=\"".$CFG_GLPI["root_doc"]."/front/cartridgeitem.form.php?id=".$data["tID"]."\">".
                 $data["type"]." - ".$data["ref"]."</a></td>";
          echo "<td class='center'>".$date_in."</td>";
-         echo "<td class='center'>".$date_use;
+         echo "<td class='center'>";
+         
+         if ($old==0 && $canedit) {
+            Html::showDateFormItem("date_use[$cart_id]", $date_use, true, true, $date_in);
+         } else {
+            echo $date_use;
+         }         
 
          $tmp_dbeg = explode("-", $data["date_in"]);
          $tmp_dend = explode("-", $data["date_use"]);
@@ -679,39 +736,38 @@ class Cartridge extends CommonDBTM {
 
          if ($old!=0) {
             echo "</td>";
-            echo "<td class='center'>".$date_out;
-         }
-         if ($old!=0) {
+            echo "<td class='center'>";
+            if ($canedit) {
+               Html::showDateFormItem("date_out[$cart_id]", $date_out, true, true, $date_use);
+            } else {
+               echo $date_out;
+            }            
+
             $tmp_dbeg = explode("-", $data["date_use"]);
             $tmp_dend = explode("-", $data["date_out"]);
 
             $use_time_tmp = mktime(0, 0, 0, $tmp_dend[1], $tmp_dend[2], $tmp_dend[0])
                             - mktime(0, 0, 0, $tmp_dbeg[1], $tmp_dbeg[2], $tmp_dbeg[0]);
             $use_time+=$use_time_tmp;
-         }
-         echo "</td><td class='center'>";
-         if ($old!=0) {
+            
+            echo "</td><td class='left'>";
+            
             if ($canedit) {
-               echo "<form method='post' action=\"".$CFG_GLPI["root_doc"]."/front/cartridge.form.php\">";
-               echo "<input type='hidden' name='cID' value='".$data['id']."'>";
-               echo "<input type='text' name='pages' value=\"".$data['pages']."\" size='10'>";
-               echo "<input type='image' name='update_pages' value='update_pages'
-                      src='".$CFG_GLPI["root_doc"]."/pics/actualiser.png' class='calendrier'>";
-               echo "</form>";
+               echo "<input type='text' name='pages[$cart_id]' value=\"".$data['pages']."\" size='6'>";
             } else {
-               echo "<input type='text' name='pages' value=\"".$data['pages']."\" size='10'>";
+               echo "<input type='text' name='pages' value=\"".$data['pages']."\" size='6'>";
             }
 
             if ($pages<$data['pages']) {
                $pages_printed += $data['pages']-$pages;
                $nb_pages_printed++;
-               echo ($data['pages']-$pages)." ".$LANG['printers'][31];
+               echo "&nbsp;".($data['pages']-$pages)." ".$LANG['printers'][31];
                $pages = $data['pages'];
             }
-            echo "</td><td class='center'>";
          }
+         echo "</td>";
          if ($canedit) {
-            echo "<span class='small_space'>";
+            echo "<td class='center'>";
             if (is_null($date_out)) {
                echo "<a href='".$CFG_GLPI["root_doc"].
                       "/front/cartridge.form.php?uninstall=uninstall&amp;id=".$data["id"].
@@ -719,39 +775,49 @@ class Cartridge extends CommonDBTM {
             } else {
                echo "<a href='".$CFG_GLPI["root_doc"].
                       "/front/cartridge.form.php?delete=delete&amp;id=".$data["id"].
-                      "&amp;tID=".$data["tID"]."'>".$LANG['buttons'][6]."</a>";
+                      "&amp;tID=".$data["tID"]."'><img title=\"".$LANG['buttons'][6]."\" alt=\"".$LANG['buttons'][6]."\" src='".$CFG_GLPI["root_doc"]."/pics/delete.png'></a>";
             }
-            echo "</span></td></tr>";
+            echo "</td></tr>";
          }
       }
-      if ($old==0 && $canedit) {
-         echo "<tr class='tab_bg_1'><td>&nbsp;</td><td class='center' colspan='3'>";
-         echo "<form method='post' action=\"".$CFG_GLPI["root_doc"]."/front/cartridge.form.php\">";
-         echo "<input type='hidden' name='pID' value='$instID'>";
-
-         if (CartridgeItem::dropdownForPrinter($printer)) {
-            echo "&nbsp;<input type='submit' name='install' value=\"".$LANG['buttons'][4]."\"
-                         class='submit'>";
+      if ($old==0) {
+         if ($canedit) {
+            echo "<tr class='tab_bg_1'><td colspan='2' class='center'>";
+            echo "<input type='hidden' name='pID' value='$instID'>";
+            if ($number > 0) {
+               echo "<input type='submit' name='update_cart_use' value=\"".$LANG['buttons'][7]."\" class='submit'>";
+            }
+            echo "</td><td  colspan='3' class='tab_bg_2 center'>";
+            if (CartridgeItem::dropdownForPrinter($printer)) {
+               echo "&nbsp;<input type='submit' name='install' value=\"".$LANG['buttons'][4]."\"
+                           class='submit'>";
+            }
+            echo "</td></tr>";
          }
-         echo "</form></td><td class='tab_bg_2 center'>&nbsp;";
-         echo "</td></tr>";
-
       } else { // Print average
          if ($number>0) {
             if ($nb_pages_printed==0) {
                $nb_pages_printed = 1;
             }
-            echo "<tr class='tab_bg_2'><td>&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td>";
-            echo "<td class='center'>".$LANG['cartridges'][40]."&nbsp;:<br>";
+            echo "<tr class='tab_bg_2'><td colspan='3'>&nbsp;</td>";
+            echo "<td class='center b'>".$LANG['cartridges'][40]."&nbsp;:<br>";
             echo round($stock_time/$number/60/60/24/30.5,1)." ".$LANG['financial'][57]."</td>";
-            echo "<td class='center'>".$LANG['cartridges'][41].":<br>";
+            echo "<td class='center b'>".$LANG['cartridges'][41].":<br>";
             echo round($use_time/$number/60/60/24/30.5,1)." ".$LANG['financial'][57]."</td>";
-            echo "<td class='center'>".$LANG['cartridges'][42].":<br>";
+            echo "<td class='center b'>".$LANG['cartridges'][42].":<br>";
             echo round($pages_printed/$nb_pages_printed)."</td>";
-            echo "<td>&nbsp;</td></tr>";
+            if ($canedit) {
+               echo "<td>";
+               echo "<input type='submit' name='update_cart_out' value=\"".$LANG['buttons'][7]."\" class='submit'>";
+               echo "</td>";
+            }
+            echo "</tr>";
          }
       }
       echo "</table></div>";
+      if ($canedit) {
+         echo "</form>";
+      }      
    }
 
 
@@ -782,6 +848,60 @@ class Cartridge extends CommonDBTM {
          return $datas['cartridges_alert_repeat'];
       }
    }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate && Session::haveRight("cartridge","r"))
+         switch ($item->getType()) {
+            case 'Printer' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['Menu'][21], self::countForPrinter($item));
+               }
+               return $LANG['Menu'][21];
+
+            case 'CartridgeItem' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['Menu'][21], self::countForCartridgeItem($item));
+               }
+               return $LANG['Menu'][21];
+      }
+      return '';
+   }
+
+
+   static function countForCartridgeItem(CartridgeItem $item) {
+
+      $restrict = "`glpi_cartridges`.`cartridgeitems_id` = '".$item->getField('id') ."'";
+
+      return countElementsInTable(array('glpi_cartridges'), $restrict);
+   }
+
+
+   static function countForPrinter(Printer $item) {
+
+      $restrict = "`glpi_cartridges`.`printers_id` = '".$item->getField('id') ."'";
+
+      return countElementsInTable(array('glpi_cartridges'), $restrict);
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      switch ($item->getType()) {
+         case 'Printer' :
+            self::showInstalled($item);
+            self::showInstalled($item, 1);
+            return true;
+
+         case 'CartridgeItem' :
+            self::showAddForm($item);
+            self::showForCartridgeItem($item);
+            self::showForCartridgeItem($item, 1);
+            return true;
+      }
+   }
 }
 
 ?>
\ No newline at end of file
