@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cartridgeitem.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: cartridgeitem.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -47,20 +47,23 @@ class CartridgeItem extends CommonDBTM {
    // From CommonDBTM
    protected $forward_entity_to = array('Cartridge', 'Infocom');
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['cartridges'][12];
+      if ($nb>1) {
+         return $LANG['cartridges'][2];
+      }
+      return $LANG['cartridges'][1];
    }
 
 
    function canCreate() {
-      return haveRight('cartridge', 'w');
+      return Session::haveRight('cartridge', 'w');
    }
 
 
    function canView() {
-      return haveRight('cartridge', 'r');
+      return Session::haveRight('cartridge', 'r');
    }
 
 
@@ -106,33 +109,25 @@ class CartridgeItem extends CommonDBTM {
    }
 
 
-   function post_getEmpty () {
-      global $CFG_GLPI;
+   function post_getEmpty() {
 
-      $this->fields["alarm_threshold"] = $CFG_GLPI["default_alarm_threshold"];
+      $this->fields["alarm_threshold"] = EntityData::getUsedConfig("cartriges_alert_repeat",
+                                                                   $this->fields["entities_id"],
+                                                                   "default_alarm_threshold", 10);
    }
 
 
    function defineTabs($options=array()) {
       global $LANG;
 
-      $ong[1] = $LANG['Menu'][21];
-      if ($this->fields['id'] > 0) {
-         if (haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-         }
-      }
+      $ong = array();
+      $this->addStandardTab('Cartridge', $ong, $options);
+      $this->addStandardTab('PrinterModel', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Document',$ong, $options);
+      $this->addStandardTab('Link',$ong, $options);
+      $this->addStandardTab('Note',$ong, $options);
+
       return $ong;
    }
 
@@ -217,11 +212,11 @@ class CartridgeItem extends CommonDBTM {
    * @return Nothing (display)
    *
    **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $LANG;
 
    // Show CartridgeItem or blank form
-      if (!haveRight("cartridge", "r")) {
+      if (!Session::haveRight("cartridge", "r")) {
         return false;
       }
 
@@ -238,26 +233,18 @@ class CartridgeItem extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;: </td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
-      echo "<td rowspan='7' class='middle right'>".$LANG['common'][25]."&nbsp;: </td>";
-      echo "<td class='center middle' rowspan='7'>";
-      echo "<textarea cols='45' rows='9' name='comment'>".$this->fields["comment"]."</textarea>";
-      echo "</td></tr>";
-
-      echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['consumables'][2]."&nbsp;: </td>";
-      echo "<td>";
-      autocompletionTextField($this, "ref");
-      echo "</td></tr>";
-
-      echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][17]."&nbsp;: </td>";
       echo "<td>";
       Dropdown::show('CartridgeItemType', array('value' => $this->fields["cartridgeitemtypes_id"]));
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['consumables'][2]."&nbsp;: </td>";
+      echo "<td>";
+      Html::autocompletionTextField($this, "ref");
+      echo "</td>";
       echo "<td>".$LANG['common'][5]."&nbsp;: </td>";
       echo "<td>";
       Dropdown::show('Manufacturer', array('value' => $this->fields["manufacturers_id"]));
@@ -270,8 +257,21 @@ class CartridgeItem extends CommonDBTM {
                            'value'  => $this->fields["users_id_tech"],
                            'right'  => 'interface',
                            'entity' => $this->fields["entities_id"]));
+      echo "</td>";
+      echo "<td rowspan='4' class='middle'>".$LANG['common'][25]."&nbsp;: </td>";
+      echo "<td class='middle' rowspan='4'>
+             <textarea cols='45' rows='9' name='comment'>".$this->fields["comment"]."</textarea>";
       echo "</td></tr>";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
+      echo "</td></tr>\n";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['consumables'][36]."&nbsp;: </td>";
       echo "<td>";
@@ -282,7 +282,8 @@ class CartridgeItem extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['consumables'][38]."&nbsp;: </td>";
       echo "<td>";
-      Dropdown::showInteger('alarm_threshold', $this->fields["alarm_threshold"], -1, 100);
+      Dropdown::showInteger('alarm_threshold', $this->fields["alarm_threshold"], 0, 100, 1,
+                            array('-1' => $LANG['setup'][307]));
       Alert::displayLastAlert('CartridgeItem', $ID);
       echo "</td></tr>";
 
@@ -331,6 +332,12 @@ class CartridgeItem extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[8]['table']     = $this->getTable();
       $tab[8]['field']     = 'alarm_threshold';
       $tab[8]['name']      = $LANG['consumables'][38];
@@ -431,8 +438,9 @@ class CartridgeItem extends CommonDBTM {
                                ."&nbsp;:  $message\n");
                      $task->addVolume(1);
                   } else {
-                     addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity)
-                                            ."&nbsp;:  $message");
+                     Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                                $entity)
+                                                      ."&nbsp;:  $message");
                   }
 
                   $input["type"]     = Alert::THRESHOLD;
@@ -450,8 +458,10 @@ class CartridgeItem extends CommonDBTM {
                      $task->log(Dropdown::getDropdownName("glpi_entities", $entity)
                                ."&nbsp;: Send cartidge alert failed\n");
                   } else {
-                     addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity)
-                                            ."&nbsp;: Send cartidge alert failed", false, ERROR);
+                     Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                                $entity)
+                                                      ."&nbsp;: Send cartidge alert failed", false,
+                                                      ERROR);
                   }
                }
             }
@@ -545,14 +555,14 @@ class CartridgeItem extends CommonDBTM {
          $pmid = $DB->result($result, $i, "pmid");
          echo "<tr class='tab_bg_1'><td class='center'>$ID</td>";
          echo "<td class='center'>$type</td>";
-         echo "<td class='tab_bg_2 center'>";
+         echo "<td class='tab_bg_2 center b'>";
          echo "<a href='".$CFG_GLPI['root_doc'].
                 "/front/cartridgeitem.form.php?deletetype=deletetype&amp;id=$ID&amp;tID=$instID'>";
-         echo "<strong>".$LANG['buttons'][6]."</strong></a></td></tr>";
-         $used[] = $pmid;
+         echo $LANG['buttons'][6]."</a></td></tr>";
+         $used[$pmid] = $pmid;
          $i++;
       }
-      if (haveRight("cartridge", "w")) {
+      if (Session::haveRight("cartridge", "w")) {
          echo "<tr class='tab_bg_1'><td>&nbsp;</td><td class='center'>";
          echo "<input type='hidden' name='tID' value='$instID'>";
          Dropdown::show('PrinterModel', array('used' => $used));
