@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commondropdown.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: commondropdown.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -49,6 +49,9 @@ abstract class CommonDropdown extends CommonDBTM {
    //Menu & navigation
    public $first_level_menu  = "config";
    public $second_level_menu = "dropdowns";
+   public $third_level_menu  = "";
+
+   public $display_dropdowntitle  = true;
 
 
    /**
@@ -62,22 +65,14 @@ abstract class CommonDropdown extends CommonDBTM {
    function defineTabs($options=array()) {
 
       $ong = array();
-      $ong[1] = $this->getTypeName();
-      foreach ($this->defineMoreTabs($options) as $key => $value) {
-         $ong[$key] = $value;
+      if ($this->dohistory) {
+         $this->addStandardTab('Log',$ong, $options);
       }
+
       return $ong;
    }
 
 
-   /**
-    * Add more tabs to display
-   **/
-   function defineMoreTabs($options=array()) {
-      return array();
-   }
-
-
    /**
     * Have I the right to "create" the Object
     *
@@ -86,7 +81,7 @@ abstract class CommonDropdown extends CommonDBTM {
     * @return booleen
    **/
    function canCreate() {
-      return haveRight('dropdown','w');
+      return Session::haveRight('dropdown', 'w');
    }
 
 
@@ -98,37 +93,7 @@ abstract class CommonDropdown extends CommonDBTM {
     * @return booleen
    **/
    function canView() {
-      return haveRight('dropdown','r');
-   }
-
-
-   /**
-    * Display content of Tab
-    *
-    * @param $ID of the item
-    * @param $tab number of the tab
-    *
-    * @return true if handled (for class stack)
-   **/
-   function showTabContent ($ID, $tab) {
-
-      if (!$this->isNewID($ID)) {
-         switch ($tab) {
-            case -1 :
-               Plugin::displayAction($this, $tab);
-               $this->displayMoreTabs($tab);
-               return false;
-
-            default :
-               $this->displayMoreTabs($tab);
-               return Plugin::displayAction($this, $tab);
-         }
-      }
-      return false;
-   }
-
-
-   function displayMoreTabs($tab) {
+      return Session::haveRight('dropdown', 'r');
    }
 
 
@@ -140,18 +105,23 @@ abstract class CommonDropdown extends CommonDBTM {
    function title() {
       global $LANG;
 
-      Dropdown::showItemTypeMenu($LANG['setup'][0], Dropdown::getStandardDropdownItemTypes(),
-                                 $this->getSearchUrl());
+      if ($this->display_dropdowntitle) {
+         Dropdown::showItemTypeMenu($LANG['setup'][0], Dropdown::getStandardDropdownItemTypes(),
+                                    $this->getSearchURL());
+      }
    }
 
 
-   function displayHeader () {
-      commonHeader($this->getTypeName(), '', $this->first_level_menu, $this->second_level_menu,
-                   get_class($this));
+   function displayHeader() {
+      if (empty($this->third_level_menu)) {
+        $this->third_level_menu = $this->getType();
+      }
+      Html::header($this->getTypeName(2), '', $this->first_level_menu, $this->second_level_menu,
+                   $this->third_level_menu);
    }
 
 
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
       if (!$this->isNewID($ID)) {
@@ -171,9 +141,9 @@ abstract class CommonDropdown extends CommonDBTM {
       echo "<input type='hidden' name='itemtype' value='".$this->getType()."'>";
       if ($this instanceof CommonDevice) {
          // Awfull hack for CommonDevice where name is designation
-         autocompletionTextField($this, "designation");
+         Html::autocompletionTextField($this, "designation");
       } else {
-         autocompletionTextField($this, "name");
+         Html::autocompletionTextField($this, "name");
       }
       echo "</td>";
 
@@ -184,7 +154,12 @@ abstract class CommonDropdown extends CommonDBTM {
       echo "</textarea></td></tr>\n";
 
       foreach ($fields as $field) {
-         echo "<tr class='tab_bg_1'><td>".$field['label']."&nbsp;:</td><td>";
+         echo "<tr class='tab_bg_1'><td>".$field['label'];
+         if (isset($field['comment']) && !empty($field['comment'])) {
+            echo "&nbsp;";
+            Html::showToolTip($field['comment']);
+         }
+         echo "&nbsp;:</td><td>";
          switch ($field['type']) {
             case 'UserDropdown' :
                User::dropdown(array('name'   => $field['name'],
@@ -202,7 +177,7 @@ abstract class CommonDropdown extends CommonDBTM {
                break;
 
             case 'text' :
-               autocompletionTextField($this, $field['name']);
+               Html::autocompletionTextField($this, $field['name']);
                break;
 
             case 'textarea' :
@@ -210,6 +185,24 @@ abstract class CommonDropdown extends CommonDBTM {
                      $this->fields[$field['name']]."</textarea >";
                break;
 
+            case 'integer' :
+               Dropdown::showInteger($field['name'], $this->fields[$field['name']]);
+               break;
+
+            case 'timestamp' :
+               $param = array('value' => $this->fields[$field['name']]);
+               if (isset($field['min'])) {
+                  $param['min'] = $field['min'];
+               }
+               if (isset($field['max'])) {
+                  $param['max'] = $field['max'];
+               }
+               if (isset($field['step'])) {
+                  $param['step'] = $field['step'];
+               }
+               Dropdown::showTimeStamp($field['name'], $param);
+               break;
+
             case 'parent' :
                if ($field['name']=='entities_id') {
                   $restrict = -1;
@@ -238,17 +231,17 @@ abstract class CommonDropdown extends CommonDBTM {
                break;
 
             case 'date' :
-               showDateFormItem($field['name'], $this->fields[$field['name']]);
+               Html::showDateFormItem($field['name'], $this->fields[$field['name']]);
                break;
 
             case 'datetime' :
-               showDateTimeFormItem($field['name'], $this->fields[$field['name']]);
+               Html::showDateTimeFormItem($field['name'], $this->fields[$field['name']]);
                break;
 
             case 'password':
                echo "<input type='password' name='password' value='' size='20' autocomplete='off'>";
                break;
-               
+
             default:
                $this->displaySpecificTypeField($ID, $field);
                break;
@@ -345,7 +338,7 @@ abstract class CommonDropdown extends CommonDBTM {
       $ID = $this->fields['id'];
 
       $RELATION = getDbRelations();
-      if (isset ($RELATION[$this->getTable()])) {
+      if (isset($RELATION[$this->getTable()])) {
          foreach ($RELATION[$this->getTable()] as $tablename => $field) {
             if ($tablename[0]!='_') {
                if (!is_array($field)) {
@@ -620,9 +613,9 @@ abstract class CommonDropdown extends CommonDBTM {
    function refreshParentInfos() {
 
       if (!$this->refresh_page) {
-         refreshDropdownPopupInMainWindow();
+         Ajax::refreshDropdownPopupInMainWindow();
       } else {
-         refreshPopupMainWindow();
+         Ajax::refreshPopupMainWindow();
       }
    }
 }
