@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commontreedropdown.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: commontreedropdown.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -52,52 +52,86 @@ abstract class CommonTreeDropdown extends CommonDropdown {
    }
 
 
-   /**
-    * Display content of Tab
-    *
-    * @param $ID of the item
-    * @param $tab number of the tab
-    *
-    * @return true if handled (for class stack)
-   **/
-   function showTabContent ($ID, $tab) {
+   function defineTabs($options=array()) {
 
-      if (!$this->isNewID($ID) && !parent::showTabContent ($ID, $tab)) {
-         switch ($tab) {
-            case 1 :
-               $this->showChildren($ID);
-               return true;
-
-            case -1 :
-               $this->showChildren($ID);
-               return false;
-         }
+      $ong = array();
+      $this->addStandardTab($this->getType(), $ong, $options);
+      if ($this->dohistory) {
+         $this->addStandardTab('Log',$ong, $options);
       }
-      return false;
+
+      return $ong;
    }
 
 
-   function prepareInputForAdd($input) {
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
 
+      if (!$withtemplate) {
+         if ($item->getType()==$this->getType()) {
+            if ($_SESSION['glpishow_count_on_tabs']) {
+               $nb = countElementsInTable($this->getTable(),
+                                          "`".$this->getForeignKeyField()."` = '".$item->getID()."'");
+               return self::createTabEntry($this->getTypeName(2), $nb);
+           }
+           return $this->getTypeName(2);
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item instanceof CommonTreeDropdown) {
+         $item->showChildren();
+      }
+      return true;
+   }
+
+
+   /**
+   * Compute completename based on parent one
+   *
+   * @param $parentCompleteName string parent complete name (need to be stripslashes / comes from DB)
+   * @param $thisName string item name (need to be addslashes : comes from input)
+   **/
+   static function getCompleteNameFromParents($parentCompleteName, $thisName) {
+     return addslashes($parentCompleteName). " > ".$thisName;
+   }
+
+
+   function adaptTreeFieldsFromUpdateOrAdd($input) {
       $parent = clone $this;
 
+      // Update case input['name'] not set :
+      if (!isset($input['name']) && isset($this->fields['name'])) {
+         $input['name'] = addslashes($this->fields['name']);
+      }
+
       if (isset($input[$this->getForeignKeyField()])
           && $input[$this->getForeignKeyField()]>0
           && $parent->getFromDB($input[$this->getForeignKeyField()])) {
 
          $input['level']        = $parent->fields['level']+1;
-         $input['completename'] = addslashes($parent->fields['completename']) . " > " .
-                                  $input['name'];
+         // Sometimes (internet address), the complete name may be different ...
+         $input['completename'] = self::getCompleteNameFromParents($parent->fields['completename'],
+                                                                   $input['name']);
       } else {
          $input[$this->getForeignKeyField()] = 0;
-         $input['level']        = 1;
-         $input['completename'] = $input['name'];
+         $input['level']                     = 1;
+         $input['completename']              = $input['name'];
       }
 
       return $input;
    }
 
 
+   function prepareInputForAdd($input) {
+     return $this->adaptTreeFieldsFromUpdateOrAdd($input);
+   }
+
+
    function pre_deleteItem() {
       global $DB;
 
@@ -108,7 +142,7 @@ abstract class CommonTreeDropdown extends CommonDropdown {
          $parent = $this->fields[$this->getForeignKeyField()];
       }
 
-      CleanFields($this->getTable(), array('ancestors_cache', 'sons_cache'));
+      $this->recursiveCleanSonsAboveID($parent);
       $tmp  = clone $this;
       $crit = array('FIELDS'                    => 'id',
                     $this->getForeignKeyField() => $this->fields["id"]);
@@ -124,32 +158,168 @@ abstract class CommonTreeDropdown extends CommonDropdown {
 
    function prepareInputForUpdate($input) {
 
-      // Can't move a parent under a child
-      if (isset($input[$this->getForeignKeyField()])
-          && in_array($input[$this->getForeignKeyField()],
-                      getSonsOf($this->getTable(), $input['id']))) {
+      if (isset($input[$this->getForeignKeyField()])) {
+         // Can't move a parent under a child
+         if (in_array($input[$this->getForeignKeyField()],
+               getSonsOf($this->getTable(), $input['id']))) {
          return false;
+         }
+         // Parent changes => clear ancestors and update its level and completename
+         if ($input[$this->getForeignKeyField()] != $this->fields[$this->getForeignKeyField()]) {
+         $input["ancestors_cache"] = NULL;
+         return $this->adaptTreeFieldsFromUpdateOrAdd($input);
+         }
+      }
+
+      // Name changes => update its completename (and its level : side effect ...)
+      if ((isset($input['name'])) && ($input['name'] != $this->fields['name'])) {
+         return $this->adaptTreeFieldsFromUpdateOrAdd($input);
       }
       return $input;
    }
 
 
-   function post_updateItem($history=1) {
+   function regenerateTreeUnderID($ID, $updateName, $changeParent) {
+      global $DB;
 
-      if (in_array('name', $this->updates)
-          || in_array($this->getForeignKeyField(), $this->updates)) {
+      if (($updateName) || ($changeParent)) {
+         $currentNode = clone $this;
 
-         if (in_array($this->getForeignKeyField(), $this->updates)) {
-            CleanFields($this->getTable(), array('ancestors_cache', 'sons_cache'));
+         if ($currentNode->getFromDB($ID)) {
+            $currentNodeCompleteName = $currentNode->getField("completename");
+            $nextNodeLevel           = ($currentNode->getField("level") + 1);
+         } else {
+            $nextNodeLevel = 1;
          }
 
-         regenerateTreeCompleteNameUnderID($this->getTable(), $this->input['id']);
+         $query = "SELECT `id`, `name`
+                   FROM `".$this->getTable()."`
+                   WHERE `".$this->getForeignKeyField()."` = '$ID'";
+         foreach ($DB->request($query) as $data) {
+            $query = "UPDATE `".$this->getTable()."`
+                      SET ";
+            $fieldsToUpdate = array();
+
+            if ($updateName || $changeParent) {
+               if (isset($currentNodeCompleteName)) {
+                  $fieldsToUpdate[] = "`completename`='".
+                  self::getCompleteNameFromParents($currentNodeCompleteName,
+                                                   addslashes($data["name"]))."'";
+               } else {
+                  $fieldsToUpdate[] = "`completename`='".addslashes($data["name"])."'";
+               }
+            }
+
+            if ($changeParent) {
+               // We have to reset the ancestors as only these changes (ie : not the children).
+               $fieldsToUpdate[] = "`ancestors_cache` = NULL";
+               // And we must update the level of the current node ...
+               $fieldsToUpdate[] = "`level` = '$nextNodeLevel'";
+            }
+            $query .= implode(', ',$fieldsToUpdate)." WHERE `id`= '".$data["id"]."'";
+            $DB->query($query);
+            $this->regenerateTreeUnderID($data["id"], $updateName, $changeParent);
+         }
+      }
+   }
+
+
+   function recursiveCleanSonsAboveID($ID) {
+      global $DB;
+
+      if ($ID > 0) {
+         $query = "UPDATE `".$this->getTable()."`
+                    SET `sons_cache` = NULL
+                    WHERE `id` = '$ID'";
+         $DB->query($query);
+
+         $currentNode = clone $this;
+         if ($currentNode->getFromDB($ID)) {
+            $parentID = $currentNode->getField($this->getForeignKeyField());
+            if ($ID != $parentID) {
+               $this->recursiveCleanSonsAboveID($parentID);
+            }
+         }
       }
    }
 
 
    function post_addItem() {
-      CleanFields($this->getTable(), 'sons_cache');
+
+      $parent = $this->fields[$this->getForeignKeyField()];
+      $this->recursiveCleanSonsAboveID($parent);
+      if ($parent && $this->dohistory) {
+         $changes[0] = '0';
+         $changes[1] = '';
+         $changes[2] = addslashes($this->getNameID());
+         Log::history($parent, $this->getType(), $changes, $this->getType(),
+                      Log::HISTORY_ADD_SUBITEM);
+      }
+   }
+
+
+   function post_updateItem($history=1) {
+      $ID = $this->getID();
+      $changeParent = in_array($this->getForeignKeyField(), $this->updates);
+      $this->regenerateTreeUnderID($ID, in_array('name', $this->updates), $changeParent);
+      $this->recursiveCleanSonsAboveID($ID);
+
+      if ($changeParent) {
+         $oldParentID     = $this->oldvalues[$this->getForeignKeyField()];
+         $newParentID     = $this->fields[$this->getForeignKeyField()];
+         $oldParentNameID = '';
+         $newParentNameID = '';
+
+         $parent = clone $this;
+         if ($oldParentID > 0) {
+            $this->recursiveCleanSonsAboveID($oldParentID);
+            if ($history) {
+               if ($parent->getFromDB($oldParentID)) {
+               $oldParentNameID = $parent->getNameID();
+               }
+               $changes[0] = '0';
+               $changes[1] = addslashes($this->getNameID());
+               $changes[2] = '';
+               Log::history($oldParentID, $this->getType(), $changes, $this->getType(),
+                            Log::HISTORY_DELETE_SUBITEM);
+            }
+         }
+
+         if ($newParentID > 0) {
+            if ($history) {
+               if ($parent->getFromDB($newParentID)) {
+               $newParentNameID = $parent->getNameID();
+               }
+               $changes[0] = '0';
+               $changes[1] = '';
+               $changes[2] = addslashes($this->getNameID());
+               Log::history($newParentID, $this->getType(), $changes, $this->getType(),
+                            Log::HISTORY_ADD_SUBITEM);
+            }
+         }
+
+         if ($history) {
+            $changes[0] = '0';
+            $changes[1] = $oldParentNameID;
+            $changes[2] = $newParentNameID;
+            Log::history($ID, $this->getType(), $changes, $this->getType(),
+                         Log::HISTORY_UPDATE_SUBITEM);
+         }
+
+      }
+   }
+
+
+   function post_deleteFromDB() {
+
+      $parent = $this->fields[$this->getForeignKeyField()];
+      if ($parent && $this->dohistory) {
+         $changes[0] = '0';
+         $changes[1] = addslashes($this->getNameID());
+         $changes[2] = '';
+         Log::history($parent, $this->getType(), $changes, $this->getType(),
+                      Log::HISTORY_DELETE_SUBITEM);
+      }
    }
 
 
@@ -176,13 +346,12 @@ abstract class CommonTreeDropdown extends CommonDropdown {
    /**
     * Print the HTML array children of a TreeDropdown
     *
-    *@param $ID of the dropdown
-    *
-    *@return Nothing (display)
+    * @return Nothing (display)
     **/
-    function showChildren($ID) {
+    function showChildren() {
       global $DB, $CFG_GLPI, $LANG;
 
+      $ID = $this->getID();
       $this->check($ID, 'r');
       $fields        = $this->getAdditionalFields();
       $nb            = count($fields);
@@ -197,7 +366,7 @@ abstract class CommonTreeDropdown extends CommonDropdown {
          echo "<tr><th colspan='2'>".$LANG['common'][93]."</th></tr>";
 
          echo "<tr class='tab_bg_1'><td>".$LANG['common'][16]."&nbsp;: ";
-         autocompletionTextField($this, "name", array('value' => ''));
+         Html::autocompletionTextField($this, "name", array('value' => ''));
 
          if ($entity_assign && $this->getForeignKeyField()!='entities_id') {
             echo "<input type='hidden' name='entities_id' value='".$_SESSION['glpiactive_entity']."'>";
@@ -359,7 +528,7 @@ abstract class CommonTreeDropdown extends CommonDropdown {
     * @param $value string
     *
     * @return string
-    */
+   **/
    static function cleanTreeText($value) {
 
       $tmp = explode('>', $value);
