@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_device.class.php 17448 2012-02-08 09:52:32Z tsmr $
+ * @version $Id: computer_device.class.php 17447 2012-02-08 09:49:41Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -74,12 +74,12 @@ class Computer_Device extends CommonDBTM {
 
 
    function canCreate() {
-      return haveRight('computer', 'w');
+      return Session::haveRight('computer', 'w');
    }
 
 
    function canView() {
-      return haveRight('computer', 'r');
+      return Session::haveRight('computer', 'r');
    }
 
 
@@ -112,7 +112,7 @@ class Computer_Device extends CommonDBTM {
       if (count($dev->getSpecifityLabel()) > 0
           && (!isset($input['specificity']) || empty($input['specificity']))) {
 
-         $dev = new $input['_itemtype'];
+         $dev = new $input['_itemtype']();
          $dev->getFromDB($input[$dev->getForeignKeyField()]);
          $input['specificity'] = $dev->getField('specif_default');
       }
@@ -135,7 +135,7 @@ class Computer_Device extends CommonDBTM {
       $changes[1] = '';
       $changes[2] = addslashes($dev->getName());
       Log::history($this->fields['computers_id'], 'Computer', $changes, get_class($dev),
-                   HISTORY_ADD_DEVICE);
+                   Log::HISTORY_ADD_DEVICE);
    }
 
 
@@ -154,7 +154,7 @@ class Computer_Device extends CommonDBTM {
       $changes[1] = addslashes($dev->getName());
       $changes[2] = '';
       Log::history($this->fields['computers_id'], 'Computer', $changes, get_class($dev),
-                   HISTORY_DELETE_DEVICE);
+                   Log::HISTORY_DELETE_DEVICE);
    }
 
 
@@ -171,7 +171,7 @@ class Computer_Device extends CommonDBTM {
       $changes[2] = $this->fields['specificity'];
       // history log
       Log::history($this->fields['computers_id'], 'Computer', $changes, $this->input['_itemtype'],
-                   HISTORY_UPDATE_DEVICE);
+                   Log::HISTORY_UPDATE_DEVICE);
    }
 
 
@@ -196,12 +196,12 @@ class Computer_Device extends CommonDBTM {
 
       echo "<div class='spaced'>";
       if ($canedit) {
-         echo "<form name='form_device_action' action='".getItemTypeFormURL(__CLASS__).
+         echo "<form name='form_device_action' action='".Toolbox::getItemTypeFormURL(__CLASS__).
                 "' method='post'>";
          echo "<input type='hidden' name='computers_id' value='$ID'>";
       }
       echo "<table class='tab_cadre_fixe' >";
-      echo "<tr><th colspan='63'>".$LANG['title'][30]."</th></tr>";
+      echo "<tr><th colspan='63'>".Toolbox::ucfirst($LANG['log'][18])."</th></tr>";
       $nb = 0;
 
       $specificity_units = array('DeviceProcessor'   => $LANG['setup'][35],
@@ -210,9 +210,10 @@ class Computer_Device extends CommonDBTM {
                                  'DeviceGraphicCard' => $LANG['common'][82]);
 
       foreach ($devtypes as $itemtype) {
-         initNavigateListItems($itemtype, $computer->getTypeName()." = ".$computer->getName());
+         Session::initNavigateListItems($itemtype,
+                                        $computer->getTypeName()." = ".$computer->getName());
 
-         $device        = new $itemtype;
+         $device        = new $itemtype();
          $specificities = $device->getSpecifityLabel();
          $specif_fields = array_keys($specificities);
          $specif_text   = implode(',',$specif_fields);
@@ -233,7 +234,7 @@ class Computer_Device extends CommonDBTM {
 
          $prev = '';
          foreach ($DB->request($query) as $data) {
-            addToNavigateListItems($itemtype, $data[$fk]);
+            Session::addToNavigateListItems($itemtype, $data[$fk]);
 
             if ($device->getFromDB($data[$fk])) {
                echo "<tr class='tab_bg_2'>";
@@ -478,7 +479,7 @@ class Computer_Device extends CommonDBTM {
    /**
     * Duplicate all device from a computer template to his clone
    **/
-   function cloneComputer ($oldid, $newid) {
+   function cloneComputer($oldid, $newid) {
       global $DB;
 
       $devtypes = self::getDeviceTypes();
@@ -532,19 +533,19 @@ class Computer_Device extends CommonDBTM {
          }
       }
 
-      if ($input['_itemtype'] != 'DeviceMemory' 
-            && isset($this->fields['specificity'])
-               && $this->fields['specificity'] == $this->input['specificity']) {
+      if ($input['_itemtype'] != 'DeviceMemory'
+          && isset($this->fields['specificity'])
+          && $this->fields['specificity'] == $this->input['specificity']) {
          // No change
          return false;
       }
 
       //For memories, type can change even if specificity not
-      if ($input['_itemtype'] == 'DeviceMemory' 
-            && (isset($this->fields['specificity'])
-               && $this->fields['specificity'] == $this->input['specificity']) 
-                  && ((isset($this->fields['devicememories_id'])
-                      && (!isset($this->input['devicememories_id']) || $this->fields['devicememories_id'] == $this->input['devicememories_id'])))) {
+      if ($input['_itemtype'] == 'DeviceMemory'
+          && (isset($this->fields['specificity'])
+              && $this->fields['specificity'] == $this->input['specificity'])
+          && ((isset($this->fields['devicememories_id'])
+               && (!isset($this->input['devicememories_id']) || $this->fields['devicememories_id'] == $this->input['devicememories_id'])))) {
          // No change
          return false;
       }
@@ -563,7 +564,7 @@ class Computer_Device extends CommonDBTM {
     *
     * @return array of Mac Addresses
    **/
-   static function getMacAddr (Computer $comp) {
+   static function getMacAddr(Computer $comp) {
       global $DB;
 
       $query = "SELECT DISTINCT `specificity`
@@ -599,4 +600,4 @@ class Computer_Device extends CommonDBTM {
 
 
 }
-?>
+?>
\ No newline at end of file
