@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_item.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: computer_item.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -62,6 +62,20 @@ class Computer_Item extends CommonDBRelation{
    }
 
 
+   /**
+    * Count connection for a Computer
+    *
+    * @param $comp Computer
+    *
+    * @return integer: count
+   **/
+   static function countForComputer(Computer $comp) {
+
+      return countElementsInTable('glpi_computers_items',
+                                  "`computers_id` ='".$comp->getField('id')."'");
+   }
+
+
    /**
     * Check right on an item - overloaded to check is_global
     *
@@ -75,10 +89,9 @@ class Computer_Item extends CommonDBRelation{
 
       if ($ID<0) {
          // Ajout
-         if (!class_exists($input['itemtype'])) {
+         if (!($item = getItemForItemtype($input['itemtype']))) {
             return false;
          }
-         $item = new $input['itemtype']();
 
          if (!$item->getFromDB($input['items_id'])) {
             return false;
@@ -159,7 +172,7 @@ class Computer_Item extends CommonDBRelation{
                && $comp->fields['locations_id'] != $item->getField('locations_id')) {
 
                $updates['locations_id'] = addslashes($comp->fields['locations_id']);
-               addMessageAfterRedirect($LANG['computers'][48], true);
+               Session::addMessageAfterRedirect($LANG['computers'][48], true);
             }
             if (($CFG_GLPI["is_user_autoupdate"]
                  && $comp->fields['users_id'] != $item->getField('users_id'))
@@ -172,7 +185,7 @@ class Computer_Item extends CommonDBRelation{
                if ($CFG_GLPI["is_group_autoupdate"]) {
                   $updates['groups_id'] = $comp->fields['groups_id'];
                }
-               addMessageAfterRedirect($LANG['computers'][50],true);
+               Session::addMessageAfterRedirect($LANG['computers'][50],true);
             }
 
             if ($CFG_GLPI["is_contact_autoupdate"]
@@ -181,14 +194,14 @@ class Computer_Item extends CommonDBRelation{
 
                $updates['contact']     = addslashes($comp->fields['contact']);
                $updates['contact_num'] = addslashes($comp->fields['contact_num']);
-               addMessageAfterRedirect($LANG['computers'][49], true);
+               Session::addMessageAfterRedirect($LANG['computers'][49], true);
             }
 
             if ($CFG_GLPI["state_autoupdate_mode"]<0
                 && $comp->fields['states_id'] != $item->getField('states_id')) {
 
                $updates['states_id'] = $comp->fields['states_id'];
-               addMessageAfterRedirect($LANG['computers'][56], true);
+               Session::addMessageAfterRedirect($LANG['computers'][56], true);
             }
 
             if ($CFG_GLPI["state_autoupdate_mode"]>0
@@ -218,12 +231,11 @@ class Computer_Item extends CommonDBRelation{
 
       if (!isset($this->input['_no_auto_action'])) {
          //Get the computer name
-         $computer = new Computer;
+         $computer = new Computer();
          $computer->getFromDB($this->fields['computers_id']);
 
          //Get device fields
-         if (class_exists($this->fields['itemtype'])) {
-            $device = new $this->fields['itemtype']();
+         if ($device = getItemForItemtype($this->fields['itemtype'])) {
             if ($device->getFromDB($this->fields['items_id'])) {
 
                if (!$device->getField('is_global')) {
@@ -334,15 +346,15 @@ class Computer_Item extends CommonDBRelation{
    *
    * Print the form for computers or templates connections to printers, screens or peripherals
    *
-   *@param $target
-   *@param $comp Computer object
-   *@param $withtemplate=''  boolean : Template or basic item.
+   * @param $comp Computer object
+   * @param $withtemplate=''  boolean : Template or basic item.
    *
-   *@return Nothing (call to classes members)
+   * @return Nothing (call to classes members)
    **/
-   static function showForComputer($target, Computer $comp, $withtemplate='') {
+   static function showForComputer(Computer $comp, $withtemplate='') {
       global $DB, $CFG_GLPI, $LANG;
 
+      $target = $comp->getFormURL();
       $ID = $comp->fields['id'];
       $canedit = $comp->can($ID,'w');
 
@@ -410,20 +422,20 @@ class Computer_Item extends CommonDBRelation{
                   $connID = $DB->result($data['result'], $i, "id");
 
                   $item->getFromDB($tID);
-                  $used[] = $tID;
+                  $used[$tID] = $tID;
 
                   echo "<tr ".($item->isDeleted()?"class='tab_bg_2_2'":"").">";
-                  echo "<td class='center'><strong>".$item->getLink()."</strong>";
+                  echo "<td class='center'><span class='b'>".$item->getLink()."</span>";
                   echo " - ".Dropdown::getDropdownName("glpi_states", $item->getField('state'));
                   echo "</td><td>".$item->getField('serial');
                   echo "</td><td>".$item->getField('otherserial');
                   echo "</td><td>";
                   if ($canedit && (empty($withtemplate) || $withtemplate != 2)) {
-                     echo "<td class='center'>";
+                     echo "<td class='center b'>";
                      echo "<a href=\"".$CFG_GLPI["root_doc"].
                             "/front/computer.form.php?computers_id=$ID&amp;id=$connID&amp;" .
                             "disconnect=1&amp;withtemplate=".$withtemplate."\">";
-                     echo "<strong>".$LANG['buttons'][10]."</strong></a></td>";
+                     echo $LANG['buttons'][10]."</a></td>";
                   }
                   echo "</tr>";
                }
@@ -478,13 +490,14 @@ class Computer_Item extends CommonDBRelation{
 
 
    /**
-   * Prints a direct connection to a computer
-   *
-   * @param $item the Monitor/Phone/Peripheral/Printer
-   *
-   * @return nothing (print out a table)
-   */
-   static function showForItem(CommonDBTM $item) {
+    * Prints a direct connection to a computer
+    *
+    * @param $item the Monitor/Phone/Peripheral/Printer
+    * @param $withtemplate integer : withtemplate param
+    *
+    * @return nothing (print out a table)
+   **/
+   static function showForItem(CommonDBTM $item, $withtemplate='') {
       // Prints a direct connection to a computer
       global $DB, $LANG;
 
@@ -501,11 +514,11 @@ class Computer_Item extends CommonDBRelation{
       // Is global connection ?
       $global=$item->getField('is_global');
 
-      $used = array();
+      $used    = array();
       $compids = array();
-      $crit = array('FIELDS'   => array('id', 'computers_id'),
-                    'itemtype' => $item->getType(),
-                    'items_id' => $ID);
+      $crit    = array('FIELDS'   => array('id', 'computers_id'),
+                       'itemtype' => $item->getType(),
+                       'items_id' => $ID);
       foreach ($DB->request('glpi_computers_items', $crit) as $data) {
          $compids[$data['id']] = $data['computers_id'];
       }
@@ -516,7 +529,7 @@ class Computer_Item extends CommonDBRelation{
          echo $LANG['connect'][4];
       } else if (count($compids)==1) {
          echo $LANG['connect'][3]."&nbsp;:&nbsp;".count($compids);
-      }else {
+      } else {
          echo $LANG['connect'][2]."&nbsp;:&nbsp;".count($compids);
       }
       echo "</th></tr>";
@@ -533,7 +546,7 @@ class Computer_Item extends CommonDBRelation{
             } else {
                echo "&nbsp;";
             }
-            $used[] = $compid;
+            $used[$compid] = $compid;
          }
 
       } else {
@@ -665,12 +678,64 @@ class Computer_Item extends CommonDBRelation{
                       'entity_restrict' => $entity_restrict,
                       'used'            => $used);
 
-      $default = "<select name='$myname'><option value='0'>".DROPDOWN_EMPTY_VALUE."</option>
+      $default = "<select name='$myname'><option value='0'>".Dropdown::EMPTY_VALUE."</option>
                   </select>\n";
-      ajaxDropdown($use_ajax, "/ajax/dropdownConnect.php", $params, $default, $rand);
+      Ajax::dropdown($use_ajax, "/ajax/dropdownConnect.php", $params, $default, $rand);
 
       return $rand;
    }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      // can exists for Template
+      if ($item->can($item->getField('id'),'r')) {
+         switch ($item->getType()) {
+            case 'Phone' :
+            case 'Printer' :
+            case 'Peripheral' :
+            case 'Monitor' :
+               if (Session::haveRight('computer', 'r')) {
+                  if ($_SESSION['glpishow_count_on_tabs']) {
+                     return self::createTabEntry($LANG['title'][27], self::countForItem($item));
+                  }
+                  return $LANG['title'][27];
+               }
+               break;
+
+            case 'Computer' :
+               if (Session::haveRight('phone', 'r')
+                   || Session::haveRight('printer', 'r')
+                   || Session::haveRight('peripheral', 'r')
+                   || Session::haveRight('monitor', 'r')) {
+                  if ($_SESSION['glpishow_count_on_tabs']) {
+                     return self::createTabEntry($LANG['title'][27], self::countForComputer($item));
+                  }
+                  return $LANG['title'][27];
+               }
+               break;
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      switch ($item->getType()) {
+         case 'Phone' :
+         case 'Printer' :
+         case 'Peripheral' :
+         case 'Monitor' :
+            self::showForItem($item);
+            return true;
+
+         case 'Computer' :
+            self::showForComputer($item);
+            return true;
+      }
+   }
 }
 
 ?>
\ No newline at end of file
