@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_softwarelicense.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: computer_softwarelicense.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -117,7 +117,7 @@ class Computer_SoftwareLicense extends CommonDBRelation {
 
       $softwarelicense_id = $license->getField('id');
 
-      if (!haveRight("software", "r") || !$softwarelicense_id) {
+      if (!Session::haveRight("software", "r") || !$softwarelicense_id) {
          return false;
       }
 
@@ -172,12 +172,12 @@ class Computer_SoftwareLicense extends CommonDBRelation {
 
       $searchID = $license->getField('id');
 
-      if (!haveRight("software", "r") || !$searchID) {
+      if (!Session::haveRight("software", "r") || !$searchID) {
          return false;
       }
 
-      $canedit         = haveRight("software", "w");
-      $canshowcomputer = haveRight("computer", "r");
+      $canedit         = Session::haveRight("software", "w");
+      $canshowcomputer = Session::haveRight("computer", "r");
 
       if (isset($_REQUEST["start"])) {
          $start = $_REQUEST["start"];
@@ -242,7 +242,7 @@ class Computer_SoftwareLicense extends CommonDBRelation {
       }
 
       // Display the pager
-      printAjaxPager($LANG['software'][9], $start, $number);
+      Html::printAjaxPager($LANG['software'][9], $start, $number);
 
       $query = "SELECT `glpi_computers_softwarelicenses`.*,
                        `glpi_computers`.`name` AS compname,
@@ -283,12 +283,12 @@ class Computer_SoftwareLicense extends CommonDBRelation {
       if ($result=$DB->query($query)) {
          if ($data=$DB->fetch_assoc($result)) {
 
-            $soft = new Software;
+            $soft = new Software();
             $soft->getFromDB($license->fields['softwares_id']);
             $showEntity = ($license->isRecursive());
             $title      =$LANG['help'][31] ." = ". $soft->fields["name"]." - " . $data["vername"];
 
-            initNavigateListItems('Computer',$title);
+            Session::initNavigateListItems('Computer', $title);
             $sort_img = "<img src='" . $CFG_GLPI["root_doc"] . "/pics/" .
                         ($order == "DESC" ? "puce-down.png" : "puce-up.png") . "' alt='' title=''>";
             if ($canedit) {
@@ -331,7 +331,7 @@ class Computer_SoftwareLicense extends CommonDBRelation {
             echo "</tr>\n";
 
             do {
-               addToNavigateListItems('Computer',$data["cID"]);
+               Session::addToNavigateListItems('Computer',$data["cID"]);
 
                echo "<tr class='tab_bg_2'>";
                if ($canedit) {
@@ -365,7 +365,7 @@ class Computer_SoftwareLicense extends CommonDBRelation {
             echo "</table>\n";
 
             if ($canedit) {
-               openArrowMassive("softinstall".$rand."",true);
+               Html::openArrowMassives("softinstall".$rand."",true);
                Dropdown::show('SoftwareLicense',
                               array('condition' => "`glpi_softwarelicenses`.`softwares_id`
                                                       = '".$license->fields['softwares_id']."'",
@@ -373,7 +373,7 @@ class Computer_SoftwareLicense extends CommonDBRelation {
 
                echo "&nbsp;<input type='submit' name='move' value=\"".
                      $LANG['buttons'][20]."\" class='submit'>&nbsp;";
-               closeArrowMassive('delete', $LANG['buttons'][6]);
+               Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
 
                echo "</form>";
             }
@@ -444,7 +444,7 @@ class Computer_SoftwareLicense extends CommonDBRelation {
     * @param $oldid ID of the computer to clone
     * @param $newid ID of the computer cloned
    **/
-   function cloneComputer ($oldid, $newid) {
+   function cloneComputer($oldid, $newid) {
       global $DB;
 
       $query = "SELECT *
@@ -460,6 +460,41 @@ class Computer_SoftwareLicense extends CommonDBRelation {
       }
    }
 
+
+  function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      switch ($item->getType()) {
+         case 'SoftwareLicense' :
+            if (!$withtemplate) {
+               $nb = 0;
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  $nb = self::countForLicense($item->getID());
+               }
+               return array(1 => SoftwareLicense::getTypeName(1),
+                            2 => self::createTabEntry(Computer::getTypeName(2), $nb));
+            }
+            break;
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='SoftwareLicense') {
+         switch ($tabnum) {
+            case 1 :
+               self::showForLicenseByEntity($item);
+               break;
+
+            case 2 :
+               self::showForLicense($item);
+               break;
+         }
+      }
+      return true;
+   }
 }
 
 ?>
\ No newline at end of file
