@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_softwareversion.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: computer_softwareversion.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -45,6 +45,16 @@ class Computer_SoftwareVersion extends CommonDBRelation {
    public $items_id_2 = 'softwareversions_id';
 
 
+   static function getTypeName($nb=0) {
+      global $LANG;
+
+      if ($nb>1) {
+         return $LANG['software'][19];
+      }
+      return $LANG['software'][44];
+   }
+
+
    function maybeDeleted() {
       // deleted information duplicate from computers
       return false;
@@ -53,6 +63,12 @@ class Computer_SoftwareVersion extends CommonDBRelation {
 
    function prepareInputForAdd($input) {
 
+      if (!isset($input['computers_id']) || !isset($input['softwareversions_id'])
+         || $input['computers_id']<=0 
+         || $input['softwareversions_id']<=0 ) {
+         return false;
+      }
+
       // Get template and deleted informations from computer
       $computer = new Computer();
       if ($computer->getFromDB($input['computers_id'])) {
@@ -63,7 +79,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
    }
 
 
-   function updateDatasForComputer ($computers_id) {
+   function updateDatasForComputer($computers_id) {
       global $DB;
 
       $comp = new Computer();
@@ -174,12 +190,12 @@ class Computer_SoftwareVersion extends CommonDBRelation {
    private static function showInstallations($searchID, $crit) {
       global $DB, $CFG_GLPI, $LANG;
 
-      if (!haveRight("software", "r") || !$searchID) {
+      if (!Session::haveRight("software", "r") || !$searchID) {
          return false;
       }
 
-      $canedit         = haveRight("software", "w");
-      $canshowcomputer = haveRight("computer", "r");
+      $canedit         = Session::haveRight("software", "w");
+      $canshowcomputer = Session::haveRight("computer", "r");
 
       if (isset($_REQUEST["start"])) {
          $start = $_REQUEST["start"];
@@ -250,7 +266,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       }
 
       // Display the pager
-      printAjaxPager($LANG['software'][19],$start,$number);
+      Html::printAjaxPager($LANG['software'][19],$start,$number);
 
       $query = "SELECT DISTINCT `glpi_computers_softwareversions`.*,
                        `glpi_computers`.`name` AS compname,
@@ -294,15 +310,15 @@ class Computer_SoftwareVersion extends CommonDBRelation {
          if ($data=$DB->fetch_assoc($result)) {
             $softwares_id = $data['sID'];
 
-            $soft       = new Software;
+            $soft       = new Software();
             $showEntity = ($soft->getFromDB($softwares_id) && $soft->isRecursive());
-            $linkUser   = haveRight('user', 'r');
+            $linkUser   = Session::haveRight('user', 'r');
             $title      = $LANG['help'][31] ." = ". $soft->fields["name"];
 
             if ($crit=="id") {
                $title .= " - " . $data["vername"];
             }
-            initNavigateListItems('Computer', $title);
+            Session::initNavigateListItems('Computer', $title);
             $sort_img="<img src='".$CFG_GLPI["root_doc"]."/pics/".
                         ($order == "DESC" ? "puce-down.png" : "puce-up.png") . "' alt='' title=''>";
 
@@ -356,7 +372,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
             echo "</tr>\n";
 
             do {
-               addToNavigateListItems('Computer',$data["cID"]);
+               Session::addToNavigateListItems('Computer',$data["cID"]);
 
                echo "<tr class='tab_bg_2'>";
                if ($canedit) {
@@ -413,12 +429,12 @@ class Computer_SoftwareVersion extends CommonDBRelation {
             echo "</table>\n";
 
             if ($canedit) {
-               openArrowMassive("softinstall".$rand."",true);
+               Html::openArrowMassives("softinstall".$rand."",true);
                SoftwareVersion::dropdown(array('name'         => 'versionID',
                                                'softwares_id' => $softwares_id));
                echo "&nbsp;<input type='submit' name='moveinstalls' value='".
                      $LANG['buttons'][20]."' class='submit'>&nbsp;";
-               closeArrowMassive('deleteinstalls', $LANG['buttons'][6]);
+               Html::closeArrowMassives(array('deleteinstalls' => $LANG['buttons'][6]));
 
                echo "</form>";
             }
@@ -443,7 +459,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
 
       $softwareversions_id = $version->getField('id');
 
-      if (!haveRight("software", "r") || !$softwareversions_id) {
+      if (!Session::haveRight("software", "r") || !$softwareversions_id) {
          return false;
       }
 
@@ -497,13 +513,13 @@ class Computer_SoftwareVersion extends CommonDBRelation {
    static function showForComputer(Computer $comp, $withtemplate = '') {
       global $DB, $CFG_GLPI, $LANG;
 
-      if (!haveRight("software", "r")) {
+      if (!Session::haveRight("software", "r")) {
          return false;
       }
 
       $computers_id = $comp->getField('id');
       $rand         = mt_rand();
-      $canedit      = haveRight("software", "w");
+      $canedit      = Session::haveRight("software", "w");
       $entities_id  = $comp->fields["entities_id"];
 
       $query = "SELECT `glpi_softwares`.`softwarecategories_id`,
@@ -528,7 +544,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
 
       echo "<div class='spaced'><table class='tab_cadre_fixe'>";
 
-      if ((empty ($withtemplate) || $withtemplate != 2) && $canedit) {
+      if ((empty($withtemplate) || $withtemplate != 2) && $canedit) {
          echo "<tr class='tab_bg_1'><td class='center' colspan='3'>";
          echo "<form method='post' action='".
                 $CFG_GLPI["root_doc"]."/front/computer_softwareversion.form.php'>";
@@ -551,22 +567,22 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       echo "<tr><th colspan='5'>";
 
       if ($DB->numrows($result)==1) {
-         echo ucfirst($LANG['software'][16]);
+         echo Toolbox::ucfirst($LANG['software'][16]);
       } else {
-         echo ucfirst($LANG['software'][17]);
+         echo Toolbox::ucfirst($LANG['software'][17]);
       }
       echo "</th></tr>";
 
       $cat = -1;
 
-      initNavigateListItems('Software',
-                            $LANG['help'][25]." = ".(empty($comp->fields["name"])
-                                                     ?"(".$comp->fields["id"].")"
-                                                     :$comp->fields["name"]));
-      initNavigateListItems('SoftwareLicense',
-                            $LANG['help'][25]." = ".(empty($comp->fields["name"])
-                                                     ?"(".$comp->fields["id"].")"
-                                                     :$comp->fields["name"]));
+      Session::initNavigateListItems('Software',
+                                     $LANG['help'][25]." = ".(empty($comp->fields["name"])
+                                                               ?"(".$comp->fields["id"].")"
+                                                               :$comp->fields["name"]));
+      Session::initNavigateListItems('SoftwareLicense',
+                                     $LANG['help'][25]." = ".(empty($comp->fields["name"])
+                                                               ?"(".$comp->fields["id"].")"
+                                                               :$comp->fields["name"]));
 
       $installed = array();
       if ($DB->numrows($result)) {
@@ -577,10 +593,10 @@ class Computer_SoftwareVersion extends CommonDBRelation {
             }
 
             $licids = self::displaySoftsByCategory($data, $computers_id, $withtemplate, $canedit);
-            addToNavigateListItems('Software', $data["softwares_id"]);
+            Session::addToNavigateListItems('Software', $data["softwares_id"]);
 
             foreach ($licids as $licid) {
-               addToNavigateListItems('SoftwareLicense', $licid);
+               Session::addToNavigateListItems('SoftwareLicense', $licid);
                $installed[] = $licid;
             }
          }
@@ -621,7 +637,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
                $cat = false;
             }
             self::displaySoftsByLicense($data, $computers_id, $withtemplate, $canedit);
-            addToNavigateListItems('SoftwareLicense', $data["id"]);
+            Session::addToNavigateListItems('SoftwareLicense', $data["id"]);
          }
          self::displayCategoryFooter(NULL, $rand, $canedit);
       }
@@ -648,12 +664,12 @@ class Computer_SoftwareVersion extends CommonDBRelation {
          echo "</table>";
 
          if ($canedit) {
-            openArrowMassive("lic_form$cat$rand", true);
+            Html::openArrowMassives("lic_form$cat$rand", true);
 
             if (isset($cat)) {
-               closeArrowMassive('massuninstall', $LANG['buttons'][5]);
+               Html::closeArrowMassives(array('massuninstall' => $LANG['buttons'][5]));
             } else {
-               closeArrowMassive('massinstall', $LANG['buttons'][4]);
+               Html::closeArrowMassives(array('massinstall' => $LANG['buttons'][4]));
             }
 
          }
@@ -702,7 +718,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       echo "<a href=\"javascript:showHideDiv('softcat$cat$rand','imgcat$cat','" . GLPI_ROOT .
              "/pics/folder.png','" . GLPI_ROOT . "/pics/folder-open.png');\">";
       echo "<img alt='' name='imgcat$cat' src='".GLPI_ROOT."/pics/folder".
-            (!$display ? '' : "-open") . ".png'>&nbsp;<strong>" . $catname . "</strong>";
+            (!$display ? '' : "-open") . ".png'>&nbsp;<span class='b'>" . $catname . "</span>";
       echo "</a></td></tr>";
 
       echo "<tr class='tab_bg_2'><td colspan='5'>";
@@ -755,7 +771,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
 
          echo " - <a href='" . $CFG_GLPI["root_doc"] . "/front/computer_softwareversion.form.php".
               "?uninstall=uninstall&amp;id=$ID&amp;computers_id=$computers_id'>";
-         echo "<strong>" . $LANG['buttons'][5] . "</strong></a>";
+         echo "<span class='b'>" . $LANG['buttons'][5] . "</span></a>";
       }
       echo "</td><td>";
 
@@ -776,15 +792,16 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       $licids = array();
       foreach ($DB->request($query) as $licdata) {
          $licids[] = $licdata['id'];
-         echo "<strong>". $licdata['name'] . "</strong> -&nbsp;".$licdata['serial']." ";
+         echo "<span class='b'>". $licdata['name'] . "</span> -&nbsp;".$licdata['serial']." ";
          if (!empty($licdata['type'])) {
             echo "(".$licdata['type'].")&nbsp; ";
          }
-         $link_item = getItemTypeFormURL('SoftwareLicense');
+         $link_item = Toolbox::getItemTypeFormURL('SoftwareLicense');
          $link      = $link_item."?id=".$licdata['id'];
-         showToolTip ($LANG['common'][16]."&nbsp;: ".$licdata['name']."<br>". $LANG['common'][19].
-                        "&nbsp;: ".$licdata['serial']."<br>".$licdata['comment'],
-                      array('link' => $link));
+         Html::showToolTip($LANG['common'][16]."&nbsp;: ".$licdata['name']."<br>".
+                              $LANG['common'][19]."&nbsp;: ".$licdata['serial']."<br>".
+                              $licdata['comment'],
+                           array('link' => $link));
          echo "<br>";
       }
 
@@ -818,13 +835,13 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       }
 
       $multiple  = false;
-      $link_item = getItemTypeFormURL('SoftwareLicense');
+      $link_item = Toolbox::getItemTypeFormURL('SoftwareLicense');
       $link      = $link_item."?id=".$data['id'];
 
       echo "<tr class='tab_bg_1'>";
       if ($canedit) {
          echo "<td>";
-         if ((empty ($withtemplate) || $withtemplate != 2)
+         if ((empty($withtemplate) || $withtemplate != 2)
              && $ID>0) {
 
             echo "<input type='checkbox' name='softversion_$ID'>";
@@ -839,22 +856,22 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       echo "<td>" . $data["state"] . "</td>";
 
       echo "<td>" . $data["version"];
-      if ((empty ($withtemplate) || $withtemplate != 2)
+      if ((empty($withtemplate) || $withtemplate != 2)
           && $canedit && $ID>0) {
 
          echo " - <a href='".$CFG_GLPI["root_doc"] ."/front/computer_softwareversion.form.php".
                "?install=install&amp;softwareversions_id=$ID&amp;computers_id=$computers_id'>";
-         echo "<strong>" . $LANG['buttons'][4] . "</strong></a>";
+         echo "<span class='b'>" . $LANG['buttons'][4] . "</span></a>";
       }
 
-      echo "</td></td><td><strong>" . $data["name"] . "</strong> -&nbsp;".$data["serial"]."&nbsp; ";
+      echo "</td></td><td class='b'>" . $data["name"] . " -&nbsp;".$data["serial"]."&nbsp; ";
       if ($data["softwarelicensetypes_id"]) {
          echo " (". Dropdown::getDropdownName("glpi_softwarelicensetypes",
                                               $data["softwarelicensetypes_id"]).")&nbsp; ";
       }
-      showToolTip ($LANG['common'][16]."&nbsp;: ".$data['name']."<br>". $LANG['common'][19].
-                     "&nbsp;: ".$data['serial']."<br>".$data['comment'],
-                   array('link' => $link));
+      Html::showToolTip($LANG['common'][16]."&nbsp;: ".$data['name']."<br>". $LANG['common'][19].
+                           "&nbsp;: ".$data['serial']."<br>".$data['comment'],
+                        array('link' => $link));
       echo "</td></tr>\n";
    }
 
@@ -890,7 +907,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
          $changes[2] = addslashes($soft->fields["name"] . " " . $vers->fields["name"]);
          // Log on Computer history
          Log::history($this->fields['computers_id'], 'Computer', $changes, 0,
-                      HISTORY_INSTALL_SOFTWARE);
+                      Log::HISTORY_INSTALL_SOFTWARE);
       }
       $comp = new Computer();
       if ($comp->getFromDB($this->fields['computers_id'])) {
@@ -899,7 +916,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
          $changes[2] = addslashes($comp->fields["name"]);
          // Log on SoftwareVersion history
          Log::history($this->fields['softwareversions_id'], 'SoftwareVersion', $changes, 0,
-                      HISTORY_INSTALL_SOFTWARE);
+                      Log::HISTORY_INSTALL_SOFTWARE);
       }
    }
 
@@ -935,7 +952,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
          $changes[2] = "";
          // Log on Computer history
          Log::history($this->fields['computers_id'], 'Computer', $changes, 0,
-                      HISTORY_UNINSTALL_SOFTWARE);
+                      Log::HISTORY_UNINSTALL_SOFTWARE);
       }
       $comp = new Computer();
       if ($comp->getFromDB($this->fields['computers_id'])) {
@@ -944,7 +961,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
          $changes[2] = "";
          // Log on SoftwareVersion history
          Log::history($this->fields['softwareversions_id'], 'SoftwareVersion', $changes, 0,
-                      HISTORY_UNINSTALL_SOFTWARE);
+                      Log::HISTORY_UNINSTALL_SOFTWARE);
       }
    }
 
@@ -975,7 +992,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
     * @param $oldid ID of the computer to clone
     * @param $newid ID of the computer cloned
    **/
-   function cloneComputer ($oldid, $newid) {
+   function cloneComputer($oldid, $newid) {
       global $DB;
 
       $query = "SELECT *
@@ -991,6 +1008,70 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       }
    }
 
+
+  function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      switch ($item->getType()) {
+         case 'Software' :
+            if (!$withtemplate) {
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry(self::getTypeName(2),
+                                              self::countForSoftware($item->getID()));
+               }
+               return self::getTypeName(2);
+            }
+            break;
+
+         case 'SoftwareVersion' :
+            if (!$withtemplate) {
+               $nb = 0;
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  $nb = self::countForVersion($item->getID());
+               }
+               return array(1 => SoftwareVersion::getTypeName(1),
+                            2 => self::createTabEntry(self::getTypeName(2), $nb));
+            }
+            break;
+
+         case 'Computer' :
+            // Installation allowed for template
+            if (Session::haveRight("software","r")) {
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry(Software::getTypeName(2),
+                                              countElementsInTable('glpi_computers_softwareversions',
+                                                                   "computers_id = '".$item->getID()."'"));
+               }
+               return Software::getTypeName(2);
+            }
+            break;
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='Software') {
+         self::showForSoftware($item);
+
+      } else if ($item->getType()=='Computer') {
+         self::showForComputer($item, $withtemplate);
+
+      } else if ($item->getType()=='SoftwareVersion') {
+         switch ($tabnum) {
+            case 1 :
+               self::showForVersionByEntity($item);
+               break;
+
+            case 2 :
+               self::showForVersion($item);
+               break;
+         }
+      }
+      return true;
+   }
+
 }
 
 ?>
\ No newline at end of file
