@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: config.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: config.class.php 17985 2012-03-23 08:50:03Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,39 +38,52 @@ if (!defined('GLPI_ROOT')) {
 
 /**
  *  Config class
- */
+**/
 class Config extends CommonDBTM {
 
+   // From CommonGLPI
+   protected $displaylist         = false;
+
    // From CommonDBTM
    public $auto_message_on_action = false;
    public $showdebug              = true;
 
-   static function getTypeName() {
+
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      // No plural
       return $LANG['common'][12];
    }
 
 
+   function canCreate() {
+      return false;
+   }
+
+
+   function canUpdate() {
+      return Session::haveRight('config', 'w');
+   }
+
+
+   function canView() {
+      return Session::haveRight('config', 'r');
+   }
+
+
    function defineTabs($options=array()) {
-      global $LANG;
 
-      $tabs[1] = $LANG['setup'][70];  // Display
-      $tabs[2] = $LANG['setup'][48];    // Prefs
-      $tabs[3] = $LANG['Menu'][38];  // Inventory
-      $tabs[4] = $LANG['title'][24];   // Helpdesk
-      $tabs[5] = $LANG['setup'][720];  // SysInfo
+      $ong = array();
+      $this->addStandardTab(__CLASS__, $ong, $options);
 
-      if (DBConnection::isDBSlaveActive()) {
-         $tabs[6]  = $LANG['setup'][800];  // Slave
-      }
-
-      return $tabs;
+      return $ong;
    }
 
 
    function showForm($ID, $options=array()) {
 
+      $this->check(1, 'r');
       $this->showTabs($options);
       $this->addDivForTabs();
    }
@@ -89,18 +102,26 @@ class Config extends CommonDBTM {
          if (empty($input["smtp_passwd"])) {
             unset($input["smtp_passwd"]);
          } else {
-            $input["smtp_passwd"] = encrypt(stripslashes($input["smtp_passwd"]), GLPIKEY);
+            $input["smtp_passwd"] = Toolbox::encrypt(stripslashes($input["smtp_passwd"]), GLPIKEY);
          }
       }
 
+      if (isset($input["_blank_smtp_passwd"]) && $input["_blank_smtp_passwd"]) {
+         $input['smtp_passwd'] = '';
+      }
+
       if (isset($input["proxy_passwd"])) {
          if (empty($input["proxy_passwd"])) {
             unset($input["proxy_passwd"]);
          } else {
-            $input["proxy_passwd"] = encrypt(stripslashes($input["proxy_passwd"]), GLPIKEY);
+            $input["proxy_passwd"] = Toolbox::encrypt(stripslashes($input["proxy_passwd"]), GLPIKEY);
          }
       }
 
+      if (isset($input["_blank_proxy_passwd"]) && $input["_blank_proxy_passwd"]) {
+         $input['proxy_passwd'] = '';
+      }
+
       // Manage DB Slave process
       if (isset($input['_dbslave_status'])) {
          $already_active = DBConnection::isDBSlaveActive();
@@ -164,11 +185,11 @@ class Config extends CommonDBTM {
    function showFormDisplay() {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight("config", "w")) {
+      if (!Session::haveRight("config", "w")) {
          return false;
       }
 
-      echo "<form name='form' action=\"".getItemTypeFormURL(__CLASS__)."\" method='post'>";
+      echo "<form name='form' action=\"".Toolbox::getItemTypeFormURL(__CLASS__)."\" method='post'>";
       echo "<div class='center' id='tabsbody'>";
       echo "<input type='hidden' name='id' value='" . $CFG_GLPI["id"] . "'>";
       echo "<table class='tab_cadre_fixe'>";
@@ -218,8 +239,16 @@ class Config extends CommonDBTM {
       echo "<tr class='tab_bg_2'>";
       echo "<td>" . $LANG['setup'][120] . "&nbsp;:</td><td>";
       Dropdown::showYesNo("use_ajax", $CFG_GLPI["use_ajax"]);
-      echo "</td><td colspan='2'></td>";
-      echo "</tr>";
+      echo "</td>";
+      if ($CFG_GLPI["use_ajax"]) {
+         echo "<td>".$LANG['setup'][119]."&nbsp;:</td><td>";
+         Dropdown::showInteger('ajax_min_textsearch_load', $CFG_GLPI["ajax_min_textsearch_load"],
+                               0, 10, 1);
+      } else {
+         echo "<td colspan='2'>&nbsp;";
+      }
+
+      echo "</td></tr>";
 
       if ($CFG_GLPI["use_ajax"]) {
          echo "<tr class='tab_bg_2'>";
@@ -257,11 +286,11 @@ class Config extends CommonDBTM {
    function showFormInventory() {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight("config", "w")) {
+      if (!Session::haveRight("config", "w")) {
          return false;
       }
 
-      echo "<form name='form' action=\"".getItemTypeFormURL(__CLASS__)."\" method='post'>";
+      echo "<form name='form' action=\"".Toolbox::getItemTypeFormURL(__CLASS__)."\" method='post'>";
       echo "<div class='center' id='tabsbody'>";
       echo "<input type='hidden' name='id' value='" . $CFG_GLPI["id"] . "'>";
       echo "<table class='tab_cadre_fixe'>";
@@ -269,7 +298,7 @@ class Config extends CommonDBTM {
       echo "<tr><th colspan='4'>" . $LANG['Menu'][38] . "</th></tr>";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td> " . $LANG['setup'][133] . "&nbsp;:</td><td>";
+      echo "<td> " . $LANG['ocsconfig'][23] . "&nbsp;:</td><td>";
       Dropdown::showYesNo("use_ocs_mode", $CFG_GLPI["use_ocs_mode"]);
       echo "</td><td> " . $LANG['setup'][271] . "&nbsp;:</td>";
       echo "<td>";
@@ -296,7 +325,7 @@ class Config extends CommonDBTM {
 
       echo "<tr class='tab_bg_2'>";
       echo "<td>" . $LANG['setup'][221] . "&nbsp;:</td><td>";
-      showDateFormItem("date_tax", $CFG_GLPI["date_tax"], false, true, '', '', false);
+      Html::showDateFormItem("date_tax", $CFG_GLPI["date_tax"], false, true, '', '', false);
       echo "</td><td> " . $LANG['setup'][275] . "&nbsp;:</td><td>";
       $this->dropdownGlobalManagement("printers_management_restrict",
                                       $CFG_GLPI["printers_management_restrict"]);
@@ -314,7 +343,7 @@ class Config extends CommonDBTM {
 
       echo "</table>";
 
-      if (haveRight("transfer","w") && isMultiEntitiesMode()) {
+      if (Session::haveRight("transfer","w") && Session::isMultiEntitiesMode()) {
          echo "<br><table class='tab_cadre_fixe'>";
          echo "<tr><th colspan='2'>" . $LANG['setup'][290] . "</th></tr>";
          echo "<tr class='tab_bg_2'>";
@@ -391,11 +420,11 @@ class Config extends CommonDBTM {
    function showFormAuthentication() {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight("config", "w")) {
+      if (!Session::haveRight("config", "w")) {
          return false;
       }
 
-      echo "<form name='form' action=\"".getItemTypeFormURL(__CLASS__)."\" method='post'>";
+      echo "<form name='form' action=\"".Toolbox::getItemTypeFormURL(__CLASS__)."\" method='post'>";
       echo "<div class='center' id='tabsbody'>";
       echo "<input type='hidden' name='id' value='" . $CFG_GLPI["id"] . "'>";
       echo "<table class='tab_cadre_fixe'>";
@@ -433,11 +462,11 @@ class Config extends CommonDBTM {
    function showFormDBSlave() {
       global $DB, $LANG, $CFG_GLPI, $DBSlave;
 
-      if (!haveRight("config", "w")) {
+      if (!Session::haveRight("config", "w")) {
          return false;
       }
 
-      echo "<form name='form' action=\"".getItemTypeFormURL(__CLASS__)."\" method='post'>";
+      echo "<form name='form' action=\"".Toolbox::getItemTypeFormURL(__CLASS__)."\" method='post'>";
       echo "<div class='center' id='tabsbody'>";
       echo "<input type='hidden' name='id' value='" . $CFG_GLPI["id"] . "'>";
       echo "<input type='hidden' name='_dbslave_status' value='1'>";
@@ -469,7 +498,13 @@ class Config extends CommonDBTM {
 
       echo "<tr class='tab_bg_2'>";
       echo "<td>" . $LANG['setup'][804] . "&nbsp;:</td><td>";
-      Dropdown::showYesNo("use_slave_for_search", $CFG_GLPI["use_slave_for_search"]);
+      $values = array(0 => $LANG['setup'][307],    // Never
+                      1 => $LANG['setup'][830],    // If synced (all changes)
+                      2 => $LANG['setup'][831],    // If synced (current user changes)
+                      3 => $LANG['setup'][832],    // If synced or read-only account
+                      4 => $LANG['setup'][805]);   // Always
+      Dropdown::showFromArray('use_slave_for_search', $values,
+                              array('value' => $CFG_GLPI["use_slave_for_search"]));
       echo "<td colspan='2'>&nbsp;</td>";
       echo "</tr>";
 
@@ -496,30 +531,23 @@ class Config extends CommonDBTM {
    function showFormHelpdesk() {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight("config", "w")) {
+      if (!Session::haveRight("config", "w")) {
          return false;
       }
 
-      echo "<form name='form' action=\"".getItemTypeFormURL(__CLASS__)."\" method='post'>";
-      echo "<div class='center' id='tabsbody'>";
+      echo "<form name='form' action=\"".Toolbox::getItemTypeFormURL(__CLASS__)."\" method='post'>";
+      echo "<div class='center spaced' id='tabsbody'>";
       echo "<table class='tab_cadre_fixe'>";
 
       echo "<tr><th colspan='4'>" . $LANG['title'][24] . "</th></tr>";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td>" . $LANG['setup'][612] . "&nbsp;:</td><td>";
-      Dropdown::showYesNo("is_ticket_category_mandatory", $CFG_GLPI["is_ticket_category_mandatory"]);
-      echo "</td><td>" . $LANG['setup'][148] . "&nbsp;:</td><td>";
+      echo "<td>" . $LANG['setup'][148] . "&nbsp;:</td><td>";
       Dropdown::showInteger('time_step', $CFG_GLPI["time_step"], 30, 60, 30, array(5  => 5,
                                                                                    10 => 10,
                                                                                    15 => 15,
                                                                                    20 => 20));
       echo "&nbsp;" . $LANG['job'][22];
-      echo "</td></tr>";
-
-      echo "<tr class='tab_bg_2'>";
-      echo "<td>" . $LANG['setup'][610] . "&nbsp;:</td><td>";
-      Dropdown::showYesNo("is_ticket_title_mandatory", $CFG_GLPI["is_ticket_title_mandatory"]);
       echo "</td><td>" . $LANG['setup'][223] . "&nbsp;:</td><td>";
       Dropdown::showHours('planning_begin', $CFG_GLPI["planning_begin"]);
       echo "&nbsp;->&nbsp;";
@@ -527,31 +555,17 @@ class Config extends CommonDBTM {
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td> " . $LANG['setup'][611] . "&nbsp;:</td><td>";
-      Dropdown::showYesNo("is_ticket_content_mandatory", $CFG_GLPI["is_ticket_content_mandatory"]);
-      echo "</td><td>".$LANG['mailgate'][7] . " (".$LANG['setup'][46].")&nbsp;:</td><td>";
+      echo "<td>".$LANG['mailgate'][7] . " (".$LANG['setup'][46].")&nbsp;:</td><td>";
       MailCollector::showMaxFilesize('default_mailcollector_filesize_max',
                                      $CFG_GLPI["default_mailcollector_filesize_max"]);
-      echo "</td></tr>";
+      echo "</td><td>&nbsp;</td><td>&nbsp;</td></tr>";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td> " . $LANG['setup'][52] . "&nbsp;:</td><td>";
-      $autoassign = array(NO_AUTO_ASSIGN                => $LANG['choice'][0],
-                          AUTO_ASSIGN_HARDWARE_CATEGORY => $LANG['setup'][51],
-                          AUTO_ASSIGN_CATEGORY_HARDWARE => $LANG['setup'][50]);
-      Dropdown::showFromArray('auto_assign_mode', $autoassign,
-                              array('value' => $CFG_GLPI["auto_assign_mode"]));
-      echo "</td><td>" . $LANG['setup'][409] . "&nbsp;:</td><td>";
+      echo "<td>" . $LANG['setup'][409] . "&nbsp;:</td><td>";
       Dropdown::show('DocumentCategory',
                      array('value' => $CFG_GLPI["documentcategories_id_forticket"],
                            'name'  => "documentcategories_id_forticket"));
-      echo "</td></tr>";
-
-      echo "<tr class='tab_bg_2'>";
-      echo "<td>" . $LANG['entity'][18] . "&nbsp;:</td><td>";
-      Dropdown::showInteger('autoclose_delay', $CFG_GLPI['autoclose_delay'], 0, 99, 1,
-                            array(-10 => $LANG['setup'][307]));
-      echo "&nbsp;".$LANG['stats'][31]."</td>";
+      echo "</td>";
       echo "<td>" . $LANG['setup'][608] . "&nbsp;:</td><td>";
       Dropdown::showYesNo("default_software_helpdesk_visible",
                           $CFG_GLPI["default_software_helpdesk_visible"]);
@@ -560,10 +574,17 @@ class Config extends CommonDBTM {
       echo "<tr class='tab_bg_2'>";
       echo "<td>" . $LANG['tracking'][37] . "&nbsp;:</td><td>";
       Dropdown::showYesNo("keep_tickets_on_delete", $CFG_GLPI["keep_tickets_on_delete"]);
-      echo "</td><td>" . $LANG['setup'][219] . "&nbsp;:</td><td>";
+      echo "</td><td colspan='2'>&nbsp;</td>";
+      echo "</tr>";
+
+      echo "<tr class='tab_bg_2'>";
+      echo "<td>" . $LANG['setup'][219] . "&nbsp;:</td><td>";
       Dropdown::showYesNo("use_anonymous_helpdesk", $CFG_GLPI["use_anonymous_helpdesk"]);
+      echo "</td><td>" . $LANG['setup'][220] . "&nbsp;:</td><td>";
+      Dropdown::showYesNo("use_anonymous_followups", $CFG_GLPI["use_anonymous_followups"]);
       echo "</td></tr>";
-      echo "</table><br>";
+
+      echo "</table>";
 
       echo "<table class='tab_cadre_fixe'>";
       echo "<tr><th colspan='7'>" . $LANG['help'][1];
@@ -654,11 +675,11 @@ class Config extends CommonDBTM {
 
       $oncentral = ($_SESSION["glpiactiveprofile"]["interface"]=="central");
       $userpref  = false;
-      $url       = getItemTypeFormURL(__CLASS__);
+      $url       = Toolbox::getItemTypeFormURL(__CLASS__);
 
       if (array_key_exists('last_login',$data)) {
          $userpref = true;
-         if ($data["id"] === getLoginUserID()) {
+         if ($data["id"] === Session::getLoginUserID()) {
             $url      = $CFG_GLPI['root_doc']."/front/preference.php";
          } else {
             $url      = $CFG_GLPI['root_doc']."/front/user.form.php";
@@ -673,7 +694,7 @@ class Config extends CommonDBTM {
       echo "<tr><th colspan='4'>" . $LANG['setup'][6] . "</th></tr>";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td>" . $LANG['setup'][111]."&nbsp;:</td><td>";
+      echo "<td>" . $LANG['setup'][131]."&nbsp;:</td><td>";
       // Limit using global config
       Dropdown::showInteger('list_limit',
                             ($data['list_limit']<$CFG_GLPI['list_limit_max']
@@ -718,12 +739,27 @@ class Config extends CommonDBTM {
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td colspan='2'></td>";
       echo "<td>".$LANG['setup'][7]."&nbsp;:</td><td>";
       $values = array(';' =>';',
                       ',' =>',');
       Dropdown::showFromArray('csv_delimiter', $values, array('value' => $data["csv_delimiter"]));
-      echo "</td></tr>";
+      echo "</td>";
+
+      if (!$userpref || $CFG_GLPI['show_count_on_tabs'] != -1) {
+         echo "<td>".$LANG['setup'][1]."&nbsp;:</td><td>";
+
+         $values = array(0 => $LANG['choice'][0],
+                         1 => $LANG['choice'][1]);
+
+         if (!$userpref) {
+            $values[-1] = $LANG['setup'][307];
+         }
+         Dropdown::showFromArray('show_count_on_tabs', $values, array('value' => $data["show_count_on_tabs"]));
+         echo "</td>";
+      } else {
+         echo "<td colspan='2'>&nbsp;</td>";
+      }
+      echo "</tr>";
 
       echo "<tr class='tab_bg_2'>";
       if ($oncentral) {
@@ -734,7 +770,7 @@ class Config extends CommonDBTM {
          echo "<td colspan='2'></td>";
       }
       echo "<td>" . ($userpref?$LANG['setup'][41]:$LANG['setup'][113]) . "&nbsp;:</td><td>";
-      if (haveRight("config","w") || ! GLPI_DEMO_MODE) {
+      if (Session::haveRight("config","w") || !GLPI_DEMO_MODE) {
          Dropdown::showLanguages("language", array('value' => $data["language"]));
       } else {
          echo "&nbsp;";
@@ -758,6 +794,18 @@ class Config extends CommonDBTM {
                                              'name'  => "default_requesttypes_id"));
          echo "</td></tr>";
 
+         echo "<tr class='tab_bg_2'><td>".$LANG['setup'][12]."&nbsp;:</td><td>";
+         if (!$userpref || Session::haveRight('own_ticket', 1)) {
+            Dropdown::showYesNo("set_default_tech", $data["set_default_tech"]);
+         } else {
+            echo Dropdown::getYesNo(0);
+         }
+         echo "</td><td>" . $LANG['setup'][11] . "&nbsp;:</td><td>";
+         Dropdown::showInteger('refresh_ticket_list', $data["refresh_ticket_list"], 1, 30, 1,
+                               array(0 => $LANG['setup'][307]));
+         echo "&nbsp;".$LANG['job'][22];
+         echo "</td>";
+         echo "</tr>";
          echo "<tr class='tab_bg_2'>";
          echo "<td>" . $LANG['setup'][114] . "&nbsp;:</td>";
          echo "<td colspan='3'>";
@@ -790,6 +838,21 @@ class Config extends CommonDBTM {
          echo "</td></tr>";
       }
 
+      // Only for user
+      if (array_key_exists('personal_token', $data)) {
+         echo "<tr class='tab_bg_1'><th colspan='4'>". $LANG['common'][108] ."</th></tr>";
+
+         echo "<tr class='tab_bg_1'><td>" . $LANG['common'][108] . "&nbsp;:";
+         if (!empty($data["personal_token"])) {
+            echo "<br>(".$LANG['users'][18]."&nbsp;".
+                       Html::convDateTime($data["personal_token_date"]).')';
+         }
+
+         echo "</td><td colspan='3'>";
+         echo "<input type='checkbox' name='_reset_personal_token'>&nbsp;".$LANG['buttons'][61];
+         echo "</td></tr>";
+      }
+
       echo "<tr class='tab_bg_2'>";
       echo "<td colspan='4' class='center'>";
       echo "<input type='submit' name='update' class='submit' value=\"".$LANG['buttons'][2]."\">";
@@ -804,11 +867,11 @@ class Config extends CommonDBTM {
     * Display a HTML report about systeme information / configuration
     *
    **/
-   function showSystemInformations () {
+   function showSystemInformations() {
       global $DB,$LANG,$CFG_GLPI;
 
       echo "<div class='center' id='tabsbody'>";
-      echo "<form name='form' action=\"".getItemTypeFormURL(__CLASS__)."\" method='post'>";
+      echo "<form name='form' action=\"".Toolbox::getItemTypeFormURL(__CLASS__)."\" method='post'>";
       echo "<input type='hidden' name='id' value='" . $CFG_GLPI["id"] . "'>";
 
       echo "<table class='tab_cadre_fixe'>";
@@ -850,7 +913,10 @@ class Config extends CommonDBTM {
       echo "<td>" . $LANG['login'][6] . "&nbsp;:</td>";
       echo "<td><input type='text' name='proxy_user' value='".$CFG_GLPI["proxy_user"]."'></td>";
       echo "<td>" . $LANG['login'][7] . "&nbsp;:</td>";
-      echo "<td><input type='password' name='proxy_passwd' value='' autocomplete='off'></td>";
+      echo "<td><input type='password' name='proxy_passwd' value='' autocomplete='off'>";
+      echo "<br><input type='checkbox' name='_blank_proxy_passwd'>&nbsp;".$LANG['setup'][284];
+
+      echo "</td>";
       echo "</tr>";
 
       echo "<tr class='tab_bg_2'>";
@@ -868,7 +934,7 @@ class Config extends CommonDBTM {
 
       echo "<tr class='tab_bg_1'><td><pre>[code]\n&nbsp;\n";
       $oldlang = $_SESSION['glpilanguage'];
-      loadLanguage('en_GB');
+      Session::loadLanguage('en_GB');
       echo "GLPI ".$CFG_GLPI['version']." (".$CFG_GLPI['root_doc']." => ".
             dirname(dirname($_SERVER["SCRIPT_FILENAME"])).")\n";
 
@@ -878,7 +944,7 @@ class Config extends CommonDBTM {
       echo "<tr><th>" . $LANG['common'][52] . "</th></tr>\n";
 
       echo "<tr class='tab_bg_1'><td><pre>\n&nbsp;\n";
-      echo wordwrap($LANG['setup'][5]."&nbsp;: ".php_uname()."\n", $width, "\n\t");
+      echo wordwrap($LANG['computers'][9]."&nbsp;: ".php_uname()."\n", $width, "\n\t");
       $exts = get_loaded_extensions();
       sort($exts);
       echo wordwrap("PHP ".phpversion()." (".implode(', ',$exts).")\n", $width, "\n\t");
@@ -899,7 +965,7 @@ class Config extends CommonDBTM {
          $msg .= $_SERVER["SERVER_SOFTWARE"];
       }
       if (isset($_SERVER["SERVER_SIGNATURE"])) {
-         $msg .= ' ('.html_clean($_SERVER["SERVER_SIGNATURE"]).')';
+         $msg .= ' ('.Html::clean($_SERVER["SERVER_SIGNATURE"]).')';
       }
       echo wordwrap($msg."\n", $width, "\n\t");
 
@@ -913,14 +979,14 @@ class Config extends CommonDBTM {
       }
       echo "MySQL: $version (".$DB->dbuser."@".$DB->dbhost."/".$DB->dbdefault.")\n\n";
 
-      checkWriteAccessToDirs(true);
+      self::checkWriteAccessToDirs(true);
 
 
       foreach ($CFG_GLPI["systeminformations_types"] as $type) {
-         $tmp = new $type;
+         $tmp = new $type();
          $tmp->showSystemInformations($width);
       }
-      loadLanguage($oldlang);
+      Session::loadLanguage($oldlang);
 
 
 
@@ -1000,7 +1066,7 @@ class Config extends CommonDBTM {
          chdir(GLPI_ROOT);
          $glpidir = str_replace(str_replace('\\', '/',getcwd()),"",str_replace('\\', '/',$currentdir));
          chdir($currentdir);
-         $globaldir = cleanParametersURL($_SERVER['REQUEST_URI']);
+         $globaldir = Html::cleanParametersURL($_SERVER['REQUEST_URI']);
          $globaldir = preg_replace("/\/[0-9a-zA-Z\.\-\_]+\.php/","",$globaldir);
 
          $CFG_GLPI["root_doc"] = str_replace($glpidir,"",$globaldir);
@@ -1031,6 +1097,162 @@ class Config extends CommonDBTM {
       $unicity = new FieldUnicity();
       $unicity->showForm($CFG_GLPI["id"], -1);
    }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      switch ($item->getType()) {
+         case 'Preference' :
+            return $LANG['setup'][6];
+
+         case 'User' :
+            if (Session::haveRight('user','w')
+                && $item->currentUserHaveMoreRightThan($item->getID())) {
+               return $LANG['Menu'][11];
+            }
+            break;
+
+         case __CLASS__ :
+            $tabs[1] = $LANG['setup'][70];   // Display
+            $tabs[2] = $LANG['setup'][48];   // Prefs
+            $tabs[3] = $LANG['Menu'][38];    // Inventory
+            $tabs[4] = $LANG['title'][24];   // Helpdesk
+            $tabs[5] = $LANG['setup'][720];  // SysInfo
+
+            if (DBConnection::isDBSlaveActive()) {
+               $tabs[6]  = $LANG['setup'][800];  // Slave
+            }
+            return $tabs;
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+      global $CFG_GLPI;
+
+      if ($item->getType()=='Preference') {
+         $config = new self();
+         $user = new User();
+         if ($user->getFromDB(Session::getLoginUserID())) {
+            $user->computePreferences();
+            $config->showFormUserPrefs($user->fields);
+         }
+
+      } else if ($item->getType()=='User') {
+         $config = new self();
+         $item->computePreferences();
+         $config->showFormUserPrefs($item->fields);
+
+      } else if($item->getType() == __CLASS__) {
+         switch ($tabnum) {
+            case 1 :
+               $item->showFormDisplay();
+               break;
+
+            case 2 :
+               $item->showFormUserPrefs($CFG_GLPI);
+               break;
+
+            case 3 :
+               $item->showFormInventory();
+               break;
+
+            case 4 :
+               $item->showFormHelpdesk();
+               break;
+
+            case 5 :
+               $item->showSystemInformations();
+               break;
+
+            case 6 :
+               $item->showFormDBSlave();
+               break;
+
+         }
+      }
+      return true;
+   }
+
+
+   /**
+    * Check Write Access to needed directories
+    *
+    * @param $fordebug boolean display for debug
+    *
+    * @return 2 : creation error 1 : delete error 0: OK
+   **/
+   static function checkWriteAccessToDirs($fordebug=false) {
+      global $LANG;
+
+      $dir_to_check = array(GLPI_CONFIG_DIR  => $LANG['install'][23],
+                            GLPI_DOC_DIR     => $LANG['install'][21],
+                            GLPI_DUMP_DIR    => $LANG['install'][16],
+                            GLPI_SESSION_DIR => $LANG['install'][50],
+                            GLPI_CRON_DIR    => $LANG['install'][52],
+                            GLPI_CACHE_DIR   => $LANG['install'][99],
+                            GLPI_GRAPH_DIR   => $LANG['install'][106]);
+      $error = 0;
+
+      foreach ($dir_to_check as $dir => $message) {
+
+         if (!$fordebug) {
+            echo "<tr class='tab_bg_1'><td class='left b'>".$message."</td>";
+         }
+         $tmperror = Toolbox::testWriteAccessToDirectory($dir);
+
+         $errors = array(4 => $LANG['install'][100],
+                         3 => $LANG['install'][101],
+                         2 => $LANG['install'][17],
+                         1 => $LANG['install'][19]);
+
+         if ($tmperror > 0) {
+            if ($fordebug) {
+               echo "<img src='".GLPI_ROOT."/pics/redbutton.png'> ".$LANG['install'][97]." $dir - ".
+                              $errors[$tmperror]."\n";
+            } else {
+               echo "<td><img src='".GLPI_ROOT."/pics/redbutton.png'><p class='red'>".
+                          $errors[$tmperror]."</p> ".$LANG['install'][97]."'".$dir."'</td></tr>";
+            }
+            $error = 2;
+         } else {
+            if ($fordebug) {
+               echo "<img src='".GLPI_ROOT."/pics/greenbutton.png'>$dir : OK\n";
+            } else {
+               echo "<td><img src='".GLPI_ROOT."/pics/greenbutton.png' alt=\"".$LANG['install'][20].
+                           "\" title=\"".$LANG['install'][20]."\"></td></tr>";
+            }
+         }
+      }
+
+      // Only write test for GLPI_LOG as SElinux prevent removing log file.
+      if (!$fordebug) {
+         echo "<tr class='tab_bg_1'><td class='left b'>".$LANG['install'][53]."</td>";
+      }
+
+      if (error_log("Test\n", 3, GLPI_LOG_DIR."/php-errors.log")) {
+         if ($fordebug) {
+            echo "<img src='".GLPI_ROOT."/pics/greenbutton.png'>".GLPI_LOG_DIR." : OK\n";
+         } else {
+            echo "<td><img src='".GLPI_ROOT."/pics/greenbutton.png' alt=\"".$LANG['install'][22].
+                       "\" title=\"".$LANG['install'][22]."\"></td></tr>";
+         }
+
+      } else {
+         if ($fordebug) {
+            echo "<img src='".GLPI_ROOT."/pics/orangebutton.png'>".$LANG['install'][97]." : ".
+                           GLPI_LOG_DIR."\n";
+         } else {
+            echo "<td><img src='".GLPI_ROOT."/pics/orangebutton.png'>".
+                      "<p class='red'>".$LANG['install'][19]."</p>".
+                      $LANG['install'][97]."'".GLPI_LOG_DIR."'</td></tr>";
+         }
+         $error = 1;
+      }
+      return $error;
+   }
 }
 
-?>
+?>
\ No newline at end of file
