@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: consumable.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: consumable.class.php 18047 2012-03-27 12:35:45Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -49,20 +49,23 @@ class Consumable extends CommonDBTM {
    var $no_form_page = false;
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>0) {
+         return $LANG['Menu'][32];
+      }
       return $LANG['consumables'][0];
    }
 
 
    function canCreate() {
-      return haveRight('consumable', 'w');
+      return Session::haveRight('consumable', 'w');
    }
 
 
    function canView() {
-      return haveRight('consumable', 'r');
+      return Session::haveRight('consumable', 'r');
    }
 
 
@@ -117,21 +120,25 @@ class Consumable extends CommonDBTM {
     * UnLink the consumable identified by $ID
     *
     *@param $ID : consumable identifier
-    *@param $users_id : ID of the user giving the consumable
+    *@param $itemtype : itemtype of who we give the consumabl
+    *@param $items_id : ID of the item giving the consumable
     *
     *@return boolean
     *
     **/
-   function out($ID, $users_id=0) {
+   function out($ID, $itemtype='', $items_id=0) {
       global $DB;
 
-      $query = "UPDATE `".$this->getTable()."`
-                SET `date_out` = '".date("Y-m-d")."',
-                    `users_id` = '$users_id'
-                WHERE `id` = '$ID'";
+      if (!empty($itemtype) && $items_id > 0) {
+         $query = "UPDATE `".$this->getTable()."`
+                   SET `date_out` = '".date("Y-m-d")."',
+                       `itemtype` = '$itemtype',
+                       `items_id` = '$items_id'
+                   WHERE `id` = '$ID'";
 
-      if ($result = $DB->query($query)) {
-         return true;
+         if ($result = $DB->query($query)) {
+            return true;
+         }
       }
       return false;
    }
@@ -324,7 +331,7 @@ class Consumable extends CommonDBTM {
          return $LANG['consumables'][20];
 
       } else if (self::isOld($cID)) {
-         return $LANG['consumables'][22];
+         return $LANG['consumables'][21];
       }
    }
 
@@ -365,12 +372,12 @@ class Consumable extends CommonDBTM {
    /**
     * Print out the consumables of a defined type
     *
-    *@param $consitem oject of ConsumableItem class
+    *@param $consitem object of ConsumableItem class
     *@param $show_old boolean : show old consumables or not.
     *
     *@return Nothing (displays)
     **/
-   static function showForItem (ConsumableItem $consitem, $show_old=0) {
+   static function showForConsumableItem(ConsumableItem $consitem, $show_old=0) {
       global $DB, $CFG_GLPI, $LANG;
 
       $tID = $consitem->getField('id');
@@ -390,40 +397,40 @@ class Consumable extends CommonDBTM {
          }
          echo "<div class='spaced'><table class='tab_cadre_fixe'>";
          if (!$show_old) {
-            echo "<tr><th colspan='7'>";
+            echo "<tr><th colspan=".($canedit?'6':'4').">";
             echo self::getCount($tID, -1);
             echo "</th></tr>";
          } else { // Old
-            echo "<tr><th colspan='8'>".$LANG['consumables'][35]."</th></tr>";
+            echo "<tr><th colspan='".($canedit?'8':'6')."'>".$LANG['consumables'][35]."</th></tr>";
          }
          $i = 0;
          echo "<tr><th>".$LANG['common'][2]."</th><th>".$LANG['consumables'][23]."</th>";
-         echo "<th>".$LANG['cartridges'][24]."</th><th>".$LANG['consumables'][26]."</th>";
+         echo "<th>".$LANG['cartridges'][24]."</th>";
          if ($show_old) {
-            echo "<th>".$LANG['common'][34]."</th>";
+            echo "<th>".$LANG['consumables'][26]."</th>";
+            echo "<th>".$LANG['consumables'][31]."</th>";
          }
-         echo "<th>".$LANG['financial'][3]."</th>";
+         echo "<th width='200px'>".$LANG['financial'][3]."</th>";
 
-         if (!$show_old && $canedit && $DB->result($result,0,0)!=0) {
-            echo "<th>";
-            User::dropdown(array('value'  => $consitem->fields["entities_id"],
-                                 'right'  => 'all'));
-            echo "&nbsp;<input type='submit' class='submit' name='give' value='".
-                           $LANG['consumables'][32]."'>";
-            echo "</th>";
-         } else {
-            echo "<th>&nbsp;</th>";
-         }
          if ($canedit) {
-            echo "<th>&nbsp;</th>";
+            if (!$show_old && $DB->result($result,0,0)!=0) {
+               echo "<th>";
+   
+               Dropdown::showAllItems("items_id", 0, 0,$consitem->fields["entities_id"],
+                                    $CFG_GLPI["consumables_types"]);
+   
+               echo "&nbsp;<input type='submit' class='submit' name='give' value='".
+                              $LANG['consumables'][32]."'>";
+               echo "</th><th>".$LANG['rulesengine'][7]."</th>";
+            } else {
+               echo "<th colspan='2'>".$LANG['rulesengine'][7]."</th>";
+            }
          }
          echo "</tr>";
 
       }
 
       $where     = "";
-      $leftjoin  = "";
-      $addselect = "";
       if (!$show_old) { // NEW
          $where = " AND `date_out` IS NULL
                   ORDER BY `date_in`, `id`";
@@ -432,56 +439,51 @@ class Consumable extends CommonDBTM {
                   ORDER BY `date_out` DESC,
                            `date_in`,
                            `id`";
-         $leftjoin  = " LEFT JOIN `glpi_users` ON (`glpi_users`.`id` = `glpi_consumables`.`users_id`) ";
-         $addselect = ", `glpi_users`.`realname` AS REALNAME,
-                        `glpi_users`.`firstname` AS FIRSTNAME,
-                        `glpi_users`.`id` AS USERID,
-                        `glpi_users`.`name` AS USERNAME ";
       }
       $query = "SELECT `glpi_consumables`.*
-                       $addselect
                 FROM `glpi_consumables`
-                $leftjoin
                 WHERE `consumableitems_id` = '$tID'
                       $where";
 
       if ($result = $DB->query($query)) {
          $number = $DB->numrows($result);
          while ($data=$DB->fetch_array($result)) {
-            $date_in  = convDate($data["date_in"]);
-            $date_out = convDate($data["date_out"]);
+            $date_in  = Html::convDate($data["date_in"]);
+            $date_out = Html::convDate($data["date_out"]);
 
             echo "<tr class='tab_bg_1'><td class='center'>".$data["id"]."</td>";
             echo "<td class='center'>".self::getStatus($data["id"])."</td>";
             echo "<td class='center'>".$date_in."</td>";
-            echo "<td class='center'>".$date_out."</td>";
-
             if ($show_old) {
+               echo "<td class='center'>".$date_out."</td>";
                echo "<td class='center'>";
-               echo formatUserName($data["USERID"], $data["USERNAME"], $data["REALNAME"], $data["FIRSTNAME"]);
+               $item = new $data['itemtype']();
+               if ($item->getFromDB($data['items_id'])) {
+                  echo $item->getLink();
+               }
                echo "</td>";
             }
             echo "<td class='center'>";
             Infocom::showDisplayLink('Consumable', $data["id"],1);
             echo "</td>";
 
-            if (!$show_old && $canedit) {
+            if ($canedit) {
                echo "<td class='center'>";
-               echo "<input type='checkbox' name='out[".$data["id"]."]'>";
+               if (!$show_old) {
+                  echo "<input type='checkbox' name='out[".$data["id"]."]'>";
+               } else {
+                  echo "<a href='".
+                        $CFG_GLPI["root_doc"]."/front/consumable.form.php?restore=restore&amp;id=".
+                        $data["id"]."&amp;tID=$tID'>".$LANG['consumables'][37]."</a>";
+               }
                echo "</td>";
-            }
-            if ($show_old && $canedit) {
                echo "<td class='center'>";
                echo "<a href='".
-                      $CFG_GLPI["root_doc"]."/front/consumable.form.php?restore=restore&amp;id=".
-                      $data["id"]."&amp;tID=$tID'>".$LANG['consumables'][37]."</a>";
+                     $CFG_GLPI["root_doc"]."/front/consumable.form.php?delete=delete&amp;id=".
+                     $data["id"]."&amp;tID=$tID'><img title=\"".$LANG['buttons'][6]."\" alt=\"".$LANG['buttons'][6]."\" src='".$CFG_GLPI["root_doc"]."/pics/delete.png'></a>";
                echo "</td>";
             }
-            echo "<td class='center'>";
-            echo "<a href='".
-                   $CFG_GLPI["root_doc"]."/front/consumable.form.php?delete=delete&amp;id=".
-                   $data["id"]."&amp;tID=$tID'>".$LANG['buttons'][6]."</a>";
-            echo "</td></tr>";
+            echo "</tr>";
          }
       }
       echo "</table></div>";
@@ -498,24 +500,24 @@ class Consumable extends CommonDBTM {
    static function showSummary() {
       global $DB, $LANG;
 
-      if (!haveRight("consumable","r")) {
+      if (!Session::haveRight("consumable","r")) {
          return false;
       }
 
-      $query = "SELECT COUNT(*) AS COUNT, `consumableitems_id`, `users_id`
+      $query = "SELECT COUNT(*) AS COUNT, `consumableitems_id`, `itemtype`, `items_id`
                 FROM `glpi_consumables`
                 WHERE `date_out` IS NOT NULL
                       AND `consumableitems_id` IN (SELECT `id`
                                                    FROM `glpi_consumableitems`
                                                    ".getEntitiesRestrictRequest("WHERE",
                                                                            "glpi_consumableitems").")
-                GROUP BY `users_id`, `consumableitems_id`";
+                GROUP BY `itemtype`, `items_id`, `consumableitems_id`";
       $used = array();
 
       if ($result=$DB->query($query)) {
          if ($DB->numrows($result)) {
             while ($data=$DB->fetch_array($result)) {
-               $used[$data["users_id"]][$data["consumableitems_id"]] = $data["COUNT"];
+               $used[$data['itemtype'].'####'.$data['items_id']][$data["consumableitems_id"]] = $data["COUNT"];
             }
          }
       }
@@ -556,7 +558,7 @@ class Consumable extends CommonDBTM {
          echo "<div class='center'><table class='tab_cadrehov'><tr>";
 
          // Type
-         echo "<th>".$LANG['common'][34]."</th>";
+         echo "<th>".$LANG['consumables'][31]."</th>";
 
          foreach ($types as $key => $type) {
             echo "<th>$type</th>";
@@ -579,8 +581,14 @@ class Consumable extends CommonDBTM {
          echo "<td class='center'>".$tot."</td>";
          echo "</tr>";
 
-         foreach ($used as $users_id => $val) {
-            echo "<tr class='tab_bg_2'><td>".getUserName($users_id)."</td>";
+         foreach ($used as $itemtype_items_id => $val) {
+            echo "<tr class='tab_bg_2'><td>";
+            list($itemtype,$items_id) = explode('####',$itemtype_items_id);
+            $item = new $itemtype();
+            if ($item->getFromDB($items_id)) {
+               echo $item->getTypeName().' - '.$item->getNameID();
+            }
+            echo "</td>";
             $tot = 0;
             foreach ($types as $id_type => $type) {
                if (!isset($val[$id_type])) {
@@ -607,6 +615,43 @@ class Consumable extends CommonDBTM {
          echo "<div class='center b'>".$LANG['consumables'][7]."</div>";
       }
    }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate && Session::haveRight("consumable","r")) {
+         switch ($item->getType()) {
+            case 'ConsumableItem' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['Menu'][32], self::countForConsumableItem($item));
+               }
+               return $LANG['Menu'][32];
+         }
+      }
+      return '';
+   }
+
+
+   static function countForConsumableItem(ConsumableItem $item) {
+
+      $restrict = "`glpi_consumables`.`consumableitems_id` = '".$item->getField('id') ."'";
+
+      return countElementsInTable(array('glpi_consumables'), $restrict);
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+         switch ($item->getType()) {
+            case 'ConsumableItem' :
+               self::showAddForm($item);
+               self::showForConsumableItem($item);
+               self::showForConsumableItem($item, 1);
+               return true;
+         }
+   }
+
 }
 
 ?>
\ No newline at end of file
