@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contact.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: contact.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -44,19 +44,22 @@ class Contact extends CommonDBTM{
    // From CommonDBTM
    public $dohistory = true;
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['Menu'][22];
+      }
       return $LANG['common'][92];
    }
 
 
    function canCreate() {
-      return haveRight('contact_enterprise', 'w');
+      return Session::haveRight('contact_enterprise', 'w');
    }
 
    function canView() {
-      return haveRight('contact_enterprise', 'r');
+      return Session::haveRight('contact_enterprise', 'r');
    }
 
 
@@ -71,25 +74,11 @@ class Contact extends CommonDBTM{
       global $LANG;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         $ong[1] = $LANG['Menu'][23];
-
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-
-         if (haveRight("link","r")) {
-            $ong[7] = $LANG['title'][34];
-         }
-
-         if (haveRight("notes","r")) {
-            $ong[10] = $LANG['title'][37];
-         }
-         $ong[12] = $LANG['title'][38];
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('Contact_Supplier', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
       return $ong;
    }
@@ -153,13 +142,9 @@ class Contact extends CommonDBTM{
     *
     * @return Nothing (display)
    **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
-      if (!haveRight("contact_enterprise","r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -173,7 +158,7 @@ class Contact extends CommonDBTM{
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][48]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
       echo "<td rowspan='7' class='middle right'>".$LANG['common'][25]."&nbsp;: </td>";
       echo "<td class='center middle' rowspan='7'>";
@@ -183,37 +168,37 @@ class Contact extends CommonDBTM{
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][43]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "firstname");
+      Html::autocompletionTextField($this, "firstname");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['help'][35]."&nbsp;: </td>";
       echo "<td>";
-      autocompletionTextField($this, "phone");
+      Html::autocompletionTextField($this, "phone");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['help'][35]." 2&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "phone2");
+      Html::autocompletionTextField($this, "phone2");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][42]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "mobile");
+      Html::autocompletionTextField($this, "mobile");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][30]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "fax");
+      Html::autocompletionTextField($this, "fax");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['setup'][14]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "email");
+      Html::autocompletionTextField($this, "email");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -382,11 +367,11 @@ class Contact extends CommonDBTM{
 
       $used = array();
       if ($number>0) {
-         initNavigateListItems('Supplier', $LANG['common'][92]." = ".$this->fields['name']);
+         Session::initNavigateListItems('Supplier', $LANG['common'][92]." = ".$this->fields['name']);
 
          while ($data= $DB->fetch_array($result)) {
             $ID = $data["id"];
-            addToNavigateListItems('Supplier', $data["entID"]);
+            Session::addToNavigateListItems('Supplier', $data["entID"]);
             $used[$data["entID"]] = $data["entID"];
             $website              = $data["website"];
 
@@ -414,7 +399,8 @@ class Contact extends CommonDBTM{
 
             if ($canedit) {
                echo "<a href='".$CFG_GLPI["root_doc"]."/front/contact.form.php?deletecontactsupplier=1".
-                     "&amp;id=$ID&amp;contacts_id=$instID'><strong>".$LANG['buttons'][6]."</strong></a>";
+                     "&amp;id=$ID&amp;contacts_id=$instID'>
+                     <span class='b'>".$LANG['buttons'][6]."</span></a>";
             } else {
                echo "&nbsp;";
             }
@@ -484,7 +470,7 @@ class Contact extends CommonDBTM{
       $filename = $vcard->getFileName();      // "xxx xxx.vcf"
 
       @Header("Content-Disposition: attachment; filename=\"$filename\"");
-      @Header("Content-Length: ".utf8_strlen($output));
+      @Header("Content-Length: ".Toolbox::strlen($output));
       @Header("Connection: close");
       @Header("content-type: text/x-vcard; charset=UTF-8");
 
