@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contract.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: contract.class.php 17231 2012-01-27 10:06:40Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -44,27 +44,31 @@ class Contract extends CommonDBTM {
    // From CommonDBTM
    public $dohistory = true;
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['Menu'][25];
+      }
       return $LANG['financial'][1];
    }
 
 
    function canCreate() {
-      return haveRight('contract', 'w');
+      return Session::haveRight('contract', 'w');
    }
 
 
    function canView() {
-      return haveRight('contract', 'r');
+      return Session::haveRight('contract', 'r');
    }
 
 
-   function post_getEmpty () {
-      global $CFG_GLPI;
+   function post_getEmpty() {
 
-      $this->fields["alert"] = $CFG_GLPI["default_contract_alert"];
+      $this->fields["alert"] = EntityData::getUsedConfig("use_contracts_alert",
+                                                         $this->fields["entities_id"],
+                                                         "default_contract_alert", 0);
    }
 
 
@@ -82,23 +86,13 @@ class Contract extends CommonDBTM {
       global $LANG;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         $ong[1] = $LANG['Menu'][23];
-         $ong[2] = $LANG['common'][96];
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-         if (haveRight("link","r")) {
-            $ong[7] = $LANG['title'][34];
-         }
-         if (haveRight("notes","r")) {
-            $ong[10] = $LANG['title'][37];
-         }
-         $ong[12] = $LANG['title'][38];
+      $this->addStandardTab('Contract_Supplier', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
       return $ong;
    }
 
@@ -143,13 +137,8 @@ class Contract extends CommonDBTM {
    *@return boolean item found
    *
    **/
-   function showForm ($ID,$options=array()) {
+   function showForm($ID,$options=array()) {
       global $LANG;
-      // Show Contract or blank form
-
-      if (!haveRight("contract","r")) {
-         return false;
-      }
 
       if ($ID > 0) {
          $this->check($ID,'r');
@@ -165,7 +154,7 @@ class Contract extends CommonDBTM {
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;:</td><td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
       echo "<td>".$LANG['financial'][6]."&nbsp;:</td><td >";
       Dropdown::show('ContractType', array('value' => $this->fields["contracttypes_id"]));
@@ -174,17 +163,17 @@ class Contract extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][4]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "num");
+      Html::autocompletionTextField($this, "num");
       echo "</td>";
       echo "<td colspan='2'></td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][5]."&nbsp;:</td><td>";
-      echo "<input type='text' name='cost' value='".formatNumber($this->fields["cost"], true).
+      echo "<input type='text' name='cost' value='".Html::formatNumber($this->fields["cost"], true).
             "' size='14'></td>";
       echo "<td>".$LANG['search'][8]."&nbsp;:</td>";
       echo "<td>";
-      showDateFormItem("begin_date", $this->fields["begin_date"]);
+      Html::showDateFormItem("begin_date", $this->fields["begin_date"]);
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -192,17 +181,18 @@ class Contract extends CommonDBTM {
       Dropdown::showInteger("duration", $this->fields["duration"], 0, 120);
       echo " ".$LANG['financial'][57];
       if (!empty($this->fields["begin_date"])) {
-         echo " -> ".getWarrantyExpir($this->fields["begin_date"], $this->fields["duration"]);
+         echo " -> ".Infocom::getWarrantyExpir($this->fields["begin_date"],
+                                               $this->fields["duration"]);
       }
       echo "</td>";
       echo "<td>".$LANG['financial'][13]."&nbsp;:</td><td>";
-      autocompletionTextField($this, "accounting_number");
+      Html::autocompletionTextField($this, "accounting_number");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][69]."&nbsp;:</td><td>";
       Dropdown::showInteger("periodicity", $this->fields["periodicity"], 12, 60, 12,
-                            array(0 => DROPDOWN_EMPTY_VALUE,
+                            array(0 => Dropdown::EMPTY_VALUE,
                                   1 => "1",
                                   2 => "2",
                                   3 => "3",
@@ -213,8 +203,8 @@ class Contract extends CommonDBTM {
       Dropdown::showInteger("notice", $this->fields["notice"], 0, 120);
       echo " ".$LANG['financial'][57];
       if (!empty($this->fields["begin_date"]) && $this->fields["notice"]>0) {
-         echo " -> ".getWarrantyExpir($this->fields["begin_date"], $this->fields["duration"],
-                                      $this->fields["notice"]);
+         echo " -> ".Infocom::getWarrantyExpir($this->fields["begin_date"],
+                                               $this->fields["duration"], $this->fields["notice"]);
       }
       echo "</td></tr>";
 
@@ -224,7 +214,7 @@ class Contract extends CommonDBTM {
       echo "<td>".$LANG['financial'][11]."&nbsp;:</td>";
       echo "<td>";
       Dropdown::showInteger("billing", $this->fields["billing"], 12, 60, 12,
-                            array(0 => DROPDOWN_EMPTY_VALUE,
+                            array(0 => Dropdown::EMPTY_VALUE,
                                   1 => "1",
                                   2 => "2",
                                   3 => "3",
@@ -285,7 +275,7 @@ class Contract extends CommonDBTM {
    }
 
 
-   static function getSearchOptionsToAdd () {
+   static function getSearchOptionsToAdd() {
       global $LANG;
 
       $tab = array();
@@ -299,7 +289,7 @@ class Contract extends CommonDBTM {
       $tab[139]['field']         = 'count';
       $tab[139]['name']          = $LANG['tracking'][29]." ".$LANG['financial'][1];
       $tab[139]['forcegroupby']  = true;
-      $tab[139]['usehaving']  = true;
+      $tab[139]['usehaving']     = true;
       $tab[139]['datatype']      = 'number';
       $tab[139]['massiveaction'] = false;
       $tab[139]['joinparams']    = array('jointype' => 'itemtype_item');
@@ -544,7 +534,7 @@ class Contract extends CommonDBTM {
    static function showCentral() {
       global $DB,$CFG_GLPI, $LANG;
 
-      if (!haveRight("contract","r")) {
+      if (!Session::haveRight("contract","r")) {
          return false;
       }
 
@@ -670,7 +660,7 @@ class Contract extends CommonDBTM {
 
       $instID = $this->fields['id'];
 
-      if (!$this->can($instID,'r') || !haveRight("contact_enterprise","r")) {
+      if (!$this->can($instID,'r') || !Session::haveRight("contact_enterprise","r")) {
          return false;
       }
       $canedit = $this->can($instID,'w');
@@ -742,7 +732,7 @@ class Contract extends CommonDBTM {
          if ($canedit) {
             echo "<a href='".$CFG_GLPI["root_doc"].
                   "/front/contract.form.php?deletecontractsupplier=1&amp;id=$ID&amp;contracts_id=".
-                  $instID."'><img src='".$CFG_GLPI["root_doc"]."/pics/delete2.png' alt='".
+                  $instID."'><img src='".$CFG_GLPI["root_doc"]."/pics/delete.png' alt='".
                   $LANG['buttons'][6]."'></a>";
          } else {
             echo "&nbsp;";
@@ -832,10 +822,9 @@ class Contract extends CommonDBTM {
       $totalnb = 0;
       for ($i=0 ; $i<$number ; $i++) {
          $itemtype = $DB->result($result, $i, "itemtype");
-         if (!class_exists($itemtype)) {
+         if (!($item = getItemForItemtype($itemtype))) {
             continue;
          }
-         $item = new $itemtype();
          if ($item->canView()) {
             $itemtable = getTableForItemType($itemtype);
             $query = "SELECT `$itemtable`.*,
@@ -868,7 +857,7 @@ class Contract extends CommonDBTM {
                }
                echo "<td class='center'>".$item->getTypeName()."&nbsp;:&nbsp;$nb</td>";
                echo "<td class='center' colspan='2'>";
-               echo "<a href='". getItemTypeSearchURL($itemtype) . "?" .
+               echo "<a href='". Toolbox::getItemTypeSearchURL($itemtype) . "?" .
                      rawurlencode("contains[0]") . "=" . rawurlencode('$$$$'.$instID) . "&amp;" .
                      rawurlencode("field[0]") . "=29&amp;sort=80&amp;order=ASC&amp;is_deleted=0".
                      "&amp;start=0". "'>" . $LANG['reports'][57]."</a></td>";
@@ -880,7 +869,7 @@ class Contract extends CommonDBTM {
                   if ($_SESSION["glpiis_ids_visible"] || empty($data["name"])) {
                      $ID = " (".$data["id"].")";
                   }
-                  $link = getItemTypeFormURL($itemtype);
+                  $link = Toolbox::getItemTypeFormURL($itemtype);
                   $name = "<a href=\"".$link."?id=".$data["id"]."\">".$data["name"]."$ID</a>";
 
                   echo "<tr class='tab_bg_1'>";
@@ -920,13 +909,13 @@ class Contract extends CommonDBTM {
       echo "<tr class='tab_bg_2'>";
       echo "<td class='center' colspan='2'>".($totalnb>0? $LANG['common'][33].
              "&nbsp;=&nbsp;$totalnb</td>" : "&nbsp;</td>");
-      echo "<td colspan='4'>&nbsp;</td></tr> ";
+      echo "<td colspan='5'>&nbsp;</td></tr> ";
 
       if ($canedit) {
          if ($this->fields['max_links_allowed']==0
              || $this->fields['max_links_allowed'] > $totalnb) {
 
-            echo "<tr class='tab_bg_1'><td colspan='4' class='right'>";
+            echo "<tr class='tab_bg_1'><td colspan='5' class='right'>";
             Dropdown::showAllItems("items_id", 0, 0,
                                    ($this->fields['is_recursive']?-1:$this->fields['entities_id']),
                                    $CFG_GLPI["contract_types"]);
@@ -937,9 +926,9 @@ class Contract extends CommonDBTM {
          }
          echo "</table>";
 
-         openArrowMassive("contract_form$rand", true);
+         Html::openArrowMassives("contract_form$rand", true);
          echo "<input type='hidden' name='contracts_id' value='$instID'>";
-         closeArrowMassive('deleteitem', $LANG['buttons'][6]);
+         Html::closeArrowMassives(array('deleteitem' => $LANG['buttons'][6]));
 
       } else {
          echo "</table>";
@@ -985,7 +974,7 @@ class Contract extends CommonDBTM {
       $itemtype = $item->getType();
       $ID = $item->fields['id'];
 
-      if (!haveRight("contract","r") || !$item->can($ID,"r")) {
+      if (!Session::haveRight("contract","r") || !$item->can($ID,"r")) {
          return false;
       }
 
@@ -1034,34 +1023,35 @@ class Contract extends CommonDBTM {
       echo "</tr>";
 
       if ($number>0) {
-         initNavigateListItems('Contract', $item->getTypeName()." = ".$item->getName());
+         Session::initNavigateListItems('Contract', $item->getTypeName()." = ".$item->getName());
       }
       $contracts = array();
       while ($i < $number) {
          $cID = $DB->result($result, $i, "contracts_id");
-         addToNavigateListItems('Contract',$cID);
+         Session::addToNavigateListItems('Contract',$cID);
          $contracts[] = $cID;
          $assocID = $DB->result($result, $i, "id");
-         $con = new Contract;
+         $con = new Contract();
          $con->getFromDB($cID);
          echo "<tr class='tab_bg_1".($con->fields["is_deleted"]?"_2":"")."'>";
-         echo "<td class='center'>";
-         echo "<a href='".$CFG_GLPI["root_doc"]."/front/contract.form.php?id=$cID'>";
-         echo "<strong>".$con->fields["name"];
+         echo "<td class='center b'>";
+         echo "<a href='".$CFG_GLPI["root_doc"]."/front/contract.form.php?id=$cID'>".
+                $con->fields["name"];
          if ($_SESSION["glpiis_ids_visible"] || empty($con->fields["name"])) {
             echo " (".$con->fields["id"].")";
          }
-         echo "</strong></a></td>";
+         echo "</a></td>";
          echo "<td class='center'>";
          echo Dropdown::getDropdownName("glpi_entities", $con->fields["entities_id"])."</td>";
          echo "<td class='center'>".$con->fields["num"]."</td>";
          echo "<td class='center'>";
          echo Dropdown::getDropdownName("glpi_contracttypes", $con->fields["contracttypes_id"])."</td>";
          echo "<td class='center'>".$con->getSuppliersNames()."</td>";
-         echo "<td class='center'>".convDate($con->fields["begin_date"])."</td>";
+         echo "<td class='center'>".Html::convDate($con->fields["begin_date"])."</td>";
          echo "<td class='center'>".$con->fields["duration"]." ".$LANG['financial'][57];
          if ($con->fields["begin_date"]!='' && !empty($con->fields["begin_date"])) {
-            echo " -> ".getWarrantyExpir($con->fields["begin_date"], $con->fields["duration"]);
+            echo " -> ".Infocom::getWarrantyExpir($con->fields["begin_date"],
+                                                  $con->fields["duration"]);
          }
          echo "</td>";
 
@@ -1070,7 +1060,7 @@ class Contract extends CommonDBTM {
             if ($canedit) {
                echo "<a href='".$CFG_GLPI["root_doc"].
                      "/front/contract.form.php?deleteitem=deleteitem&amp;id=$assocID&amp;contracts_id=$cID'>";
-               echo "<img src='".$CFG_GLPI["root_doc"]."/pics/delete2.png' alt='".
+               echo "<img src='".$CFG_GLPI["root_doc"]."/pics/delete.png' alt='".
                      $LANG['buttons'][6]."'></a>";
             } else {
                echo "&nbsp;";
@@ -1185,9 +1175,9 @@ class Contract extends CommonDBTM {
          foreach ($querys as $type => $query) {
             foreach ($DB->request($query) as $data) {
                $entity = $data['entities_id'];
-               $message = $data["name"].": ".getWarrantyExpir($data["begin_date"],
-                                                              $data["duration"],
-                                                              $data["notice"])."<br>\n";
+               $message = $data["name"].": ".Infocom::getWarrantyExpir($data["begin_date"],
+                                                                       $data["duration"],
+                                                                       $data["notice"])."<br>\n";
                $contract_infos[$type][$entity][$data['id']] = $data;
 
                 if (!isset($contract_messages[$type][$entity])) {
@@ -1211,8 +1201,9 @@ class Contract extends CommonDBTM {
                                                        $entity).":  $message\n");
                   $task->addVolume(1);
                } else {
-                  addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
-                                                                    $entity).":  $message");
+                  Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                             $entity).
+                                                   ":  $message");
                }
 
                $alert = new Alert();
@@ -1230,8 +1221,10 @@ class Contract extends CommonDBTM {
                   $task->log(Dropdown::getDropdownName("glpi_entities", $entity).
                              ":  Send contract alert failed\n");
                } else {
-                  addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity).
-                                          ":  Send contract alert failed", false, ERROR);
+                  Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                             $entity)
+                                                      .":  Send contract alert failed",
+                                                   false, ERROR);
                }
             }
          }
@@ -1309,7 +1302,7 @@ class Contract extends CommonDBTM {
          }
          echo "<option selected value='".$p['value']."'>".$output."</option>";
       } else {
-         echo "<option value='-1'>".DROPDOWN_EMPTY_VALUE."</option>";
+         echo "<option value='-1'>".Dropdown::EMPTY_VALUE."</option>";
       }
       $prev = -1;
       while ($data=$DB->fetch_array($result)) {
@@ -1330,8 +1323,9 @@ class Contract extends CommonDBTM {
             }
 
             echo "<option  value='".$data["id"]."'>";
-            echo utf8_substr($data["name"]." - #".$data["num"]." - ".
-                             convDateTime($data["begin_date"]),0,$_SESSION["glpidropdown_chars_limit"]);
+            echo Toolbox::substr($data["name"]." - #".$data["num"]." - ".
+                                 Html::convDateTime($data["begin_date"]), 0,
+                                                    $_SESSION["glpidropdown_chars_limit"]);
             echo "</option>";
          }
       }
@@ -1411,14 +1405,36 @@ class Contract extends CommonDBTM {
     * @param $value default value
    **/
    static function dropdownAlert($myname, $value) {
+
+      Dropdown::showFromArray($myname, self::getAlertName(), array('value' => $value));
+   }
+
+
+   /**
+    * Get the possible value for contract alert
+    *
+    * @since version 0.83
+    *
+    * @param $val if not set, ask for all values, else for 1 value
+    *
+    * @return array or string
+    */
+   static function getAlertName($val=NULL) {
       global $LANG;
 
-      $tmp[0]                     = DROPDOWN_EMPTY_VALUE;
+      $tmp[0]                     = Dropdown::EMPTY_VALUE;
       $tmp[pow(2, Alert::END)]    = $LANG['buttons'][32];
       $tmp[pow(2, Alert::NOTICE)] = $LANG['financial'][10];
       $tmp[(pow(2, Alert::END)+pow(2, Alert::NOTICE))]
                                   = $LANG['buttons'][32]." + ". $LANG['financial'][10];
-      Dropdown::showFromArray($myname, $tmp, array('value' => $value));
+
+      if (is_null($val)) {
+         return $tmp;
+      }
+      if (isset($tmp[$val])) {
+         return $tmp[$val];
+      }
+      return NOT_AVAILABLE;
    }
 
 
@@ -1442,4 +1458,4 @@ class Contract extends CommonDBTM {
    }
 
 }
-?>
\ No newline at end of file
+?>
