@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: crontask.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: crontask.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -55,10 +55,13 @@ class CronTask extends CommonDBTM{
    /**
     * Name of the type
    **/
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['crontask'][0];
+      if ($nb>1) {
+         return $LANG['crontask'][0];
+      }
+      return $LANG['log'][59];
    }
 
 
@@ -66,20 +69,19 @@ class CronTask extends CommonDBTM{
       global $LANG;
 
       $ong = array();
-      $ong[1] = $LANG['Menu'][13]; // Stat
-      $ong[2] = $LANG['Menu'][30]; // Logs
+      $this->addStandardTab('CronTaskLog', $ong, $options);
 
       return $ong;
    }
 
 
    function canCreate() {
-      return haveRight('config', 'w');
+      return Session::haveRight('config', 'w');
    }
 
 
    function canView() {
-      return haveRight('config', 'r');
+      return Session::haveRight('config', 'r');
    }
 
 
@@ -137,7 +139,7 @@ class CronTask extends CommonDBTM{
     *    if disable : 1: by config, 2: by system lock, 3: by plugin
     *
    **/
-   function isDisabled () {
+   function isDisabled() {
 
       if ($this->fields['state']==self::STATE_DISABLE) {
          return 1;
@@ -276,7 +278,7 @@ class CronTask extends CommonDBTM{
          return false;
       }
       $log     = new CronTaskLog();
-      $content = utf8_substr($content, 0, 200);
+      $content = Toolbox::substr($content, 0, 200);
       return $log->add(array('crontasks_id'    => $this->fields['id'],
                              'date'            => $_SESSION['glpi_currenttime'],
                              'content'         => addslashes($content),
@@ -379,10 +381,10 @@ class CronTask extends CommonDBTM{
     *
     * @return Nothing (display)
    **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
-      if (!haveRight("config","r") || !$this->getFromDB($ID)) {
+      if (!Session::haveRight("config","r") || !$this->getFromDB($ID)) {
          return false;
       }
 
@@ -413,20 +415,20 @@ class CronTask extends CommonDBTM{
       echo "<tr class='tab_bg_1'><td>".$LANG['joblist'][0]."&nbsp;:&nbsp;</td><td>";
       if (is_file(GLPI_CRON_DIR. '/'.$this->fields["name"].'.lock')
           || is_file(GLPI_CRON_DIR. '/all.lock')) {
-         echo "<strong>" . $LANG['crontask'][60]."</strong><br>";
+         echo "<span class='b'>" . $LANG['crontask'][60]."</span><br>";
          $tmpstate = self::STATE_DISABLE;
       }
 
       if ($isplug) {
          $plug = new Plugin();
          if (!$plug->isActivated($isplug["plugin"])) {
-            echo "<strong>" . $LANG['crontask'][61]."</strong><br>";
+            echo "<span class='b'>" . $LANG['crontask'][61]."</span><br>";
             $tmpstate = self::STATE_DISABLE;
          }
       }
 
       if ($this->fields["state"]==self::STATE_RUNNING) {
-         echo "<strong>" . $this->getStateName(self::STATE_RUNNING)."</strong>";
+         echo "<span class='b'>" . $this->getStateName(self::STATE_RUNNING)."</span>";
       } else {
          self::dropdownState('state', $this->fields["state"]);
       }
@@ -435,10 +437,10 @@ class CronTask extends CommonDBTM{
       echo "<tr class='tab_bg_1'><td>".$LANG['crontask'][36]."&nbsp;:&nbsp;</td><td>";
       $modes = array();
       if ($this->fields['allowmode']&self::MODE_INTERNAL) {
-         $modes[self::MODE_INTERNAL] = $this->getModeName(self::MODE_INTERNAL);
+         $modes[self::MODE_INTERNAL] = self::getModeName(self::MODE_INTERNAL);
       }
       if ($this->fields['allowmode']&self::MODE_EXTERNAL) {
-         $modes[self::MODE_EXTERNAL] = $this->getModeName(self::MODE_EXTERNAL);
+         $modes[self::MODE_EXTERNAL] = self::getModeName(self::MODE_EXTERNAL);
       }
       Dropdown::showFromArray('mode', $modes, array('value' => $this->fields['mode']));
       echo "</td></tr>";
@@ -451,13 +453,14 @@ class CronTask extends CommonDBTM{
 
       echo "<tr class='tab_bg_1'><td>".$LANG['setup'][130]."&nbsp;:&nbsp;</td><td>";
       Dropdown::showInteger('logs_lifetime', $this->fields['logs_lifetime'], 10, 360, 10,
-                            array(0 => $LANG['setup'][200]), array('suffix' => $LANG['stats'][31]));
+                            array(0 => $LANG['setup'][200]),
+                            array('suffix' => Toolbox::ucfirst($LANG['calendar'][12])));
       echo "</td><td>".$LANG['crontask'][40]."&nbsp;:&nbsp;</td><td>";
 
       if (empty($this->fields['lastrun'])) {
          echo $LANG['setup'][307];
       } else {
-         echo convDateTime($this->fields['lastrun']);
+         echo Html::convDateTime($this->fields['lastrun']);
          echo " <a href='".$this->getFormURL()."?id=$ID&amp;resetdate=1'>";
          echo "<img src='".GLPI_ROOT."/pics/reset.png' alt=\"".$LANG['buttons'][16]."\" title=\"".
                 $LANG['buttons'][16]."\"></a>";
@@ -508,9 +511,9 @@ class CronTask extends CommonDBTM{
          }
 
          if ($next<time()) {
-            echo $LANG['crontask'][42].' ('.convDateTime($disp).') ';
+            echo $LANG['crontask'][42].' ('.Html::convDateTime($disp).') ';
          } else {
-            echo convDateTime($disp);
+            echo Html::convDateTime($disp);
          }
       }
 
@@ -724,8 +727,14 @@ class CronTask extends CommonDBTM{
     * @return the name of last task launched
    **/
    static public function launch($mode, $max=1, $name='') {
+      global $LANG;
 
       $taskname = '';
+      //If cron is launched in command line, and if memory is insufficient, display a warning in
+      //the logs
+      if ($mode==self::MODE_EXTERNAL && Toolbox::checkMemoryLimit() == 2) {
+         Toolbox::logDebug($LANG['install'][88]);
+      }
 
       if (self::get_lock()) {
          $crontask = new self();
@@ -745,32 +754,32 @@ class CronTask extends CommonDBTM{
                if (is_callable($fonction)) {
                   if ($crontask->start()) { // Lock in DB + log start
                      $taskname = $crontask->fields['name'];
-                     logInFile('cron', $prefix."Launch ".$crontask->fields['name']."\n");
+                     Toolbox::logInFile('cron', $prefix."Launch ".$crontask->fields['name']."\n");
                      $retcode = call_user_func($fonction, $crontask);
                      $crontask->end($retcode); // Unlock in DB + log end
                   } else {
-                     logInFile('cron', $prefix."Can't start ".$crontask->fields['name']."\n");
+                     Toolbox::logInFile('cron', $prefix."Can't start ".$crontask->fields['name']."\n");
                   }
 
                } else {
                   if (is_array($fonction)) {
                      $fonction = implode('::',$fonction);
                   }
-                  logInFile('php-errors', "Undefined function '$fonction' (for cron)\n");
-                  logInFile('cron',
+                  Toolbox::logInFile('php-errors', "Undefined function '$fonction' (for cron)\n");
+                  Toolbox::logInFile('cron',
                             $prefix."Can't start ".$crontask->fields['name'].
                               "\nUndefined function '$fonction'\n");
                }
 
             } else if ($i==1) {
-               logInFile('cron', $prefix."Nothing to launch\n");
+               Toolbox::logInFile('cron', $prefix."Nothing to launch\n");
             }
          } // end for
          $_SESSION["glpicronuserrunning"]='';
          self::release_lock();
 
       } else {
-         logInFile('cron', "Can't get DB lock'\n");
+         Toolbox::logInFile('cron', "Can't get DB lock'\n");
       }
 
       return $taskname;
@@ -794,17 +803,21 @@ class CronTask extends CommonDBTM{
       if (!isPluginItemType($itemtype)) {
          return false;
       }
+      $temp = new self();
+      // Avoid duplicate entry
+      if ($temp->getFromDBbyName($itemtype, $name)) {
+         return false;
+      }
       $input = array('itemtype'  => $itemtype,
                      'name'      => $name,
                      'frequency' => $frequency);
 
       foreach (array('allowmode', 'comment', 'hourmax', 'hourmin', 'logs_lifetime', 'mode',
                      'param', 'state') as $key) {
-         if (isset ($options[$key])) {
+         if (isset($options[$key])) {
             $input[$key] = $options[$key];
          }
       }
-      $temp = new CronTask();
       return $temp->add($input);
    }
 
@@ -887,7 +900,7 @@ class CronTask extends CommonDBTM{
 
          if ($data = $DB->fetch_assoc($result)) {
             echo "<tr class='tab_bg_1'><td>".$LANG['search'][8]."&nbsp;:&nbsp;</td>";
-            echo "<td class='right'>".convDateTime($data['datemin'])."</td></tr>";
+            echo "<td class='right'>".Html::convDateTime($data['datemin'])."</td></tr>";
 
             echo "<tr class='tab_bg_2'><td>".$LANG['crontask'][51]."&nbsp;:&nbsp;</td>";
             echo "<td class='right'>".number_format($data['elapsedmin'],2)." ".$LANG['stats'][34];
@@ -962,7 +975,7 @@ class CronTask extends CommonDBTM{
       }
 
       // Display the pager
-      printAjaxPager($LANG['crontask'][47], $start, $number);
+      Html::printAjaxPager($LANG['crontask'][47], $start, $number);
 
       $query = "SELECT *
                 FROM `glpi_crontasklogs`
@@ -983,7 +996,8 @@ class CronTask extends CommonDBTM{
             do {
                echo "<tr class='tab_bg_2'>";
                echo "<td><a href='javascript:reloadTab(\"crontasklogs_id=".
-                          $data['crontasklogs_id']."\");'>".convDateTime($data['date'])."</a></td>";
+                          $data['crontasklogs_id']."\");'>".Html::convDateTime($data['date']).
+                    "</a></td>";
                echo "<td class='right'>".number_format($data['elapsed'], 3)."s</td>";
                echo "<td class='right'>".$data['volume']."</td>";
                echo "<td>".$data['content']."</td>";
@@ -1033,7 +1047,7 @@ class CronTask extends CommonDBTM{
             $first = true;
             do {
                echo "<tr class='tab_bg_2'>";
-               echo "<td class='center'>".($first ? convDateTime($data['date'])
+               echo "<td class='center'>".($first ? Html::convDateTime($data['date'])
                                                   : "&nbsp;")."</a></td>";
 
                switch ($data['state']) {
@@ -1090,18 +1104,17 @@ class CronTask extends CommonDBTM{
       $tab[3]['name']          = $LANG['joblist'][6];
       $tab[3]['nosearch']      = true;
       $tab[3]['nosort']        = true;
-      $tab[2]['massiveaction'] = false;
+      $tab[3]['massiveaction'] = false;
 
       $tab[4]['table']         = $this->getTable();
       $tab[4]['field']         = 'state';
       $tab[4]['name']          = $LANG['joblist'][0];
-      $tab[4]['massiveaction'] = false;
       $tab[4]['searchtype']    = array('equals');
-
+      $tab[4]['massiveaction'] = false;
+      
       $tab[5]['table']         = $this->getTable();
       $tab[5]['field']         = 'mode';
       $tab[5]['name']          = $LANG['crontask'][36];
-      $tab[5]['massiveaction'] = false;
 
       $tab[6]['table']         = $this->getTable();
       $tab[6]['field']         = 'frequency';
@@ -1220,7 +1233,7 @@ class CronTask extends CommonDBTM{
    **/
    static function cronCheckUpdate($task) {
 
-      $result = checkNewVersionAvailable(1);
+      $result = Toolbox::checkNewVersionAvailable(1);
       $task->log($result);
 
       return 1;
@@ -1235,7 +1248,7 @@ class CronTask extends CommonDBTM{
     **/
    static function cronOptimize($task) {
 
-      $nb = optimize_tables(NULL, true);
+      $nb = DBmysql::optimize_tables(NULL, true);
       $task->setVolume($nb);
 
       return 1;
@@ -1255,7 +1268,7 @@ class CronTask extends CommonDBTM{
       // Crontasks running for more than 1 hour or 2 frequency
       $query = "SELECT *
                 FROM `glpi_crontasks`
-                WHERE `state` = '2'
+                WHERE `state` = '".self::STATE_RUNNING."'
                       AND ((unix_timestamp(`lastrun`) + 2 * `frequency` < unix_timestamp(now()))
                            OR (unix_timestamp(`lastrun`) + 2*".HOUR_TIMESTAMP." < unix_timestamp(now())))";
       $crontasks = array();
@@ -1328,13 +1341,13 @@ class CronTask extends CommonDBTM{
 
       // Heures
       for ($i=1 ; $i<24 ; $i++) {
-         $tab[$i*HOUR_TIMESTAMP] = $i . ' ' .$LANG['job'][21];
+         $tab[$i*HOUR_TIMESTAMP] = $i . ' ' .Toolbox::ucfirst($LANG['gmt'][1]);
       }
 
       // Jours
       $tab[DAY_TIMESTAMP] = $LANG['setup'][305];
       for ($i=2 ; $i<7 ; $i++) {
-         $tab[$i*DAY_TIMESTAMP] = $i . ' ' .$LANG['stats'][31];
+         $tab[$i*DAY_TIMESTAMP] = $i . ' ' .Toolbox::ucfirst($LANG['calendar'][12]);
       }
 
       $tab[WEEK_TIMESTAMP]  = $LANG['setup'][308];
@@ -1343,5 +1356,43 @@ class CronTask extends CommonDBTM{
       Dropdown::showFromArray($name, $tab, array('value' => $value));
    }
 
+
+   /**
+    * Call cron without time check
+    *
+    * @return boolean : true if launched
+   **/
+   static function callCronForce() {
+      global $CFG_GLPI;
+
+      $path = $CFG_GLPI['root_doc']."/front/cron.php";
+
+      echo "<div style=\"background-image: url('$path');\"></div>";
+      return true;
+   }
+
+
+   /**
+    * Call cron if time since last launch elapsed
+    *
+    * @return nothing
+   **/
+   static function callCron() {
+
+      if (isset($_SESSION["glpicrontimer"])) {
+         // call static function callcron() every 5min
+         if ((time()-$_SESSION["glpicrontimer"])>300) {
+
+            if (self::callCronForce()) {
+               // Restart timer
+               $_SESSION["glpicrontimer"] = time();
+            }
+         }
+
+      } else {
+         // Start timer
+         $_SESSION["glpicrontimer"] = time();
+      }
+   }
 }
 ?>
