@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: displaypreference.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: displaypreference.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -42,6 +42,8 @@ class DisplayPreference extends CommonDBTM {
    // From CommonDBTM
    var $auto_message_on_action = false;
 
+   protected $displaylist = false;
+
    function prepareInputForAdd($input) {
       global $DB;
 
@@ -63,7 +65,7 @@ class DisplayPreference extends CommonDBTM {
     * @param $itemtype itemtype
     * @param $user_id user ID
    **/
-   static function getForTypeUser ($itemtype, $user_id) {
+   static function getForTypeUser($itemtype, $user_id) {
       global $DB;
 
       // Add default items for user
@@ -102,7 +104,7 @@ class DisplayPreference extends CommonDBTM {
    function activatePerso($input) {
       global $DB;
 
-      if (!haveRight("search_config", "w")) {
+      if (!Session::haveRight("search_config", "w")) {
          return false;
       }
 
@@ -213,11 +215,11 @@ class DisplayPreference extends CommonDBTM {
       }
 
       $item = NULL;
-      if ($itemtype!='States' && class_exists($itemtype)) {
-         $item = new $itemtype();
+      if ($itemtype!='States') {
+         $item = getItemForItemtype($itemtype);
       }
 
-      $IDuser = getLoginUserID();
+      $IDuser = Session::getLoginUserID();
 
       echo "<div class='center' id='tabsbody' >";
       // Defined items
@@ -231,7 +233,7 @@ class DisplayPreference extends CommonDBTM {
       $numrows = $DB->numrows($result);
 
       if ($numrows==0) {
-         checkRight("search_config", "w");
+         Session::checkRight("search_config", "w");
          echo "<table class='tab_cadre_fixe'><tr><th colspan='4'>";
          echo "<form method='post' action='$target'>";
          echo "<input type='hidden' name='itemtype' value='$itemtype'>";
@@ -282,7 +284,7 @@ class DisplayPreference extends CommonDBTM {
 
 
          // print entity
-         if (isMultiEntitiesMode()
+         if (Session::isMultiEntitiesMode()
              && (isset($CFG_GLPI["union_search_type"][$itemtype])
                  || ($item && $item->maybeRecursive())
                  || count($_SESSION["glpiactiveentities"])>1)
@@ -370,11 +372,11 @@ class DisplayPreference extends CommonDBTM {
       $IDuser = 0;
 
       $item = NULL;
-      if ($itemtype!='States' && class_exists($itemtype)) {
-         $item = new $itemtype();
+      if ($itemtype!='States') {
+         $item = getItemForItemtype($itemtype);
       }
 
-      $global_write = haveRight("search_config_global", "w");
+      $global_write = Session::haveRight("search_config_global", "w");
 
       echo "<div class='center' id='tabsbody' >";
       // Defined items
@@ -434,7 +436,7 @@ class DisplayPreference extends CommonDBTM {
       echo "</td></tr>";
 
       // print entity
-      if (isMultiEntitiesMode()
+      if (Session::isMultiEntitiesMode()
           && (isset($CFG_GLPI["union_search_type"][$itemtype])
               || ($item && $item->maybeRecursive())
               || count($_SESSION["glpiactiveentities"])>1)
@@ -511,19 +513,21 @@ class DisplayPreference extends CommonDBTM {
       echo "</div>";
    }
 
+
    /**
     * show defined display preferences for a user
     *
     * @param $users_id integer user ID
-    */
+   **/
    static function showForUser($users_id) {
       global $DB, $LANG;
 
-      $url = getItemTypeFormURL(__CLASS__);
+      $url = Toolbox::getItemTypeFormURL(__CLASS__);
 
-      $query = "SELECT `itemtype`, COUNT(*) as nb
+      $query = "SELECT `itemtype`,
+                       COUNT(*) AS nb
                 FROM `glpi_displaypreferences`
-                WHERE `users_id`='$users_id'
+                WHERE `users_id` = '$users_id'
                 GROUP BY `itemtype`";
 
       $req = $DB->request($query);
@@ -535,8 +539,7 @@ class DisplayPreference extends CommonDBTM {
          foreach ($req as $data) {
             echo "<tr class='tab_bg_1'><td width='10'>";
             echo "<input  type='checkbox' name='itemtype[".$data["itemtype"]."]' value='1'></td>";
-            if (class_exists($data["itemtype"])) {
-               $item = new $data["itemtype"];
+            if ($item = getItemForItemtype($data["itemtype"])) {
                $name = $item->getTypeName();
             } else {
                $name = $data["itemtype"];
@@ -545,15 +548,82 @@ class DisplayPreference extends CommonDBTM {
             echo "</tr>";
          }
          echo "</table>";
-         openArrowMassive('formprefs', true);
-         closeArrowMassive('delete_for_user', $LANG['buttons'][6]);
+         Html::openArrowMassives('formprefs', true);
+         Html::closeArrowMassives(array('delete_for_user' => $LANG['buttons'][6]));
          echo "</form>";
+
       } else {
          echo "<table class='tab_cadre_fixe'>";
          echo "<tr class='tab_bg_2'><td class='b center'>".$LANG['search'][15]."</td></tr>";
          echo "</table>";
       }
    }
+
+
+   /**
+    * For tab management : force isNewItem
+    *
+    * @since version 0.83
+   **/
+   function isNewItem() {
+      return false;
+   }
+
+
+   function defineTabs($options=array()) {
+      global $LANG;
+
+      $ong = array();
+      $this->addStandardTab(__CLASS__, $ong, $options);
+      $ong['no_all_tab'] = true;
+      return $ong;
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      switch ($item->getType()) {
+         case 'Preference' :
+            if (Session::haveRight('search_config', 'w')) {
+               return $LANG['central'][12];
+            }
+            break;
+
+         case __CLASS__:
+            $ong = array();
+            $ong[1] = $LANG['central'][13];  // view group
+            if (Session::haveRight('search_config', 'w')) {
+               $ong[2] = $LANG['central'][12]; // view personnal
+            }
+            return $ong;
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+      global $CFG_GLPI;
+
+      switch ($item->getType()) {
+         case 'Preference' :
+            self::showForUser(Session::getLoginUserID());
+            return true;
+
+         case __CLASS__ :
+            switch ($tabnum) {
+               case 1 :
+                  $item->showFormGlobal($_POST['target'], $_POST["displaytype"]);
+                  return true;
+
+               case 2 :
+                  Session::checkRight('search_config', 'w');
+                  $item->showFormPerso($_POST['target'], $_POST["displaytype"]);
+                  return true;
+            }
+      }
+      return false;
+   }
 }
 
 ?>
