@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: document.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: document.class.php 17176 2012-01-24 16:35:17Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -44,27 +44,32 @@ class Document extends CommonDBTM {
    // From CommonDBTM
    public $dohistory = true;
 
-   static function getTypeName() {
+   protected $forward_entity_to = array('Document_Item');
+
+
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['Menu'][27];
+      if ($nb>1) {
+         return $LANG['Menu'][27];
+      }
+      return $LANG['document'][18];
    }
 
 
    function canCreate() {
 
       // Have right to add document OR ticket followup
-      return haveRight('document', 'w') || haveRight('add_followups', '1');
+      return Session::haveRight('document', 'w') || Session::haveRight('add_followups', '1');
    }
 
 
    function canUpdate() {
-      return haveRight('document', 'w');
+      return Session::haveRight('document', 'w');
    }
 
 
    function canCreateItem() {
-      //
       // From Ticket Document Tab => check right to add followup.
       if (isset($this->fields['tickets_id'])
           && $this->fields['tickets_id']>0) {
@@ -74,14 +79,16 @@ class Document extends CommonDBTM {
             return $ticket->canAddFollowups();
          }
       }
-      if (haveRight('document', 'w')) {
+
+      if (Session::haveRight('document', 'w')) {
          return parent::canCreateItem();
       }
       return false;
    }
 
+
    function canView() {
-      return haveRight('document', 'r');
+      return Session::haveRight('document', 'r');
    }
 
 
@@ -99,46 +106,49 @@ class Document extends CommonDBTM {
                                      "`sha1sum`='".$this->fields["sha1sum"]."'")<=1) {
 
             if (unlink(GLPI_DOC_DIR."/".$this->fields["filepath"])) {
-               addMessageAfterRedirect($LANG['document'][24]." ".GLPI_DOC_DIR."/".
-                                       $this->fields["filepath"]);
+               Session::addMessageAfterRedirect($LANG['document'][24]." ".GLPI_DOC_DIR."/".
+                                                $this->fields["filepath"]);
             } else {
-               addMessageAfterRedirect($LANG['document'][25]." ".GLPI_DOC_DIR."/".
-                                       $this->fields["filepath"], false, ERROR);
+               Session::addMessageAfterRedirect($LANG['document'][25]." ".GLPI_DOC_DIR."/".
+                                                $this->fields["filepath"], false, ERROR);
             }
          }
       }
    }
 
 
-   static function addTab(CommonDBTM $item, &$tab) {
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
       global $LANG;
-      $tab[5] = $LANG['Menu'][27];
-      /// TODO first try for
-/*
-      if (haveRight("document","r")) {
-         $nb     = Document_Item::countForItem($item);
-         $tab[5] = $LANG['Menu'][27]." ($nb)";
-      }*/
+
+      // Can exist for template
+      if (Session::haveRight("document","r")
+          || $item->getType()=='Ticket'
+          || $item->getType()=='KnowbaseItem') {
+
+         if ($_SESSION['glpishow_count_on_tabs']) {
+            return self::createTabEntry($LANG['Menu'][27], Document_Item::countForItem($item));
+         }
+         return $LANG['Menu'][27];
+      }
+      return '';
    }
 
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      self::showAssociated($item, $withtemplate);
+      return true;
+   }
+
+
    function defineTabs($options=array()) {
       global $LANG;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         $ong[1] = $LANG['document'][19];
-
-         self::addTab($this,$ong);
-//         $ong[5] = $LANG['document'][20];
-
-         if (haveRight("notes","r")) {
-            $ong[10] = $LANG['title'][37];
-         }
-         $ong[12] = $LANG['title'][38];
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('Document_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
       return $ong;
    }
@@ -150,8 +160,8 @@ class Document extends CommonDBTM {
       // security (don't accept filename from $_POST)
       unset($input['filename']);
 
-      if ($uid=getLoginUserID()) {
-         $input["users_id"] = getLoginUserID();
+      if ($uid=Session::getLoginUserID()) {
+         $input["users_id"] = Session::getLoginUserID();
       }
 
       // Create a doc only selecting a file from a item form
@@ -159,17 +169,17 @@ class Document extends CommonDBTM {
 
       if (isset($input["items_id"])
           && isset($input["itemtype"])
-          && class_exists($input["itemtype"])
+          && ($item = getItemForItemtype($input["itemtype"]))
           && $input["items_id"]>0) {
 
-         $item     = new $input["itemtype"]();
          $typename = $item->getTypeName();
          $name     = NOT_AVAILABLE;
 
          if ($item->getFromDB($input["items_id"])) {
             $name = $item->getNameID();
          }
-         $input["name"] = addslashes(resume_text($LANG['document'][18]." $typename - ".$name, 200));
+         $input["name"] = addslashes(Html::resume_text($LANG['document'][18]." $typename - ".$name,
+                                                       200));
          $create_from_item = true;
       }
 
@@ -210,7 +220,7 @@ class Document extends CommonDBTM {
                        'entities_id'=>$input['entities_id']);
          foreach ($DB->request($this->getTable(), $crit) as $data) {
             $link=$this->getFormURL();
-            addMessageAfterRedirect($LANG['document'][48].
+            Session::addMessageAfterRedirect($LANG['document'][48].
                "&nbsp;: <a href=\"".$link."?id=".
                      $data['id']."\">".$data['name']."</a>",
                false, ERROR, true);
@@ -225,8 +235,9 @@ class Document extends CommonDBTM {
       global $LANG;
 
       if (isset($this->input["items_id"])
-          && $this->input["items_id"] > 0
           && isset($this->input["itemtype"])
+          && ($this->input["items_id"] > 0
+              || ($this->input["items_id"]==0 && $this->input["itemtype"]=='Entity'))
           && !empty($this->input["itemtype"])) {
 
          $docitem = new Document_Item();
@@ -279,13 +290,9 @@ class Document extends CommonDBTM {
     *
     * @return Nothing (display)
    **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI,$LANG;
 
-      if (!haveRight("document","r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -306,14 +313,14 @@ class Document extends CommonDBTM {
          }
          echo "</th>";
          echo "<th colspan='2'>".$LANG['common'][26]."&nbsp;: ".
-               convDateTime($this->fields["date_mod"])."</th>";
+               Html::convDateTime($this->fields["date_mod"])."</th>";
          echo "</tr>\n";
       }
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
       echo "<td rowspan='6' class='middle right'>".$LANG['common'][25]."&nbsp;: </td>";
       echo "<td class='center middle' rowspan='6'>";
@@ -343,7 +350,7 @@ class Document extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['document'][33]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "link");
+      Html::autocompletionTextField($this, "link");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -355,7 +362,7 @@ class Document extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['document'][4]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "mime");
+      Html::autocompletionTextField($this, "mime");
 
       if ($ID>0) {
          echo "</td><td>".$LANG['document'][1]."&nbsp;:</td>";
@@ -376,7 +383,7 @@ class Document extends CommonDBTM {
    static function getMaxUploadSize() {
       global $LANG;
 
-      $max_size  = return_bytes_from_ini_vars(ini_get("upload_max_filesize"));
+      $max_size  = Toolbox::return_bytes_from_ini_vars(ini_get("upload_max_filesize"));
       $max_size /= 1024*1024;
       return round($max_size,1)." ".$LANG['common'][45];
    }
@@ -423,8 +430,8 @@ class Document extends CommonDBTM {
          $fileout = $this->fields['filename'];
       }
 
-      if (utf8_strlen($fileout)>$len) {
-         $fileout = utf8_substr($fileout,0,$len)."&hellip;";
+      if (Toolbox::strlen($fileout)>$len) {
+         $fileout = Toolbox::substr($fileout,0,$len)."&hellip;";
       }
 
       $out = "<a href='".$CFG_GLPI["root_doc"]."/front/document.send.php?docid=".
@@ -447,7 +454,7 @@ class Document extends CommonDBTM {
             }
          }
       }
-      $out .= "<strong>$fileout</strong></a>";
+      $out .= "<span class='b'>$fileout</span></a>";
 
       return $out;
    }
@@ -495,38 +502,53 @@ class Document extends CommonDBTM {
 
       if (isset($_SESSION["glpiactiveprofile"]["interface"])
           && $_SESSION["glpiactiveprofile"]["interface"]=="central") {
-
+         
          // My doc Check and Common doc right access
-         if ($this->can($this->fields["id"],'r') || $this->fields["users_id"]===getLoginUserID()) {
+         if ($this->can($this->fields["id"],'r')
+             || $this->fields["users_id"]===Session::getLoginUserID()) {
+            return true;
+         }
+
+         // Reminder Case
+         $query = "SELECT *
+                   FROM `glpi_documents_items`
+                   LEFT JOIN `glpi_reminders`
+                        ON (`glpi_reminders`.`id` = `glpi_documents_items`.`items_id`
+                            AND `glpi_documents_items`.`itemtype` = 'Reminder')
+                   ".Reminder::addVisibilityJoins()."                            
+                   WHERE `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."'
+                         AND ".Reminder::addVisibilityRestrict();
+         $result = $DB->query($query);
+         if ($DB->numrows($result)>0) {
             return true;
          }
 
          // Knowbase Case
-         if (haveRight("knowbase","r")) {
+         if (Session::haveRight("knowbase","r")) {
             $query = "SELECT *
                       FROM `glpi_documents_items`
                       LEFT JOIN `glpi_knowbaseitems`
-                           ON (`glpi_knowbaseitems`.`id` = `glpi_documents_items`.`items_id`)
-                      WHERE `glpi_documents_items`.`itemtype` = 'KnowbaseItem'
-                            AND `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."'".
-                            getEntitiesRestrictRequest(' AND', 'glpi_knowbaseitems', '', '', true);
-
+                           ON (`glpi_knowbaseitems`.`id` = `glpi_documents_items`.`items_id`
+                               AND `glpi_documents_items`.`itemtype` = 'KnowbaseItem')
+                      ".KnowbaseItem::addVisibilityJoins()."
+                      WHERE `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."' 
+                              AND ".KnowbaseItem::addVisibilityRestrict();
             $result = $DB->query($query);
             if ($DB->numrows($result)>0) {
                return true;
             }
          }
 
-         if (haveRight("faq","r")) {
+         if (Session::haveRight("faq","r")) {
             $query = "SELECT *
                       FROM `glpi_documents_items`
                       LEFT JOIN `glpi_knowbaseitems`
-                           ON (`glpi_knowbaseitems`.`id` = `glpi_documents_items`.`items_id`)
-                      WHERE `glpi_documents_items`.`itemtype` = 'KnowbaseItem'
-                            AND `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."'
-                            AND `glpi_knowbaseitems`.`is_faq` = '1'".
-                            getEntitiesRestrictRequest(' AND', 'glpi_knowbaseitems', '', '', true);
-
+                           ON (`glpi_knowbaseitems`.`id` = `glpi_documents_items`.`items_id`
+                               AND `glpi_documents_items`.`itemtype` = 'KnowbaseItem')
+                      ".KnowbaseItem::addVisibilityJoins()."
+                      WHERE `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."'
+                            AND `glpi_knowbaseitems`.`is_faq` = '1' 
+                            AND ".KnowbaseItem::addVisibilityRestrict();
             $result = $DB->query($query);
             if ($DB->numrows($result)>0) {
                return true;
@@ -535,7 +557,7 @@ class Document extends CommonDBTM {
 
          // Tracking Case
          if (isset($options["tickets_id"])) {
-            $job = new Ticket;
+            $job = new Ticket();
 
             if ($job->can($options["tickets_id"],'r')) {
                $query = "SELECT *
@@ -551,32 +573,48 @@ class Document extends CommonDBTM {
             }
          }
 
-      } else if (getLoginUserID()) { // ! central
-
+      } else if (Session::getLoginUserID()) { // ! central
+         
          // Check if it is my doc
-         if ($this->fields["users_id"]===getLoginUserID()) {
+         if ($this->fields["users_id"]===Session::getLoginUserID()) {
             return true;
          }
-         if (haveRight("faq","r")) {
+         
+         // Reminder Case
+         $query = "SELECT *
+                   FROM `glpi_documents_items`
+                   LEFT JOIN `glpi_reminders`
+                        ON (`glpi_reminders`.`id` = `glpi_documents_items`.`items_id`
+                            AND `glpi_documents_items`.`itemtype` = 'Reminder')
+                   ".Reminder::addVisibilityJoins()."                            
+                   WHERE `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."'
+                         AND ".Reminder::addVisibilityRestrict();
+         $result = $DB->query($query);
+         if ($DB->numrows($result)>0) {
+            return true;
+         }
+                  
+         if (Session::haveRight("faq","r")) {
             // Check if it is a FAQ document
             $query = "SELECT *
                       FROM `glpi_documents_items`
                       LEFT JOIN `glpi_knowbaseitems`
                            ON (`glpi_knowbaseitems`.`id` = `glpi_documents_items`.`items_id`)
+                      ".KnowbaseItem::addVisibilityJoins()."
                       WHERE `glpi_documents_items`.`itemtype` = 'KnowbaseItem'
                             AND `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."'
-                            AND `glpi_knowbaseitems`.`is_faq` = '1'".
-                            getEntitiesRestrictRequest(' AND', 'glpi_knowbaseitems', '', '', true);
-
+                            AND `glpi_knowbaseitems`.`is_faq` = '1'
+                            AND ".KnowbaseItem::addVisibilityRestrict();
+            
             $result = $DB->query($query);
             if ($DB->numrows($result)>0) {
                return true;
             }
          }
-
+         
          // Tracking Case
          if (isset($options["tickets_id"])) {
-            $job = new Ticket;
+            $job = new Ticket();
 
             if ($job->can($options["tickets_id"],'r')) {
                $query = "SELECT *
@@ -599,11 +637,15 @@ class Document extends CommonDBTM {
                    FROM `glpi_documents_items`
                    LEFT JOIN `glpi_knowbaseitems`
                         ON (`glpi_knowbaseitems`.`id` = `glpi_documents_items`.`items_id`)
+                   LEFT JOIN `glpi_entities_knowbaseitems`
+                        ON (`glpi_entities_knowbaseitems`.`knowbaseitems_id`
+                              = `glpi_knowbaseitems`.`id`)
                    WHERE `glpi_documents_items`.`itemtype` = 'KnowbaseItem'
                          AND `glpi_documents_items`.`documents_id` = '".$this->fields["id"]."'
                          AND `glpi_knowbaseitems`.`is_faq` = '1'
-                         AND `glpi_knowbaseitems`.`entities_id` = '0'
-                         AND `glpi_knowbaseitems`.`is_recursive` = '1'";
+                         AND `glpi_entities_knowbaseitems`.`entities_id` = '0'
+                         AND `glpi_entities_knowbaseitems`.`is_recursive` = '1'";
+                         $where = " ";
 
          $result = $DB->query($query);
          if ($DB->numrows($result)>0) {
@@ -755,10 +797,9 @@ class Document extends CommonDBTM {
 
       for ($i=0 ; $i < $number ; $i++) {
          $itemtype=$DB->result($result, $i, "itemtype");
-         if (!class_exists($itemtype)) {
+         if (!($item = getItemForItemtype($itemtype))) {
             continue;
          }
-         $item = new $itemtype();
 
          if ($item->canView()) {
             $column="name";
@@ -766,9 +807,6 @@ class Document extends CommonDBTM {
                $column = "id";
             }
 
-            if ($itemtype == 'KnowbaseItem') {
-               $column = "question";
-            }
             $itemtable = getTableForItemType($itemtype);
             $query = "SELECT `$itemtable`.*,
                              `glpi_documents_items`.`id` AS IDD, ";
@@ -780,6 +818,12 @@ class Document extends CommonDBTM {
                           LEFT JOIN `glpi_entities`
                               ON (`glpi_entities`.`id` = `glpi_documents_items`.`items_id`)
                           WHERE ";
+            } else if ($itemtype == 'KnowbaseItem') {
+               $query .= "-1 AS entity
+                          FROM `glpi_documents_items`, `$itemtable`
+                          ".KnowbaseItem::addVisibilityJoins()."
+                          WHERE `$itemtable`.`id` = `glpi_documents_items`.`items_id`
+                          AND ";
             } else {
                $query .= "`glpi_entities`.`id` AS entity
                           FROM `glpi_documents_items`, `$itemtable`
@@ -789,13 +833,30 @@ class Document extends CommonDBTM {
                           AND ";
             }
             $query .= "`glpi_documents_items`.`itemtype` = '$itemtype'
-                       AND `glpi_documents_items`.`documents_id` = '$instID' ".
-                       getEntitiesRestrictRequest(" AND ",$itemtable,'','',$item->maybeRecursive());
+                       AND `glpi_documents_items`.`documents_id` = '$instID' ";
+            if ($itemtype =='KnowbaseItem') {
+               if (Session::getLoginUserID()) {
+                 $where = "AND ".KnowbaseItem::addVisibilityRestrict();
+               } else {
+                  // Anonymous access
+                  if (Session::isMultiEntitiesMode()) {
+                     $where = " AND (`glpi_entities_knowbaseitems`.`entities_id` = '0'
+                                 AND `glpi_entities_knowbaseitems`.`is_recursive` = '1')";
+                  }
+               }
+            } else {
+               $query.= getEntitiesRestrictRequest(" AND ",$itemtable,'','',$item->maybeRecursive());
+            }
 
             if ($item->maybeTemplate()) {
                $query .= " AND `$itemtable`.`is_template` = '0'";
             }
-            $query .= " ORDER BY `glpi_entities`.`completename`, `$itemtable`.`$column`";
+            
+            if ($itemtype =='KnowbaseItem') {
+               $query .= " ORDER BY `$itemtable`.`$column`";
+            } else {
+               $query .= " ORDER BY `glpi_entities`.`completename`, `$itemtable`.`$column`";
+            }
 
             if ($itemtype == 'SoftwareLicense') {
                $soft = new Software();
@@ -816,10 +877,6 @@ class Document extends CommonDBTM {
                         $data["name"] = $LANG['job'][38]." ".$data["id"];
                      }
 
-                     if ($itemtype == 'KnowbaseItem') {
-                        $data["name"] = $data["question"];
-                     }
-
                      if ($itemtype == 'SoftwareLicense') {
                         $soft->getFromDB($data['softwares_id']);
                         $data["name"] = $data["name"].' - '.$soft->fields['name'];
@@ -829,7 +886,7 @@ class Document extends CommonDBTM {
                         $ID = " (".$data["id"].")";
                      }
 
-                     $link = getItemTypeFormURL($itemtype);
+                     $link = Toolbox::getItemTypeFormURL($itemtype);
                      $name = "<a href=\"".$link."?id=".$data["id"]."\">".$data["name"]."$ID</a>";
 
                      echo "<tr class='tab_bg_1'>";
@@ -875,8 +932,8 @@ class Document extends CommonDBTM {
          echo "</td></tr>";
          echo "</table>";
 
-         openArrowMassive("document_form$rand", true);
-         closeArrowMassive('deletedocumentitem', $LANG['buttons'][6]);
+         Html::openArrowMassives("document_form$rand", true);
+         Html::closeArrowMassives(array('deletedocumentitem' => $LANG['buttons'][6]));
 
       } else {
          echo "</table>";
@@ -923,12 +980,12 @@ class Document extends CommonDBTM {
       $fullpath = GLPI_DOC_DIR."/_uploads/".$filename;
 
       if (!is_dir(GLPI_DOC_DIR."/_uploads")) {
-         addMessageAfterRedirect($LANG['document'][35], false, ERROR);
+         Session::addMessageAfterRedirect($LANG['document'][35], false, ERROR);
          return false;
       }
 
       if (!is_file($fullpath)) {
-         addMessageAfterRedirect($LANG['document'][38]."&nbsp;: ".$fullpath, false, ERROR);
+         Session::addMessageAfterRedirect($LANG['document'][38]."&nbsp;: ".$fullpath, false, ERROR);
          return false;
       }
       $sha1sum  = sha1_file($fullpath);
@@ -947,11 +1004,11 @@ class Document extends CommonDBTM {
                      "`sha1sum`='".sha1_file(GLPI_DOC_DIR."/".$input['current_filepath'])."'")<=1) {
 
          if (unlink(GLPI_DOC_DIR."/".$input['current_filepath'])) {
-            addMessageAfterRedirect($LANG['document'][24]." ".$input['current_filename']);
+            Session::addMessageAfterRedirect($LANG['document'][24]." ".$input['current_filename']);
          } else {
-            addMessageAfterRedirect($LANG['document'][25]." ".$input['current_filename'].
-                                    " (".GLPI_DOC_DIR."/".$input['current_filepath'].")",
-                                    false, ERROR);
+            Session::addMessageAfterRedirect($LANG['document'][25]." ".$input['current_filename'].
+                                              " (".GLPI_DOC_DIR."/".$input['current_filepath'].")",
+                                             false, ERROR);
          }
       }
 
@@ -967,17 +1024,17 @@ class Document extends CommonDBTM {
       if (is_writable(GLPI_DOC_DIR."/_uploads/") && is_writable ($fullpath)) { // Move if allowed
 
          if (self::renameForce($fullpath, GLPI_DOC_DIR."/".$new_path)) {
-            addMessageAfterRedirect($LANG['document'][39]);
+            Session::addMessageAfterRedirect($LANG['document'][39]);
          } else {
-            addMessageAfterRedirect($LANG['document'][40],false,ERROR);
+            Session::addMessageAfterRedirect($LANG['document'][40], false, ERROR);
             return false;
          }
 
       } else { // Copy (will overwrite dest file is present)
          if (copy($fullpath, GLPI_DOC_DIR."/".$new_path)) {
-            addMessageAfterRedirect($LANG['document'][41]);
+            Session::addMessageAfterRedirect($LANG['document'][41]);
          } else {
-            addMessageAfterRedirect($LANG['document'][40],false,ERROR);
+            Session::addMessageAfterRedirect($LANG['document'][40], false, ERROR);
             return false;
          }
       }
@@ -1007,11 +1064,11 @@ class Document extends CommonDBTM {
          switch ($FILEDESC['error']) {
             case 1 :
             case 2 :
-               addMessageAfterRedirect($LANG['document'][23],false,ERROR);
+               Session::addMessageAfterRedirect($LANG['document'][23], false, ERROR);
                break;
 
             case 4 :
-//                addMessageAfterRedirect($LANG['document'][28],false,ERROR);
+//                Session::addMessageAfterRedirect($LANG['document'][28],false,ERROR);
                break;
          }
 
@@ -1033,11 +1090,11 @@ class Document extends CommonDBTM {
                      "`sha1sum`='".sha1_file(GLPI_DOC_DIR."/".$input['current_filepath'])."'")<=1) {
 
          if (unlink(GLPI_DOC_DIR."/".$input['current_filepath'])) {
-            addMessageAfterRedirect($LANG['document'][24]." ".$input['current_filename']);
+            Session::addMessageAfterRedirect($LANG['document'][24]." ".$input['current_filename']);
          } else {
-            addMessageAfterRedirect($LANG['document'][25]." ".$input['current_filename'].
-                                    " (".GLPI_DOC_DIR."/".$input['current_filepath'].")",
-                                    false,ERROR);
+            Session::addMessageAfterRedirect($LANG['document'][25]." ".$input['current_filename'].
+                                              " (".GLPI_DOC_DIR."/".$input['current_filepath'].")",
+                                             false, ERROR);
          }
       }
 
@@ -1048,7 +1105,7 @@ class Document extends CommonDBTM {
 
       // Move uploaded file
       if (self::renameForce($FILEDESC['tmp_name'], GLPI_DOC_DIR."/".$path)) {
-         addMessageAfterRedirect($LANG['document'][26]);
+         Session::addMessageAfterRedirect($LANG['document'][26]);
          // For display
          $input['filename'] = addslashes($FILEDESC['name']);
          // Storage path
@@ -1057,7 +1114,7 @@ class Document extends CommonDBTM {
          $input['sha1sum']  = $sha1sum;
          return true;
       }
-      addMessageAfterRedirect($LANG['document'][27],false,ERROR);
+      Session::addMessageAfterRedirect($LANG['document'][27], false, ERROR);
       return false;
    }
 
@@ -1076,28 +1133,29 @@ class Document extends CommonDBTM {
       if (empty($dir)) {
          $message = $LANG['document'][32];
 
-         if (haveRight('dropdown','r')) {
+         if (Session::haveRight('dropdown','r')) {
             $dt = new DocumentType();
             $message .= " <a target='_blank' href='".$dt->getSearchURL()."'>
                          <img src=\"".$CFG_GLPI["root_doc"]."/pics/aide.png\"></a>";
          }
-         addMessageAfterRedirect($message, false, ERROR);
+         Session::addMessageAfterRedirect($message, false, ERROR);
          return '';
       }
 
       if (!is_dir(GLPI_DOC_DIR)) {
-         addMessageAfterRedirect($LANG['document'][31]." ".GLPI_DOC_DIR, false, ERROR);
+         Session::addMessageAfterRedirect($LANG['document'][31]." ".GLPI_DOC_DIR, false, ERROR);
          return '';
       }
       $subdir = $dir.'/'.substr($sha1sum,0,2);
 
       if (!is_dir(GLPI_DOC_DIR."/".$subdir) && @mkdir(GLPI_DOC_DIR."/".$subdir,0777,true)) {
-         addMessageAfterRedirect($LANG['document'][34]." ".GLPI_DOC_DIR."/".$subdir);
+         Session::addMessageAfterRedirect($LANG['document'][34]." ".GLPI_DOC_DIR."/".$subdir);
       }
 
       if (!is_dir(GLPI_DOC_DIR."/".$subdir)) {
-         addMessageAfterRedirect($LANG['document'][29]." ".GLPI_DOC_DIR."/".$subdir." ".
-                                 $LANG['document'][30],false,ERROR);
+         Session::addMessageAfterRedirect($LANG['document'][29]." ".GLPI_DOC_DIR."/".$subdir." ".
+                                           $LANG['document'][30],
+                                          false, ERROR);
          return '';
       }
       return $subdir.'/'.substr($sha1sum,2).'.'.$dir;
@@ -1129,7 +1187,7 @@ class Document extends CommonDBTM {
 
          if (count($uploaded_files)) {
             echo "<select name='$myname'>";
-            echo "<option value=''>".DROPDOWN_EMPTY_VALUE."</option>";
+            echo "<option value=''>".Dropdown::EMPTY_VALUE."</option>";
 
             foreach ($uploaded_files as $key => $val) {
                echo "<option value='$val'>$val</option>";
@@ -1164,7 +1222,7 @@ class Document extends CommonDBTM {
 
       if ($result = $DB->query($query)) {
          if ($DB->numrows($result)>0) {
-            return utf8_strtoupper($ext);
+            return Toolbox::strtoupper($ext);
          }
       }
       return "";
@@ -1188,7 +1246,7 @@ class Document extends CommonDBTM {
 
       if ($item->getType() != 'Ticket'
           && $item->getType() != 'KnowbaseItem'
-          && !haveRight('document','r')) {
+          && !Session::haveRight('document','r')) {
          return false;
       }
 
@@ -1205,11 +1263,7 @@ class Document extends CommonDBTM {
          $linkparam = "&amp;tickets_id=".$item->fields['id'];
       }
 
-      if ($item->getType() == 'Ticket' && $item->getField('status') == 'closed') {
-         $canedit = false;
-      } else {
-         $canedit = $item->can($ID,'w');
-      }
+      $canedit =  $item->canadditem('Document');
 
       $is_recursive=$item->isRecursive();
 
@@ -1224,7 +1278,7 @@ class Document extends CommonDBTM {
                 WHERE `glpi_documents_items`.`items_id` = '$ID'
                       AND `glpi_documents_items`.`itemtype` = '".$item->getType()."' ";
 
-      if (getLoginUserID()) {
+      if (Session::getLoginUserID()) {
          $query .= getEntitiesRestrictRequest(" AND","glpi_documents",'','',true);
       } else {
          // Anonymous access from FAQ
@@ -1246,7 +1300,7 @@ class Document extends CommonDBTM {
                     WHERE `glpi_documents_items`.`documents_id` = '$ID'
                           AND `glpi_documents_items`.`itemtype` = '".$item->getType()."' ";
 
-         if (getLoginUserID()) {
+         if (Session::getLoginUserID()) {
             $query .= getEntitiesRestrictRequest(" AND","glpi_documents",'','',true);
          } else {
             // Anonymous access from FAQ
@@ -1267,33 +1321,35 @@ class Document extends CommonDBTM {
       echo "<div class='spaced'><table class='tab_cadre_fixe'>";
       echo "<tr><th colspan='7'>";
 
-      if ($DB->numrows($result)==0) {
+      if ($number==0) {
          echo $LANG['document'][17];
-      } else if ($DB->numrows($result)==1) {
+      } else if ($number==1) {
          echo $LANG['document'][21];
       } else {
          echo $LANG['document'][20];
       }
 
       echo "</th></tr>";
-      echo "<tr><th>".$LANG['common'][16]."</th>";
-      echo "<th>".$LANG['entity'][0]."</th>";
-      echo "<th>".$LANG['document'][2]."</th>";
-      echo "<th>".$LANG['document'][33]."</th>";
-      echo "<th>".$LANG['document'][3]."</th>";
-      echo "<th>".$LANG['document'][4]."</th>";
+      if ($number > 0) {
+         echo "<tr><th>".$LANG['common'][16]."</th>";
+         echo "<th>".$LANG['entity'][0]."</th>";
+         echo "<th>".$LANG['document'][2]."</th>";
+         echo "<th>".$LANG['document'][33]."</th>";
+         echo "<th>".$LANG['document'][3]."</th>";
+         echo "<th>".$LANG['document'][4]."</th>";
 
-      if ($withtemplate<2) {
-         echo "<th>&nbsp;</th>";
+         if ($withtemplate<2) {
+            echo "<th>&nbsp;</th>";
+         }
+         echo "</tr>";
       }
-      echo "</tr>";
       $used = array();
 
       if ($number) {
          // Don't use this for document associated to document
          // To not loose navigation list for current document
          if ($item->getType() != 'Document') {
-            initNavigateListItems('Document', $item->getTypeName()." = ".$item->getName());
+            Session::initNavigateListItems('Document', $item->getTypeName()." = ".$item->getName());
          }
 
          $document = new Document();
@@ -1308,7 +1364,7 @@ class Document extends CommonDBTM {
             }
 
             if ($item->getType() != 'Document') {
-               addToNavigateListItems('Document', $docID);
+               Session::addToNavigateListItems('Document', $docID);
             }
             $used[$docID] = $docID;
             $assocID      = $data["assocID"];
@@ -1338,7 +1394,8 @@ class Document extends CommonDBTM {
                   echo "<a href='".$CFG_GLPI["root_doc"];
                   echo "/front/document.form.php?deletedocumentitem=1&amp;id=$assocID";
                   echo "&amp;itemtype=".$item->getType()."&amp;items_id=$ID&amp;documents_id=$docID'>";
-                  echo $LANG['buttons'][6]."</a>";
+                  echo "<img title=\"".$LANG['buttons'][6]."\" alt=\"".$LANG['buttons'][6]."\"
+                        src='".$CFG_GLPI["root_doc"]."/pics/delete.png'></a>";
                } else {
                   echo "&nbsp;";
                }
@@ -1355,7 +1412,10 @@ class Document extends CommonDBTM {
          $entity   = $_SESSION["glpiactive_entity"];
 
          if ($item->isEntityAssign()) {
-            $entity = $item->getEntityID();
+            /// Case of personal items : entity = -1 : create on active entity (Reminder case))
+            if ($item->getEntityID() >=0 ) {
+               $entity = $item->getEntityID();
+            }
 
             if ($item->isRecursive()) {
                $entities = getSonsOf('glpi_entities',$entity);
@@ -1374,37 +1434,44 @@ class Document extends CommonDBTM {
             $result = $DB->query($q);
             $nb = $DB->result($result,0,0);
 
-            echo "<tr class='tab_bg_1'><td class='center' colspan='3'>";
+            echo "<tr class='tab_bg_1'>";
+//            echo "<th class='right'>".$LANG['document'][6]."&nbsp :</th>";
+
+            echo "<td class='center' colspan='2'>";
+            echo $LANG['document'][3]."&nbsp:";
+            Dropdown::show('DocumentCategory',array('entity' => $entities));
+            echo "</td>";
+            echo "<td class='center' colspan='3'>";
             echo "<input type='hidden' name='entities_id' value='$entity'>";
             echo "<input type='hidden' name='is_recursive' value='$is_recursive'>";
             echo "<input type='hidden' name='itemtype' value='".$item->getType()."'>";
             echo "<input type='hidden' name='items_id' value='$ID'>";
             if ($item->getType()=='Ticket') {
-               echo "<input type='hidden' name='documentcategories_id' value='".$CFG_GLPI["documentcategories_id_forticket"]."'>";
                echo "<input type='hidden' name='tickets_id' value='$ID'>";
+               echo "<input type='hidden' name='documentcategories_id' value='".$CFG_GLPI["documentcategories_id_forticket"]."'>";
             }
             echo "<input type='file' name='filename' size='25'>&nbsp;";
             echo "(".self::getMaxUploadSize().")&nbsp;";
-
-            echo "<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'>";
             echo "</td>";
+            echo "<td colspan='2' class='center'>";
+            echo "<input type='submit' name='add' value=\"".$LANG['document'][6]."\" class='submit'>";
+            echo "</td></tr>";
 
             if ($item->getType() == 'Document') {
                $used[$ID] = $ID;
             }
 
-            if (haveRight('document','r') && $nb>count($used)) {
-               echo "<td class='left' colspan='2'>";
+            if (Session::haveRight('document','r') && $nb>count($used)) {
+               echo "<tr class='tab_bg_1'>";
+               echo "<td colspan='5' class='center'>";
                self::dropdown(array('entity' => $entities ,
                                     'used'   => $used));
-               echo "</td><td class='center'>";
+               echo "</td><td colspan='2' class='center'>";
                echo "<input type='submit' name='adddocumentitem' value=\"".
-                      $LANG['buttons'][8]."\" class='submit'>";
-               echo "</td><td>&nbsp;</td>";
-            } else {
-               echo "<td colspan='4'>&nbsp;</td>";
+                      $LANG['document'][5]."\" class='submit'>";
+               echo "</td>";
+               echo "</tr>";
             }
-            echo "</tr>";
          }
       }
       echo "</table></form></div>";
@@ -1456,7 +1523,7 @@ class Document extends CommonDBTM {
       $result = $DB->query($query);
 
       echo "<select name='_rubdoc' id='rubdoc$rand'>";
-      echo "<option value='0'>".DROPDOWN_EMPTY_VALUE."</option>";
+      echo "<option value='0'>".Dropdown::EMPTY_VALUE."</option>";
 
       while ($data=$DB->fetch_assoc($result)) {
          echo "<option value='".$data['id']."'>".$data['name']."</option>";
@@ -1469,8 +1536,8 @@ class Document extends CommonDBTM {
                       'myname' => $p['name'],
                       'used'   => $p['used']);
 
-      ajaxUpdateItemOnSelectEvent("rubdoc$rand","show_".$p['name']."$rand",
-                                  $CFG_GLPI["root_doc"]."/ajax/dropdownRubDocument.php", $params);
+      Ajax::updateItemOnSelectEvent("rubdoc$rand","show_".$p['name']."$rand",
+                                    $CFG_GLPI["root_doc"]."/ajax/dropdownRubDocument.php", $params);
 
       echo "<span id='show_".$p['name']."$rand'>";
       $_POST["entity"] = $p['entity'];
