@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: document_item.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: document_item.class.php 17688 2012-03-01 11:41:03Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -47,10 +47,14 @@ class Document_Item extends CommonDBRelation{
    public $itemtype_2 = 'itemtype';
    public $items_id_2 = 'items_id';
 
+
    function prepareInputForAdd($input) {
 
-      if (empty($input['itemtype']) || empty($input['items_id']) || $input['items_id']==0
-         || empty($input['documents_id']) || $input['documents_id']==0) {
+      if (empty($input['itemtype'])
+          || ((empty($input['items_id']) || $input['items_id']==0)
+              && $input['itemtype']!='Entity')
+          || empty($input['documents_id'])
+          || $input['documents_id']==0) {
          return false;
       }
 
@@ -68,14 +72,19 @@ class Document_Item extends CommonDBRelation{
       return $input;
    }
 
+
    function post_addItem() {
 
       if ($this->fields['itemtype'] == 'Ticket') {
          $ticket = new Ticket();
-         $ticket->update(array('id'            => $this->fields['items_id'],
-                               'date_mod'      => $_SESSION["glpi_currenttime"],
-                               '_forcenotif'   => true,
-                               '_donotadddocs' => true));
+         $input = array('id'            => $this->fields['items_id'],
+                        'date_mod'      => $_SESSION["glpi_currenttime"],
+                        '_donotadddocs' => true);
+
+         if (!isset($this->input['_do_notif']) || $this->input['_do_notif']) {
+            $input['_forcenotif'] = true;
+         }
+         $ticket->update($input);
       }
       parent::post_addItem();
    }
@@ -83,35 +92,65 @@ class Document_Item extends CommonDBRelation{
 
    static function countForItem(CommonDBTM $item) {
 
-      $restrict = "`glpi_documents_items`.`documents_id` = `glpi_documents`.`id`
-                   AND `glpi_documents_items`.`items_id` = '".$item->getField('id')."'
+      $restrict = "`glpi_documents_items`.`items_id` = '".$item->getField('id')."'
                    AND `glpi_documents_items`.`itemtype` = '".$item->getType()."'";
 
-      if (getLoginUserID()) {
-         $restrict .= getEntitiesRestrictRequest(" AND ", "glpi_documents", '', '', true);
+      if (Session::getLoginUserID()) {
+         $restrict .= getEntitiesRestrictRequest(" AND ", "glpi_documents_items", '', '', true);
       } else {
          // Anonymous access from FAQ
-         $restrict .= " AND `glpi_documents`.`entities_id` = '0' ";
+         $restrict .= " AND `glpi_documents_items`.`entities_id` = '0' ";
       }
 
-      $nb = countElementsInTable(array('glpi_documents_items', 'glpi_documents'), $restrict);
+      $nb = countElementsInTable(array('glpi_documents_items'), $restrict);
 
       // Document case : search in both
       if ($item->getType() == 'Document') {
-         $restrict = "`glpi_documents_items`.`items_id` = `glpi_documents`.`id`
-                      AND `glpi_documents_items`.`documents_id` = '".$item->getField('id')."'
+         $restrict = "`glpi_documents_items`.`documents_id` = '".$item->getField('id')."'
                       AND `glpi_documents_items`.`itemtype` = '".$item->getType()."'";
 
-         if (getLoginUserID()) {
-            $restrict .= getEntitiesRestrictRequest(" AND ", "glpi_documents", '', '', true);
+         if (Session::getLoginUserID()) {
+            $restrict .= getEntitiesRestrictRequest(" AND ", "glpi_documents_items", '', '', true);
          } else {
             // Anonymous access from FAQ
-            $restrict .= " AND `glpi_documents`.`entities_id` = '0' ";
+            $restrict .= " AND `glpi_documents_items`.`entities_id` = '0' ";
          }
-         $nb += countElementsInTable(array('glpi_documents_items', 'glpi_documents'), $restrict);
+         $nb += countElementsInTable(array('glpi_documents_items'), $restrict);
       }
       return $nb ;
    }
 
+
+   static function countForDocument(Document $item) {
+
+      $restrict = "`glpi_documents_items`.`documents_id` = '".$item->getField('id')."'
+                   AND `glpi_documents_items`.`itemtype` != '".$item->getType()."'";
+
+      return countElementsInTable(array('glpi_documents_items'), $restrict);
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (Session::haveRight('document', 'r')) {
+         if ($_SESSION['glpishow_count_on_tabs']) {
+            return self::createTabEntry($LANG['document'][19], self::countForDocument($item));
+         }
+         return $LANG['document'][19];
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      switch ($item->getType()) {
+         case 'Document' :
+            $item->showItems();
+            return true;
+      }
+   }
+
 }
 ?>
