@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entity.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: entity.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -41,7 +41,8 @@ if (!defined('GLPI_ROOT')) {
  */
 class Entity extends CommonTreeDropdown {
 
-   var $must_be_replace = true;
+   public $must_be_replace = true;
+   public $dohistory       = true;
 
    function getFromDB($ID) {
       global $LANG;
@@ -61,32 +62,35 @@ class Entity extends CommonTreeDropdown {
    }
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['Menu'][37];
+      if ($nb>1) {
+         return $LANG['Menu'][37];
+      }
+      return $LANG['entity'][0];
    }
 
 
    function canCreate() {
-      return haveRight('entity', 'w');
+      return Session::haveRight('entity', 'w');
    }
 
 
    function canView() {
-      return haveRight('entity', 'r');
+      return Session::haveRight('entity', 'r');
    }
 
 
    function canCreateItem() {
       // Check the parent
-      return haveRecursiveAccessToEntity($this->getField('entities_id'));
+      return Session::haveRecursiveAccessToEntity($this->getField('entities_id'));
    }
 
 
    function canUpdateItem() {
       // Check the current entity
-      return haveAccessToEntity($this->getField('id'));
+      return Session::haveAccessToEntity($this->getField('id'));
    }
 
 
@@ -98,134 +102,19 @@ class Entity extends CommonTreeDropdown {
    function defineTabs($options=array()) {
       global $LANG;
 
-      $ong[1] = $LANG['title'][26];          // Main
+      $ong = array();
+      $this->addStandardTab($this->getType(), $ong, $options);
+      $this->addStandardTab('Profile_User',$ong, $options);
+      $this->addStandardTab('EntityData', $ong, $options);
+      $this->addStandardTab('Rule', $ong, $options);
+      $this->addStandardTab('Document',$ong, $options);
+      $this->addStandardTab('Note',$ong, $options);
+      $this->addStandardTab('Log',$ong, $options);
 
-      if (!$this->isNewID($this->fields['id'])) {
-         $ong[2] = $LANG['financial'][44];   // Address
-         $ong[3] = $LANG['Menu'][14];        // Users
-         $ong[4] = $LANG['rulesengine'][17]; // Rules
-         $ong[5] = $LANG['entity'][14];      // Advanced
-
-         if (haveRight("document","r")) {
-            $ong[6] = $LANG['Menu'][27];       // Docs
-         }
-         if (haveRight('notification','r')) {
-            $ong[7] = $LANG['setup'][704];      // Notification
-         }
-         if (haveRight('entity_helpdesk','r')) {
-            $ong[8] = $LANG['title'][24];       // Helpdesk
-         }
-         $ong[9] = $LANG['Menu'][38];      // Inventory
-         if (haveRight("notes","r")) {
-            $ong[10] = $LANG['title'][37];
-         }
-      }
       return $ong;
    }
 
 
-   /**
-    * Display content of Tab
-    *
-    * @param $ID of the item
-    * @param $tab number of the tab
-    *
-    * @return true if handled (for class stack)
-    */
-   function showTabContent ($ID, $tab) {
-      global $CFG_GLPI;
-
-      if (!$this->isNewID($ID)) {
-         switch ($tab) {
-            case -1 :   // All
-               $this->showChildren($ID);
-               EntityData::showStandardOptions($this);
-               Profile_User::showForEntity($this);
-
-               $collection = new RuleRightCollection();
-               if ($collection->canList()) {
-                  $ldaprule = new RuleRight();
-                  $ldaprule->showAndAddRuleForm($this);
-               }
-               $collection = new RuleOcsCollection();
-               if ($collection->canList()) {
-                  $ocsrule = new RuleOcs();
-                  $ocsrule->showAndAddRuleForm($this);
-               }
-               $collection = new RuleMailCollectorCollection();
-               if ($collection->canList()) {
-                  $mailcollector = new RuleMailCollector();
-                  $mailcollector->showAndAddRuleForm($this);
-               }
-               EntityData::showAdvancedOptions($this);
-               Document::showAssociated($this);
-               EntityData::showNotificationOptions($this);
-               EntityData::showHelpdeskOptions($this);
-               EntityData::showInventoryOptions($this);
-               Plugin::displayAction($this, $tab);
-               break;
-
-            case 2 :
-               EntityData::showStandardOptions($this);
-               break;
-
-            case 3 :
-               Profile_User::showForEntity($this);
-               break;
-
-            case 4 :
-               $collection = new RuleRightCollection();
-               if ($collection->canList()) {
-                  $ldaprule = new RuleRight();
-                  $ldaprule->showAndAddRuleForm($this);
-               }
-               $collection = new RuleOcsCollection();
-               if ($collection->canList()) {
-                  $ocsrule = new RuleOcs();
-                  $ocsrule->showAndAddRuleForm($this);
-               }
-               $collection = new RuleMailCollectorCollection();
-               if ($collection->canList()) {
-                  $mailcollector = new RuleMailCollector();
-                  $mailcollector->showAndAddRuleForm($this);
-               }
-               break;
-
-            case 5 :
-               EntityData::showAdvancedOptions($this);
-               break;
-
-            case 6 :
-               Document::showAssociated($this);
-               break;
-
-            case 7 :
-               EntityData::showNotificationOptions($this);
-               break;
-
-            case 8 :
-               EntityData::showHelpdeskOptions($this);
-               break;
-
-            case 9 :
-               EntityData::showInventoryOptions($this);
-               break;
-
-            case 10 :
-               showNotesForm(getItemTypeFormURL('EntityData'), 'EntityData', $_POST["id"]);
-               break;
-
-            default :
-               if (!Plugin::displayAction($this, $tab)) {
-                  $this->showChildren($ID);
-               }
-               return false;
-         }
-      }
-      return false;
-   }
-
-
    /**
     * Print a good title for entity pages
     *
@@ -237,12 +126,13 @@ class Entity extends CommonTreeDropdown {
       $buttons = array();
       $title   = $LANG['Menu'][37];
       $buttons["entity.form.php?id=0"] = $LANG['entity'][2];
-      displayTitle($CFG_GLPI["root_doc"]."/pics/groupes.png", $LANG['Menu'][37], $title, $buttons);
+      Html::displayTitle($CFG_GLPI["root_doc"]."/pics/groupes.png", $LANG['Menu'][37], $title,
+                         $buttons);
    }
 
 
-   function displayHeader () {
-      commonHeader($this->getTypeName(), '', "admin", "entity");
+   function displayHeader() {
+      Html::header($this->getTypeName(), '', "admin", "entity");
    }
 
 
@@ -286,7 +176,7 @@ class Entity extends CommonTreeDropdown {
 
    function post_addItem() {
 
-      CleanFields($this->getTable(), 'sons_cache');
+      parent::post_addItem();
 
       // Add right to current user - Hack to avoid login/logout
       $_SESSION['glpiactiveentities'][$this->fields['id']] = $this->fields['id'];
@@ -302,7 +192,8 @@ class Entity extends CommonTreeDropdown {
                 WHERE `entities_id` = '".$this->fields['id']."'";
       $result = $DB->query($query);
 
-      Rule::cleanForItemAction($this);
+      // most use entities_id, RuleDictionnarySoftwareCollection use new_entities_id
+      Rule::cleanForItemAction($this, '%entities_id');
       Rule::cleanForItemCriteria($this);
    }
 
@@ -330,7 +221,7 @@ class Entity extends CommonTreeDropdown {
       $tab[3]['name']          = $LANG['financial'][44];
       $tab[3]['massiveaction'] = false;
       $tab[3]['joinparams']    = array('jointype' => 'child');
-      $tab[3]['datatype']      = 'string';
+      $tab[3]['datatype']      = 'text';
 
       $tab[4]['table']         = 'glpi_entitydatas';
       $tab[4]['field']         = 'website';
@@ -444,12 +335,216 @@ class Entity extends CommonTreeDropdown {
       $tab[20]['joinparams']    = array('jointype' => 'child');
       $tab[20]['datatype']      = 'string';
 
+      $tab[21]['table']         = 'glpi_entitydatas';
+      $tab[21]['field']         = 'notification_subject_tag';
+      $tab[21]['name']          = $LANG['mailing'][2];
+      $tab[21]['joinparams']    = array('jointype' => 'child');
+      $tab[21]['datatype']      = 'string';
+
+      $tab[22]['table']         = 'glpi_entitydatas';
+      $tab[22]['field']         = 'admin_email_name';
+      $tab[22]['name']          = $LANG['setup'][208];
+      $tab[22]['joinparams']    = array('jointype' => 'child');
+      $tab[22]['datatype']      = 'string';
+
+      $tab[23]['table']         = 'glpi_entitydatas';
+      $tab[23]['field']         = 'admin_reply_name';
+      $tab[23]['name']          = $LANG['setup'][209];
+      $tab[23]['joinparams']    = array('jointype' => 'child');
+      $tab[23]['datatype']      = 'string';
+
+      $tab[24]['table']         = 'glpi_entitydatas';
+      $tab[24]['field']         = 'mailing_signature';
+      $tab[24]['name']          = $LANG['setup'][204];
+      $tab[24]['joinparams']    = array('jointype' => 'child');
+      $tab[24]['datatype']      = 'text';
+
       $tab[25]['table']         = 'glpi_entitydatas';
       $tab[25]['field']         = 'postcode';
       $tab[25]['name']          = $LANG['financial'][100];
       $tab[25]['joinparams']    = array('jointype' => 'child');
       $tab[25]['datatype']      = 'string';
 
+      $tab[26]['table']         = 'glpi_entitydatas';
+      $tab[26]['field']         = 'cartridges_alert_repeat';
+      $tab[26]['name']          = $LANG['setup'][244];
+      $tab[26]['joinparams']    = array('jointype' => 'child');
+      $tab[26]['massiveaction'] = false;
+      $tab[26]['nosearch']      = true;
+
+      $tab[27]['table']         = 'glpi_entitydatas';
+      $tab[27]['field']         = 'consumables_alert_repeat';
+      $tab[27]['name']          = $LANG['setup'][243];
+      $tab[27]['joinparams']    = array('jointype' => 'child');
+      $tab[27]['massiveaction'] = false;
+      $tab[27]['nosearch']      = true;
+
+      $tab[28]['table']         = 'glpi_entitydatas';
+      $tab[28]['field']         = 'notepad';
+      $tab[28]['name']          = $LANG['title'][37];
+      $tab[28]['joinparams']    = array('jointype' => 'child');
+      $tab[28]['datatype']      = 'text';
+
+      $tab[29]['table']         = 'glpi_entitydatas';
+      $tab[29]['field']         = 'use_licenses_alert';
+      $tab[29]['name']          = $LANG['setup'][264];
+      $tab[29]['massiveaction'] = false;
+      $tab[29]['nosearch']      = true;
+      $tab[29]['joinparams']    = array('jointype' => 'child');
+
+      $tab[30]['table']         = 'glpi_entitydatas';
+      $tab[30]['field']         = 'use_contracts_alert';
+      $tab[30]['name']          = $LANG['setup'][246];
+      $tab[30]['massiveaction'] = false;
+      $tab[30]['nosearch']      = true;
+      $tab[30]['joinparams']    = array('jointype' => 'child');
+
+      $tab[31]['table']         = 'glpi_entitydatas';
+      $tab[31]['field']         = 'use_infocoms_alert';
+      $tab[31]['name']          = $LANG['setup'][247];
+      $tab[31]['massiveaction'] = false;
+      $tab[31]['nosearch']      = true;
+      $tab[31]['joinparams']    = array('jointype' => 'child');
+
+      $tab[32]['table']         = 'glpi_entitydatas';
+      $tab[32]['field']         = 'use_reservations_alert';
+      $tab[32]['name']          = $LANG['setup'][707];
+      $tab[32]['massiveaction'] = false;
+      $tab[32]['nosearch']      = true;
+      $tab[32]['joinparams']    = array('jointype' => 'child');
+
+      $tab[33]['table']         = 'glpi_entitydatas';
+      $tab[33]['field']         = 'autoclose_delay';
+      $tab[33]['name']          = $LANG['entity'][18];
+      $tab[33]['massiveaction'] = false;
+      $tab[33]['nosearch']      = true;
+      $tab[33]['joinparams']    = array('jointype' => 'child');
+
+      $tab[34]['table']         = 'glpi_entitydatas';
+      $tab[34]['field']         = 'notclosed_delay';
+      $tab[34]['name']          = $LANG['setup'][708];
+      $tab[34]['massiveaction'] = false;
+      $tab[34]['nosearch']      = true;
+      $tab[34]['joinparams']    = array('jointype' => 'child');
+
+      $tab[35]['table']         = 'glpi_entitydatas';
+      $tab[35]['field']         = 'auto_assign_mode';
+      $tab[35]['name']          = $LANG['setup'][52];
+      $tab[35]['massiveaction'] = false;
+      $tab[35]['nosearch']      = true;
+      $tab[35]['joinparams']    = array('jointype' => 'child');
+
+      $tab[36]['table']         = 'glpi_entitydatas';
+      $tab[36]['field']         = 'calendars_id';        // not a dropdown because of special value
+      $tab[36]['name']          = $LANG['buttons'][15];
+      $tab[36]['massiveaction'] = false;
+      $tab[36]['nosearch']      = true;
+      $tab[36]['joinparams']    = array('jointype' => 'child');
+
+      $tab[37]['table']         = 'glpi_entitydatas';
+      $tab[37]['field']         = 'tickettype';
+      $tab[37]['name']          = $LANG['entity'][28];
+      $tab[37]['massiveaction'] = false;
+      $tab[37]['nosearch']      = true;
+      $tab[37]['joinparams']    = array('jointype' => 'child');
+
+      $tab[38]['table']         = 'glpi_entitydatas';
+      $tab[38]['field']         = 'autofill_buy_date';
+      $tab[38]['name']          = $LANG['financial'][14];
+      $tab[38]['massiveaction'] = false;
+      $tab[38]['nosearch']      = true;
+      $tab[38]['joinparams']    = array('jointype' => 'child');
+
+      $tab[39]['table']         = 'glpi_entitydatas';
+      $tab[39]['field']         = 'autofill_order_date';
+      $tab[39]['name']          = $LANG['financial'][28];
+      $tab[39]['massiveaction'] = false;
+      $tab[39]['nosearch']      = true;
+      $tab[39]['joinparams']    = array('jointype' => 'child');
+
+      $tab[40]['table']         = 'glpi_entitydatas';
+      $tab[40]['field']         = 'autofill_delivery_date';
+      $tab[40]['name']          = $LANG['financial'][27];
+      $tab[40]['massiveaction'] = false;
+      $tab[40]['nosearch']      = true;
+      $tab[40]['joinparams']    = array('jointype' => 'child');
+
+      $tab[41]['table']         = 'glpi_entitydatas';
+      $tab[41]['field']         = 'autofill_use_date';
+      $tab[41]['name']          = $LANG['financial'][76];
+      $tab[41]['massiveaction'] = false;
+      $tab[41]['nosearch']      = true;
+      $tab[41]['joinparams']    = array('jointype' => 'child');
+
+      $tab[42]['table']         = 'glpi_entitydatas';
+      $tab[42]['field']         = 'autofill_warranty_date';
+      $tab[42]['name']          = $LANG['financial'][29];
+      $tab[42]['massiveaction'] = false;
+      $tab[42]['nosearch']      = true;
+      $tab[42]['joinparams']    = array('jointype' => 'child');
+
+      $tab[43]['table']         = 'glpi_entitydatas';
+      $tab[43]['field']         = 'inquest_config';
+      $tab[43]['name']          = $LANG['entity'][19];
+      $tab[43]['massiveaction'] = false;
+      $tab[43]['nosearch']      = true;
+      $tab[43]['joinparams']    = array('jointype' => 'child');
+
+      $tab[44]['table']         = 'glpi_entitydatas';
+      $tab[44]['field']         = 'inquest_rate';
+      $tab[44]['name']          = $LANG['entity'][21];
+      $tab[44]['massiveaction'] = false;
+      $tab[44]['joinparams']    = array('jointype' => 'child');
+      $tab[44]['datatype']      = 'number';
+
+      $tab[45]['table']         = 'glpi_entitydatas';
+      $tab[45]['field']         = 'inquest_delay';
+      $tab[45]['name']          = $LANG['entity'][20];
+      $tab[45]['massiveaction'] = false;
+      $tab[45]['joinparams']    = array('jointype' => 'child');
+      $tab[45]['datatype']      = 'number';
+
+      $tab[46]['table']         = 'glpi_entitydatas';
+      $tab[46]['field']         = 'inquest_URL';
+      $tab[46]['name']          = $LANG['common'][94];
+      $tab[46]['massiveaction'] = false;
+      $tab[46]['joinparams']    = array('jointype' => 'child');
+      $tab[46]['datatype']      = 'string';
+
+      $tab[47]['table']         = 'glpi_entitydatas';
+      $tab[47]['field']         = 'tickettemplates_id';  // not a dropdown because of special value
+      $tab[47]['name']          = $LANG['job'][58];
+      $tab[47]['massiveaction'] = false;
+      $tab[47]['nosearch']      = true;
+      $tab[47]['joinparams']    = array('jointype' => 'child');
+
+      $tab[48]['table']         = 'glpi_entitydatas';
+      $tab[48]['field']         = 'default_contract_alert';
+      $tab[48]['name']          = $LANG['setup'][246].' - '.$LANG['setup'][46];
+      $tab[48]['massiveaction'] = false;
+      $tab[48]['nosearch']      = true;
+      $tab[48]['joinparams']    = array('jointype' => 'child');
+
+      $tab[49]['table']         = 'glpi_entitydatas';
+      $tab[49]['field']         = 'default_infocom_alert';
+      $tab[49]['name']          = $LANG['setup'][247].' - '.$LANG['setup'][46];
+      $tab[49]['massiveaction'] = false;
+      $tab[49]['nosearch']      = true;
+      $tab[49]['joinparams']    = array('jointype' => 'child');
+
+      $tab[50]['table']         = 'glpi_entitydatas';
+      $tab[50]['field']         = 'default_alarm_threshold';
+      $tab[50]['name']          = $LANG['setup'][115];
+      $tab[50]['massiveaction'] = false;
+      $tab[50]['nosearch']      = true;
+      $tab[50]['datatype']      = 'number';
+
+      $tab[51]['table']         = 'glpi_entitydatas';
+      $tab[51]['field']         = 'entities_id_software';   // not a dropdown because of special value
+      $tab[51]['name']          = $LANG['software'][10];
+      $tab[51]['massiveaction'] = false;
+      $tab[51]['nosearch']      = true;
+
       return $tab;
    }
 
@@ -513,7 +608,13 @@ class Entity extends CommonTreeDropdown {
    }
 
 
-   function addRule($input) {
+   /**
+    * @since version 0.83 (before addRule)
+    *
+    * @param $input array of values
+    *
+   **/
+   function executeAddRule($input) {
       global $LANG;
 
       $this->check($_POST["affectentity"], 'w');
@@ -524,7 +625,7 @@ class Entity extends CommonTreeDropdown {
 
       if ($ruleid) {
          //Add an action associated to the rule
-         $ruleAction = new RuleAction;
+         $ruleAction = new RuleAction();
 
          //Action is : affect computer to this entity
          $ruleAction->addActionByAttributes("assign", $ruleid, "entities_id",
@@ -542,66 +643,71 @@ class Entity extends CommonTreeDropdown {
       }
 
       Event::log($ruleid, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
-      glpi_header($_SERVER['HTTP_REFERER']);
+      Html::back();
    }
 
 
-   static function getEntitiesToNotify($field, $with_value=false) {
+   /**
+    * get all entities with a notification option set
+    * manage CONFIG_PARENT (or NULL) value
+    *
+    * @param $field  String name of the field to search (>0)
+    *
+    * @return Array of id => value
+   **/
+   static function getEntitiesToNotify($field) {
       global $DB, $CFG_GLPI;
 
+      $entities = array();
+
+      // root entity first
+      $ent = new EntityData();
+      if ($ent->getFromDB(0)) {  // always exists
+         $val = $ent->getField($field);
+         if ($val>0) {
+            $entities[0] = $val;
+         }
+      }
+
+      // Others entities in level order (parent first)
       $query = "SELECT `glpi_entities`.`id` AS `entity`,
+                       `glpi_entities`.`entities_id` AS `parent`,
                        `glpi_entitydatas`.`$field`
                 FROM `glpi_entities`
                 LEFT JOIN `glpi_entitydatas`
                      ON (`glpi_entitydatas`.`entities_id` = `glpi_entities`.`id`)
-                ORDER BY `glpi_entities`.`entities_id` ASC";
+                ORDER BY `glpi_entities`.`level` ASC";
 
-      $entities = array();
 
       foreach ($DB->request($query) as $entitydatas) {
-         self::getDefaultValueForAttributeInEntity($field, $entities, $entitydatas);
-      }
+         if ((is_null($entitydatas[$field]) || $entitydatas[$field]==EntityData::CONFIG_PARENT)
+             && isset($entities[$entitydatas['parent']])) {
 
-      //If root entity doesn't have row in glpi_entitydatas
-      $query = "SELECT `$field`
-                FROM `glpi_entitydatas`
-                WHERE `entities_id` = '0'";
-      $result = $DB->query($query);
+            // config inherit from parent
+            $entities[$entitydatas['entity']] = $entities[$entitydatas['parent']];
 
-      if ($DB->numrows($result)) {
-         self::getDefaultValueForAttributeInEntity($field, $entities,
-                                                   array('entity' => 0,
-                                                         $field   => $DB->result($result, 0,
-                                                                                 $field)));
+         } else if ($entitydatas[$field] > 0) {
 
-      } else if ($CFG_GLPI[$field]) {
-         $entities[0] = $CFG_GLPI[$field];
+            // config found in entity
+            $entities[$entitydatas['entity']] = $entitydatas[$field];
+         }
       }
 
       return $entities;
    }
 
 
-   static function getDefaultValueForAttributeInEntity($field, &$entities, $entitydatas) {
-      global $CFG_GLPI;
+   function showNotesForm() {
 
-      //If there's a configuration for this entity & the value is not the one of the global config
-      if (isset($entitydatas[$field])
-          && ($entitydatas[$field] > 0
-              || ($field == 'autoclose_delay' && $entitydatas[$field] == 0))) {
-         $entities[$entitydatas['entity']] = $entitydatas[$field];
-
-      //No configuration for this entity : if global config allows notification then add the entity
-      //to the array of entities to be notified
-      } else if ((!isset($entitydatas[$field])
-                  || $entitydatas[$field] == -1
-                  || is_null($entitydatas[$field]))
-                 && isset($CFG_GLPI[$field])) {
-
-         $entities[$entitydatas['entity']] = $CFG_GLPI[$field];
+      if (isset($this->fields['id'])) {
+         $entitydata = new EntityData();
+         if (!$entitydata->getFromDB($this->fields['id'])) {
+            $entitydata->add(array('entities_id' => $this->fields['id']));
+            $entitydata->getFromDB($this->fields['id']);
+         }
+         $entitydata->showNotesForm();
       }
    }
-
 }
 
 ?>
