@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: infocom.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: infocom.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -56,27 +56,85 @@ class Infocom extends CommonDBChild {
    const ON_ASSET_IMPORT    = 5;
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      // Always plural
       return $LANG['financial'][3];
    }
 
 
    function canCreate() {
-      return haveRight('infocom', 'w');
+      return Session::haveRight('infocom', 'w');
    }
 
 
    function canView() {
-      return haveRight('infocom', 'r');
+      return Session::haveRight('infocom', 'r');
    }
 
 
    function post_getEmpty() {
-      global $CFG_GLPI;
 
-      $this->fields["alert"] = $CFG_GLPI["default_infocom_alert"];
+      $this->fields["alert"] = EntityData::getUsedConfig("use_infocoms_alert",
+                                                         $this->fields["entities_id"],
+                                                         "default_infocom_alert", 0);
+   }
+
+
+   function getLogTypeID() {
+      return array($this->fields['itemtype'], $this->fields['items_id']);
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      // Can exists on template
+      if (Session::haveRight("infocom","r")) {
+         switch ($item->getType()) {
+            case 'Supplier' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['common'][96], self::countForSupplier($item));
+               }
+               return $LANG['common'][96];
+
+            default :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['Menu'][26],
+                                              countElementsInTable('glpi_infocoms',
+                                                                   "`itemtype` = '".$item->getType()."'
+                                                                     AND `items_id` = '".$item->getID()."'"));
+               }
+               return $LANG['Menu'][26];
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      switch ($item->getType()) {
+         case 'Supplier' :
+            $item->showInfocoms();
+            break;
+
+         default :
+            self::showForItem($item, $withtemplate);
+      }
+      return true;
+   }
+
+
+   static function countForSupplier(Supplier $item) {
+
+      $restrict = "`glpi_infocoms`.`suppliers_id` = '".$item->getField('id') ."'
+                    AND `itemtype` NOT IN ('ConsumableItem', 'CartridgeItem', 'Software') ".
+                    getEntitiesRestrictRequest(" AND ", "glpi_infocoms", '',
+                                               $_SESSION['glpiactiveentities']);
+
+      return countElementsInTable(array('glpi_infocoms'), $restrict);
    }
 
 
@@ -117,10 +175,9 @@ class Infocom extends CommonDBChild {
       global $CFG_GLPI;
 
       if (!$this->getFromDBforDevice($input['itemtype'],$input['items_id'])) {
-         $input['alert'] = $CFG_GLPI["default_infocom_alert"];
-         if (class_exists($input['itemtype'])) {
-            $item = new $input['itemtype']();
+         if ($item = getItemForItemtype($input['itemtype'])) {
             if ($item->getFromDB($input['items_id'])) {
+               $input['alert']        = EntityData::getUsedConfig('default_infocom_alert', $item->getEntityID());
                $input['entities_id']  = $item->getEntityID();
                $input['is_recursive'] = intval($item->isRecursive());
                return $input;
@@ -288,8 +345,7 @@ class Infocom extends CommonDBChild {
    **/
 //    function isEntityAssign() {
 //
-//       if (isset($this->fields["itemtype"]) && class_exists($this->fields["itemtype"])) {
-//          $item = new $this->fields["itemtype"]();
+//       if (isset($this->fields["itemtype"]) && $item = getItemForItemtype($this->fields["itemtype"])) {
 //          return $item->isEntityAssign();
 //       }
 //
@@ -303,8 +359,7 @@ class Infocom extends CommonDBChild {
    **/
 //    function getEntityID () {
 //
-//       if (class_exists($this->fields["itemtype"])) {
-//          $item = new $this->fields["itemtype"]();
+//       if ($item = getItemForItemtype($this->fields["itemtype"])) {
 //          if ($item->getFromDB($this->fields["items_id"])) {
 //             return $item->getEntityID();
 //          }
@@ -319,8 +374,7 @@ class Infocom extends CommonDBChild {
    **/
 //    function maybeRecursive() {
 //
-//       if (class_exists($this->fields["itemtype"])) {
-//          $item = new $this->fields["itemtype"]();
+//       if ($item = getItemForItemtype($this->fields["itemtype"])) {
 //          return $item->maybeRecursive();
 //       }
 //
@@ -336,8 +390,7 @@ class Infocom extends CommonDBChild {
    **/
 //    function isRecursive() {
 //
-//       if (class_exists($this->fields["itemtype"])) {
-//          $item = new $this->fields["itemtype"]();
+//       if ($item = getItemForItemtype($this->fields["itemtype"])) {
 //          return $item->isRecursive();
 //       }
 //
@@ -391,7 +444,7 @@ class Infocom extends CommonDBChild {
             $item_infocom = new $data["itemtype"]();
             if ($item_infocom->getFromDB($data["items_id"])) {
                $entity   = $data['entities_id'];
-               $warranty = getWarrantyExpir($data["warranty_date"], $data["warranty_duration"]);
+               $warranty = self::getWarrantyExpir($data["warranty_date"], $data["warranty_duration"]);
                $message  = $LANG['mailing'][40]." ".$item_infocom->getTypeName()." - ".
                            $item_infocom->getName()." : ".$warranty."<br>";
                $data['warrantyexpiration']        = $warranty;
@@ -409,14 +462,14 @@ class Infocom extends CommonDBChild {
       foreach ($items_infos as $entity => $items) {
          if (NotificationEvent::raiseEvent("alert", new self(), array('entities_id' => $entity,
                                                                       'items'       => $items))) {
-            $message     = $items_messages[$entity];
+            $message = $items_messages[$entity];
             $cron_status = 1;
             if ($task) {
                $task->log(Dropdown::getDropdownName("glpi_entities", $entity).":  $message\n");
                $task->addVolume(1);
             } else {
-               addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
-                                                                 $entity).":  $message");
+               Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                          $entity).":  $message");
             }
 
             $alert = new Alert();
@@ -433,8 +486,9 @@ class Infocom extends CommonDBChild {
                $task->log(Dropdown::getDropdownName("glpi_entities", $entity).
                           ":  Send infocom alert failed\n");
             } else {
-               addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",$entity).
-                                       ":  Send infocom alert failed", false, ERROR);
+               Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity).
+                                                  ":  Send infocom alert failed",
+                                                false, ERROR);
             }
          }
       }
@@ -452,7 +506,7 @@ class Infocom extends CommonDBChild {
       global $LANG;
 
       echo "<select name='$name'>";
-      echo "<option value='0'".($value==0?" selected ":"")." >".DROPDOWN_EMPTY_VALUE."</option>";
+      echo "<option value='0'".($value==0?" selected ":"")." >".Dropdown::EMPTY_VALUE."</option>";
       echo "<option value=\"".pow(2,Alert::END)."\" ".($value==pow(2,Alert::END)?" selected ":"")." >".
              $LANG['financial'][80]." </option>";
       echo "</select>";
@@ -469,7 +523,7 @@ class Infocom extends CommonDBChild {
       global $LANG;
 
       echo "<select name='$name'>";
-      echo "<option value='0' ".($value==0?" selected ":"").">".DROPDOWN_EMPTY_VALUE."</option>";
+      echo "<option value='0' ".($value==0?" selected ":"").">".Dropdown::EMPTY_VALUE."</option>";
       echo "<option value='2' ".($value==2?" selected ":"").">".$LANG['financial'][47]."</option>";
       echo "<option value='1' ".($value==1?" selected ":"").">".$LANG['financial'][48]."</option>";
       echo "</select>";
@@ -520,16 +574,16 @@ class Infocom extends CommonDBChild {
          sscanf($date_achat, "%4s-%2s-%2s",$date_Y, $date_m, $date_d);
 
          $timestamp2 = mktime(0,0,0, $date_m, $date_d, $date_Y);
-         $timestamp = mktime(0,0,0, date("m"), date("d"), date("Y"));
+         $timestamp  = mktime(0,0,0, date("m"), date("d"), date("Y"));
 
          $diff = floor(($timestamp - $timestamp2) / (MONTH_TIMESTAMP)); // Mois d'utilisation
 
          if ($diff) {
-            return formatNumber((($totalcost+$value)/$diff)); // TCO mensuel
+            return Html::formatNumber((($totalcost+$value)/$diff)); // TCO mensuel
          }
          return "";
       }
-      return formatNumber(($totalcost+$value)); // TCO
+      return Html::formatNumber(($totalcost+$value)); // TCO
    }// fin showTCO
 
 
@@ -545,10 +599,9 @@ class Infocom extends CommonDBChild {
    static function showDisplayLink($itemtype, $device_id, $update=0) {
       global $DB,$CFG_GLPI,$LANG;
 
-      if (!haveRight("infocom","r") || !class_exists($itemtype)) {
+      if (!Session::haveRight("infocom","r") || !($item = getItemForItemtype($itemtype))) {
          return false;
       }
-      $item = new $itemtype();
 
       $query="SELECT COUNT(*)
               FROM `glpi_infocoms`
@@ -561,7 +614,7 @@ class Infocom extends CommonDBChild {
       if ($DB->result($result,0,0)>0) {
          $add = "";
          $text = $LANG['buttons'][23];
-      } else if (!haveRight("infocom","w")) {
+      } else if (!Session::haveRight("infocom","w")) {
          return false;
       }
 
@@ -677,7 +730,7 @@ class Infocom extends CommonDBChild {
                   $date_m2 = $date_m2+12;
                }
                $ecartmois = ($date_m2-$date_m)+1; // calcul ecart entre mois d'acquisition
-                                                  // et debut annee fiscale
+                                                // et debut annee fiscale
                $prorata   = $ecartfinmoiscourant+$ecartmois-$ecartmoisexercice;
                ## calcul tableau d'amortissement ##
                $txlineaire     = (100/$duree); // calcul du taux lineaire virtuel
@@ -691,7 +744,7 @@ class Infocom extends CommonDBChild {
                for($i=1 ; $i<=$dureedegressif ; $i++) {
                   $tab['annee'][$i]    = $date_Y+$i-1;
                   $tab['vcnetdeb'][$i] = $mrt; // Pour chaque annee on calcule la valeur comptable nette
-                                               // de debut d'exercice
+                                             // de debut d'exercice
                   $tab['annuite'][$i]  = $tab['vcnetdeb'][$i]*$txdegressif/100;
                   $tab['vcnetfin'][$i] = $mrt - $tab['annuite'][$i]; //Pour chaque annee on calcule la valeur
                                                                    //comptable nette de fin d'exercice
@@ -709,7 +762,7 @@ class Infocom extends CommonDBChild {
                   $txlineaire = 100;
                }
                $annuite = ($tab['vcnetfin'][$dureedegressif]*$txlineaire)/100; // calcul de l'annuite
-               $mrt     = $tab['vcnetfin'][$dureedegressif];
+               $mrt = $tab['vcnetfin'][$dureedegressif];
                for($i=$dureedegressif+1 ; $i<=$dureedegressif+$dureelineaire ; $i++) {
                   $tab['annee'][$i]    = $date_Y+$i-1;
                   $tab['annuite'][$i]  = $annuite;
@@ -771,7 +824,7 @@ class Infocom extends CommonDBChild {
       global $CFG_GLPI, $LANG;
 
       // Show Infocom or blank form
-      if (!haveRight("infocom","r")) {
+      if (!Session::haveRight("infocom","r")) {
          return false;
       }
 
@@ -787,11 +840,9 @@ class Infocom extends CommonDBChild {
          }
 
          if (!strpos($_SERVER['PHP_SELF'],"infocoms-show")
-             && in_array($item->getType(),
-                         array('CartridgeItem', 'ConsumableItem', 'Software'))) {
+             && in_array($item->getType(), array('CartridgeItem', 'ConsumableItem', 'Software'))) {
             echo "<div class='firstbloc center'>".$LANG['financial'][84]."</div>";
          }
-
          if (!$ic->getFromDBforDevice($item->getType(),$dev_ID)) {
             $input = array('itemtype'    => $item->getType(),
                            'items_id'    => $dev_ID,
@@ -829,7 +880,7 @@ class Infocom extends CommonDBChild {
                                                 'entity' => $item->getEntityID()));
             }
             echo "</td>";
-            if (haveRight("budget","r")) {
+            if (Session::haveRight("budget","r")) {
                echo "<td>".$LANG['financial'][87]."&nbsp;:</td><td >";
                Dropdown::show('Budget', array('value'    => $ic->fields["budgets_id"],
                                               'entity'   => $item->getEntityID(),
@@ -845,10 +896,10 @@ class Infocom extends CommonDBChild {
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][18]."&nbsp;:</td>";
             echo "<td >";
-            autocompletionTextField($ic, "order_number", array('option' => $option));
+            Html::autocompletionTextField($ic, "order_number", array('option' => $option));
             echo "</td>";
             echo "<td>".$LANG['financial'][28]."&nbsp;:</td><td>";
-            showDateFormItem("order_date", $ic->fields["order_date"], true, $editcalendar);
+            Html::showDateFormItem("order_date", $ic->fields["order_date"], true, $editcalendar);
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
@@ -856,43 +907,45 @@ class Infocom extends CommonDBChild {
             echo "<td>";
             $objectName = autoName($ic->fields["immo_number"], "immo_number", ($withtemplate==2),
                                    'Infocom', $item->getEntityID());
-            autocompletionTextField($ic, "immo_number", array('value'  => $objectName,
+            Html::autocompletionTextField($ic, "immo_number", array('value'  => $objectName,
                                                               'option' => $option));
             echo "</td>";
             echo "<td>".$LANG['financial'][14]."&nbsp;:</td><td>";
-            showDateFormItem("buy_date", $ic->fields["buy_date"], true, $editcalendar);
+            Html::showDateFormItem("buy_date", $ic->fields["buy_date"], true, $editcalendar);
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][82]."&nbsp;:</td>";
             echo "<td>";
-            autocompletionTextField($ic, "bill", array('option' => $option));
+            Html::autocompletionTextField($ic, "bill", array('option' => $option));
             echo "</td>";
             echo "<td>".$LANG['financial'][27]."&nbsp;:</td><td>";
-            showDateFormItem("delivery_date", $ic->fields["delivery_date"], true, $editcalendar);
+            Html::showDateFormItem("delivery_date", $ic->fields["delivery_date"], true,
+                                   $editcalendar);
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][19]."&nbsp;:</td><td>";
-            autocompletionTextField($ic, "delivery_number", array('option' => $option));
+            Html::autocompletionTextField($ic, "delivery_number", array('option' => $option));
             echo "</td>";
             echo "<td>".$LANG['financial'][76]."&nbsp;:</td><td>";
-            showDateFormItem("use_date",$ic->fields["use_date"], true, $editcalendar);
+            Html::showDateFormItem("use_date",$ic->fields["use_date"], true, $editcalendar);
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][21]."&nbsp;:</td>";
             echo "<td><input type='text' name='value' $option value='".
-                  formatNumber($ic->fields["value"], true)."' size='14'></td>";
+                  Html::formatNumber($ic->fields["value"], true)."' size='14'></td>";
             echo "</td>";
             echo "<td>".$LANG['financial'][114]."&nbsp;:</td><td>";
-            showDateFormItem("inventory_date",$ic->fields["inventory_date"], true, $editcalendar);
+            Html::showDateFormItem("inventory_date",$ic->fields["inventory_date"], true,
+                                   $editcalendar);
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][78]."&nbsp;:</td>";
             echo "<td><input type='text' $option name='warranty_value' value='".
-                     formatNumber($ic->fields["warranty_value"], true)."' size='14'></td>";
+                       Html::formatNumber($ic->fields["warranty_value"], true)."' size='14'></td>";
             echo "<td rowspan='5'>".$LANG['common'][25]."&nbsp;:</td>";
             echo "<td rowspan='5' class='middle'>";
             echo "<textarea cols='45' rows='9' name='comment' >".$ic->fields["comment"];
@@ -900,10 +953,11 @@ class Infocom extends CommonDBChild {
 
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][81]."&nbsp;:</td><td>";
-            echo formatNumber(self::Amort($ic->fields["sink_type"], $ic->fields["value"],
-                                          $ic->fields["sink_time"], $ic->fields["sink_coeff"],
-                                          $ic->fields["warranty_date"], $ic->fields["use_date"],
-                                          $date_tax,"n"));
+            echo Html::formatNumber(self::Amort($ic->fields["sink_type"], $ic->fields["value"],
+                                                   $ic->fields["sink_time"],
+                                                   $ic->fields["sink_coeff"],
+                                                   $ic->fields["warranty_date"],
+                                                   $ic->fields["use_date"], $date_tax,"n"));
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
@@ -927,8 +981,8 @@ class Infocom extends CommonDBChild {
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][77]."&nbsp;:</td>";
             echo "<td>";
-            autocompletionTextField($ic, "sink_coeff", array('size'   => 14,
-                                                             'option' => $option));
+            Html::autocompletionTextField($ic, "sink_coeff", array('size'   => 14,
+                                                                   'option' => $option));
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
@@ -955,7 +1009,8 @@ class Infocom extends CommonDBChild {
             echo "<tr><th colspan='4'>".$LANG['financial'][7]."</th></tr>";
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][29]."&nbsp;:</td><td>";
-            showDateFormItem("warranty_date", $ic->fields["warranty_date"], true, $editcalendar);
+            Html::showDateFormItem("warranty_date", $ic->fields["warranty_date"], true,
+                                   $editcalendar);
             echo "</td>";
 
             echo "<td>".$LANG['financial'][15]."&nbsp;:</td><td>";
@@ -975,13 +1030,14 @@ class Infocom extends CommonDBChild {
                echo " ".$LANG['financial'][57];
             }
             echo "<span class='small_space'>".$LANG['financial'][88]."</span>&nbsp;";
-            echo getWarrantyExpir($ic->fields["warranty_date"], $ic->fields["warranty_duration"]);
+            echo self::getWarrantyExpir($ic->fields["warranty_date"],
+                                        $ic->fields["warranty_duration"]);
             echo "</td></tr>";
 
             echo "<tr class='tab_bg_1'>";
             echo "<td>".$LANG['financial'][16]."&nbsp;:</td>";
             echo "<td >";
-            autocompletionTextField($ic, "warranty_info", array('option' => $option));
+            Html::autocompletionTextField($ic, "warranty_info", array('option' => $option));
             echo "</td>";
 
             if ($CFG_GLPI['use_mailing']) {
@@ -1016,7 +1072,7 @@ class Infocom extends CommonDBChild {
 
 
 
-   static function getSearchOptionsToAdd ($itemtype) {
+   static function getSearchOptionsToAdd($itemtype) {
       global $LANG;
 
 
@@ -1378,16 +1434,15 @@ class Infocom extends CommonDBChild {
       return $tab;
    }
 
-
    /**
     * Display debug information for infocom of current object
    **/
    function showDebug() {
 
       $item = array('item_name'           => '',
-                     'warrantyexpiration' => '',
-                     'itemtype'           => $this->fields['itemtype'],
-                     'items_id'           => $this->fields['items_id']);
+                    'warrantyexpiration' => '',
+                    'itemtype'           => $this->fields['itemtype'],
+                    'items_id'           => $this->fields['items_id']);
 
       $options['entities_id'] = $this->getEntityID();
       $options['items']       = array($item);
@@ -1403,7 +1458,7 @@ class Infocom extends CommonDBChild {
     * @param $newid ID of the item cloned
     * @param $newitemtype itemtype of the new item (= $itemtype if empty)
    **/
-   function cloneItem ($itemtype, $oldid, $newid, $newitemtype = '') {
+   function cloneItem($itemtype, $oldid, $newid, $newitemtype='') {
       global $DB;
 
 
@@ -1416,7 +1471,7 @@ class Infocom extends CommonDBChild {
          unset ($input["id"]);
          if (isset($input["immo_number"])) {
             $input["immo_number"] = autoName($input["immo_number"], "immo_number", 1, 'Infocom',
-                                    $input['entities_id']);
+                                             $input['entities_id']);
          }
          $date_fields = array('buy_date', 'delivery_date', 'inventory_date', 'order_date',
                               'use_date', 'warranty_date');
@@ -1429,6 +1484,33 @@ class Infocom extends CommonDBChild {
       }
    }
 
+
+   /**
+    * Get date using a begin date and a period in month
+    *
+    * @param $from date: begin date
+    * @param $addwarranty integer: period in months
+    * @param $deletenotice integer: period in months of notice
+    *
+    * @return expiration date string
+   **/
+   static function getWarrantyExpir($from, $addwarranty, $deletenotice=0) {
+      global $LANG;
+
+      // Life warranty
+      if ($addwarranty==-1 && $deletenotice==0) {
+         return $LANG['setup'][307];
+      }
+
+      if ($from==NULL || empty($from)) {
+         return "";
+      }
+
+      return Html::convDate(date("Y-m-d",
+                                 strtotime("$from+$addwarranty month -$deletenotice month")));
+   }
+
+
 }
 
-?>
+?>
\ No newline at end of file
