@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: knowbaseitemcategory.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: knowbaseitemcategory.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,19 +39,26 @@ if (!defined('GLPI_ROOT')) {
 /// Class KnowbaseItemCategory
 class KnowbaseItemCategory extends CommonTreeDropdown {
 
+   // From CommonDBTM
+   public $dohistory = true;
+
+
    function canCreate() {
-      return haveRight('entity_dropdown', 'w');
+      return Session::haveRight('entity_dropdown', 'w');
    }
 
 
    function canView() {
-      return haveRight('entity_dropdown', 'r');
+      return Session::haveRight('entity_dropdown', 'r');
    }
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['dropdown'][27];
+      }
       return $LANG['setup'][87];
    }
 
@@ -97,32 +104,34 @@ class KnowbaseItemCategory extends CommonTreeDropdown {
       $faq_limit = '';
 
       if ($faq) {
-         if (!$CFG_GLPI["use_public_faq"] && !haveRight("faq","r")) {
+         if (!$CFG_GLPI["use_public_faq"] && !Session::haveRight("faq","r")) {
             return false;
          }
 
-         if (getLoginUserID()) {
+         if (Session::getLoginUserID()) {
             $faq_limit = getEntitiesRestrictRequest("AND", "glpi_knowbaseitemcategories", "", "",
                                                     true);
          } else {
             // Anonymous access
-            if (isMultiEntitiesMode()) {
+            if (Session::isMultiEntitiesMode()) {
                $faq_limit = " AND (`glpi_knowbaseitemcategories`.`entities_id` = '0'
                                    AND `glpi_knowbaseitemcategories`.`is_recursive` = '1')";
             }
          }
 
          // Get All FAQ categories
-         if (!isset($_SESSION['glpi_faqcategories'])) {
+         if (true || !isset($_SESSION['glpi_faqcategories'])) {
 
             $_SESSION['glpi_faqcategories'] = '(0)';
             $tmp = array();
             $query = "SELECT DISTINCT `glpi_knowbaseitems`.`knowbaseitemcategories_id`
                       FROM `glpi_knowbaseitems`
+                      ".KnowbaseItem::addVisibilityJoins()."
                       LEFT JOIN `glpi_knowbaseitemcategories`
                            ON (`glpi_knowbaseitemcategories`.`id`
                                  = `glpi_knowbaseitems`.`knowbaseitemcategories_id`)
                       WHERE `glpi_knowbaseitems`.`is_faq` = '1'
+                            AND ".KnowbaseItem::addVisibilityRestrict()."
                             $faq_limit";
 
             if ($result=$DB->query($query)) {
@@ -138,19 +147,20 @@ class KnowbaseItemCategory extends CommonTreeDropdown {
                }
                if (count($tmp)) {
                   $_SESSION['glpi_faqcategories'] = "('".implode("','",$tmp)."')";
+                  echo '.';
                }
             }
          }
          $query = "SELECT DISTINCT `glpi_knowbaseitemcategories`.*
                    FROM `glpi_knowbaseitemcategories`
-                   WHERE `id` IN ".$_SESSION['glpi_faqcategories']."
+                   WHERE `glpi_knowbaseitemcategories`.`id` IN ".$_SESSION['glpi_faqcategories']."
                          AND (`glpi_knowbaseitemcategories`.`knowbaseitemcategories_id`
                                  = '".$params["knowbaseitemcategories_id"]."')
                          $faq_limit
                    ORDER BY `name` ASC";
 
       } else {
-         if (!haveRight("knowbase", "r")) {
+         if (!Session::haveRight("knowbase", "r")) {
             return false;
          }
          $faq_limit = getEntitiesRestrictRequest("AND", "glpi_knowbaseitemcategories", "entities_id",
@@ -178,7 +188,7 @@ class KnowbaseItemCategory extends CommonTreeDropdown {
             while ($tmpID!=0) {
                $query2 = "SELECT *
                           FROM `glpi_knowbaseitemcategories`
-                          WHERE `id` = '$tmpID'
+                          WHERE `glpi_knowbaseitemcategories`.`id` = '$tmpID'
                                 $faq_limit";
                $result2 = $DB->query($query2);
 
@@ -205,9 +215,10 @@ class KnowbaseItemCategory extends CommonTreeDropdown {
                $ID = $row["id"];
                echo "<td class='tdkb_result'>";
                echo "<img alt='' src='".$CFG_GLPI["root_doc"]."/pics/folder.png' hspace='5'>";
-               echo "<strong><a href='".$params['target']."?knowbaseitemcategories_id=".$row["id"]."'>".
-                              $row["name"]."</a></strong>";
-               echo "<div class='kb_resume'>".resume_text($row['comment'],60)."</div>";
+               echo "<span class='b'>".
+                    "<a href='".$params['target']."?knowbaseitemcategories_id=".$row["id"]."'>".
+                      $row["name"]."</a></span>";
+               echo "<div class='kb_resume'>".Html::resume_text($row['comment'],60)."</div>";
 
                if ($i%3==2) {
                   echo "</tr>";
