@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailcollector.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: mailcollector.class.php 18022 2012-03-27 07:57:42Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -70,31 +70,33 @@ class MailCollector  extends CommonDBTM {
    public $dohistory = true;
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['Menu'][39];
+      if ($nb>1) {
+         return $LANG['Menu'][39];
+      }
+      return $LANG['mailgate'][0];
    }
 
 
    function canCreate() {
-      return haveRight('config', 'w');
+      return Session::haveRight('config', 'w');
    }
 
 
    function canView() {
-      return haveRight('config', 'r');
+      return Session::haveRight('config', 'r');
    }
 
 
-   function post_getEmpty () {
+   function post_getEmpty() {
       global $CFG_GLPI;
 
       $this->fields['filesize_max'] = $CFG_GLPI['default_mailcollector_filesize_max'];
       $this->fields['is_active']=1;
    }
 
-
    function prepareInputForUpdate($input) {
       global $LANG;
 
@@ -102,17 +104,21 @@ class MailCollector  extends CommonDBTM {
          if (empty($input["passwd"])) {
             unset($input["passwd"]);
          } else {
-            $input["passwd"] = encrypt(stripslashes($input["passwd"]), GLPIKEY);
+            $input["passwd"] = Toolbox::encrypt(stripslashes($input["passwd"]), GLPIKEY);
          }
       }
 
-      if (isset ($input['mail_server']) && !empty ($input['mail_server'])) {
-         $input["host"] = constructMailServerConfig($input);
+      if (isset($input["_blank_passwd"]) && $input["_blank_passwd"]) {
+         $input['passwd'] = '';
+      }
+
+      if (isset($input['mail_server']) && !empty($input['mail_server'])) {
+         $input["host"] = Toolbox::constructMailServerConfig($input);
       }
 
       if (!NotificationMail::isUserAddressValid($input['name'])) {
-         addMessageAfterRedirect($LANG['mailing'][111].' : '.$LANG['mailing'][110],
-                                 false, ERROR);
+         Session::addMessageAfterRedirect($LANG['mailing'][111].' : '.$LANG['mailing'][110],
+                                          false, ERROR);
       }
 
       return $input;
@@ -126,17 +132,17 @@ class MailCollector  extends CommonDBTM {
          if (empty($input["passwd"])) {
             unset($input["passwd"]);
          } else {
-            $input["passwd"] = encrypt(stripslashes($input["passwd"]), GLPIKEY);
+            $input["passwd"] = Toolbox::encrypt(stripslashes($input["passwd"]), GLPIKEY);
          }
       }
 
-      if (isset ($input['mail_server']) && !empty ($input['mail_server'])) {
-         $input["host"] = constructMailServerConfig($input);
+      if (isset($input['mail_server']) && !empty($input['mail_server'])) {
+         $input["host"] = Toolbox::constructMailServerConfig($input);
       }
 
       if (!NotificationMail::isUserAddressValid($input['name'])) {
-         addMessageAfterRedirect($LANG['mailing'][111].' : '.$LANG['mailing'][110],
-                                 false, ERROR);
+         Session::addMessageAfterRedirect($LANG['mailing'][111].' : '.$LANG['mailing'][110],
+                                          false, ERROR);
       }
 
       return $input;
@@ -147,13 +153,34 @@ class MailCollector  extends CommonDBTM {
       global $LANG;
 
       $ong = array();
-      $ong[1] = $LANG['title'][26];
-      if ($this->fields['id'] > 0) {
-         $ong[12] = $LANG['title'][38];
-      }
+      $this->addStandardTab(__CLASS__, $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
+
       return $ong;
    }
 
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case __CLASS__ :
+               return self::getTypeName(1);
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+      global $CFG_GLPI;
+
+      if($item->getType() == __CLASS__) {
+         $item->showGetMessageForm($item->getID());
+      }
+      return true;
+   }
+
 
    /**
     * Print the mailgate form
@@ -167,7 +194,7 @@ class MailCollector  extends CommonDBTM {
    function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
-      if (!haveRight("config", "r")) {
+      if (!Session::haveRight("config", "r")) {
          return false;
       }
       if ($ID > 0) {
@@ -184,22 +211,27 @@ class MailCollector  extends CommonDBTM {
          echo "<tr class='tab_bg_1'><td colspan='2'>".$LANG['mailgate'][4]."</td></tr>";
       }
 
-      echo "<tr class='tab_bg_1'><td>".$LANG['common'][16]." (".$LANG['mailing'][111].")&nbsp;:</td><td>";
-      autocompletionTextField($this, "name");
+      echo "<tr class='tab_bg_1'><td>".$LANG['common'][16]." (".$LANG['mailing'][111].")&nbsp;:";
+      echo "</td><td>";
+      Html::autocompletionTextField($this, "name");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'><td>".$LANG['common'][60]."&nbsp;:</td><td>";
       Dropdown::showYesNo("is_active", $this->fields["is_active"]);
       echo "</td></tr>";
 
-      showMailServerConfig($this->fields["host"]);
+      Toolbox::showMailServerConfig($this->fields["host"]);
 
       echo "<tr class='tab_bg_1'><td>".$LANG['login'][6]."&nbsp;:</td><td>";
-      autocompletionTextField($this, "login");
+      Html::autocompletionTextField($this, "login");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'><td>".$LANG['login'][7]."&nbsp;:</td>";
-      echo "<td><input type='password' name='passwd' value='' size='20' autocomplete='off'></td>";
+      echo "<td><input type='password' name='passwd' value='' size='20' autocomplete='off'>";
+      if ($ID > 0) {
+         echo "<input type='checkbox' name='_blank_passwd'>&nbsp;".$LANG['setup'][284];
+      }
+      echo "</td>";
       echo "</tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -211,7 +243,7 @@ class MailCollector  extends CommonDBTM {
       echo "<td><textarea cols='45' rows='5' name='comment' >".$this->fields["comment"]."</textarea>";
 
       if ($ID>0) {
-         echo "<br>".$LANG['common'][26]."&nbsp;: ".convDateTime($this->fields["date_mod"]);
+         echo "<br>".$LANG['common'][26]."&nbsp;: ".Html::convDateTime($this->fields["date_mod"]);
       }
       echo "</td></tr>";
 
@@ -225,7 +257,7 @@ class MailCollector  extends CommonDBTM {
       global $LANG;
 
       echo "<br><br><div class='center'>";
-      echo "<form name='form' method='post' action='".getItemTypeFormURL(__CLASS__)."'>";
+      echo "<form name='form' method='post' action='".Toolbox::getItemTypeFormURL(__CLASS__)."'>";
       echo "<table class='tab_cadre'>";
       echo "<tr class='tab_bg_2'><td class='center'>";
       echo "<input type='submit' name='get_mails' value=\"".$LANG['mailgate'][2]."\" class='submit'>";
@@ -298,7 +330,7 @@ class MailCollector  extends CommonDBTM {
       foreach ($DB->request($query) as $data) {
          $todelete[$data['mailcollectors_id']][$data['messageid']] = $data;
       }
-      $ticket = new Ticket;
+      $ticket = new Ticket();
       foreach ($todelete as $mailcollector_id => $rejected) {
          if ($this->getFromDB($mailcollector_id)) {
             $this->mid          = -1;
@@ -313,7 +345,7 @@ class MailCollector  extends CommonDBTM {
                if (isset($rejected[$head['message_id']])) {
                   if ($action == 1) {
                      $tkt = array();
-                     $tkt = $this->buildTicket($i, array('mailcollectors_id' => $mailcollector_id,
+                     $tkt = $this->buildTicket($i, array('mailgates_id' => $mailcollector_id,
                                                          'play_rules'        => false));
                      $tkt['_users_id_requester'] = $rejected[$head['message_id']]['users_id'];
                      $tkt['entities_id']         = $entity;
@@ -335,8 +367,9 @@ class MailCollector  extends CommonDBTM {
                               '>' => '');
                foreach ($rejected as $id => $data) {
                   if ($action == 1) {
-                     addMessageAfterRedirect($LANG['mailgate'][14]."&nbsp;: ".strtr($id,$clean),
-                                             false, ERROR);
+                     Session::addMessageAfterRedirect($LANG['mailgate'][14]."&nbsp;: ".strtr($id,
+                                                                                             $clean),
+                                                      false, ERROR);
                   } else { // Delete data in notimportedemail table
                      $rejectedmail = new NotImportedEmail();
                      $rejectedmail->delete(array('id' => $data['id']));
@@ -366,7 +399,7 @@ class MailCollector  extends CommonDBTM {
          $this->fetch_emails = 0;
          //Connect to the Mail Box
          $this->connect();
-         $rejected = new NotImportedEmail;
+         $rejected = new NotImportedEmail();
 
          // Clean from previous collect (from GUI, cron already truncate the table)
          $rejected->deleteByCriteria(array('mailcollectors_id' => $this->fields['id']));
@@ -377,7 +410,7 @@ class MailCollector  extends CommonDBTM {
             $error = 0;
             $refused = 0;
 
-            for($i=1 ; $i<=$tot && $this->fetch_emails<$this->maxfetch_emails ; $i++) {
+            for ($i=1 ; $i<=$tot && $this->fetch_emails<$this->maxfetch_emails ; $i++) {
                $tkt = $this->buildTicket($i, array('mailgates_id' => $mailgateID,
                                                    'play_rules'   => true));
 
@@ -386,16 +419,17 @@ class MailCollector  extends CommonDBTM {
 
                //If entity assigned, or email refused by rule, or no user associated with the email
                $user_condition = ($CFG_GLPI["use_anonymous_helpdesk"]
-                                  ||(isset($tkt['_users_id_requester']) && $tkt['_users_id_requester'] > 0));
+                                  ||(isset($tkt['_users_id_requester'])
+                                     && $tkt['_users_id_requester'] > 0));
 
                // Manage blacklisted emails
                if (isset($tkt['_blacklisted']) && $tkt['_blacklisted']) {
                   $this->deleteMails($i);
                // entities_id set when new ticket / tickets_id when new followup
                } else if (((isset($tkt['entities_id']) || isset($tkt['tickets_id']))
-                    && $user_condition)
-                   || isset($tkt['_refuse_email_no_response'])
-                   || isset($tkt['_refuse_email_with_response'])) {
+                           && $user_condition)
+                          || isset($tkt['_refuse_email_no_response'])
+                          || isset($tkt['_refuse_email_with_response'])) {
 
                   if (isset($tkt['_refuse_email_with_response'])) {
                      $this->sendMailRefusedResponse($tkt['_head']['from'], $tkt['name']);
@@ -405,7 +439,7 @@ class MailCollector  extends CommonDBTM {
                      $delete_mail = true;
                      $refused++;
                   } else if (isset($tkt['entities_id']) || isset($tkt['tickets_id'])) {
-                     $tkt['_mailgate'] = $mailgateID;
+
                      $result           = imap_fetchheader($this->marubox, $i);
 
                      // Is a mail responding of an already existgin ticket ?
@@ -469,11 +503,13 @@ class MailCollector  extends CommonDBTM {
             if ($display) {
 
                if ($error==0) {
-                  addMessageAfterRedirect($LANG['mailgate'][3]."&nbsp;: ".$this->fetch_emails);
+                  Session::addMessageAfterRedirect($LANG['mailgate'][3]."&nbsp;: ".
+                                                   $this->fetch_emails);
                } else {
-                  addMessageAfterRedirect($LANG['mailgate'][3]."&nbsp;: ".$this->fetch_emails.
-                                          " ($error ".$LANG['common'][63].")",
-                                          false, ERROR);
+                  Session::addMessageAfterRedirect($LANG['mailgate'][3]."&nbsp;: ".
+                                                    $this->fetch_emails." ($error ".
+                                                    $LANG['common'][63].")",
+                                                   false, ERROR);
                }
 
             } else {
@@ -484,7 +520,7 @@ class MailCollector  extends CommonDBTM {
 
          } else {
             if ($display) {
-               addMessageAfterRedirect($LANG['log'][41], false, ERROR);
+               Session::addMessageAfterRedirect($LANG['log'][41], false, ERROR);
             } else {
                return "Could not connect to mailgate server";
             }
@@ -492,8 +528,8 @@ class MailCollector  extends CommonDBTM {
 
       } else {
          if ($display) {
-            addMessageAfterRedirect($LANG['common'][54]."&nbsp;: mailgate ".$mailgateID,
-                                    false, ERROR);
+            Session::addMessageAfterRedirect($LANG['common'][54]."&nbsp;: mailgate ".$mailgateID,
+                                             false, ERROR);
          } else {
             return 'Could find mailgate '.$mailgateID;
          }
@@ -508,16 +544,16 @@ class MailCollector  extends CommonDBTM {
     *
     * @return ticket fields array
     */
-   function buildTicket($i,$options=array()) {
+   function buildTicket($i, $options=array()) {
+      global $CFG_GLPI;
 
       $play_rules = (isset($options['play_rules']) && $options['play_rules']);
-
-      $head = $this->getHeaders($i); // Get Header Info Return Array Of Headers
-                                     // **Key Are (subject,to,toOth,toNameOth,from,fromName)
-
+      $head       = $this->getHeaders($i); // Get Header Info Return Array Of Headers
+                                           // **Key Are (subject,to,toOth,toNameOth,from,fromName)
       $tkt = array();
       $tkt['_blacklisted'] = false;
-
+      // For RuleTickets
+      $tkt['_mailgate']    = $options['mailgates_id'];
       // Detect if it is a mail reply
       $glpi_message_match = "/GLPI-([0-9]+)\.[0-9]+\.[0-9]+@\w*/";
 
@@ -532,12 +568,13 @@ class MailCollector  extends CommonDBTM {
          if (is_writable(GLPI_DOC_DIR."/_tmp/")) {
             $_FILES = $this->getAttached($i, GLPI_DOC_DIR."/_tmp/", $this->fields['filesize_max']);
          } else {
-            logInFile('mailgate', GLPI_DOC_DIR."/_tmp/ is not writable");
+            Toolbox::logInFile('mailgate', GLPI_DOC_DIR."/_tmp/ is not writable");
          }
       }
       //  Who is the user ?
       $tkt['_users_id_requester'] = User::getOrImportByEmail($head['from']);
       $tkt["_users_id_requester_notif"]['use_notification'] = 1;
+      // Set alternative email if user not found / used if anonymous mail creation is enable
       if (!$tkt['_users_id_requester']) {
          $tkt["_users_id_requester_notif"]['alternative_email'] = $head['from'];
       }
@@ -547,17 +584,18 @@ class MailCollector  extends CommonDBTM {
          foreach ($head['ccs'] as $cc) {
             if ($cc != $head['from']
                 && strcasecmp($cc, $this->fields['name'])
-                && ($tmp=User::getOrImportByEmail($cc))>0) {
+                && ($tmp=User::getOrImportByEmail($cc)) > 0) {
                $tkt['_additional_observers'][] = array('users_id'         => $tmp,
                                                        'use_notification' => 1);
             }
          }
       }
+
       if (count($head['tos'])) {
          foreach ($head['tos'] as $to) {
             if ($to != $head['from']
                 && strcasecmp($to, $this->fields['name'])
-                && ($tmp=User::getOrImportByEmail($to, false))>0) {
+                && ($tmp=User::getOrImportByEmail($to)) > 0) {
                $tkt['_additional_observers'][] = array('users_id'         => $tmp,
                                                        'use_notification' => 1);
             }
@@ -574,12 +612,12 @@ class MailCollector  extends CommonDBTM {
       $tkt['_head']    = $head;
 
       if (!empty($this->charset) && !$this->body_converted) {
-         $body = encodeInUtf8($body,$this->charset);
+         $body = Toolbox::encodeInUtf8($body,$this->charset);
          $this->body_converted = true;
       }
 
-      if (!seems_utf8($body)) {
-         $tkt['content'] = encodeInUtf8($body);
+      if (!Toolbox::seems_utf8($body)) {
+         $tkt['content'] = Toolbox::encodeInUtf8($body);
       } else {
          $tkt['content'] = $body;
       }
@@ -604,7 +642,7 @@ class MailCollector  extends CommonDBTM {
       }
 
       // See in title
-      if (!isset($tkt['tickets_id']) && preg_match('/\[GLPI #(\d+)\]/',$head['subject'],$match)) {
+      if (!isset($tkt['tickets_id']) && preg_match('/\[.+#(\d+)\]/',$head['subject'],$match)) {
          $tkt['tickets_id'] = intval($match[1]);
       }
 
@@ -612,12 +650,15 @@ class MailCollector  extends CommonDBTM {
       if (isset($tkt['tickets_id'])) {
          // it's a reply to a previous ticket
          $job = new Ticket();
+         $tu  = new Ticket_User();
 
          // Check if ticket  exists and users_id exists in GLPI
          /// TODO check if users_id have right to add a followup to the ticket
          if ($job->getFromDB($tkt['tickets_id'])
              && $job->fields['status'] != 'closed'
-             && ($tkt['_users_id_requester'] > 0 || Ticket_User::isAlternateEmailForTicket($tkt['tickets_id'],$head['from']))) {
+             && ($CFG_GLPI['use_anonymous_followups']
+                 || $tkt['_users_id_requester'] > 0
+                 || $tu->isAlternateEmailForITILObject($tkt['tickets_id'], $head['from']))) {
 
             $content        = explode("\n", $tkt['content']);
             $tkt['content'] = "";
@@ -636,7 +677,6 @@ class MailCollector  extends CommonDBTM {
                         unset($to_keep[$ID-1]);
                      }
                   }
-
                } else {
                   $to_keep[$ID] = $ID;
                }
@@ -657,7 +697,7 @@ class MailCollector  extends CommonDBTM {
       }
 
       $tkt['name'] = $this->textCleaner($head['subject']);
-      if (! isset($tkt['tickets_id'])) {
+      if (!isset($tkt['tickets_id'])) {
          // Which entity ?
          //$tkt['entities_id']=$this->fields['entities_id'];
          //$tkt['Subject']= $head['subject'];   // not use for the moment
@@ -673,7 +713,7 @@ class MailCollector  extends CommonDBTM {
       }
 
       $tkt['requesttypes_id'] = RequestType::getDefault('mail');
-      $tkt['content']         = clean_cross_side_scripting_deep(html_clean($tkt['content']));
+      $tkt['content']         = Toolbox::clean_cross_side_scripting_deep(Html::clean($tkt['content']));
 
       if ($play_rules) {
          $rule_options['ticket']              = $tkt;
@@ -684,7 +724,7 @@ class MailCollector  extends CommonDBTM {
          $output         = $rulecollection->processAllRules(array(), array(), $rule_options);
 
          // New ticket : compute all
-         if (! isset($tkt['tickets_id'])) {
+         if (!isset($tkt['tickets_id'])) {
             foreach ($output as $key => $value) {
                $tkt[$key] = $value;
             }
@@ -699,7 +739,7 @@ class MailCollector  extends CommonDBTM {
          }
       }
 
-      $tkt = addslashes_deep($tkt);
+      $tkt = Toolbox::addslashes_deep($tkt);
       return $tkt;
    }
 
@@ -713,7 +753,7 @@ class MailCollector  extends CommonDBTM {
    function textCleaner($text) {
 
       $text = str_replace("=20", "\n", $text);
-      $text =  clean_cross_side_scripting_deep($text);
+      $text =  Toolbox::clean_cross_side_scripting_deep($text);
       return $text;
    }
 
@@ -723,7 +763,7 @@ class MailCollector  extends CommonDBTM {
 
       $r = mb_list_encodings();
       for ($n=sizeOf($r) ; $n--; ) {
-         $r[$n] = utf8_strtolower($r[$n]);
+         $r[$n] = Toolbox::strtolower($r[$n]);
       }
       return $r;
    }
@@ -747,15 +787,15 @@ class MailCollector  extends CommonDBTM {
 
       if (function_exists('mb_list_encodings') && function_exists('mb_convert_encoding')) {
          $encodings       = $this->mb_list_lowerencodings();
-         $inputCharset    = utf8_strtolower($inputCharset);
-         $targetCharset   = utf8_strtolower($targetCharset);
-         $fallbackCharset = utf8_strtolower($fallbackCharset);
+         $inputCharset    = Toolbox::strtolower($inputCharset);
+         $targetCharset   = Toolbox::strtolower($targetCharset);
+         $fallbackCharset = Toolbox::strtolower($fallbackCharset);
          $decodedStr      = '';
          $mimeStrs        = imap_mime_header_decode($mimeStr);
 
          for ($n=sizeOf($mimeStrs),$i=0 ; $i<$n ; $i++) {
             $mimeStr = $mimeStrs[$i];
-            $mimeStr->charset = utf8_strtolower($mimeStr->charset);
+            $mimeStr->charset = Toolbox::strtolower($mimeStr->charset);
 
             if (($mimeStr->charset == 'default' && $inputCharset == $targetCharset)
                 || $mimeStr->charset == $targetCharset) {
@@ -780,7 +820,7 @@ class MailCollector  extends CommonDBTM {
     ///Connect To the Mail Box
    function connect() {
       $this->marubox = @imap_open($this->fields['host'], $this->fields['login'],
-                                  decrypt($this->fields['passwd'],GLPIKEY), CL_EXPUNGE);
+                                  Toolbox::decrypt($this->fields['passwd'],GLPIKEY), CL_EXPUNGE);
    }
 
 
@@ -814,7 +854,7 @@ class MailCollector  extends CommonDBTM {
                 || preg_match("/^Received/i", $line)) {
                // separate name and value
                if (preg_match("/^([^:]*): (.*)/i", $line, $arg)) {
-                  $key = utf8_strtolower($arg[1]);
+                  $key = Toolbox::strtolower($arg[1]);
 
                   if (!isset($head[$key])) {
                      $head[$key] = '';
@@ -852,26 +892,31 @@ class MailCollector  extends CommonDBTM {
 
       $mail_details=array();
 
-      if (utf8_strtolower($sender->mailbox)!='mailer-daemon'
-          && utf8_strtolower($sender->mailbox)!='postmaster') {
+      if (Toolbox::strtolower($sender->mailbox)!='mailer-daemon'
+          && Toolbox::strtolower($sender->mailbox)!='postmaster') {
 
          // Construct to and cc arrays
          $tos = array();
          $ccs = array();
          if (count($mail_header->to)) {
             foreach ($mail_header->to as $data) {
-               $tos[] = utf8_strtolower($data->mailbox).'@'.$data->host;
+               $tos[] = Toolbox::strtolower($data->mailbox).'@'.$data->host;
             }
          }
          if (isset($mail_header->cc) && count($mail_header->cc)) {
             foreach ($mail_header->cc as $data) {
-               $ccs[] = utf8_strtolower($data->mailbox).'@'.$data->host;
+               $ccs[] = Toolbox::strtolower($data->mailbox).'@'.$data->host;
             }
          }
 
-         $mail_details = array('from'       => utf8_strtolower($sender->mailbox).'@'.$sender->host,
+         // secu on subject setting
+         if (!isset($mail_header->subject)) {
+            $mail_header->subject = '';         
+         }
+         
+         $mail_details = array('from'       => Toolbox::strtolower($sender->mailbox).'@'.$sender->host,
                                'subject'    => $mail_header->subject,
-                               'to'         => utf8_strtolower($to->mailbox).'@'.$to->host,
+                               'to'         => Toolbox::strtolower($to->mailbox).'@'.$to->host,
                                'message_id' => $mail_header->message_id,
                                'tos'        => $tos,
                                'ccs'        => $ccs);
@@ -1056,7 +1101,7 @@ class MailCollector  extends CommonDBTM {
     * Result is stored in $this->files
     *
     */
-   function getRecursiveAttached ($mid, $path, $maxsize, $structure, $part="") {
+   function getRecursiveAttached($mid, $path, $maxsize, $structure, $part="") {
       global $LANG;
 
       if ($structure->type == 1) { // multipart
@@ -1074,8 +1119,8 @@ class MailCollector  extends CommonDBTM {
             // if there are any dparameters present in this part
             if (count($structure->dparameters)>0) {
                foreach ($structure->dparameters as $dparam) {
-                  if ((utf8_strtoupper($dparam->attribute)=='NAME')
-                      || (utf8_strtoupper($dparam->attribute)=='FILENAME')) {
+                  if ((Toolbox::strtoupper($dparam->attribute)=='NAME')
+                      || (Toolbox::strtoupper($dparam->attribute)=='FILENAME')) {
 
                      $filename = $dparam->value;
                   }
@@ -1088,8 +1133,8 @@ class MailCollector  extends CommonDBTM {
             // if there are any parameters present in this part
             if (count($structure->parameters)>0) {
                foreach ($structure->parameters as $param) {
-                  if ((utf8_strtoupper($param->attribute)=='NAME')
-                      || (utf8_strtoupper($param->attribute)=='FILENAME')) {
+                  if ((Toolbox::strtoupper($param->attribute)=='NAME')
+                      || (Toolbox::strtoupper($param->attribute)=='FILENAME')) {
 
                      $filename = $param->value;
                   }
@@ -1110,7 +1155,7 @@ class MailCollector  extends CommonDBTM {
 
          if ($structure->bytes > $maxsize) {
             $this->addtobody .= "<br>".$LANG['mailgate'][6]." (" .
-                                getSize($structure->bytes) . "): ".$filename;
+                                Toolbox::getSize($structure->bytes) . "): ".$filename;
             return false;
          }
 
@@ -1140,12 +1185,11 @@ class MailCollector  extends CommonDBTM {
             }
 
             if (file_put_contents($path.$filename, $message)) {
-               $this->files['multiple'] = true;
-               $j = count($this->files)-1;
-               $this->files[$j]['filename']['size']     = $structure->bytes;
-               $this->files[$j]['filename']['name']     = $filename;
-               $this->files[$j]['filename']['tmp_name'] = $path.$filename;
-               $this->files[$j]['filename']['type']     = $this->get_mime_type($structure);
+               $this->files['filename']['size'][]     = $structure->bytes;
+               $this->files['filename']['name'][]     = $filename;
+               $this->files['filename']['tmp_name'][] = $path.$filename;
+               $this->files['filename']['type'][]     = $this->get_mime_type($structure);
+               $this->files['filename']['error'][]    = 0;
             }
          } // fetchbody
       } // Single part
@@ -1161,7 +1205,7 @@ class MailCollector  extends CommonDBTM {
     *
     * @return array like $_FILES
     */
-   function getAttached ($mid, $path, $maxsize) {
+   function getAttached($mid, $path, $maxsize) {
 
       $this->getStructure($mid);
       $this->files     = array();
@@ -1246,8 +1290,8 @@ class MailCollector  extends CommonDBTM {
                $task->log("Collect mails from ".$data["host"]."\n");
                $message = $mc->collect($data["id"]);
 
-               $task->log("$message\n");
                $task->addVolume($mc->fetch_emails);
+               $task->log("$message\n");
 
                $max -= $mc->fetch_emails;
             }
@@ -1312,7 +1356,7 @@ class MailCollector  extends CommonDBTM {
    function sendMailRefusedResponse($to='', $subject='') {
       global $CFG_GLPI, $LANG;
 
-      $mmail           = new NotificationMail;
+      $mmail           = new NotificationMail();
       $mmail->AddCustomHeader("Auto-Submitted: auto-replied");
       $mmail->SetFrom($CFG_GLPI["admin_email"], $CFG_GLPI["admin_email_name"]);
       $mmail->AddAddress($to);
@@ -1328,8 +1372,8 @@ class MailCollector  extends CommonDBTM {
       if (countElementsInTable($this->getTable())) {
          $buttons = array();
          $buttons["notimportedemail.php"] = $LANG['rulesengine'][142];
-         displayTitle($CFG_GLPI["root_doc"] . "/pics/users.png", $LANG['rulesengine'][142], '',
-                      $buttons);
+         Html::displayTitle($CFG_GLPI["root_doc"] . "/pics/users.png", $LANG['rulesengine'][142],
+                            '', $buttons);
       }
    }
 
@@ -1348,7 +1392,7 @@ class MailCollector  extends CommonDBTM {
    static function showMaxFilesize($name, $value = 0) {
       global $LANG;
 
-      $sizes[0] = $LANG['ocsconfig'][11];
+      $sizes[0] = $LANG['mailgate'][8];
       for ($index=1 ; $index<100 ; $index++) {
          $sizes[$index*1048576] = $index. ' '.$LANG['common'][82];
       }
@@ -1362,6 +1406,7 @@ class MailCollector  extends CommonDBTM {
       Rule::cleanForItemCriteria($this, 'mailcollector');
       Rule::cleanForItemCriteria($this, '_mailgate');
    }
-}
 
+
+}
 ?>
\ No newline at end of file
