@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: networkequipment.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: networkequipment.class.php 17560 2012-02-21 10:39:36Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -56,19 +56,19 @@ class NetworkEquipment extends CommonDBTM {
       global $LANG;
 
       if ($nb>1) {
-         return $LANG['Menu'][2];
+         return $LANG['Menu'][1];
       }
       return $LANG['help'][26];
    }
 
 
    function canCreate() {
-      return haveRight('networking', 'w');
+      return Session::haveRight('networking', 'w');
    }
 
 
    function canView() {
-      return haveRight('networking', 'r');
+      return Session::haveRight('networking', 'r');
    }
 
 
@@ -76,32 +76,16 @@ class NetworkEquipment extends CommonDBTM {
       global $LANG;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         $ong[1] = $LANG['title'][27];
-         if (haveRight("contract","r") || haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            if (haveRight("show_all_ticket","1")) {
-               $ong[6] = $LANG['title'][28];
-            }
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-            if (haveRight("reservation_central","r")) {
-               $ong[11] = $LANG['Menu'][17];
-            }
-            $ong[12] = $LANG['title'][38];
-         }
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('NetworkPort', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Reservation', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
+
       return $ong;
    }
 
@@ -197,7 +181,7 @@ class NetworkEquipment extends CommonDBTM {
     *
     * @return booleen
    **/
-   function canUnrecurs () {
+   function canUnrecurs() {
       global $DB;
 
       $ID = $this->fields['id'];
@@ -260,12 +244,12 @@ class NetworkEquipment extends CommonDBTM {
     *
     *@return boolean item found
    **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $LANG;
 
       // Show device or blank form
 
-      if (!haveRight("networking","r")) {
+      if (!Session::haveRight("networking","r")) {
          return false;
       }
 
@@ -279,16 +263,16 @@ class NetworkEquipment extends CommonDBTM {
       if (isset($options['withtemplate']) && $options['withtemplate'] == 2) {
          $template   = "newcomp";
          $datestring = $LANG['computers'][14]."&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else if (isset($options['withtemplate']) && $options['withtemplate'] == 1) {
          $template   = "newtemplate";
          $datestring = $LANG['computers'][14]."&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else {
          $datestring = $LANG['common'][26]."&nbsp;: ";
-         $date       = convDateTime($this->fields["date_mod"]);
+         $date       = Html::convDateTime($this->fields["date_mod"]);
          $template   = false;
       }
 
@@ -300,7 +284,7 @@ class NetworkEquipment extends CommonDBTM {
       echo "<td>";
       $objectName = autoName($this->fields["name"], "name", ($template === "newcomp"),
                              $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, "name", array('value' => $objectName));
+      Html::autocompletionTextField($this, "name", array('value' => $objectName));
       echo "</td>";
       echo "<td>".$LANG['state'][0]."&nbsp;:</td>";
       echo "<td>";
@@ -333,9 +317,12 @@ class NetworkEquipment extends CommonDBTM {
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][21]."&nbsp;:</td>";
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "contact_num");
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
       echo "</td>";
       echo "<td>".$LANG['common'][22]."&nbsp;:</td>";
       echo "<td>";
@@ -344,13 +331,25 @@ class NetworkEquipment extends CommonDBTM {
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][18]."&nbsp;:</td>";
+      echo "<td>".$LANG['common'][21]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "contact");
+      Html::autocompletionTextField($this, "contact_num");
       echo "</td>";
       echo "<td>".$LANG['common'][19]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "serial");
+      Html::autocompletionTextField($this, "serial");
+      echo "</td></tr>";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][18]."&nbsp;:</td>";
+      echo "<td>";
+      Html::autocompletionTextField($this, "contact");
+      echo "</td>";
+      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>";
+      echo "<td>";
+      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
+                             $this->getType(), $this->fields["entities_id"]);
+      Html::autocompletionTextField($this, "otherserial", array('value' => $objectName));
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -360,44 +359,39 @@ class NetworkEquipment extends CommonDBTM {
                            'entity' => $this->fields["entities_id"],
                            'right'  => 'all'));
       echo "</td>";
-      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>";
-      echo "<td>";
-      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
-                             $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, "otherserial", array('value' => $objectName));
-      echo "</td></tr>";
-
-      echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][35]."&nbsp;:</td>";
-      echo "<td>";
-      Dropdown::show('Group', array('value'  => $this->fields["groups_id"],
-                                    'entity' => $this->fields["entities_id"]));
-      echo "</td>";
       echo "<td>".$LANG['setup'][88]."&nbsp;:</td>";
       echo "<td>";
       Dropdown::show('Network', array('value' => $this->fields["networks_id"]));
       echo "</td></tr>";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][35]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('Group', array('value'     => $this->fields["groups_id"],
+                                    'entity'    => $this->fields["entities_id"],
+                                    'condition' => '`is_itemgroup`'));
+      echo "</td>";
+      echo "<td rowspan='7'>".$LANG['common'][25]."&nbsp;:</td>";
+      echo "<td rowspan='7'>
+            <textarea cols='45' rows='12' name='comment' >".$this->fields["comment"]."</textarea>";
+      echo "</td></tr>";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['setup'][89]."&nbsp;:</td>";
       echo "<td>";
       Dropdown::show('Domain', array('value' => $this->fields["domains_id"]));
-      echo "</td>";
-      echo "<td rowspan='6'>".$LANG['common'][25]."&nbsp;:</td>";
-      echo "<td rowspan='6'>
-            <textarea cols='45' rows='8' name='comment' >".$this->fields["comment"]."</textarea>";
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['networking'][14]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "ip");
+      Html::autocompletionTextField($this, "ip");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['networking'][15]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "mac");
+      Html::autocompletionTextField($this, "mac");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -410,7 +404,7 @@ class NetworkEquipment extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['networking'][5]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "ram");
+      Html::autocompletionTextField($this, "ram");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -457,7 +451,7 @@ class NetworkEquipment extends CommonDBTM {
       $tab[40]['name']  = $LANG['common'][22];
 
       $tab[31]['table'] = 'glpi_states';
-      $tab[31]['field'] = 'name';
+      $tab[31]['field'] = 'completename';
       $tab[31]['name']  = $LANG['state'][0];
 
       $tab[5]['table']     = $this->getTable();
@@ -484,9 +478,10 @@ class NetworkEquipment extends CommonDBTM {
       $tab[70]['field'] = 'name';
       $tab[70]['name']  = $LANG['common'][34];
 
-      $tab[71]['table'] = 'glpi_groups';
-      $tab[71]['field'] = 'name';
-      $tab[71]['name']  = $LANG['common'][35];
+      $tab[71]['table']     = 'glpi_groups';
+      $tab[71]['field']     = 'completename';
+      $tab[71]['name']      = $LANG['common'][35];
+      $tab[71]['condition'] = '`is_itemgroup`';
 
       $tab[19]['table']         = $this->getTable();
       $tab[19]['field']         = 'date_mod';
@@ -540,6 +535,12 @@ class NetworkEquipment extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[80]['table']         = 'glpi_entities';
       $tab[80]['field']         = 'completename';
       $tab[80]['name']          = $LANG['entity'][0];
@@ -554,5 +555,4 @@ class NetworkEquipment extends CommonDBTM {
    }
 
 }
-
 ?>
