@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: networkport.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: networkport.class.php 18087 2012-03-29 10:52:38Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -45,17 +45,19 @@ class NetworkPort extends CommonDBChild {
    public $dohistory = true;
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['networking'][6];
+      }
       return $LANG['networking'][4];
    }
 
 
    function canCreate() {
 
-      if (isset($this->fields['itemtype'])) {
-         $item = new $this->fields['itemtype']();
+      if (isset($this->fields['itemtype']) && $item=getItemForItemtype($this->fields['itemtype'])) {
          return $item->canCreate();
       }
 
@@ -82,7 +84,7 @@ class NetworkPort extends CommonDBChild {
 
       if (count($updates)) {
          $save_ID = $this->fields["id"];
-         $n       = new NetworkPort_NetworkPort;
+         $n       = new NetworkPort_NetworkPort();
 
          if ($this->fields["id"]=$n->getOppositeContact($save_ID)) {
             $this->updateInDB($updates);
@@ -109,7 +111,7 @@ class NetworkPort extends CommonDBChild {
       // Not attached to itemtype -> not added
       if (!isset($input['itemtype'])
           || empty($input['itemtype'])
-          || !class_exists($input['itemtype'])
+          || !($item = getItemForItemtype($input['itemtype']))
           || !isset($input['items_id'])
           || $input['items_id'] <= 0) {
          return false;
@@ -119,7 +121,6 @@ class NetworkPort extends CommonDBChild {
          unset($input["logical_number"]);
       }
 
-      $item = new $input['itemtype']();
       if ($item->getFromDB($input['items_id'])) {
          $input['entities_id']  = $item->getEntityID();
          $input['is_recursive'] = intval($item->isRecursive());
@@ -165,7 +166,7 @@ class NetworkPort extends CommonDBChild {
    **/
    function getContact($ID) {
 
-      $wire = new NetworkPort_NetworkPort;
+      $wire = new NetworkPort_NetworkPort();
       if ($contact_id = $wire->getOppositeContact($ID)) {
          return $contact_id;
       }
@@ -174,10 +175,11 @@ class NetworkPort extends CommonDBChild {
 
 
    function defineTabs($options=array()) {
-      global $LANG, $CFG_GLPI;
+      global $LANG;
 
-      $ong[1]  = $LANG['title'][26];
-      $ong[12] = $LANG['title'][38];
+      $ong = array();
+      $this->addStandardTab('NetworkPort_Vlan', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
       return $ong;
    }
@@ -235,11 +237,10 @@ class NetworkPort extends CommonDBChild {
 
       $rand = mt_rand();
       echo "<select name='itemtype[$ID]' id='itemtype$rand'>";
-      echo "<option value='0'>".DROPDOWN_EMPTY_VALUE."</option>";
+      echo "<option value='0'>".Dropdown::EMPTY_VALUE."</option>";
 
       foreach ($CFG_GLPI["networkport_types"] as $key => $itemtype) {
-         if (class_exists($itemtype)) {
-            $item = new $itemtype();
+         if ($item = getItemForItemtype($itemtype)) {
             echo "<option value='".$itemtype."'>".$item->getTypeName()."</option>";
          } else {
             unset($CFG_GLPI["networkport_types"][$key]);
@@ -253,9 +254,9 @@ class NetworkPort extends CommonDBChild {
                       'comments'        => $p['comments'],
                       'myname'          => $p['name']);
 
-      ajaxUpdateItemOnSelectEvent("itemtype$rand", "show_".$p['name']."$rand",
-                                  $CFG_GLPI["root_doc"]."/ajax/dropdownConnectPortDeviceType.php",
-                                  $params);
+      Ajax::updateItemOnSelectEvent("itemtype$rand", "show_".$p['name']."$rand",
+                                    $CFG_GLPI["root_doc"]."/ajax/dropdownConnectPortDeviceType.php",
+                                    $params);
 
       echo "<span id='show_".$p['name']."$rand'>&nbsp;</span>\n";
 
@@ -266,46 +267,47 @@ class NetworkPort extends CommonDBChild {
    /**
     * Show ports for an item
     *
-    * @param $itemtype integer : item type
-    * @param $ID integer : item ID
+    * @param $item CommonDBTM object
     * @param $withtemplate integer : withtemplate param
    **/
-   static function showForItem($itemtype, $ID, $withtemplate = '') {
+   static function showForItem(CommonDBTM $item, $withtemplate='') {
       global $DB, $CFG_GLPI, $LANG;
 
       $rand = mt_rand();
 
-      if (!class_exists($itemtype)) {
+      $itemtype = $item->getType();
+      $items_id = $item->getField('id');
+
+      if (!Session::haveRight('networking','r') || !$item->can($items_id, 'r')) {
          return false;
       }
 
-      $item = new $itemtype();
-      if (!haveRight('networking','r') || !$item->can($ID, 'r')) {
-         return false;
+      $canedit = $item->can($items_id, 'w');
+      $showmassiveactions = false;
+      if ($withtemplate!=2) {
+         $showmassiveactions = count(Dropdown::getMassiveActions(__CLASS__));
       }
 
-      $canedit = $item->can($ID, 'w');
-
       // Show Add Form
       if ($canedit
           && (empty($withtemplate) || $withtemplate !=2)) {
          echo "\n<div class='firstbloc'><table class='tab_cadre_fixe'>";
-         echo "<tr><td class='tab_bg_2 center'>";
+         echo "<tr><td class='tab_bg_2 center b'>";
          echo "<a href='" . $CFG_GLPI["root_doc"] .
-               "/front/networkport.form.php?items_id=$ID&amp;itemtype=$itemtype'><strong>".
-               $LANG['networking'][19]."</strong></a></td>\n";
-         echo "<td class='tab_bg_2 center' width='50%'>";
+               "/front/networkport.form.php?items_id=$items_id&amp;itemtype=$itemtype'>
+               ".$LANG['networking'][19]."</a></td>\n";
+         echo "<td class='tab_bg_2 center b' width='50%'>";
          echo "<a href='" . $CFG_GLPI["root_doc"] .
-               "/front/networkport.form.php?items_id=$ID&amp;itemtype=$itemtype&amp;several=1'>
-               <strong>".$LANG['networking'][46]."</strong></a></td>\n";
+               "/front/networkport.form.php?items_id=$items_id&amp;itemtype=$itemtype&amp;several=1'>
+               ".$LANG['networking'][46]."</a></td>\n";
          echo "</tr></table></div>\n";
       }
 
-      initNavigateListItems('NetworkPort', $item->getTypeName()." = ".$item->getName());
+      Session::initNavigateListItems('NetworkPort', $item->getTypeName()." = ".$item->getName());
 
       $query = "SELECT `id`
                 FROM `glpi_networkports`
-                WHERE `items_id` = '$ID'
+                WHERE `items_id` = '$items_id'
                       AND `itemtype` = '$itemtype'
                 ORDER BY `name`,
                          `logical_number`";
@@ -316,12 +318,10 @@ class NetworkPort extends CommonDBChild {
          if ($DB->numrows($result) != 0) {
             $colspan = 9;
 
-            if ($withtemplate != 2) {
-               if ($canedit) {
-                  $colspan++;
-                  echo "\n<form id='networking_ports$rand' name='networking_ports$rand' method='post'
-                        action='" . $CFG_GLPI["root_doc"] . "/front/networkport.form.php'>\n";
-               }
+            if ($showmassiveactions) {
+               $colspan++;
+               echo "\n<form id='networking_ports$rand' name='networking_ports$rand' method='post'
+                     action='" . $CFG_GLPI["root_doc"] . "/front/networkport.form.php'>\n";
             }
 
             echo "<table class='tab_cadre_fixe'>\n";
@@ -335,7 +335,7 @@ class NetworkPort extends CommonDBChild {
             echo "&nbsp;:&nbsp;".$DB->numrows($result)."</th></tr>\n";
 
             echo "<tr>";
-            if ($withtemplate != 2 && $canedit) {
+            if ($showmassiveactions) {
                echo "<th>&nbsp;</th>\n";
             }
             echo "<th>#</th>\n";
@@ -354,15 +354,15 @@ class NetworkPort extends CommonDBChild {
 
             while ($devid = $DB->fetch_row($result)) {
                $netport->getFromDB(current($devid));
-               addToNavigateListItems('NetworkPort', $netport->fields["id"]);
+               Session::addToNavigateListItems('NetworkPort', $netport->fields["id"]);
 
                echo "<tr class='tab_bg_1'>\n";
-               if ($withtemplate != 2 && $canedit) {
+               if ($showmassiveactions) {
                   echo "<td class='center' width='20'>";
                   echo "<input type='checkbox' name='del_port[".$netport->fields["id"]."]' value='1'>";
                   echo "</td>\n";
                }
-               echo "<td class='center'><strong>";
+               echo "<td class='center'><span class='b'>";
                if ($canedit && $withtemplate != 2) {
                   echo "<a href=\"" . $CFG_GLPI["root_doc"] . "/front/networkport.form.php?id=" .
                         $netport->fields["id"] . "\">";
@@ -371,8 +371,8 @@ class NetworkPort extends CommonDBChild {
                if ($canedit && $withtemplate != 2) {
                   echo "</a>";
                }
-               echo "</strong>";
-               showToolTip($netport->fields['comment']);
+               echo "</span>";
+               Html::showToolTip($netport->fields['comment']);
                echo "</td>\n";
                echo "<td>" . $netport->fields["name"] . "</td>\n";
                echo "<td>".Dropdown::getDropdownName("glpi_netpoints",
@@ -398,13 +398,11 @@ class NetworkPort extends CommonDBChild {
             }
             echo "</table>\n";
 
-            if ($canedit && $withtemplate != 2) {
-               openArrowMassive("networking_ports$rand", true);
+            if ($showmassiveactions) {
+               Html::openArrowMassives("networking_ports$rand", true);
                Dropdown::showForMassiveAction('NetworkPort');
-               closeArrowMassive();
-            }
-
-            if ($canedit && $withtemplate != 2) {
+               $actions = array();
+               Html::closeArrowMassives($actions);
                echo "</form>";
             }
 
@@ -431,28 +429,26 @@ class NetworkPort extends CommonDBChild {
          return false;
       }
 
-      $contact = new NetworkPort_NetworkPort;
+      $contact = new NetworkPort_NetworkPort();
       $canedit = $device1->can($device1->fields["id"], 'w');
       $ID      = $netport->fields["id"];
 
       if ($contact_id = $contact->getOppositeContact($ID)) {
          $netport->getFromDB($contact_id);
 
-         if (class_exists($netport->fields["itemtype"])) {
-            $device2 = new $netport->fields["itemtype"]();
+         if ($device2 = getItemForItemtype($netport->fields["itemtype"])) {
 
             if ($device2->getFromDB($netport->fields["items_id"])) {
                echo "\n<table width='100%'>\n";
                echo "<tr " . ($device2->fields["is_deleted"] ? "class='tab_bg_2_2'" : "") . ">";
-               echo "<td><strong>";
+               echo "<td><span class='b'>";
 
                if ($device2->can($device2->fields["id"], 'r')) {
                   echo $netport->getLink();
-                  echo "</strong>\n";
-                  showToolTip($netport->fields['comment']);
-                  echo "&nbsp;".$LANG['networking'][25] . " <strong>";
-                  echo $device2->getLink();
-                  echo "</strong>";
+                  echo "</span>\n";
+                  Html::showToolTip($netport->fields['comment']);
+                  echo "&nbsp;".$LANG['networking'][25] . " <span class='b'>".$device2->getLink();
+                  echo "</span>";
 
                   if ($device1->fields["entities_id"] != $device2->fields["entities_id"]) {
                      echo "<br>(". Dropdown::getDropdownName("glpi_entities",
@@ -461,7 +457,7 @@ class NetworkPort extends CommonDBChild {
 
                   // 'w' on dev1 + 'r' on dev2 OR 'r' on dev1 + 'w' on dev2
                   if ($canedit || $device2->can($device2->fields["id"], 'w')) {
-                     echo "</td>\n<td class='right'><strong>";
+                     echo "</td>\n<td class='right'><span class='b'>";
 
                      if ($withtemplate != 2) {
                         echo "<a href=\"".$netport->getFormURL()."?disconnect=".
@@ -471,7 +467,7 @@ class NetworkPort extends CommonDBChild {
                         "&nbsp;";
                      }
 
-                     echo "</strong>";
+                     echo "</span>";
                   }
 
                } else {
@@ -480,10 +476,10 @@ class NetworkPort extends CommonDBChild {
                   } else {
                      echo $LANG['common'][0];
                   }
-                  echo "</strong> " . $LANG['networking'][25] . " <strong>";
+                  echo "</span> " . $LANG['networking'][25] . " <span class='b'>";
                   echo $device2->getName();
-                  echo "</strong><br>(" .Dropdown::getDropdownName("glpi_entities",
-                                                                   $device2->getEntityID()) .")";
+                  echo "</span><br>(" .Dropdown::getDropdownName("glpi_entities",
+                                                                 $device2->getEntityID()) .")";
                }
 
                echo "</td></tr></table>\n";
@@ -520,7 +516,7 @@ class NetworkPort extends CommonDBChild {
          $options['several'] = false;
       }
 
-      if (!haveRight("networking", "r")) {
+      if (!Session::haveRight("networking", "r")) {
          return false;
       }
 
@@ -536,8 +532,7 @@ class NetworkPort extends CommonDBChild {
       $type = $this->fields['itemtype'];
       $link = NOT_AVAILABLE;
 
-      if (class_exists($this->fields['itemtype'])) {
-         $item = new $this->fields['itemtype']();
+      if ($item = getItemForItemtype($this->fields['itemtype'])) {
          $type = $item->getTypeName();
 
          if ($item->getFromDB($this->fields["items_id"])) {
@@ -552,14 +547,14 @@ class NetworkPort extends CommonDBChild {
       }
 
       // Ajout des infos deja remplies
-      if (isset ($_POST) && !empty ($_POST)) {
+      if (isset($_POST) && !empty($_POST)) {
          foreach ($netport->fields as $key => $val) {
             if ($key!='id' && isset($_POST[$key])) {
                $netport->fields[$key] = $_POST[$key];
             }
          }
       }
-      $this->showTabs($ID);
+      $this->showTabs();
 
       $options['entities_id'] = $item->getField('entities_id');
       $this->showFormHeader($options);
@@ -595,7 +590,7 @@ class NetworkPort extends CommonDBChild {
       if (!$options['several']) {
          echo "<tr class='tab_bg_1'><td>" . $LANG['networking'][21] . "&nbsp;:</td>\n";
          echo "<td>";
-         autocompletionTextField($this,"logical_number", array('size' => 5));
+         Html::autocompletionTextField($this,"logical_number", array('size' => 5));
          echo "</td></tr>\n";
 
       } else {
@@ -603,7 +598,7 @@ class NetworkPort extends CommonDBChild {
          echo "<td>";
          echo "<input type='hidden' name='several' value='yes'>";
          echo "<input type='hidden' name='logical_number' value=''>\n";
-         echo $LANG['networking'][47] . "&nbsp;:&nbsp;";
+         echo Toolbox::ucfirst($LANG['pager'][2]) . "&nbsp;:&nbsp;";
          Dropdown::showInteger('from_logical_number', 0, 0, 100);
          echo "&nbsp;".$LANG['networking'][48] . "&nbsp;:&nbsp;";
          Dropdown::showInteger('to_logical_number', 0, 0, 100);
@@ -612,7 +607,7 @@ class NetworkPort extends CommonDBChild {
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['common'][16] . "&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['common'][65] . "&nbsp;:</td>\n<td>";
@@ -620,7 +615,7 @@ class NetworkPort extends CommonDBChild {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['networking'][14] . "&nbsp;:</td>\n<td>";
-      autocompletionTextField($this, "ip");
+      Html::autocompletionTextField($this, "ip");
       echo "</td></tr>\n";
 
       // Show device MAC adresses
@@ -633,7 +628,7 @@ class NetworkPort extends CommonDBChild {
          if (count($macs) > 0) {
             echo "<tr class='tab_bg_1'><td>" . $LANG['networking'][15] . "&nbsp;:</td>\n<td>";
             echo "<select name='pre_mac'>\n";
-            echo "<option value=''>".DROPDOWN_EMPTY_VALUE."</option>\n";
+            echo "<option value=''>".Dropdown::EMPTY_VALUE."</option>\n";
 
             foreach ($macs as $key => $val) {
                echo "<option value='" . $val . "' >$val</option>\n";
@@ -648,19 +643,19 @@ class NetworkPort extends CommonDBChild {
       }
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['networking'][15] . "&nbsp;:</td>\n<td>";
-      autocompletionTextField($this, "mac");
+      Html::autocompletionTextField($this, "mac");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['networking'][60] . "&nbsp;:</td>\n<td>";
-      autocompletionTextField($this, "netmask");
+      Html::autocompletionTextField($this, "netmask");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['networking'][59] . "&nbsp;:</td>\n<td>";
-      autocompletionTextField($this, "gateway");
+      Html::autocompletionTextField($this, "gateway");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['networking'][61] . "&nbsp;:</td>\n<td>";
-      autocompletionTextField($this, "subnet");
+      Html::autocompletionTextField($this, "subnet");
       echo "</td></tr>\n";
 
       if (!$options['several']) {
@@ -820,9 +815,9 @@ class NetworkPort extends CommonDBChild {
       $types = array('Computer', 'NetworkEquipment', 'Printer');
 
       foreach ($types as $itemtype) {
-         $result = $this->getUniqueObjectByFDQNAndType($fqdn, $itemtype, $entity);
+         $result = self::getUniqueObjectByFDQNAndType($fqdn, $itemtype, $entity);
 
-         if (!empty ($result)) {
+         if (!empty($result)) {
             return $result;
          }
       }
@@ -843,13 +838,12 @@ class NetworkPort extends CommonDBChild {
    static function getUniqueObjectByFDQNAndType($fqdn, $itemtype, $entity) {
       global $DB;
 
-      if (class_exists($itemtype)) {
-         $item = new $itemtype();
+      if ($item = getItemForItemtype($itemtype)) {
 
-         $query = "SELECT `obj.id`
+         $query = "SELECT `obj`.`id`
                    FROM " . $item->getTable() . " AS obj,
                         `glpi_domains` AS gdd
-                   WHERE `obj.entities_id` = '$entity'
+                   WHERE `obj`.`entities_id` = '$entity'
                          AND `obj`.`domains_id` = `gdd`.`id`
                          AND LOWER('$fqdn') = (CONCAT(LOWER(`obj`.`name`), '.' ,
                                                       LOWER(`gdd`.`name`)))";
@@ -865,7 +859,7 @@ class NetworkPort extends CommonDBChild {
    }
 
 
-   static function getSearchOptionsToAdd ($itemtype) {
+   static function getSearchOptionsToAdd($itemtype) {
       global $LANG;
 
       $tab = array();
@@ -1022,6 +1016,40 @@ class NetworkPort extends CommonDBChild {
       return $tab;
    }
 
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG, $CFG_GLPI;
+
+      // Can exists on template
+      if (Session::haveRight('networking','r')) {
+         if (in_array($item->getType(), $CFG_GLPI["networkport_types"])) {
+            if ($_SESSION['glpishow_count_on_tabs']) {
+               return self::createTabEntry($LANG['networking'][6], self::countForItem($item));
+            }
+            return $LANG['networking'][6];
+         }
+      }
+      return '';
+   }
+
+
+   static function countForitem(CommonDBTM $item) {
+
+      return countElementsInTable('glpi_networkports',
+                                  "`itemtype` = '".$item->getType()."'
+                                   AND `items_id` ='".$item->getField('id')."'");
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+      global $CFG_GLPI;
+
+      if (in_array($item->getType(), $CFG_GLPI["networkport_types"])) {
+         self::showForItem($item);
+         return true;
+      }
+   }
+
 }
 
 ?>
