@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtarget.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notificationtarget.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -108,14 +108,23 @@ class NotificationTarget extends CommonDBChild {
 
 
    function getSubjectPrefix($event='') {
-      return "[GLPI] ";
+      $perso_tag = trim(EntityData::getUsedConfig('notification_subject_tag',$this->getEntity(),
+                                                  '', ''));
+      if (empty($perso_tag)) {
+         $perso_tag = "GLPI";
+      }
+      return "[$perso_tag] ";
+
    }
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['mailing'][113];
+      if ($nb>1) {
+         return $LANG['mailing'][121];
+      }
+      return $LANG['mailing'][131];
    }
 
 
@@ -177,8 +186,8 @@ class NotificationTarget extends CommonDBChild {
    **/
    static function getInstanceByType($itemtype, $event='', $options=array()) {
 
-      if ($itemtype != '' && class_exists($itemtype)) {
-         return self::getInstance(new $itemtype (), $event, $options);
+      if ($itemtype != '' && ($item = getItemForItemtype($itemtype))) {
+         return self::getInstance($item, $event, $options);
       }
       return false;
    }
@@ -187,13 +196,13 @@ class NotificationTarget extends CommonDBChild {
    function showForNotification(Notification $notification) {
       global $LANG;
 
-      if (!haveRight("notification", "r")) {
+      if (!Session::haveRight("notification", "r")) {
          return false;
       }
 
       echo "<form name='notificationtargets_form' id='notificationtargets_form'
              method='post' action=' ";
-      echo getItemTypeFormURL(__CLASS__)."'>";
+      echo Toolbox::getItemTypeFormURL(__CLASS__)."'>";
       echo "<table class='tab_cadre_fixe'>";
       echo "<tr><th colspan='4'>" . $LANG['mailing'][121] . "</th></tr>";
       echo "<tr class='tab_bg_2'>";
@@ -399,12 +408,17 @@ class NotificationTarget extends CommonDBChild {
    /**
     * Add new mail with lang to current email array
     *
-    * @param $data : array of data (mail, lang)
+    * @param $data : array of data (mail, lang[, id for user])
    **/
    function addToAddressesList($data) {
       global $CFG_GLPI;
 
-      $new_mail = trim(utf8_strtolower($data['email']));
+      // No email set : get default for user
+      if (!isset($data['email']) && isset($data['id'])) {
+         $data['email'] = UserEmail::getDefaultForUser($data['id']);
+      }
+
+      $new_mail = trim(Toolbox::strtolower($data['email']));
       $new_lang = '';
       if (isset($data['language'])) {
          $new_lang = trim($data['language']);
@@ -415,7 +429,7 @@ class NotificationTarget extends CommonDBChild {
          $username = $data['name'];
       }
       if (isset($data['id']) && $data['id'] > 0) {
-         $user = new User;
+         $user = new User();
          if (!$user->getFromDB($data['id'])
              || $user->getField('is_deleted')==1
              || $user->getField('is_active')==0) {
@@ -465,11 +479,9 @@ class NotificationTarget extends CommonDBChild {
    **/
    function getItemAuthorAddress() {
 
-      $user = new User;
+      $user = new User();
       if ($this->obj->isField('users_id') && $user->getFromDB($this->obj->getField('users_id'))) {
-
-         $this->addToAddressesList(array('email'    => $user->getField('email'),
-                                         'language' => $user->getField('language'),
+         $this->addToAddressesList(array('language' => $user->getField('language'),
                                          'id'       => $user->getField('id')));
       }
    }
@@ -492,15 +504,23 @@ class NotificationTarget extends CommonDBChild {
 
    /**
     * Get targets for all the users of a group
+    *
+    * @param $manager : 0 user, 1 supervisor
+    * @param $group_id id of the group
    **/
-   function getUsersAddressesByGroup($group_id) {
+   function getAddressesByGroup($manager, $group_id) {
       global $DB;
 
+      // members/managers of the group allowed on object entity
+      // filter group with 'is_assign' (attribute can be unset after notification)
       $query = $this->getDistinctUserSql()."
                FROM `glpi_groups_users`
                INNER JOIN `glpi_users` ON (`glpi_groups_users`.`users_id` = `glpi_users`.`id`) ".
                $this->getProfileJoinSql()."
-               WHERE `glpi_groups_users`.`groups_id` = '".$group_id."'";
+               INNER JOIN `glpi_groups` ON (`glpi_groups_users`.`groups_id` = `glpi_groups`.`id`)
+               WHERE `glpi_groups_users`.`groups_id` = '$group_id'
+                     AND `glpi_groups_users`.`is_manager` = '$manager'
+                     AND `glpi_groups`.`is_notify`";
 
       foreach ($DB->request($query) as $data) {
          $this->addToAddressesList($data);
@@ -508,29 +528,9 @@ class NotificationTarget extends CommonDBChild {
    }
 
 
-   /**
-    * Get targets for all the users of a group
-   **/
-   function getSupervisorAddressByGroup($groups_id) {
-      global $DB;
-
-      $query = $this->getDistinctUserSql()."
-               FROM `glpi_groups`
-               INNER JOIN `glpi_users` ON (`glpi_users`.`id` = `glpi_groups`.`users_id`) ".
-               $this->getProfileJoinSql()."
-               WHERE `glpi_groups`.`id` = '".$groups_id."'";
-
-         foreach ($DB->request($query) as $data) {
-            $this->addToAddressesList($data);
-         }
-         $this->addToAddressesList($data);
-   }
-
-
    function getDistinctUserSql() {
 
       return  "SELECT DISTINCT `glpi_users`.id AS id,
-                               `glpi_users`.`email` AS email,
                                `glpi_users`.`language` AS language";
    }
 
@@ -555,7 +555,7 @@ class NotificationTarget extends CommonDBChild {
 
       $this->events = $this->getEvents();
       //If plugin adds new events for an already defined type
-      doHook('item_get_events', $this);
+      Plugin::doHook('item_get_events', $this);
 
       return $this->events;
    }
@@ -564,7 +564,9 @@ class NotificationTarget extends CommonDBChild {
    function addTarget ($target='', $label='', $type=Notification::USER_TYPE) {
 
       $key = $type.'_'.$target;
-      $this->notification_targets[$key]                  = $key;
+      // Value used for sort
+      $this->notification_targets[$key]                  = $type.'_'.$label;
+      // Displayed value
       $this->notification_targets_labels[$type][$target] = $label;
    }
 
@@ -582,9 +584,12 @@ class NotificationTarget extends CommonDBChild {
    function addGroupsToTargets($entity) {
       global $LANG, $DB;
 
+      // Filter groups which can be notified and have members (as notifications are sent to members)
       $query = "SELECT `id`, `name`
                 FROM `glpi_groups`".
                 getEntitiesRestrictRequest(" WHERE", 'glpi_groups', 'entities_id', $entity, true)."
+                      AND `is_usergroup`
+                      AND `is_notify`
                 ORDER BY `name`";
 
       foreach ($DB->request($query) as $data) {
@@ -610,7 +615,7 @@ class NotificationTarget extends CommonDBChild {
    function getNotificationTargets($entity) {
       global $LANG;
 
-      if (haveRight("config", "w")) {
+      if (Session::haveRight("config", "w")) {
          $this->addTarget(Notification::GLOBAL_ADMINISTRATOR, $LANG['setup'][237]);
       }
       $this->addTarget(Notification::ENTITY_ADMINISTRATOR,
@@ -637,7 +642,7 @@ class NotificationTarget extends CommonDBChild {
     * @param $data
     * @param $options
    **/
-   function getSpecificTargets ($data, $options) {
+   function getSpecificTargets($data, $options) {
    }
 
 
@@ -657,7 +662,7 @@ class NotificationTarget extends CommonDBChild {
     * @param $field look for user looking for this field in the object which raises the event
     * @param $search_in_object search is done in the object ? if not  in target object.
     */
-   function getUserByField ($field, $search_in_object=false) {
+   function getUserByField($field, $search_in_object=false) {
       global $DB;
 
       $id = 0;
@@ -691,6 +696,20 @@ class NotificationTarget extends CommonDBChild {
    }
 
 
+   /**
+    * Get Group of technicians in charge of the item
+   **/
+   function getItemGroupTechInChargeAddress() {
+
+      if ($this->target_object) {
+         $id = $this->target_object->getField('groups_id_tech');
+         if ($id>0) {
+            $this->getAddressesByGroup(0, $id);
+         }
+      }
+   }
+
+
    /**
     * Get user owner of the material
    **/
@@ -796,6 +815,11 @@ class NotificationTarget extends CommonDBChild {
                   $this->getItemTechnicianInChargeAddress();
                   break;
 
+               //Group of technician in charge of the ticket
+               case Notification::ITEM_TECH_GROUP_IN_CHARGE :
+                  $this->getItemGroupTechInChargeAddress();
+                  break;
+
                //User who's owner of the material
                case Notification::ITEM_USER :
                   $this->getItemOwnerAddress();
@@ -814,12 +838,12 @@ class NotificationTarget extends CommonDBChild {
 
          //Send to all the users of a group
          case Notification::GROUP_TYPE :
-            $this->getUsersAddressesByGroup($data['items_id']);
+            $this->getAddressesByGroup(0, $data['items_id']);
             break;
 
          //Send to all the users of a group
          case Notification::SUPERVISOR_GROUP_TYPE :
-            $this->getSupervisorAddressByGroup($data['items_id']);
+            $this->getAddressesByGroup(1, $data['items_id']);
             break;
 
          //Send to all the users of a profile
@@ -883,7 +907,7 @@ class NotificationTarget extends CommonDBChild {
                                 'label' => $LANG['setup'][227]));
 
       $this->getDatasForTemplate($event, $options);
-      doHook('item_get_datas', $this);
+      Plugin::doHook('item_get_datas', $this);
 
       return $this->datas;
    }
@@ -939,5 +963,136 @@ class NotificationTarget extends CommonDBChild {
       }
    }
 
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate && Session::haveRight('notification', 'r')) {
+         switch ($item->getType()) {
+            case 'Group' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['setup'][704], self::countForGroup($item));
+               }
+               return $LANG['setup'][704];
+
+            case 'Notification' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['mailing'][121],
+                                              countElementsInTable($this->getTable(),
+                                                                   "notifications_id = '".$item->getID()."'"));
+               }
+               return $LANG['mailing'][121];
+         }
+      }
+      return '';
+   }
+
+
+   /**
+    * Count Notification for a group
+    *
+    * @since verson 0.83
+    *
+    * @param $group Group
+    *
+    * @return integer
+   **/
+   static function countForGroup(Group $group) {
+      global $DB;
+
+      $sql = "SELECT COUNT(*)AS cpt
+              FROM `glpi_notificationtargets`
+              INNER JOIN `glpi_notifications`
+                    ON (`glpi_notifications`.`id` = `glpi_notificationtargets`.`notifications_id`)
+              WHERE `items_id` = '".$group->getID()."'
+                    AND (`type` = '".Notification::SUPERVISOR_GROUP_TYPE."'
+                         OR `type` = '".Notification::GROUP_TYPE."') ".
+                    getEntitiesRestrictRequest('AND', 'glpi_notifications', '', '', true);
+      $data = $DB->request($sql)->next();
+      return $data['cpt'];
+   }
+
+
+   /**
+    * Display notification registered for a group
+    *
+    * @since version 0.83
+    *
+    * @param $group Group
+    *
+    * @return nothing
+   **/
+   static function showForGroup(Group $group) {
+      global $LANG, $DB;
+
+      if (!Session::haveRight("notification", "r")) {
+         return false;
+      }
+
+      $sql = "SELECT `glpi_notifications`.`id`
+              FROM `glpi_notificationtargets`
+              INNER JOIN `glpi_notifications`
+                    ON (`glpi_notifications`.`id` = `glpi_notificationtargets`.`notifications_id`)
+              WHERE `items_id` = '".$group->getID()."'
+                    AND (`type` = '".Notification::SUPERVISOR_GROUP_TYPE."'
+                         OR `type` = '".Notification::GROUP_TYPE."') ".
+                    getEntitiesRestrictRequest('AND', 'glpi_notifications', '', '', true);
+      $req = $DB->request($sql);
+
+      echo "<table class='tab_cadre_fixe'>";
+
+      if ($req->numrows()) {
+         echo "<tr><th>".$LANG['common'][16]."</th>";
+         echo "<th>".Entity::getTypeName()."</th>";
+         echo "<th>".$LANG['common'][60]."</th>";
+         echo "<th>".$LANG['common'][17]."</th>";
+         echo "<th>".$LANG['mailing'][120]."</th>";
+         echo "<th>".NotificationEvent::getTypeName()."</th>";
+         echo "<th>".NotificationTemplate::getTypeName()."</th></tr>";
+
+         $notif = new Notification();
+         Session::initNavigateListItems('Notification',
+                                        $group->getTypeName()." = ".$group->getNameID());
+         foreach ($req as $data) {
+            Session::addToNavigateListItems('Notification', $data['id']);
+
+            if ($notif->getFromDB($data['id'])) {
+               echo "<tr class='tab_bg_2'><td>".$notif->getLink();
+               echo "</td><td>".dropdown::getDropdownName('glpi_entities', $notif->getEntityID());
+               echo "</td><td>".dropdown::getYesNo($notif->getField('is_active'))."</td><td>";
+               $itemtype = $notif->getField('itemtype');
+               if ($tmp = getItemForItemtype($itemtype)) {
+                  echo $tmp->getTypeName();
+               }
+               echo "</td><td>".Notification::getMode($notif->getField('mode'));
+               echo "</td><td>".NotificationEvent::getEventName($itemtype, $notif->getField('event'));
+               echo "</td><td>".Dropdown::getDropdownName('glpi_notificationtemplates',
+                                                          $notif->getField('notificationtemplates_id'));
+               echo "</td></tr>";
+            }
+         }
+      } else {
+      echo "<tr class='tab_bg_2'><td class='b center'>".$LANG['search'][15]."</td></tr>";
+      }
+      echo "</table>";
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='Group') {
+         self::showForGroup($item);
+
+      } else if ($item->getType()=='Notification') {
+         $target = self::getInstanceByType($item->getField('itemtype'),
+                                           $item->getField('event'),
+                                           array('entities_id' => $item->getField('entities_id')));
+         if ($target) {
+            $target->showForNotification($item);
+         }
+      }
+      return true;
+   }
+
 }
 ?>
