@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtemplatetranslation.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notificationtemplatetranslation.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,9 +39,12 @@ class NotificationTemplateTranslation extends CommonDBChild {
    public $items_id  = 'notificationtemplates_id';
    public $dohistory = true;
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['mailing'][109];
+      }
       return $LANG['mailing'][126];
    }
 
@@ -60,34 +63,34 @@ class NotificationTemplateTranslation extends CommonDBChild {
 
 
    function defineTabs($options=array()) {
-      global $LANG;
 
-      $tabs[1] = $LANG['common'][12];
-      if ($this->fields['id'] > 0) {
-         $tabs[12] = $LANG['title'][38];
-      }
-      return $tabs;
+
+      $ong = array();
+      $ong['empty'] = $this->getTypeName(1); // History as single tab seems "strange"
+      $this->addStandardTab('Log', $ong, $options);
+
+      return $ong;
    }
 
 
    function canCreate() {
-      return haveRight('config', 'w');
+      return Session::haveRight('config', 'w');
    }
 
 
    function canView() {
-      return haveRight('config', 'r');
+      return Session::haveRight('config', 'r');
    }
 
 
    function showForm($ID, $options) {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight("config", "w")) {
+      if (!Session::haveRight("config", "w")) {
          return false;
       }
 
-      if (empty ($ID)) {
+      if (empty($ID)) {
           if ($this->getEmpty()) {
              $notificationtemplates_id = $options['notificationtemplates_id'];
           }
@@ -98,19 +101,19 @@ class NotificationTemplateTranslation extends CommonDBChild {
           }
        }
 
-      $canedit = haveRight("config", "w");
+      $canedit = Session::haveRight("config", "w");
 
-      $template = new NotificationTemplate;
+      $template = new NotificationTemplate();
       $template->getFromDB($notificationtemplates_id);
 
-      initEditorSystem('content_html');
+      Html::initEditorSystem('content_html');
 
       $this->showTabs($options);
       $this->showFormHeader($options);
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$template->getTypeName()."</td>";
-      echo "<td colspan='2'><a href='".getItemTypeFormURL('NotificationTemplate').
+      echo "<td colspan='2'><a href='".Toolbox::getItemTypeFormURL('NotificationTemplate').
             "?id=".$notificationtemplates_id."'>".$template->getField('name')."</a>";
       echo "</td><td><a href='#' onClick=\"var w=window.open('".$CFG_GLPI["root_doc"].
              "/front/popup.php?popup=list_notificationtags&amp;sub_type=".
@@ -162,18 +165,18 @@ class NotificationTemplateTranslation extends CommonDBChild {
       global $DB, $LANG, $CFG_GLPI;
 
       $nID     = $template->getField('id');
-      $canedit = haveRight("config", "w");
+      $canedit = Session::haveRight("config", "w");
 
 
       if ($canedit) {
          echo "<div class='center'>".
-              "<a href='".getItemTypeFormURL('NotificationTemplateTranslation').
+              "<a href='".Toolbox::getItemTypeFormURL('NotificationTemplateTranslation').
                 "?notificationtemplates_id=".$nID."'>". $LANG['mailing'][124]."</a></div><br>";
       }
 
       echo "<div class='center' id='tabsbody'>";
-      initNavigateListItems('NotificationTemplateTranslation',
-                            $template->getTypeName() . " = ". $template->fields["name"]);
+      Session::initNavigateListItems('NotificationTemplateTranslation',
+                                     $template->getTypeName() . " = ". $template->fields["name"]);
 
       echo "<form name='form_language' id='form_language' method='post'>";
       echo "<table class='tab_cadre_fixe'>";
@@ -183,11 +186,11 @@ class NotificationTemplateTranslation extends CommonDBChild {
                             array('notificationtemplates_id' => $nID)) as $data) {
 
          if ($this->getFromDB($data['id'])) {
-            addToNavigateListItems('NotificationTemplateTranslation',$data['id']);
+            Session::addToNavigateListItems('NotificationTemplateTranslation',$data['id']);
             echo "<tr class='tab_bg_1'><td class='center'>";
             echo "<input type='checkbox' name=\"languages[" . $data['id'] . "]\"></td>";
             echo "<td class='center'>";
-            echo "<a href='".getItemTypeFormURL('NotificationTemplateTranslation').
+            echo "<a href='".Toolbox::getItemTypeFormURL('NotificationTemplateTranslation').
                   "?id=".$data['id']."&notificationtemplates_id=".$nID."'>";
 
             if ($data['language'] != '') {
@@ -203,8 +206,8 @@ class NotificationTemplateTranslation extends CommonDBChild {
       echo "</table>";
 
       if ($canedit) {
-         openArrowMassive("form_language", true);
-         closeArrowMassive("delete_languages", $LANG["buttons"][6]);
+         Html::openArrowMassives("form_language", true);
+         Html::closeArrowMassives(array("delete_languages" => $LANG["buttons"][6]));
       }
    }
 
@@ -217,7 +220,8 @@ class NotificationTemplateTranslation extends CommonDBChild {
    static function cleanContentHtml($input) {
 
       if (!$input['content_text']) {
-         $input['content_text'] = html_clean(unclean_cross_side_scripting_deep($input['content_html']));
+         $input['content_text']
+               = Html::clean(Toolbox::unclean_cross_side_scripting_deep($input['content_html']));
       }
       return $input;
    }
@@ -332,5 +336,33 @@ class NotificationTemplateTranslation extends CommonDBChild {
       echo "</table></div>";
    }
 
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case 'NotificationTemplate' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry(self::getTypeName(2),
+                                              countElementsInTable($this->getTable(),
+                                                                   "notificationtemplates_id = '".$item->getID()."'"));
+               }
+               return self::getTypeName(2);
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='NotificationTemplate') {
+         $temp = new self();
+         $temp->showSummary($item);
+      }
+      return true;
+   }
+
 }
 ?>
