@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: peripheral.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: peripheral.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -63,12 +63,12 @@ class Peripheral  extends CommonDBTM {
 
 
    function canCreate() {
-      return haveRight('peripheral', 'w');
+      return Session::haveRight('peripheral', 'w');
    }
 
 
    function canView() {
-      return haveRight('peripheral', 'r');
+      return Session::haveRight('peripheral', 'r');
    }
 
 
@@ -76,42 +76,16 @@ class Peripheral  extends CommonDBTM {
       global $LANG;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         if (haveRight("computer","r")) {
-            $ong[1] = $LANG['title'][27];
-         }
-
-         if (haveRight("contract","r") || haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            if (haveRight("show_all_ticket","1")) {
-               $ong[6] = $LANG['title'][28];
-            }
-
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-
-            if (haveRight("reservation_central","r")) {
-               $ong[11] = $LANG['Menu'][17];
-            }
-
-            $ong[12] = $LANG['title'][38];
-         }
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('Computer_Item', $ong, $options);
+      $this->addStandardTab('NetworkPort', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Reservation', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
       return $ong;
    }
@@ -231,7 +205,7 @@ class Peripheral  extends CommonDBTM {
     *
     * @return boolean item found
     **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
       $target       = $this->getFormURL();
@@ -245,10 +219,6 @@ class Peripheral  extends CommonDBTM {
          $withtemplate = $options['withtemplate'];
       }
 
-      if (!haveRight("peripheral","r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -259,16 +229,16 @@ class Peripheral  extends CommonDBTM {
       if (isset($options['withtemplate']) && $options['withtemplate'] == 2) {
          $template   = "newcomp";
          $datestring = $LANG['computers'][14];
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else if (isset($options['withtemplate']) && $options['withtemplate'] == 1) {
          $template   = "newtemplate";
          $datestring = $LANG['computers'][14];
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else {
          $datestring = $LANG['common'][26];
-         $date       = convDateTime($this->fields["date_mod"]);
+         $date       = Html::convDateTime($this->fields["date_mod"]);
          $template   = false;
       }
 
@@ -280,7 +250,7 @@ class Peripheral  extends CommonDBTM {
       echo "<td>";
       $objectName = autoName($this->fields["name"], "name", ($template === "newcomp"),
                              $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, "name", array('value' => $objectName));
+      Html::autocompletionTextField($this, "name", array('value' => $objectName));
       echo "</td>\n";
       echo "<td>".$LANG['state'][0]."&nbsp;:</td>\n";
       echo "<td>";
@@ -312,9 +282,12 @@ class Peripheral  extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][21]."&nbsp;:</td>\n";
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "contact_num");
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
       echo "</td>";
       echo "<td>".$LANG['common'][22]."&nbsp;:</td>\n";
       echo "<td>";
@@ -322,13 +295,25 @@ class Peripheral  extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][18]."&nbsp;:</td>\n";
+      echo "<td>".$LANG['common'][21]."&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "contact");
-      echo "</td>\n";
+      Html::autocompletionTextField($this, "contact_num");
+      echo "</td>";
       echo "<td>".$LANG['common'][19]."&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "serial");
+      Html::autocompletionTextField($this, "serial");
+      echo "</td></tr>\n";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][18]."&nbsp;:</td>\n";
+      echo "<td>";
+      Html::autocompletionTextField($this, "contact");
+      echo "</td>\n";
+      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>\n";
+      echo "<td>";
+      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
+                             $this->getType(), $this->fields["entities_id"]);
+      Html::autocompletionTextField($this, "otherserial", array('value' => $objectName));
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -338,19 +323,6 @@ class Peripheral  extends CommonDBTM {
                            'entity' => $this->fields["entities_id"],
                            'right'  => 'all'));
       echo "</td>\n";
-      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>\n";
-      echo "<td>";
-      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
-                             $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, "otherserial", array('value' => $objectName));
-      echo "</td></tr>\n";
-
-      echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][35]."&nbsp;:</td>\n";
-      echo "<td>";
-      Dropdown::show('Group', array('value'  => $this->fields["groups_id"],
-                                    'entity' => $this->fields["entities_id"]));
-      echo "</td>\n";
       echo "<td>".$LANG['peripherals'][33]."&nbsp;:</td>\n";
       echo "<td>";
       Dropdown::showGlobalSwitch($this->fields["id"],
@@ -361,15 +333,22 @@ class Peripheral  extends CommonDBTM {
                                        'target'       => $target));
       echo "</td></tr>\n";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][35]."&nbsp;:</td>\n";
+      echo "<td>";
+      Dropdown::show('Group', array('value'     => $this->fields["groups_id"],
+                                    'entity'    => $this->fields["entities_id"],
+                                    'condition' => '`is_itemgroup`'));
+      echo "</td>\n";
+      echo "<td rowspan='3'>".$LANG['common'][25]."&nbsp;:</td>\n";
+      echo "<td rowspan='3'>
+            <textarea cols='45' rows='6' name='comment' >".$this->fields["comment"]."</textarea>";
+      echo "</td></tr>\n";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['peripherals'][18]."&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "brand");
-      echo "</td>\n";
-      echo "<td rowspan='2'>";
-      echo $LANG['common'][25]."&nbsp;:</td>\n";
-      echo "<td rowspan='2'>
-            <textarea cols='45' rows='3' name='comment' >".$this->fields["comment"]."</textarea>";
+      Html::autocompletionTextField($this, "brand");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -392,7 +371,7 @@ class Peripheral  extends CommonDBTM {
     *
     * @return a SQL command which return a set of (itemtype, items_id)
     **/
-   function getSelectLinkedItem () {
+   function getSelectLinkedItem() {
 
       return "SELECT 'Computer', `computers_id`
               FROM `glpi_computers_items`
@@ -430,7 +409,7 @@ class Peripheral  extends CommonDBTM {
       $tab[40]['name']  = $LANG['common'][22];
 
       $tab[31]['table'] = 'glpi_states';
-      $tab[31]['field'] = 'name';
+      $tab[31]['field'] = 'completename';
       $tab[31]['name']  = $LANG['state'][0];
 
       $tab[5]['table']     = $this->getTable();
@@ -457,9 +436,10 @@ class Peripheral  extends CommonDBTM {
       $tab[70]['field'] = 'name';
       $tab[70]['name']  = $LANG['common'][34];
 
-      $tab[71]['table'] = 'glpi_groups';
-      $tab[71]['field'] = 'name';
-      $tab[71]['name']  = $LANG['common'][35];
+      $tab[71]['table']     = 'glpi_groups';
+      $tab[71]['field']     = 'completename';
+      $tab[71]['name']      = $LANG['common'][35];
+      $tab[71]['condition'] = '`is_itemgroup`';
 
       $tab[19]['table']         = $this->getTable();
       $tab[19]['field']         = 'date_mod';
@@ -491,6 +471,12 @@ class Peripheral  extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[80]['table']         = 'glpi_entities';
       $tab[80]['field']         = 'completename';
       $tab[80]['name']          = $LANG['entity'][0];
