@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: phone.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: phone.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -45,20 +45,23 @@ class Phone extends CommonDBTM {
    protected $forward_entity_to = array('Infocom', 'NetworkPort', 'ReservationItem');
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['Menu'][34];
+      }
       return $LANG['help'][35];
    }
 
 
    function canCreate() {
-      return haveRight('phone', 'w');
+      return Session::haveRight('phone', 'w');
    }
 
 
    function canView() {
-      return haveRight('phone', 'r');
+      return Session::haveRight('phone', 'r');
    }
 
 
@@ -66,40 +69,16 @@ class Phone extends CommonDBTM {
       global $LANG, $CFG_GLPI;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         $ong[1] = $LANG['title'][27];
-
-         if (haveRight("contract","r") || haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            if (haveRight("show_all_ticket","1")) {
-               $ong[6] = $LANG['title'][28];
-            }
-
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-
-            if (haveRight("reservation_central","r")) {
-               $ong[11] = $LANG['Menu'][17];
-            }
-
-            $ong[12] = $LANG['title'][38];
-         }
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('Computer_Item', $ong, $options);
+      $this->addStandardTab('NetworkPort', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Reservation', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
       return $ong;
    }
@@ -221,7 +200,7 @@ class Phone extends CommonDBTM {
     *
     *@return boolean item found
     **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
       $target       = $this->getFormURL();
@@ -235,10 +214,6 @@ class Phone extends CommonDBTM {
          $withtemplate = $options['withtemplate'];
       }
 
-      if (!haveRight("phone","r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -252,16 +227,16 @@ class Phone extends CommonDBTM {
       if (isset($options['withtemplate']) && $options['withtemplate'] == 2) {
          $template   = "newcomp";
          $datestring = $LANG['computers'][14]."&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else if (isset($options['withtemplate']) && $options['withtemplate'] == 1) {
          $template   = "newtemplate";
          $datestring = $LANG['computers'][14]."&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else {
          $datestring = $LANG['common'][26]."&nbsp;: ";
-         $date       = convDateTime($this->fields["date_mod"]);
+         $date       = Html::convDateTime($this->fields["date_mod"]);
          $template   = false;
       }
 
@@ -270,7 +245,7 @@ class Phone extends CommonDBTM {
       echo "<td>";
       $objectName = autoName($this->fields["name"], "name", ($template === "newcomp"),
                              $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, 'name', array('value' => $objectName));
+      Html::autocompletionTextField($this, 'name', array('value' => $objectName));
       echo "</td>";
       echo "<td>".$LANG['state'][0]."&nbsp;:</td>";
       echo "<td>";
@@ -302,9 +277,12 @@ class Phone extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][21]."&nbsp;:</td>";
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "contact_num");
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
       echo "</td>";
       echo "<td>".$LANG['common'][22]."&nbsp;:</td>";
       echo "<td>";
@@ -312,12 +290,24 @@ class Phone extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][18]."&nbsp;:</td><td>";
-      autocompletionTextField($this, "contact");
+      echo "<td>".$LANG['common'][21]."&nbsp;:</td>";
+      echo "<td>";
+      Html::autocompletionTextField($this, "contact_num");
       echo "</td>";
       echo "<td>".$LANG['common'][19]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this,"serial");
+      Html::autocompletionTextField($this,"serial");
+      echo "</td></tr>\n";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][18]."&nbsp;:</td><td>";
+      Html::autocompletionTextField($this, "contact");
+      echo "</td>";
+      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>";
+      echo "<td>";
+      $objectName = autoName($this->fields["otherserial"], "otherserial",($template === "newcomp"),
+                             $this->getType(), $this->fields["entities_id"]);
+      Html::autocompletionTextField($this, 'otherserial', array('value' => $objectName));
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -327,19 +317,6 @@ class Phone extends CommonDBTM {
                            'entity' => $this->fields["entities_id"],
                            'right'  => 'all'));
       echo "</td>";
-      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>";
-      echo "<td>";
-      $objectName = autoName($this->fields["otherserial"], "otherserial",($template === "newcomp"),
-                             $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, 'otherserial', array('value' => $objectName));
-      echo "</td></tr>\n";
-
-      echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][35]."&nbsp;:</td>";
-      echo "<td>";
-      Dropdown::show('Group', array('value'  => $this->fields["groups_id"],
-                                    'entity' => $this->fields["entities_id"]));
-      echo "</td>";
       echo "<td>".$LANG['peripherals'][33]."&nbsp;:</td>";
       echo "<td>";
       Dropdown::showGlobalSwitch($this->fields["id"],
@@ -350,15 +327,22 @@ class Phone extends CommonDBTM {
                                        'target'       => $target));
       echo "</td></tr>\n";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][35]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('Group', array('value'     => $this->fields["groups_id"],
+                                    'entity'    => $this->fields["entities_id"],
+                                    'condition' => '`is_itemgroup`'));
+      echo "</td>";
+      echo "<td rowspan='7'>".$LANG['common'][25]."&nbsp;:</td>";
+      echo "<td rowspan='7'>
+            <textarea cols='45' rows='14' name='comment' >".$this->fields["comment"]."</textarea>";
+      echo "</td></tr>\n";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['peripherals'][18]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this,"brand");
-      echo "</td>";
-      echo "<td rowspan='6'>";
-      echo $LANG['common'][25]."&nbsp;:</td>";
-      echo "<td rowspan='6'>
-            <textarea cols='45' rows='9' name='comment' >".$this->fields["comment"]."</textarea>";
+      Html::autocompletionTextField($this,"brand");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -370,12 +354,12 @@ class Phone extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['setup'][71]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "firmware");
+      Html::autocompletionTextField($this, "firmware");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['phones'][40]."&nbsp;:</td><td>";
-      autocompletionTextField($this, "number_line");
+      Html::autocompletionTextField($this, "number_line");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -413,7 +397,7 @@ class Phone extends CommonDBTM {
     *
     * @return a SQL command which return a set of (itemtype, items_id)
     **/
-   function getSelectLinkedItem () {
+   function getSelectLinkedItem() {
 
       return "SELECT 'Computer', `computers_id`
               FROM `glpi_computers_items`
@@ -451,7 +435,7 @@ class Phone extends CommonDBTM {
       $tab[40]['name']  = $LANG['common'][22];
 
       $tab[31]['table'] = 'glpi_states';
-      $tab[31]['field'] = 'name';
+      $tab[31]['field'] = 'completename';
       $tab[31]['name']  = $LANG['state'][0];
 
       $tab[5]['table']     = $this->getTable();
@@ -483,9 +467,10 @@ class Phone extends CommonDBTM {
       $tab[70]['field'] = 'name';
       $tab[70]['name']  = $LANG['common'][34];
 
-      $tab[71]['table'] = 'glpi_groups';
-      $tab[71]['field'] = 'name';
-      $tab[71]['name']  = $LANG['common'][35];
+      $tab[71]['table']     = 'glpi_groups';
+      $tab[71]['field']     = 'completename';
+      $tab[71]['name']      = $LANG['common'][35];
+      $tab[71]['condition'] = '`is_itemgroup`';
 
       $tab[19]['table']         = $this->getTable();
       $tab[19]['field']         = 'date_mod';
@@ -522,6 +507,12 @@ class Phone extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[42]['table'] = 'glpi_phonepowersupplies';
       $tab[42]['field'] = 'name';
       $tab[42]['name']  = $LANG['phones'][36];
