@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: planning.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: planning.class.php 17244 2012-01-27 10:38:40Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -93,11 +93,11 @@ class Planning {
       $message = '';
 
       foreach ($CFG_GLPI['planning_types'] as $itemtype) {
-         $data = call_user_func(array($itemtype, 'populatePlanning'), array('who'       => $users_id,
-                                                                            'who_group' => 0,
-                                                                            'begin'     => $begin,
-                                                                            'end'       => $end));
-
+         $data = call_user_func(array($itemtype, 'populatePlanning'),
+                                array('who'       => $users_id,
+                                      'who_group' => 0,
+                                      'begin'     => $begin,
+                                      'end'       => $end));
          if (count($data) && method_exists($itemtype,'getAlreadyPlannedInformation')) {
             foreach ($data as $key => $val) {
                if (!isset($except[$itemtype])
@@ -111,7 +111,7 @@ class Planning {
          }
       }
       if ($planned) {
-         addMessageAfterRedirect($LANG['planning'][2].'<br>'.$message, false, ERROR);
+         Session::addMessageAfterRedirect($LANG['planning'][2].'<br>'.$message, false, ERROR);
       }
       return $planned;
    }
@@ -179,7 +179,7 @@ class Planning {
              title=\"".$LANG['buttons'][12]."\"></a>";
       echo "</td>";
       echo "<td>";
-      if (haveRight("show_all_planning","1")) {
+      if (Session::haveRight("show_all_planning","1")) {
          echo "<input type='radio' id='radio_user' name='usertype' value='user' ".
                 ($usertype=="user"?"checked":"").">";
          $rand_user  =User::dropdown(array( 'name'   => 'uID',
@@ -190,9 +190,10 @@ class Planning {
          echo "\n<hr>";
          echo "<input type='radio' id='radio_group' name='usertype' value='group' ".
                 ($usertype=="group"?"checked":"").">";
-         $rand_group = Dropdown::show('Group', array('value'  => $gID,
-                                                     'name'   => 'gID',
-                                                     'entity' => $_SESSION["glpiactive_entity"]));
+         $rand_group = Dropdown::show('Group', array('value'     => $gID,
+                                                     'name'      => 'gID',
+                                                     'entity'    => $_SESSION["glpiactive_entity"],
+                                                     'condition' => '`is_usergroup`'));
          echo "\n<hr>";
          echo "<input type='radio' id='radio_user_group' name='usertype' value='user_group' ".
                 ($usertype=="user_group"?"checked":"").">";
@@ -207,7 +208,7 @@ class Planning {
          echo "});";
          echo "</script>\n";
 
-      } else if (haveRight("show_group_planning","1")) {
+      } else if (Session::haveRight("show_group_planning","1")) {
          echo "<select name='usertype'>";
          echo "<option value='user' ".($usertype=='user'?'selected':'').">".$LANG['joblist'][1];
          echo "</option>";
@@ -218,7 +219,7 @@ class Planning {
       echo "</td>";
 
       echo "<td>";
-      showDateFormItem("date", $date, false);
+      Html::showDateFormItem("date", $date, false);
       echo "</td>\n";
 
       echo "<td><select name='type'>";
@@ -226,28 +227,34 @@ class Planning {
            "</option>";
       echo "<option value='week' ".($type=="week"?" selected ":"").">".$LANG['planning'][6].
            "</option>";
-      echo "<option value='month' ".($type=="month"?" selected ":"").">".$LANG['planning'][14].
-           "</option>";
+      echo "<option value='month' ".($type=="month"?" selected ":"").">".
+             Toolbox::ucfirst($LANG['financial'][57])."</option>";
       echo "</select></td>\n";
 
       echo "<td rowspan='2' class='center'>";
       echo "<input type='submit' class='button' name='submit' value=\"". $LANG['buttons'][7] ."\">";
       echo "</td>\n";
 
-      echo "<td>";
-      echo "<a target='_blank'
-            href=\"".$CFG_GLPI["root_doc"]."/front/planning.php?genical=1&amp;uID=".$uID.
-                  "&amp;gID=".$gID."&amp;usertype=".$usertype."\"
-            title=\"".$LANG['planning'][12]."\">".
-            "<span style='font-size:10px'>-".$LANG['planning'][10]."</span></a>";
-      echo "<br>";
+      if ($uID || $gID) {
 
-      // Todo recup l'url complete de glpi proprement, ? nouveau champs table config ?
-      echo "<a target='_blank' href=\"webcal://".$_SERVER['HTTP_HOST'].$CFG_GLPI["root_doc"].
-             "/front/planning.php?genical=1&amp;uID=".$uID."&amp;gID=".$gID.
-             "&amp;usertype=".$usertype."\" title=\"".$LANG['planning'][13]."\">";
-      echo "<span style='font-size:10px'>-".$LANG['planning'][11]."</span></a>";
-      echo "</td>\n";
+         echo "<td>";
+         echo "<a target='_blank'
+               href=\"".$CFG_GLPI["root_doc"]."/front/planning.php?genical=1&amp;uID=".$uID.
+                     "&amp;gID=".$gID."&amp;usertype=".$usertype."&amp;token=".
+                     User::getPersonalToken(Session::getLoginUserID(true))."\"
+                     title=\"".$LANG['planning'][12]."\">".
+               "<span style='font-size:10px'>-".$LANG['planning'][10]."</span></a>";
+         echo "<br>";
+   
+         // Todo recup l'url complete de glpi proprement, ? nouveau champs table config ?
+         echo "<a target='_blank' href=\"webcal://".$_SERVER['HTTP_HOST'].$CFG_GLPI["root_doc"].
+               "/front/planning.php?genical=1&amp;uID=".$uID."&amp;gID=".$gID.
+               "&amp;usertype=".$usertype."&amp;token=".
+               User::getPersonalToken(Session::getLoginUserID(true))."\" title=\"".
+               $LANG['planning'][13]."\">";
+         echo "<span style='font-size:10px'>-".$LANG['planning'][11]."</span></a>";
+         echo "</td>\n";
+      }
 
       echo "<td>";
       echo "<a href=\"".$CFG_GLPI["root_doc"]."/front/planning.php?type=".$type."&amp;uID=".$uID.
@@ -260,6 +267,180 @@ class Planning {
    }
 
 
+   /**
+    * Show the availability of a user
+    *
+    * @since version 0.83
+    *
+    * @param $who ID of the user
+    * @param $begin begin date to check
+    * @param $end end date to check
+    *
+    * @return Nothing (display function)
+   **/
+   static function checkAvailability($who, $begin='', $end='') {
+      global $LANG, $CFG_GLPI, $DB;
+      if (empty($who)) {
+         return false;
+      }
+      if (empty($begin)) {
+         $begin = date("Y-m-d");
+      }
+      if (empty($end)) {
+         $end = date("Y-m-d");
+      }
+      if ($end < $begin) {
+         $end = $begin;
+      }
+      $realbegin = $begin." ".$CFG_GLPI["planning_begin"];
+      $realend   = $end." ".$CFG_GLPI["planning_end"];
+
+      echo "<div class='center'><form method='get' name='form' action='planning.php'>\n";
+      echo "<table class='tab_cadre'>";
+      echo "<tr class='tab_bg_1'><th colspan='2'>".$LANG['common'][75]."&nbsp:</th>";
+      echo "<th colspan='3'>".getUserName($who)."</th></tr>";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['buttons'][33]." : </td>\n";
+      echo "<td>";
+      Html::showDateFormItem("begin", $begin, false);
+      echo "</td>\n";
+      echo "<td>".$LANG['buttons'][32]." : </td>\n";
+      echo "<td>";
+      Html::showDateFormItem("end", $end, false);
+      echo "</td>\n";
+
+      echo "<td rowspan='2' class='center'>";
+      echo "<input type='hidden' name='users_id' value=\"$who\">";
+      echo "<input type='submit' class='button' name='checkavailability' value=\"".
+             $LANG['buttons'][7] ."\">";
+      echo "</td>\n";
+
+      echo "</tr>";
+      echo "</table></form></div>\n";
+
+
+            // ---------------Tracking
+      $interv = TicketTask::populatePlanning(array('who'       => $who,
+                                                   'who_group' => 0,
+                                                   'begin'     => $realbegin,
+                                                   'end'       => $realend));
+      // ---------------Problem
+      $interv2 = ProblemTask::populatePlanning(array('who'       => $who,
+                                                     'who_group' => 0,
+                                                     'begin'     => $realbegin,
+                                                     'end'       => $realend));
+
+      // ---------------reminder
+      $datareminders = Reminder::populatePlanning(array('who'       => $who,
+                                                        'who_group' => 0,
+                                                        'begin'     => $realbegin,
+                                                        'end'       => $realend));
+
+      $interv = array_merge($interv, $interv2, $datareminders);
+
+      // Print Headers
+      echo "<br><div class='center'><table class='tab_cadre_fixe'>";
+      $colnumber  = 1;
+      $plan_begin = explode(":",$CFG_GLPI["planning_begin"]);
+      $plan_end   = explode(":",$CFG_GLPI["planning_end"]);
+      $begin_hour = intval($plan_begin[0]);
+      $end_hour   = intval($plan_end[0]);
+      if ($plan_end[1]!=0) {
+         $end_hour++;
+      }
+      $colsize = floor((100-15)/($end_hour-$begin_hour));
+
+      // Print Headers
+      echo "<tr class='tab_bg_1'><th width='15%'>&nbsp;</th>";
+
+      for ($i=$begin_hour ; $i<$end_hour ; $i++) {
+         echo "<th width='$colsize%' colspan='4'>".($i<10?'0':'').$i.
+                " -> ". (($i+1)<10?'0':'').($i+1)."</th>";
+         $colnumber += 4;
+      }
+      echo "</tr>";
+
+      $day_begin = strtotime($realbegin);
+      $day_end   = strtotime($realend);
+
+
+      for ($time=$day_begin ; $time<$day_end ; $time+=DAY_TIMESTAMP) {
+         $current_day = date('Y-m-d', $time);
+         echo "<tr><th>".Html::convDate($current_day)."</th>";
+         $begin_quarter = $begin_hour*4;
+         $end_quarter   = $end_hour*4;
+         for ($i=$begin_quarter ; $i<$end_quarter ; $i++) {
+
+            $begin_time = date("Y-m-d H:i:s", strtotime($current_day)+($i)*HOUR_TIMESTAMP/4);
+            $end_time   = date("Y-m-d H:i:s", strtotime($current_day)+($i+1)*HOUR_TIMESTAMP/4);
+            // Init activity interval
+            $begin_act = $end_time;
+            $end_act   = $begin_time;
+
+
+            /// TODO : review system if 2 independent task from :10 -> :20 + :40 -> :50
+            /// Will view not available from :10 to :50
+            /// So do not display text for the moment
+            reset($interv);
+            while ($data=current($interv)) {
+               if ($data["begin"]>=$begin_time && $data["end"]<=$end_time) {
+                  // In
+                  if ($begin_act > $data["begin"]) {
+                     $begin_act = $data["begin"];
+                  }
+                  if ($end_act < $data["end"]) {
+                     $end_act   = $data["end"];
+                  }
+
+                  unset($interv[key($interv)]);
+               } else if ($data["begin"]<$begin_time && $data["end"]>$end_time) {
+                  // Through
+                  $begin_act = $begin_time;
+                  $end_act   = $end_time;
+
+                  next($interv);
+               } else if ($data["begin"]>=$begin_time && $data["begin"]<$end_time) {
+                  // Begin
+                  if ($begin_act > $data["begin"]) {
+                     $begin_act = $data["begin"];
+                  }
+                  $end_act   = $end_time;
+
+                  next($interv);
+               } else if ($data["end"]>$begin_time && $data["end"]<=$end_time) {
+                  //End
+                  $begin_act = $begin_time;
+                  if ($end_act < $data["end"]) {
+                     $end_act = $data["end"];
+                  }
+                  unset($interv[key($interv)]);
+               } else { // Defautl case
+                  next($interv);
+               }
+            }
+            if ($begin_act < $end_act) {
+               // Activity in hour
+               echo "<td class='notavailable'>&nbsp;</td>";
+            } else {
+               // No activity
+               echo "<td class='available' >&nbsp;</td>";
+            }
+         }
+         echo "</tr>";
+      }
+      echo "<tr class='tab_bg_1'><td colspan='$colnumber'>&nbsp;</td></tr>";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<th>".$LANG['profiles'][34]."</th>";
+      echo "<td class='available' colspan=8>".$LANG['reservation'][4]."</td>";
+      echo "<td class='notavailable' colspan=8>".$LANG['reservation'][11]."</td>";
+      echo "<td colspan='".($colnumber-17)."'>&nbsp;</td></tr>";
+      echo "</table></div>";
+
+   }
+
+
    /**
     * Show the planning
     *
@@ -273,7 +454,8 @@ class Planning {
    static function show($who, $who_group, $when, $type) {
       global $LANG, $CFG_GLPI, $DB;
 
-      if (!haveRight("show_planning","1") && !haveRight("show_all_planning","1")) {
+      if (!Session::haveRight("show_planning","1")
+          && !Session::haveRight("show_all_planning","1")) {
          return false;
       }
 
@@ -353,24 +535,29 @@ class Planning {
 
 
       // ---------------Tracking
-      $interv = TicketPlanning::populatePlanning(array('who'       => $who,
-                                                       'who_group' => $who_group,
-                                                       'begin'     => $begin,
-                                                       'end'       => $end));
+      $interv = TicketTask::populatePlanning(array('who'       => $who,
+                                                   'who_group' => $who_group,
+                                                   'begin'     => $begin,
+                                                   'end'       => $end));
+      // ---------------Problem
+      $interv2 = ProblemTask::populatePlanning(array('who'       => $who,
+                                                     'who_group' => $who_group,
+                                                     'begin'     => $begin,
+                                                     'end'       => $end));
 
       // ---------------reminder
-      $datareminders = Reminder::populatePlanning(array('who'      => $who,
-                                                       'who_group' => $who_group,
-                                                       'begin'     => $begin,
-                                                       'end'       => $end));
+      $datareminders = Reminder::populatePlanning(array('who'       => $who,
+                                                        'who_group' => $who_group,
+                                                        'begin'     => $begin,
+                                                        'end'       => $end));
 
-      $interv = array_merge($interv, $datareminders);
+      $interv = array_merge($interv, $interv2, $datareminders);
 
       // --------------- Plugins
-      $data = doHookFunction("planning_populate", array("begin"     => $begin,
-                                                        "end"       => $end,
-                                                        "who"       => $who,
-                                                        "who_group" => $who_group));
+      $data = Plugin::doHookFunction("planning_populate", array("begin"     => $begin,
+                                                                "end"       => $end,
+                                                                "who"       => $who,
+                                                                "who_group" => $who_group));
 
       if (isset($data["items"])&&count($data["items"])) {
          $interv = array_merge($data["items"], $interv);
@@ -391,7 +578,7 @@ class Planning {
                echo "<tr>";
                for ($i=1 ; $i<=7 ; $i++) {
                   echo "<td class='tab_bg_3 top' width='12%'>";
-                  echo "<strong>".self::displayUsingTwoDigits($hour).":00</strong><br>";
+                  echo "<span class='b'>".self::displayUsingTwoDigits($hour).":00</span><br>";
 
                   // From midnight
                   if ($hour==$hour_begin) {
@@ -446,7 +633,7 @@ class Planning {
                $begin_time = date("Y-m-d H:i:s", strtotime($when)+($hour)*HOUR_TIMESTAMP);
                $end_time   = date("Y-m-d H:i:s", strtotime($when)+($hour+1)*HOUR_TIMESTAMP);
                echo "<td class='tab_bg_3 top' width='12%'>";
-               echo "<strong>".self::displayUsingTwoDigits($hour).":00</strong><br>";
+               echo "<span class='b'>".self::displayUsingTwoDigits($hour).":00</span><br>";
                reset($interv);
                while ($data=current($interv)) {
                   $type = "";
@@ -587,9 +774,15 @@ class Planning {
          }
 
       } else if (isset($val["tickets_id"])) {  // show tracking
-         TicketPlanning::displayPlanningItem($val, $who, $type, $complete);
+         TicketTask::displayPlanningItem($val, $who, $type, $complete);
 
-      } else {  // show Reminder
+      } else if (isset($val["problems_id"])) {  // show tracking
+         ProblemTask::displayPlanningItem($val, $who, $type, $complete);
+
+      } /*else if (isset($val["changes_id"])) {  // show tracking
+         ChangeTask::displayPlanningItem($val, $who, $type, $complete);
+
+      }*/ else {  // show Reminder
          Reminder::displayPlanningItem($val, $who, $type, $complete);
       }
       echo "</div><br>";
@@ -623,7 +816,7 @@ class Planning {
    static function showCentral($who) {
       global $CFG_GLPI, $LANG;
 
-      if (!haveRight("show_planning","1") || $who<=0) {
+      if (!Session::haveRight("show_planning","1") || $who<=0) {
          return false;
       }
 
@@ -639,10 +832,16 @@ class Planning {
       $end   = date("Y-m-d H:i:s", $end);
 
       // ---------------Tracking
-      $interv = TicketPlanning::populatePlanning(array('who'       => $who,
-                                                       'who_group' => 0,
-                                                       'begin'     => $begin,
-                                                       'end'       => $end));
+      $interv = TicketTask::populatePlanning(array('who'       => $who,
+                                                   'who_group' => 0,
+                                                   'begin'     => $begin,
+                                                   'end'       => $end));
+
+      // ---------------Problem
+      $interv2 = ProblemTask::populatePlanning(array('who'       => $who,
+                                                     'who_group' => 0,
+                                                     'begin'     => $begin,
+                                                     'end'       => $end));
 
       // ---------------Reminder
       $data = Reminder::populatePlanning(array('who'       => $who,
@@ -650,13 +849,13 @@ class Planning {
                                                'begin'     => $begin,
                                                'end'       => $end));
 
-      $interv = array_merge($interv, $data);
+      $interv = array_merge($interv, $interv2, $data);
 
       // ---------------Plugin
-      $data = doHookFunction("planning_populate", array("begin"     => $begin,
-                                                        "end"       => $end,
-                                                        "who"       => $who,
-                                                        "who_group" => -1));
+      $data = Plugin::doHookFunction("planning_populate", array("begin"     => $begin,
+                                                                "end"       => $end,
+                                                                "who"       => $who,
+                                                                "who_group" => -1));
 
       if (isset($data["items"]) && count($data["items"])) {
          $interv = array_merge($data["items"], $interv);
@@ -708,12 +907,11 @@ class Planning {
       include_once (GLPI_ROOT . "/lib/icalcreator/iCalcreator.class.php");
       $v = new vcalendar();
 
-      if (! empty ( $CFG_GLPI["version"])) {
+      if (!empty( $CFG_GLPI["version"])) {
          $v->setConfig( 'unique_id', "GLPI-Planning-".trim($CFG_GLPI["version"]) );
       } else {
          $v->setConfig( 'unique_id', "GLPI-Planning-UnknownVersion" );
       }
-      $v->setConfig( 'filename', "glpi.ics" );
 
       $v->setProperty( "method", "PUBLISH" );
       $v->setProperty( "version", "2.0" );
@@ -727,10 +925,16 @@ class Planning {
       $end   = date("Y-m-d H:i:s", $end);
 
       // ---------------Tracking
-      $interv = TicketPlanning::populatePlanning(array('who'       => $who,
-                                                       'who_group' => $who_group,
-                                                       'begin'     => $begin,
-                                                       'end'       => $end));
+      $interv = TicketTask::populatePlanning(array('who'       => $who,
+                                                   'who_group' => $who_group,
+                                                   'begin'     => $begin,
+                                                   'end'       => $end));
+
+      // ---------------Problem
+      $interv2 = ProblemTask::populatePlanning(array('who'       => $who,
+                                                     'who_group' => $who_group,
+                                                     'begin'     => $begin,
+                                                     'end'       => $end));
 
       // ---------------Reminder
       $data = Reminder::populatePlanning(array('who'       => $who,
@@ -738,18 +942,18 @@ class Planning {
                                                'begin'     => $begin,
                                                'end'       => $end));
 
-      $interv = array_merge($interv, $data);
+      $interv = array_merge($interv, $interv2, $data);
 
       // ---------------Plugin
-      $data = doHookFunction("planning_populate", array("begin"     => $begin,
-                                                        "end"       => $end,
-                                                        "who"       => $who,
-                                                        "who_group" => $who_group));
+      $data = Plugin::doHookFunction("planning_populate", array("begin"     => $begin,
+                                                                "end"       => $end,
+                                                                "who"       => $who,
+                                                                "who_group" => $who_group));
 
       if (isset($data["items"]) && count($data["items"])) {
          $interv = array_merge($data["items"], $interv);
       }
-
+      
       if (count($interv)>0) {
          foreach ($interv as $key => $val) {
             $vevent = new vevent(); //initiate EVENT
@@ -775,7 +979,7 @@ class Planning {
             }
 
             if (isset($val["content"])) {
-               $vevent->setProperty( "description", html_clean($val["content"]) );
+               $vevent->setProperty( "description", Html::clean($val["content"]) );
             } else if (isset($val["name"])) {
                $vevent->setProperty( "description", $val["name"] );
             }
@@ -790,7 +994,7 @@ class Planning {
          }
       }
       $v->sort();
-      //$v->parse();
+//       $v->parse();
       return $v->returnCalendar();
    }
 
