@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: plugin.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: plugin.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -201,7 +201,7 @@ class Plugin extends CommonDBTM {
                $function = "plugin_version_$filename";
                if (function_exists($function)) {
                   $file_plugins[$filename] = $function();
-                  $file_plugins[$filename] = addslashes_deep($file_plugins[$filename]);
+                  $file_plugins[$filename] = Toolbox::addslashes_deep($file_plugins[$filename]);
                }
             }
          }
@@ -288,10 +288,11 @@ class Plugin extends CommonDBTM {
       $pluglist = $this->find("", "name, directory");
       $i = 0;
       $PLUGIN_HOOKS_SAVE = $PLUGIN_HOOKS;
-      echo "<tr><th colspan='7'>".$LANG['plugins'][0]."</th></tr>\n";
+      echo "<tr><th colspan='8'>".$LANG['plugins'][0]."</th></tr>\n";
 
       if (!empty($pluglist)) {
          echo "<tr><th>".$LANG['common'][16]."</th><th>".$LANG['rulesengine'][78]."</th>";
+         echo "<th>".$LANG['install'][92]."</th>";
          echo "<th>".$LANG['state'][0]."</th><th>".$LANG['plugins'][9]."</th>";
          echo "<th>".$LANG['financial'][45]."</th><th colspan='2'>&nbsp;</th></tr>\n";
 
@@ -319,14 +320,29 @@ class Plugin extends CommonDBTM {
                 && isset($PLUGIN_HOOKS['config_page'][$plug['directory']])) {
 
                echo "<a href='".$CFG_GLPI["root_doc"]."/plugins/".$plug['directory']."/".
-                      $PLUGIN_HOOKS['config_page'][$plug['directory']]."'><strong>".$plug['name'].
-                     "</strong></a>";
+                      $PLUGIN_HOOKS['config_page'][$plug['directory']]."'>
+                      <span class='b'>".$plug['name']."</span></a>";
             } else {
                echo $plug['name'];
             }
             echo "</td>";
-            echo "<td>".$plug['version']."</td>";
-            echo "<td>";
+            echo "<td>".$plug['version']."</td><td>";
+            if ($plug['license']) {
+               $link = '';
+               if (file_exists(GLPI_ROOT.'/plugins/'.$plug['directory'].'/LICENSE')) {
+                  $link = $CFG_GLPI['root_doc'].'/plugins/'.$plug['directory'].'/LICENSE';
+               } else if (file_exists(GLPI_ROOT.'/plugins/'.$plug['directory'].'/COPYING.txt')) {
+                  $link = $CFG_GLPI['root_doc'].'/plugins/'.$plug['directory'].'/COPYING.txt';
+               }
+               if ($link) {
+                  echo "<a href='$link'>".$plug['license']."</a>";
+               } else {
+                  echo $plug['license'];
+               }
+            } else {
+               echo "&nbsp;";
+            }
+            echo "</td><td>";
             switch ($plug['state']) {
                case self::ANEW :
                   echo $LANG['joblist'][9];
@@ -436,7 +452,7 @@ class Plugin extends CommonDBTM {
                      if ($function(true)) {
                         $this->update(array('id'    => $ID,
                                             'state' => self::NOTACTIVATED));
-                        glpi_header($this->getSearchURL());
+                        Html::redirect($this->getSearchURL());
                      }
                   } else {
                      echo $LANG['plugins'][5]."&nbsp;: "."plugin_".$plug['directory']."_check_config";
@@ -739,7 +755,7 @@ class Plugin extends CommonDBTM {
                           44 => "Budget");
 
       //Add plugins types
-      $typetoname = doHookFunction("migratetypes",$typetoname);
+      $typetoname = self::doHookFunction("migratetypes",$typetoname);
 
       foreach ($types as $num => $name) {
          $typetoname[$num] = $name;
@@ -825,7 +841,7 @@ class Plugin extends CommonDBTM {
       $pluglist = $plug->find("","name, directory");
       foreach ($pluglist as $plugin) {
          $msg  = substr(str_pad($plugin['directory'],30),0,16)." ".$LANG['common'][16].":".
-                 utf8_substr(str_pad($plugin['name'],40),0,30)." ".$LANG['rulesengine'][78].
+                 Toolbox::substr(str_pad($plugin['name'],40),0,30)." ".$LANG['rulesengine'][78].
                  "&nbsp;:".str_pad($plugin['version'],10)." ".$LANG['joblist'][0]."&nbsp;:";
 
          switch ($plugin['state']) {
@@ -892,10 +908,10 @@ class Plugin extends CommonDBTM {
       }
 
       foreach (array('contract_types', 'document_types', 'helpdesk_visible_types', 'infocom_types',
-                     'linkgroup_types', 'linkuser_types', 'massiveaction_nodelete_types',
-                     'massiveaction_noupdate_types', 'networkport_types',
-                     'notificationtemplates_types', 'planning_types', 'reservation_types',
-                     'rulecollections_types', 'systeminformations_types',
+                     'linkgroup_tech_types', 'linkgroup_types', 'linkuser_tech_types',
+                     'linkuser_types', 'massiveaction_nodelete_types','massiveaction_noupdate_types',
+                     'networkport_types', 'notificationtemplates_types', 'planning_types',
+                     'reservation_types', 'rulecollections_types', 'systeminformations_types',
                      'ticket_types', 'unicity_types') as $att) {
          if (isset($attrib[$att]) && $attrib[$att]) {
             array_push($CFG_GLPI[$att], $itemtype);
@@ -903,10 +919,24 @@ class Plugin extends CommonDBTM {
          }
       }
 
+      if (isset($attrib['addtabon'])) {
+         if (!is_array($attrib['addtabon'])) {
+            $attrib['addtabon'] = array($attrib['addtabon']);
+         }
+         foreach ($attrib['addtabon'] as $form) {
+            CommonGLPI::registerStandardTab($form, $itemtype);
+         }
+      }
+
+      //Manage entity forward from a source itemtype to this itemtype
+      if (isset($attrib['forwardentityfrom'])) {
+         CommonDBTM::addForwardEntity($attrib['forwardentityfrom'], $itemtype);
+      }
+
       // Use it for plugin debug
 //       if (count($attrib)) {
 //          foreach ($attrib as $key => $val) {
-//             logInFile('debug',"Attribut $key used by $itemtype no more used for plugins\n");
+//             Toolbox::logInFile('debug',"Attribut $key used by $itemtype no more used for plugins\n");
 //          }
       //}
       return true;
@@ -1035,6 +1065,176 @@ class Plugin extends CommonDBTM {
       return $order;
    }
 
-}
 
-?>
+   /**
+    * This function executes a hook.
+    * @param $name Name of hook to fire
+    * @param $param Parameters if needed : if object limit to the itemtype
+    * @return mixed $data
+    */
+   static function doHook ($name,$param=NULL) {
+      global $PLUGIN_HOOKS;
+
+      if ($param==NULL) {
+         $data = func_get_args();
+      } else {
+         $data = $param;
+      }
+
+      // Apply hook only for the item
+      if ($param != NULL && is_object($param)) {
+         $itemtype = get_class($param);
+         if (isset($PLUGIN_HOOKS[$name]) && is_array($PLUGIN_HOOKS[$name])) {
+            foreach ($PLUGIN_HOOKS[$name] as $plug => $tab) {
+               if (isset($tab[$itemtype])) {
+                  if (file_exists(GLPI_ROOT . "/plugins/$plug/hook.php")) {
+                     include_once(GLPI_ROOT . "/plugins/$plug/hook.php");
+                  }
+                  if (is_callable($tab[$itemtype])) {
+                     call_user_func($tab[$itemtype],$data);
+                  }
+               }
+            }
+         }
+      } else { // Standard hook call
+         if (isset($PLUGIN_HOOKS[$name]) && is_array($PLUGIN_HOOKS[$name])) {
+            foreach ($PLUGIN_HOOKS[$name] as $plug => $function) {
+               if (file_exists(GLPI_ROOT . "/plugins/$plug/hook.php")) {
+                  include_once(GLPI_ROOT . "/plugins/$plug/hook.php");
+               }
+               if (is_callable($function)) {
+                  call_user_func($function,$data);
+               }
+            }
+         }
+      }
+      /* Variable-length argument lists have a slight problem when */
+      /* passing values by reference. Pity. This is a workaround.  */
+      return $data;
+   }
+
+
+   /**
+    * This function executes a hook.
+    * @param $name Name of hook to fire
+    * @param $parm Parameters
+    * @return mixed $data
+    */
+   static function doHookFunction($name,$parm=NULL) {
+      global $PLUGIN_HOOKS;
+
+      $ret = $parm;
+      if (isset($PLUGIN_HOOKS[$name]) && is_array($PLUGIN_HOOKS[$name])) {
+         foreach ($PLUGIN_HOOKS[$name] as $plug => $function) {
+            if (file_exists(GLPI_ROOT . "/plugins/$plug/hook.php")) {
+               include_once(GLPI_ROOT . "/plugins/$plug/hook.php");
+            }
+            if (is_callable($function)) {
+               $ret = call_user_func($function, $ret);
+            }
+         }
+      }
+      /* Variable-length argument lists have a slight problem when */
+      /* passing values by reference. Pity. This is a workaround.  */
+      return $ret;
+   }
+
+
+   /**
+    * This function executes a hook for 1 plugin.
+    * @param $plugname Name of the plugin
+    * @param $hook function to be called (may be an array for call a class method)
+    * @param $options params passed to the function
+    *
+    * @return mixed $data
+    */
+   static function doOneHook($plugname,$hook,$options=array()) {
+
+      $plugname=strtolower($plugname);
+      if (!is_array($hook)) {
+         $hook = "plugin_" . $plugname . "_" . $hook;
+         if (file_exists(GLPI_ROOT . "/plugins/$plugname/hook.php")) {
+            include_once(GLPI_ROOT . "/plugins/$plugname/hook.php");
+         }
+      }
+      if (is_callable($hook)) {
+         return call_user_func($hook, $options);
+      }
+   }
+
+
+   /**
+    * Get dropdowns for plugins
+    *
+    * @return Array containing plugin dropdowns
+    */
+   static function getDropdowns() {
+
+      $dps = array();
+      if (isset($_SESSION["glpi_plugins"]) && is_array($_SESSION["glpi_plugins"])) {
+         foreach ($_SESSION["glpi_plugins"] as  $plug) {
+            $tab = self::doOneHook($plug,'getDropdown');
+            if (is_array($tab)) {
+               $function = "plugin_version_$plug";
+               $name     = $function();
+               $dps      = array_merge($dps, array($name['name'] => $tab));
+            }
+         }
+      }
+      return $dps;
+   }
+
+
+   /**
+    * Get database relations for plugins
+    *
+    * @return Array containing plugin database relations
+    */
+   static function getDatabaseRelations() {
+
+      $dps = array();
+      if (isset($_SESSION["glpi_plugins"]) && is_array($_SESSION["glpi_plugins"])) {
+         foreach ($_SESSION["glpi_plugins"] as $plug) {
+            if (file_exists(GLPI_ROOT . "/plugins/$plug/hook.php")) {
+               include_once(GLPI_ROOT . "/plugins/$plug/hook.php");
+            }
+            $function2 = "plugin_".$plug."_getDatabaseRelations";
+            if (function_exists($function2)) {
+               $dps = array_merge_recursive($dps,$function2());
+            }
+         }
+      }
+      return $dps;
+   }
+
+
+   /**
+    * Get additional search options managed by plugins
+    *
+    * @param $itemtype
+    *
+    * @return Array containing plugin search options for given type
+    */
+   static function getAddSearchOptions($itemtype) {
+      global $PLUGIN_HOOKS;
+
+      $sopt = array();
+      if (isset($_SESSION['glpi_plugins']) && count($_SESSION['glpi_plugins'])) {
+         foreach ($_SESSION['glpi_plugins'] as $plug) {
+            if (file_exists(GLPI_ROOT . "/plugins/$plug/hook.php")) {
+               include_once(GLPI_ROOT . "/plugins/$plug/hook.php");
+            }
+            $function = "plugin_".$plug."_getAddSearchOptions";
+            if (function_exists($function)) {
+               $tmp = $function($itemtype);
+               if (count($tmp)) {
+                  $sopt += $tmp;
+               }
+            }
+         }
+      }
+      return $sopt;
+   }
+
+}
+?>
\ No newline at end of file
