@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: printer.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: printer.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -63,12 +63,12 @@ class Printer  extends CommonDBTM {
 
 
    function canCreate() {
-      return haveRight('printer', 'w');
+      return Session::haveRight('printer', 'w');
    }
 
 
    function canView() {
-      return haveRight('printer', 'r');
+      return Session::haveRight('printer', 'r');
    }
 
 
@@ -76,46 +76,17 @@ class Printer  extends CommonDBTM {
       global $LANG, $CFG_GLPI;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         if (haveRight("cartridge","r")) {
-            $ong[1] = $LANG['Menu'][21];
-         }
-
-         if (haveRight("networking","r") || haveRight("computer","r")) {
-            $ong[3] = $LANG['title'][27];
-         }
-
-         if (haveRight("contract","r") || haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            if (haveRight("show_all_ticket","1")) {
-               $ong[6] = $LANG['title'][28];
-            }
-
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-
-            if (haveRight("reservation_central","r")) {
-               $ong[11] = $LANG['Menu'][17];
-            }
-
-            $ong[12] = $LANG['title'][38];
-         }
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('Cartridge', $ong, $options);
+      $this->addStandardTab('Computer_Item', $ong, $options);
+      $this->addStandardTab('NetworkPort', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Reservation', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
       return $ong;
    }
@@ -129,7 +100,7 @@ class Printer  extends CommonDBTM {
     *
     * @return booleen
     **/
-   function canUnrecurs () {
+   function canUnrecurs() {
       global $DB, $CFG_GLPI;
 
       $ID = $this->fields['id'];
@@ -202,6 +173,12 @@ class Printer  extends CommonDBTM {
       } else {
          $input['init_pages_counter'] = 0;
       }
+      if (isset($input['last_pages_counter'])) {
+         $input['last_pages_counter'] = intval($input['last_pages_counter']);
+      } else {
+         $input['last_pages_counter'] = $input['init_pages_counter'];
+      }
+
 
       return $input;
    }
@@ -212,6 +189,9 @@ class Printer  extends CommonDBTM {
       if (isset($input['init_pages_counter'])) {
          $input['init_pages_counter'] = intval($input['init_pages_counter']);
       }
+      if (isset($input['last_pages_counter'])) {
+         $input['last_pages_counter'] = intval($input['last_pages_counter']);
+      }
 
       return $input;
    }
@@ -327,7 +307,7 @@ class Printer  extends CommonDBTM {
     *
      *@return boolean item found
     **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
       $target       = $this->getFormURL();
@@ -341,10 +321,6 @@ class Printer  extends CommonDBTM {
          $withtemplate = $options['withtemplate'];
       }
 
-      if (!haveRight("printer","r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -355,16 +331,16 @@ class Printer  extends CommonDBTM {
       if (isset($options['withtemplate']) && $options['withtemplate'] == 2) {
          $template   = "newcomp";
          $datestring = $LANG['computers'][14]."&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else if (isset($options['withtemplate']) && $options['withtemplate'] == 1) {
          $template   = "newtemplate";
          $datestring = $LANG['computers'][14]."&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else {
          $datestring = $LANG['common'][26]."&nbsp;: ";
-         $date       = convDateTime($this->fields["date_mod"]);
+         $date       = Html::convDateTime($this->fields["date_mod"]);
          $template   = false;
       }
 
@@ -376,7 +352,7 @@ class Printer  extends CommonDBTM {
       echo "<td>";
       $objectName = autoName($this->fields["name"], "name", ($template === "newcomp"),
                              $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, 'name', array('value' => $objectName));
+      Html::autocompletionTextField($this, 'name', array('value' => $objectName));
       echo "</td>\n";
       echo "<td>".$LANG['state'][0]."&nbsp;:</td>\n";
       echo "<td>";
@@ -408,23 +384,38 @@ class Printer  extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][21]."&nbsp;:</td>\n";
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "contact_num");
-      echo "</td>\n";
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
+      echo "</td>";
       echo "<td>".$LANG['common'][22]."&nbsp;:</td>\n";
       echo "<td>";
       Dropdown::show('PrinterModel', array('value' => $this->fields["printermodels_id"]));
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][18]."&nbsp;:</td>\n";
+      echo "<td>".$LANG['common'][21]."&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "contact");
+      Html::autocompletionTextField($this, "contact_num");
       echo "</td>\n";
       echo "<td>".$LANG['common'][19]."&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "serial");
+      Html::autocompletionTextField($this, "serial");
+      echo "</td></tr>\n";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][18]."&nbsp;:</td>\n";
+      echo "<td>";
+      Html::autocompletionTextField($this, "contact");
+      echo "</td>\n";
+      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>\n";
+      echo "<td>";
+      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
+                             $this->getType(), $this->fields["entities_id"]);
+      Html::autocompletionTextField($this, 'otherserial', array('value' => $objectName));
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -434,19 +425,6 @@ class Printer  extends CommonDBTM {
                            'entity' => $this->fields["entities_id"],
                            'right'  => 'all'));
       echo "</td>\n";
-      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>\n";
-      echo "<td>";
-      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
-                             $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, 'otherserial', array('value' => $objectName));
-      echo "</td></tr>\n";
-
-      echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][35]."&nbsp;:</td>\n";
-      echo "<td>";
-      Dropdown::show('Group', array('value'  => $this->fields["groups_id"],
-                                    'entity' => $this->fields["entities_id"]));
-      echo "</td>\n";
       echo "<td>".$LANG['peripherals'][33]."&nbsp;:</td>";
       echo "<td>";
       if ($this->can($ID,'w')) {
@@ -465,30 +443,43 @@ class Printer  extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['setup'][89]."&nbsp;:</td>\n";
+      echo "<td>".$LANG['common'][35]."&nbsp;:</td>\n";
       echo "<td>";
-      Dropdown::show('Domain', array('value' => $this->fields["domains_id"]));
-      echo "</td>";
+      Dropdown::show('Group', array('value'     => $this->fields["groups_id"],
+                                    'entity'    => $this->fields["entities_id"],
+                                    'condition' => '`is_itemgroup`'));
+      echo "</td>\n";
       echo "<td>".$LANG['setup'][88]."&nbsp;:</td>\n";
       echo "<td>";
       Dropdown::show('Network', array('value' => $this->fields["networks_id"]));
       echo "</td></tr>\n";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['setup'][89]."&nbsp;:</td>\n";
+      echo "<td>";
+      Dropdown::show('Domain', array('value' => $this->fields["domains_id"]));
+      echo "</td>";
+      echo "<td rowspan='6'>".$LANG['common'][25]."&nbsp;:</td>\n";
+      echo "<td rowspan='6'><textarea cols='45' rows='12' name='comment' >".
+            $this->fields["comment"]."</textarea>";
+      echo "</td></tr>\n";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['devices'][6]."&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "memory_size");
-      echo "</td>";
-      echo "<td rowspan='4'>";
-      echo $LANG['common'][25]."&nbsp;:</td>\n";
-      echo "<td rowspan='4'><textarea cols='45' rows='8' name='comment' >".
-            $this->fields["comment"]."</textarea>";
+      Html::autocompletionTextField($this, "memory_size");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['printers'][30]."&nbsp;:</td>\n";
       echo "<td>";
-      autocompletionTextField($this, "init_pages_counter");
+      Html::autocompletionTextField($this, "init_pages_counter", array('size' => 10));
+      echo "</td></tr>\n";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['printers'][26]."&nbsp;:</td>\n";
+      echo "<td>";
+      Html::autocompletionTextField($this, "last_pages_counter", array('size' => 10));
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -497,21 +488,21 @@ class Printer  extends CommonDBTM {
       // serial interface
       echo "<tr><td>".$LANG['printers'][14]."</td><td>";
       Dropdown::showYesNo("have_serial", $this->fields["have_serial"]);
-      echo "</td></tr>";
+      echo "</td>";
       // parallel interface?
-      echo "<tr><td>".$LANG['printers'][15]."</td><td>";
+      echo "<td>".$LANG['printers'][15]."</td><td>";
       Dropdown::showYesNo("have_parallel", $this->fields["have_parallel"]);
       echo "</td></tr>";
       // USB interface?
       echo "<tr><td>".$LANG['printers'][27]."</td><td>";
       Dropdown::showYesNo("have_usb", $this->fields["have_usb"]);
-      echo "</td></tr>";
+      echo "</td>";
       // ethernet interface?
-      echo "<tr><td>".$LANG['printers'][28]."</td><td>";
+      echo "<td>".$LANG['printers'][28]."</td><td>";
       Dropdown::showYesNo("have_ethernet",$this->fields["have_ethernet"]);
       echo "</td></tr>";
       // wifi ?
-      echo "<tr><td>".$LANG['printers'][29]."</td><td>";
+      echo "<tr><td>".$LANG['printers'][29]."</td><td colspan='3'>";
       Dropdown::showYesNo("have_wifi", $this->fields["have_wifi"]);
       echo "</td></tr></table>\n";
 
@@ -535,7 +526,7 @@ class Printer  extends CommonDBTM {
     *
     * @return a SQL command which return a set of (itemtype, items_id)
     **/
-   function getSelectLinkedItem () {
+   function getSelectLinkedItem() {
 
       return "SELECT 'Computer', `computers_id`
               FROM `glpi_computers_items`
@@ -573,7 +564,7 @@ class Printer  extends CommonDBTM {
       $tab[40]['name']  = $LANG['common'][22];
 
       $tab[31]['table'] = 'glpi_states';
-      $tab[31]['field'] = 'name';
+      $tab[31]['field'] = 'completename';
       $tab[31]['name']  = $LANG['state'][0];
 
       $tab[5]['table']     = $this->getTable();
@@ -600,9 +591,10 @@ class Printer  extends CommonDBTM {
       $tab[70]['field'] = 'name';
       $tab[70]['name']  = $LANG['common'][34];
 
-      $tab[71]['table'] = 'glpi_groups';
-      $tab[71]['field'] = 'name';
-      $tab[71]['name']  = $LANG['common'][35];
+      $tab[71]['table']     = 'glpi_groups';
+      $tab[71]['field']     = 'completename';
+      $tab[71]['name']      = $LANG['common'][35];
+      $tab[71]['condition'] = '`is_itemgroup`';
 
       $tab[19]['table']         = $this->getTable();
       $tab[19]['field']         = 'date_mod';
@@ -640,6 +632,17 @@ class Printer  extends CommonDBTM {
       $tab[46]['name']     = $LANG['printers'][29];
       $tab[46]['datatype'] = 'bool';
 
+      $tab[11]['table']    = $this->getTable();
+      $tab[11]['field']    = 'init_pages_counter';
+      $tab[11]['name']     = $LANG['printers'][30];
+      $tab[11]['datatype'] = 'number';
+      $tab[11]['nosearch'] = true; // only display and histo, no index
+
+      $tab[12]['table']    = $this->getTable();
+      $tab[12]['field']    = 'last_pages_counter';
+      $tab[12]['name']     = $LANG['printers'][26];
+      $tab[12]['datatype'] = 'number';
+
       $tab[90]['table']         = $this->getTable();
       $tab[90]['field']         = 'notepad';
       $tab[90]['name']          = $LANG['title'][37];
@@ -662,6 +665,12 @@ class Printer  extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[80]['table']         = 'glpi_entities';
       $tab[80]['field']         = 'completename';
       $tab[80]['name']          = $LANG['entity'][0];
@@ -680,14 +689,16 @@ class Printer  extends CommonDBTM {
 
       return $tab;
    }
-      /**
+
+
+  /**
     * Add a printer. If already exist in trash restore it
     *
     * @param name the printer's name
     * @param manufacturer the software's manufacturer
     * @param entity the entity in which the software must be added
     * @param comment comment
-   */
+   **/
    function addOrRestoreFromTrash($name, $manufacturer, $entity, $comment='') {
       global $DB;
 
@@ -771,6 +782,6 @@ class Printer  extends CommonDBTM {
    function removeFromTrash($ID) {
       return $this->restore(array("id" => $ID));
    }
-}
 
+}
 ?>
\ No newline at end of file
