@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: profile.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -42,12 +42,13 @@ class Profile extends CommonDBTM {
    // Specific ones
 
    /// Helpdesk fields of helpdesk profiles
-   static public $helpdesk_rights = array('add_followups', 'create_ticket', 'create_validation',
+   static public $helpdesk_rights = array('add_followups', 'create_ticket',
+                                          'create_ticket_on_login', 'create_validation',
                                           'update_own_followups', 'faq', 'helpdesk_hardware',
                                           'helpdesk_item_type', 'observe_ticket', 'password_update',
                                           'reminder_public', 'reservation_helpdesk',
                                           'show_group_hardware', 'show_group_ticket',
-                                          'validate_ticket');
+                                          'ticketrecurrent', 'tickettemplate', 'validate_ticket');
 
 
    /// Common fields used for all profiles type
@@ -55,54 +56,95 @@ class Profile extends CommonDBTM {
 
 
    /// Fields not related to a basic right
-   static public $noright_fields = array('comment', 'date_mod', 'helpdesk_hardware',
-                                         'helpdesk_item_type', 'helpdesk_status', 'own_ticket',
-                                         'show_group_hardware', 'show_group_ticket');
+   static public $noright_fields = array('comment', /*'change_status',*/ 'date_mod',
+                                         'helpdesk_hardware','helpdesk_item_type', 'own_ticket',
+                                         'problem_status', 'show_group_hardware',
+                                         'show_group_ticket', 'ticket_status');
 
 
    var $dohistory = true;
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['Menu'][35];
+      if ($nb>1) {
+         return $LANG['Menu'][35];
+      }
+      return $LANG['profiles'][22];
    }
 
 
    function canCreate() {
-      return haveRight('profile', 'w');
+      return Session::haveRight('profile', 'w');
    }
 
 
    function canView() {
-      return haveRight('profile', 'r');
+      return Session::haveRight('profile', 'r');
    }
 
 
    function defineTabs($options=array()) {
+
+      $ong = array();
+      $this->addStandardTab(__CLASS__, $ong, $options);
+      $this->addStandardTab('Profile_User', $ong, $options);
+      $this->addStandardTab('Log',$ong, $options);
+      return $ong;
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
       global $LANG;
 
-      if (!$this->fields['id']) {
-         $ong[1] = $LANG['common'][12];
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case __CLASS__ :
+               if ($item->fields['interface']=='helpdesk') {
+                  $ong[1] = $LANG['Menu'][31]; // Helpdesk
 
-      } else if ($this->fields['interface']=='helpdesk') {
-         $ong[1] = $LANG['Menu'][31]; // Helpdesk
-         if (haveRight("user","r")) {
-            $ong[4] = $LANG['Menu'][14];
+               } else {
+                  $ong[2] = $LANG['Menu'][38].'/'.$LANG['Menu'][26].'/'.$LANG['Menu'][18]; // Inventory/Management
+                  $ong[3] = $LANG['title'][24]; // Assistance
+                  $ong[4] = $LANG['setup'][619]; // Life cycles
+                  $ong[5] = $LANG['Menu'][15].'/'.$LANG['common'][12]; // Administration/Setup
+               }
+               return $ong;
          }
-         $ong[12] = $LANG['title'][38];
-
-      } else {
-         $ong[1] = $LANG['Menu'][38].'/'.$LANG['Menu'][26].'/'.$LANG['Menu'][18]; // Inventory/Management
-         $ong[2] = $LANG['title'][24]; // Assistance
-         $ong[3] = $LANG['Menu'][15].'/'.$LANG['common'][12]; // Administration/Setup
-         if (haveRight("user","r")) {
-            $ong[4] = $LANG['Menu'][14];
-         }
-         $ong[12] = $LANG['title'][38];
       }
-      return $ong;
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType() == __CLASS__) {
+         $item->cleanProfile();
+         switch ($tabnum) {
+            case 1 :
+               $item->showFormHelpdesk();
+               break;
+
+            case 2 :
+               $item->showFormInventory();
+               break;
+
+            case 3 :
+               $item->showFormTracking();
+               break;
+
+            case 4 :
+               $item->showFormLifeCycle();
+               break;
+
+            case 5 :
+               $item->showFormAdmin();
+               break;
+
+         }
+      }
+      return true;
    }
 
 
@@ -123,8 +165,8 @@ class Profile extends CommonDBTM {
 
       if (isset($this->fields['is_default']) && $this->fields["is_default"]==1) {
          $query = "UPDATE ". $this->getTable()."
-                   SET `is_default` = '0'
-                   WHERE `id` <> '".$this->fields['id']."'";
+                  SET `is_default` = '0'
+                  WHERE `id` <> '".$this->fields['id']."'";
          $DB->query($query);
       }
    }
@@ -162,18 +204,45 @@ class Profile extends CommonDBTM {
          }
       }
 
-      if (isset($input["_cycles"])) {
-         $tab = Ticket::getAllStatusArray();
+      if (isset($input["_cycles_ticket"])) {
+         $tab   = Ticket::getAllStatusArray();
          $cycle = array();
          foreach ($tab as $from => $label) {
             foreach ($tab as $dest => $label) {
-               if ($from!=$dest && $input["_cycle"][$from][$dest]==0) {
+               if ($from!=$dest && $input["_cycle_ticket"][$from][$dest]==0) {
                   $cycle[$from][$dest] = 0;
                }
             }
          }
-         $input["helpdesk_status"] = exportArrayToDB($cycle);
+         $input["ticket_status"] = exportArrayToDB($cycle);
       }
+
+      if (isset($input["_cycles_problem"])) {
+         $tab   = Problem::getAllStatusArray();
+         $cycle = array();
+         foreach ($tab as $from => $label) {
+            foreach ($tab as $dest => $label) {
+               if ($from!=$dest && $input["_cycle_problem"][$from][$dest]==0) {
+                  $cycle[$from][$dest] = 0;
+               }
+            }
+         }
+         $input["problem_status"] = exportArrayToDB($cycle);
+      }
+
+//       if (isset($input["_cycles_change"])) {
+//          $tab   = Change::getAllStatusArray();
+//          $cycle = array();
+//          foreach ($tab as $from => $label) {
+//             foreach ($tab as $dest => $label) {
+//                if ($from!=$dest && $input["_cycle_change"][$from][$dest]==0) {
+//                   $cycle[$from][$dest] = 0;
+//                }
+//             }
+//          }
+//          $input["change_status"] = exportArrayToDB($cycle);
+//       }
+
       return $input;
    }
 
@@ -215,11 +284,15 @@ class Profile extends CommonDBTM {
       }
 
       // Decode status array
-      if (isset($this->fields["helpdesk_status"]) && !is_array($this->fields["helpdesk_status"])) {
-         $this->fields["helpdesk_status"] = importArrayFromDB($this->fields["helpdesk_status"]);
-         // Need to be an array not a null value
-         if (is_null($this->fields["helpdesk_status"])) {
-            $this->fields["helpdesk_status"] = array();
+      $fields_to_decode = array('ticket_status','problem_status'/*,'change_status'*/);
+      foreach ($fields_to_decode as $val) {
+
+         if (isset($this->fields[$val]) && !is_array($this->fields[$val])) {
+            $this->fields[$val] = importArrayFromDB($this->fields[$val]);
+            // Need to be an array not a null value
+            if (is_null($this->fields[$val])) {
+               $this->fields[$val] = array();
+            }
          }
       }
    }
@@ -240,7 +313,7 @@ class Profile extends CommonDBTM {
       }
 
       // Profile right : may modify profile so can attach all profile
-      if (haveRight("profile","w")) {
+      if (Session::haveRight("profile","w")) {
          return $query." 1 ";
       }
 
@@ -337,7 +410,7 @@ class Profile extends CommonDBTM {
    }
 
 
-   function post_getEmpty () {
+   function post_getEmpty() {
       global $LANG;
 
       $this->fields["interface"] = "helpdesk";
@@ -360,7 +433,7 @@ class Profile extends CommonDBTM {
 
       $onfocus = "";
       $new = false;
-      $rowspan = 4;
+      $rowspan = 5;
       if ($ID > 0) {
          $rowspan++;
          $this->check($ID,'r');
@@ -399,10 +472,15 @@ class Profile extends CommonDBTM {
       Dropdown::showYesNo("password_update", $this->fields["password_update"]);
       echo "</td></tr>\n";
 
+      echo "<tr class='tab_bg_1'><td>".$LANG['profiles'][3]."&nbsp;:</td><td>";
+      Dropdown::showYesNo("create_ticket_on_login", $this->fields["create_ticket_on_login"]);
+      echo "</td></tr>\n";
+
       if ($ID>0) {
          echo "<tr class='tab_bg_1'><td>".$LANG['common'][26]."&nbsp;: </td>";
          echo "<td>";
-         echo ($this->fields["date_mod"] ? convDateTime($this->fields["date_mod"]) : $LANG['setup'][307]);
+         echo ($this->fields["date_mod"] ? Html::convDateTime($this->fields["date_mod"])
+                                         : $LANG['setup'][307]);
          echo "</td></tr>";
       }
 
@@ -412,21 +490,20 @@ class Profile extends CommonDBTM {
       return true;
    }
 
-
    /**
-   * Print the helpdesk right form for the current profile
-   *
-   * @param $target of the form
+    * Print the helpdesk right form for the current profile
+    *
    **/
-   function showFormHelpdesk($target) {
+   function showFormHelpdesk() {
       global $LANG,$CFG_GLPI;
 
       $ID = $this->fields['id'];
+      $target = $this->getFormURL();
 
-      if (!haveRight("profile","r")) {
+      if (!Session::haveRight("profile","r")) {
          return false;
       }
-      if ($canedit=haveRight("profile","w")) {
+      if ($canedit=Session::haveRight("profile","w")) {
          echo "<form method='post' action='$target'>";
       }
 
@@ -461,8 +538,7 @@ class Profile extends CommonDBTM {
       echo "<td>".$LANG['setup'][350]."&nbsp;:</td>";
       echo "<td><select name='helpdesk_hardware'>";
       echo "<option value='0' ".($this->fields["helpdesk_hardware"]==0?"selected":"")." >".
-             DROPDOWN_EMPTY_VALUE;
-      echo "</option>\n";
+             Dropdown::EMPTY_VALUE."</option>\n";
       echo "<option value=\"".pow(2,HELPDESK_MY_HARDWARE)."\" ".
              ($this->fields["helpdesk_hardware"]==pow(2,HELPDESK_MY_HARDWARE)?"selected":"")." >".
              $LANG['tracking'][1]."</option>\n";
@@ -480,9 +556,8 @@ class Profile extends CommonDBTM {
 
       foreach ($CFG_GLPI["ticket_types"] as $key => $itemtype) {
 
-         if (class_exists($itemtype)) {
+         if ($item = getItemForItemtype($itemtype)) {
             if (!isPluginItemType($itemtype)) { // No Plugin for the moment
-               $item = new $itemtype();
                echo "<option value='".$itemtype."' ".
                      (in_array($itemtype,$this->fields["helpdesk_item_type"])?" selected":"").">".
                      $item->getTypeName()."</option>\n";
@@ -539,19 +614,19 @@ class Profile extends CommonDBTM {
    /**
     * Print the Inventory/Management/Toolsd right form for the current profile
     *
-    * @param $target of the form
     * @param $openform boolean open the form
     * @param $closeform boolean close the form
    **/
-   function showFormInventory($target, $openform=true, $closeform=true) {
+   function showFormInventory($openform=true, $closeform=true) {
       global $LANG;
 
       $ID = $this->fields['id'];
+      $target = $this->getFormURL();
 
-      if (!haveRight("profile","r")) {
+      if (!Session::haveRight("profile","r")) {
          return false;
       }
-      if (($canedit=haveRight("profile","w")) && $openform) {
+      if (($canedit=Session::haveRight("profile","w")) && $openform) {
          echo "<form method='post' action='$target'>";
       }
 
@@ -651,13 +726,13 @@ class Profile extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td>".$LANG['Menu'][33]."&nbsp;: </td><td>";
+      echo "<td>".$LANG['ocsconfig'][24]."&nbsp;: </td><td>";
       self::dropdownNoneReadWrite("ocsng", $this->fields["ocsng"], 1, 0, 1);
       echo "</td>";
-      echo "<td>".$LANG['profiles'][31]."&nbsp;:</td><td>";
+      echo "<td>".$LANG['ocsconfig'][22]."&nbsp;:</td><td>";
       self::dropdownNoneReadWrite("sync_ocsng", $this->fields["sync_ocsng"], 1, 0, 1);
       echo "</td>";
-      echo "<td>".$LANG['profiles'][30]."&nbsp;:</td><td>";
+      echo "<td>".$LANG['ocsconfig'][21]."&nbsp;:</td><td>";
       self::dropdownNoneReadWrite("view_ocsng", $this->fields["view_ocsng"], 1, 1, 0);
       echo "</td></tr>\n";
 
@@ -682,21 +757,21 @@ class Profile extends CommonDBTM {
 
 
    /**
-   * Print the Tracking right form for the current profile
-   *
-   * @param $target of the form
-   * @param $openform boolean open the form
-   * @param $closeform boolean close the form
+    * Print the Tracking right form for the current profile
+    *
+    * @param $openform boolean open the form
+    * @param $closeform boolean close the form
    **/
-   function showFormTracking($target, $openform=true, $closeform=true) {
+   function showFormTracking($openform=true, $closeform=true) {
       global $LANG,$CFG_GLPI;
 
       $ID = $this->fields['id'];
+      $target = $this->getFormURL();
 
-      if (!haveRight("profile","r")) {
+      if (!Session::haveRight("profile","r")) {
          return false;
       }
-      if (($canedit=haveRight("profile","w")) && $openform) {
+      if (($canedit=Session::haveRight("profile","w")) && $openform) {
          echo "<form method='post' action='$target'>";
       }
 
@@ -721,13 +796,24 @@ class Profile extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_2'>";
-      echo "<td colspan='2'>&nbsp;</td>";
       echo "<td>".$LANG['profiles'][4]."&nbsp;:</td><td>";
       Dropdown::showYesNo("group_add_followups", $this->fields["group_add_followups"]);
       echo "</td>";
       echo "<td>".$LANG['profiles'][45]."&nbsp;:</td><td>";
       Dropdown::showYesNo("global_add_tasks", $this->fields["global_add_tasks"]);
-      echo "</td></tr>\n";
+      echo "</td>";
+      echo "<td>&nbsp;</td><td>&nbsp;</td>";
+      echo "</tr>\n";
+
+      echo "<tr class='tab_bg_2'>";
+      echo "<td>".$LANG['job'][59]."&nbsp;: </td><td>";
+      self::dropdownNoneReadWrite("tickettemplate", $this->fields["tickettemplate"], 1, 1, 1);
+      echo "</td>";
+      echo "<td>".$LANG['jobrecurrent'][1]."&nbsp;:</td><td>";
+      self::dropdownNoneReadWrite("ticketrecurrent", $this->fields["ticketrecurrent"], 1, 1, 1);
+      echo "</td>";
+      echo "<td>&nbsp;</td><td>&nbsp;</td>";
+      echo "</tr>\n";
 
       echo "<tr class='tab_bg_5'><th colspan='6'>".$LANG['profiles'][40]."</th>";
       echo "</tr>\n";
@@ -752,8 +838,9 @@ class Profile extends CommonDBTM {
       echo "</td>\n";
       echo "<td colspan='2'></td></tr>\n";
 
-      echo "<tr class='tab_bg_5'><th colspan='6'>".$LANG['ocsconfig'][50]."</th><";
-      echo "/tr>\n";
+      echo "<tr class='tab_bg_5'><th colspan='6'>".$LANG['profiles'][54]."</th>";
+      echo "</tr>\n";
+
       echo "<tr class='tab_bg_2'>";
       echo "<td>".$LANG['profiles'][14]."&nbsp;:</td><td>";
       Dropdown::showYesNo("delete_ticket", $this->fields["delete_ticket"]);
@@ -797,7 +884,7 @@ class Profile extends CommonDBTM {
       echo "<td>".$LANG['setup'][350]."&nbsp;:</td>";
       echo "\n<td><select name='helpdesk_hardware'>";
       echo "<option value='0' ".($this->fields["helpdesk_hardware"]==0?"selected":"")." >".
-             DROPDOWN_EMPTY_VALUE."</option>\n";
+             Dropdown::EMPTY_VALUE."</option>\n";
       echo "<option value=\"".pow(2,HELPDESK_MY_HARDWARE)."\" ".
             ($this->fields["helpdesk_hardware"]==pow(2,HELPDESK_MY_HARDWARE)?"selected":"")." >".
             $LANG['tracking'][1]."</option>\n";
@@ -814,9 +901,8 @@ class Profile extends CommonDBTM {
       echo "<select name='helpdesk_item_type[]' multiple size='3'>";
 
       foreach ($CFG_GLPI["ticket_types"] as $key => $itemtype) {
-         if (class_exists($itemtype)) {
+         if ($item = getItemForItemtype($itemtype)) {
             if (!isPluginItemType($itemtype)) { // No Plugin for the moment
-               $item = new $itemtype();
                echo "<option value='".$itemtype."' ".
                      (in_array($itemtype, $this->fields["helpdesk_item_type"])?" selected":"").">".
                      $item->getTypeName()."</option>\n";
@@ -864,12 +950,75 @@ class Profile extends CommonDBTM {
       Dropdown::showYesNo("show_all_planning", $this->fields["show_all_planning"]);
       echo "</td></tr>\n";
 
-      echo "</table><br><table class='tab_cadre_fixe'>";
+      echo "<tr class='tab_bg_5'><th colspan='6'>".$LANG['Menu'][7]/*." / ".$LANG['Menu'][8]*/."</th>";
+      echo "</tr>\n";
+
+      echo "<tr class='tab_bg_2'>";
+      echo "<td>".$LANG['profiles'][52]."&nbsp;:</td><td>";
+      Dropdown::showYesNo("edit_all_problem", $this->fields["edit_all_problem"]);
+      echo "</td>";
+      echo "<td>".$LANG['profiles'][25]."&nbsp;:</td><td>";
+      Dropdown::showYesNo("show_all_problem", $this->fields["show_all_problem"]);
+      echo "</td>";
+      echo "<td>".$LANG['profiles'][53]."&nbsp;:</td><td>";
+      Dropdown::showYesNo("show_my_problem", $this->fields["show_my_problem"]);
+      echo "</td>";
+      echo "</tr>\n";
+
+
+//       echo "<tr class='tab_bg_2'>";
+//       echo "<td>".$LANG['profiles'][56]."&nbsp;:</td><td>";
+//       Dropdown::showYesNo("edit_all_change", $this->fields["edit_all_change"]);
+//       echo "</td>";
+//       echo "<td>".$LANG['profiles'][55]."&nbsp;:</td><td>";
+//       Dropdown::showYesNo("show_all_change", $this->fields["show_all_change"]);
+//       echo "</td>";
+//       echo "<td>".$LANG['profiles'][57]."&nbsp;:</td><td>";
+//       Dropdown::showYesNo("show_my_change", $this->fields["show_my_change"]);
+//       echo "</td>";
+//       echo "</tr>\n";
+
+      if ($canedit && $closeform) {
+         echo "<tr class='tab_bg_1'>";
+         echo "<td colspan='6' class='center'>";
+         echo "<input type='hidden' name='id' value=$ID>";
+         echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\" class='submit'>";
+         echo "</td></tr>\n";
+         echo "</table></form>\n";
+      } else {
+         echo "</table>\n";
+      }
+      echo "</div>";
+   }
+
+   /**
+   * Print the Life Cycles form for the current profile
+   *
+   * @param $openform boolean open the form
+   * @param $closeform boolean close the form
+   **/
+   function showFormLifeCycle($openform=true, $closeform=true) {
+      global $LANG,$CFG_GLPI;
+
+      $ID = $this->fields['id'];
+      $target = $this->getFormURL();
+
+      if (!Session::haveRight("profile","r")) {
+         return false;
+      }
+
+      if (($canedit=Session::haveRight("profile","w")) && $openform) {
+         echo "<form method='post' action='$target'>";
+      }
+
+      echo "<div class='spaced'>";
+
+      echo "<table class='tab_cadre_fixe'>";
       $tabstatus = Ticket::getAllStatusArray();
 
       echo "<th colspan='".(count($tabstatus)+1)."'>".$LANG['setup'][615]."</th>";
       echo "<tr class='tab_bg_1'><td class='b center'>".$LANG['setup'][616];
-      echo "<input type='hidden' name='_cycles' value='1'</td>";
+      echo "<input type='hidden' name='_cycles_ticket' value='1'</td>";
       foreach ($tabstatus as $label) {
          echo "<td class='center'>$label</td>";
       }
@@ -882,14 +1031,71 @@ class Profile extends CommonDBTM {
             if ($dest==$from) {
                echo Dropdown::getYesNo(1);
             } else {
-               Dropdown::showYesNo("_cycle[$from][$dest]",
-                                   (!isset($this->fields['helpdesk_status'][$from][$dest])
-                                    || $this->fields['helpdesk_status'][$from][$dest]));
+               Dropdown::showYesNo("_cycle_ticket[$from][$dest]",
+                                   (!isset($this->fields['ticket_status'][$from][$dest])
+                                    || $this->fields['ticket_status'][$from][$dest]));
             }
             echo "</td>";
          }
          echo "</tr>\n";
       }
+      echo "</table>";
+
+      echo "<table class='tab_cadre_fixe'>";
+      $tabstatus = Problem::getAllStatusArray();
+
+      echo "<th colspan='".(count($tabstatus)+1)."'>".$LANG['setup'][617]."</th>";
+      echo "<tr class='tab_bg_1'><td class='b center'>".$LANG['setup'][616];
+      echo "<input type='hidden' name='_cycles_problem' value='1'</td>";
+      foreach ($tabstatus as $label) {
+         echo "<td class='center'>$label</td>";
+      }
+      echo "</tr>\n";
+
+      foreach ($tabstatus as $from => $label) {
+         echo "<tr class='tab_bg_2'><td class='tab_bg_1'>$label</td>";
+         foreach ($tabstatus as $dest => $label) {
+            echo "<td class='center'>";
+            if ($dest==$from) {
+               echo Dropdown::getYesNo(1);
+            } else {
+               Dropdown::showYesNo("_cycle_problem[$from][$dest]",
+                                   (!isset($this->fields['problem_status'][$from][$dest])
+                                    || $this->fields['problem_status'][$from][$dest]));
+            }
+            echo "</td>";
+         }
+         echo "</tr>\n";
+      }
+
+//       echo "</table>";
+//
+//       echo "<table class='tab_cadre_fixe'>";
+//       $tabstatus = Change::getAllStatusArray();
+//
+//       echo "<th colspan='".(count($tabstatus)+1)."'>".$LANG['setup'][618]."</th>";
+//       echo "<tr class='tab_bg_1'><td class='b center'>".$LANG['setup'][616];
+//       echo "<input type='hidden' name='_cycles_change' value='1'</td>";
+//       foreach ($tabstatus as $label) {
+//          echo "<td class='center'>$label</td>";
+//       }
+//       echo "</tr>\n";
+//
+//       foreach ($tabstatus as $from => $label) {
+//          echo "<tr class='tab_bg_2'><td class='tab_bg_1'>$label</td>";
+//          foreach ($tabstatus as $dest => $label) {
+//             echo "<td class='center'>";
+//             if ($dest==$from) {
+//                echo Dropdown::getYesNo(1);
+//             } else {
+//                Dropdown::showYesNo("_cycle_change[$from][$dest]",
+//                                    (!isset($this->fields['change_status'][$from][$dest])
+//                                     || $this->fields['change_status'][$from][$dest]));
+//             }
+//             echo "</td>";
+//          }
+//          echo "</tr>\n";
+//       }
 
       if ($canedit && $closeform) {
          echo "<tr class='tab_bg_1'>";
@@ -906,27 +1112,27 @@ class Profile extends CommonDBTM {
 
 
    /**
-   * Print the central form for a profile
-   *
-   * @param $target target of the form
-   * @param $openform boolean open the form
-   * @param $closeform boolean close the form
+    * Print the central form for a profile
+    *
+    * @param $openform boolean open the form
+    * @param $closeform boolean close the form
    **/
-   function showFormAdmin($target, $openform=true, $closeform=true) {
+   function showFormAdmin($openform=true, $closeform=true) {
       global $LANG;
 
       $ID = $this->fields['id'];
+      $target = $this->getFormURL();
 
-      if (!haveRight("profile","r")) {
+      if (!Session::haveRight("profile","r")) {
          return false;
       }
 
       echo "<div class='firstbloc'>";
-      if (($canedit=haveRight("profile","w")) && $openform) {
+      if (($canedit=Session::haveRight("profile","w")) && $openform) {
          echo "<form method='post' action='$target'>";
       }
 
-      echo "<table class='tab_cadre_fixe'><tr>";
+      echo "<table class='tab_cadre_fixe'>";
 
       // Administration
       echo "<tr class='tab_bg_1'><th colspan='6'>".$LANG['Menu'][15]."</th></tr>\n";
@@ -1036,7 +1242,7 @@ class Profile extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_4'>";
-      echo "<td>".$LANG['title'][30]."&nbsp;:</td><td>";
+      echo "<td>".Toolbox::ucfirst($LANG['log'][18])."&nbsp;:</td><td>";
       self::dropdownNoneReadWrite("device", $this->fields["device"], 1, 0, 1);
       echo "</td>";
       echo "<td>".$LANG['setup'][0]."&nbsp;:</td><td>";
@@ -1115,6 +1321,11 @@ class Profile extends CommonDBTM {
       $tab[3]['datatype']      = 'bool';
       $tab[3]['massiveaction'] = false;
 
+      $tab[118]['table']    = $this->getTable();
+      $tab[118]['field']    = 'create_ticket_on_login';
+      $tab[118]['name']     = $LANG['profiles'][3];
+      $tab[118]['datatype'] = 'bool';
+
       $tab[16]['table']    = $this->getTable();
       $tab[16]['field']    = 'comment';
       $tab[16]['name']     = $LANG['common'][25];
@@ -1228,17 +1439,17 @@ class Profile extends CommonDBTM {
 
       $tab[39]['table']    = $this->getTable();
       $tab[39]['field']    = 'ocsng';
-      $tab[39]['name']     = $LANG['Menu'][33];
+      $tab[39]['name']     = $LANG['ocsconfig'][0];
       $tab[39]['datatype'] = 'right';
 
       $tab[40]['table']    = $this->getTable();
       $tab[40]['field']    = 'view_ocsng';
-      $tab[40]['name']     = $LANG['profiles'][30];
+      $tab[40]['name']     = $LANG['ocsconfig'][21];
       $tab[40]['datatype'] = 'right';
 
       $tab[41]['table']    = $this->getTable();
       $tab[41]['field']    = 'sync_ocsng';
-      $tab[41]['name']     = $LANG['profiles'][31];
+      $tab[41]['name']     = $LANG['ocsconfig'][22];
       $tab[41]['datatype'] = 'right';
 
       $tab['config'] = $LANG['common'][12];
@@ -1255,7 +1466,7 @@ class Profile extends CommonDBTM {
 
       $tab[44]['table']    = $this->getTable();
       $tab[44]['field']    = 'device';
-      $tab[44]['name']     = $LANG['title'][30];
+      $tab[44]['name']     = Toolbox::ucfirst($LANG['log'][18]);
       $tab[44]['datatype'] = 'right';
 
       $tab[106]['table']    = $this->getTable();
@@ -1392,6 +1603,11 @@ class Profile extends CommonDBTM {
       $tab[102]['name']     = $LANG['profiles'][5];
       $tab[102]['datatype'] = 'bool';
 
+      $tab[103]['table']    = $this->getTable();
+      $tab[103]['field']    = 'tickettemplate';
+      $tab[103]['name']     = $LANG['job'][28];
+      $tab[103]['datatype'] = 'right';
+
       $tab[65]['table']    = $this->getTable();
       $tab[65]['field']    = 'delete_ticket';
       $tab[65]['name']     = $LANG['profiles'][14];
@@ -1533,12 +1749,56 @@ class Profile extends CommonDBTM {
       $tab[99]['datatype'] = 'bool';
 
       $tab[100]['table']         = $this->getTable();
-      $tab[100]['field']         = 'helpdesk_status';
+      $tab[100]['field']         = 'ticket_status';
       $tab[100]['name']          = $LANG['setup'][615];
       $tab[100]['nosearch']      = true;
       $tab[100]['datatype']      = 'text';
       $tab[100]['massiveaction'] = false;
 
+      $tab[110]['table']         = $this->getTable();
+      $tab[110]['field']         = 'problem_status';
+      $tab[110]['name']          = $LANG['setup'][617];
+      $tab[110]['nosearch']      = true;
+      $tab[110]['datatype']      = 'text';
+      $tab[110]['massiveaction'] = false;
+
+      $tab[112]['table']    = $this->getTable();
+      $tab[112]['field']    = 'show_my_problem';
+      $tab[112]['name']     = $LANG['profiles'][53];
+      $tab[112]['datatype'] = 'bool';
+
+      $tab[113]['table']    = $this->getTable();
+      $tab[113]['field']    = 'show_all_problem';
+      $tab[113]['name']     = $LANG['profiles'][25];
+      $tab[113]['datatype'] = 'bool';
+
+      $tab[114]['table']    = $this->getTable();
+      $tab[114]['field']    = 'edit_all_problem';
+      $tab[114]['name']     = $LANG['profiles'][52];
+      $tab[114]['datatype'] = 'bool';
+
+//       $tab[111]['table']         = $this->getTable();
+//       $tab[111]['field']         = 'change_status';
+//       $tab[111]['name']          = $LANG['setup'][618];
+//       $tab[111]['nosearch']      = true;
+//       $tab[111]['datatype']      = 'text';
+//       $tab[111]['massiveaction'] = false;
+//
+//       $tab[115]['table']    = $this->getTable();
+//       $tab[115]['field']    = 'show_my_change';
+//       $tab[115]['name']     = $LANG['profiles'][57];
+//       $tab[115]['datatype'] = 'bool';
+//
+//       $tab[116]['table']    = $this->getTable();
+//       $tab[116]['field']    = 'show_all_change';
+//       $tab[116]['name']     = $LANG['profiles'][55];
+//       $tab[116]['datatype'] = 'bool';
+//
+//       $tab[117]['table']    = $this->getTable();
+//       $tab[117]['field']    = 'edit_all_change';
+//       $tab[117]['name']     = $LANG['profiles'][56];
+//       $tab[117]['datatype'] = 'bool';
+
       $tab['other'] = $LANG['common'][62];
 
       $tab[4]['table']    = $this->getTable();
@@ -1606,7 +1866,7 @@ class Profile extends CommonDBTM {
          }
       }
 
-      $profiles[0] = DROPDOWN_EMPTY_VALUE;
+      $profiles[0] = Dropdown::EMPTY_VALUE;
 
       $query = "SELECT *
                 FROM `glpi_profiles` ".
@@ -1671,4 +1931,4 @@ class Profile extends CommonDBTM {
       }
    }
 }
-?>
+?>
\ No newline at end of file
