@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile_user.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: profile_user.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -45,12 +45,12 @@ class Profile_User extends CommonDBTM {
 
 
    function canView() {
-      return haveRight('user','r');
+      return Session::haveRight('user','r');
    }
 
 
    function canCreate() {
-      return haveRight('user','w');
+      return Session::haveRight('user','w');
    }
 
 
@@ -59,7 +59,7 @@ class Profile_User extends CommonDBTM {
       return $user->can($this->fields['users_id'],'r')
              && Profile::currentUserHaveMoreRightThan(
                                array($this->fields['profiles_id'] => $this->fields['profiles_id']))
-             && haveAccessToEntity($this->fields['entities_id']);
+             && Session::haveAccessToEntity($this->fields['entities_id']);
    }
 
 
@@ -73,7 +73,7 @@ class Profile_User extends CommonDBTM {
           || !isset($input['users_id'])
           || $input['users_id'] < 0) {
 
-         addMessageAfterRedirect($LANG['common'][24], false, ERROR);
+         Session::addMessageAfterRedirect($LANG['common'][24], false, ERROR);
          return false;
       }
       return $input;
@@ -96,14 +96,15 @@ class Profile_User extends CommonDBTM {
       $canedit = $user->can($ID,'w');
 
       $strict_entities = self::getUserEntities($ID,false);
-      if (!haveAccessToOneOfEntities($strict_entities) && !isViewAllEntities()) {
+      if (!Session::haveAccessToOneOfEntities($strict_entities)
+          && !Session::isViewAllEntities()) {
          $canedit = false;
       }
 
-      $canshowentity = haveRight("entity","r");
+      $canshowentity = Session::haveRight("entity","r");
       $rand=mt_rand();
       echo "<form name='entityuser_form$rand' id='entityuser_form$rand' method='post' action='";
-      echo getItemTypeFormURL(__CLASS__)."'>";
+      echo Toolbox::getItemTypeFormURL(__CLASS__)."'>";
 
       if ($canedit) {
          echo "<div class='firstbloc'>";
@@ -112,8 +113,7 @@ class Profile_User extends CommonDBTM {
 
          echo "<tr class='tab_bg_2'><td class='center'>";
          echo "<input type='hidden' name='users_id' value='$ID'>";
-         Dropdown::show('Entity', array('entity' => $_SESSION['glpiactiveentities'],
-                                        'value'  => $_SESSION['glpiactive_entity']));
+         Dropdown::show('Entity', array('entity' => $_SESSION['glpiactiveentities']));
          echo "</td><td class='center'>".$LANG['profiles'][22]."&nbsp;: ";
          Profile::dropdownUnder(array('value' => Profile::getDefault()));
          echo "</td><td class='center'>".$LANG['profiles'][28]."&nbsp;: ";
@@ -164,7 +164,7 @@ class Profile_User extends CommonDBTM {
             echo "<td>";
 
             if ($canshowentity) {
-               echo "<a href='".getItemTypeFormURL('Entity')."?id=".$data["entities_id"]."'>";
+               echo "<a href='".Toolbox::getItemTypeFormURL('Entity')."?id=".$data["entities_id"]."'>";
             }
             echo $data["completename"].
                  ($_SESSION["glpiis_ids_visible"]?" (".$data["entities_id"].")":"");
@@ -176,7 +176,7 @@ class Profile_User extends CommonDBTM {
             echo "<td>".$data["name"];
 
             if ($data["is_dynamic"] || $data["is_recursive"]) {
-               echo "<strong>&nbsp;(";
+               echo "<span class='b'>&nbsp;(";
                if ($data["is_dynamic"]) {
                   echo "D";
                }
@@ -186,7 +186,7 @@ class Profile_User extends CommonDBTM {
                if ($data["is_recursive"]) {
                   echo "R";
                }
-               echo ")</strong>";
+               echo ")</span>";
             }
             echo "</td>";
          }
@@ -195,8 +195,8 @@ class Profile_User extends CommonDBTM {
       echo "</table>";
 
       if ($canedit) {
-         openArrowMassive("entityuser_form$rand",true);
-         closeArrowMassive('delete', $LANG['buttons'][6]);
+         Html::openArrowMassives("entityuser_form$rand",true);
+         Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
       }
       echo "</form></div>";
    }
@@ -217,13 +217,13 @@ class Profile_User extends CommonDBTM {
       }
 
       $canedit     = $entity->can($ID,"w");
-      $canshowuser = haveRight("user","r");
+      $canshowuser = Session::haveRight("user", "r");
       $nb_per_line = 3;
       $rand        = mt_rand();
 
       if ($canedit) {
          echo "<form name='entityuser_form$rand' id='entityuser_form$rand' method='post' action='";
-         echo getItemTypeFormURL(__CLASS__)."'>";
+         echo Toolbox::getItemTypeFormURL(__CLASS__)."'>";
          $headerspan = $nb_per_line*2;
       } else {
          $headerspan = $nb_per_line;
@@ -257,11 +257,11 @@ class Profile_User extends CommonDBTM {
                      ON (`glpi_profiles_users`.`profiles_id` = `glpi_profiles`.`id`)
                 LEFT JOIN `glpi_users` ON (`glpi_users`.`id` = `glpi_profiles_users`.`users_id`)
                 WHERE `glpi_profiles_users`.`entities_id` = '$ID'
-                      AND `glpi_users`.`is_deleted` = '0'";
+                     AND `glpi_users`.`is_deleted` = '0'";
 
       $result = $DB->query($query);
       if ($DB->numrows($result)>0) {
-         initNavigateListItems('User', $LANG['entity'][0]." = ".$entity->fields['name']);
+         Session::initNavigateListItems('User', $LANG['entity'][0]." = ".$entity->fields['name']);
 
          while ($data=$DB->fetch_array($result)) {
             echo "<tr><th colspan='$headerspan'>".$LANG['profiles'][22]."&nbsp;: ".$data["name"];
@@ -287,7 +287,7 @@ class Profile_User extends CommonDBTM {
                $i = 0;
 
                while ($data2=$DB->fetch_array($result2)) {
-                  addToNavigateListItems('User',$data2["id"]);
+                  Session::addToNavigateListItems('User',$data2["id"]);
 
                   if ($i%$nb_per_line==0) {
                      if ($i!=0) {
@@ -306,7 +306,7 @@ class Profile_User extends CommonDBTM {
                                       $data2["firstname"], $canshowuser);
 
                   if ($data2["is_dynamic"] || $data2["is_recursive"]) {
-                     echo "<strong>&nbsp;(";
+                     echo "<span class='b'>&nbsp;(";
                      if ($data2["is_dynamic"]) {
                         echo "D";
                      }
@@ -316,7 +316,7 @@ class Profile_User extends CommonDBTM {
                      if ($data2["is_recursive"]) {
                         echo "R";
                      }
-                     echo ")</strong>";
+                     echo ")</span>";
                   }
                   echo "</td>";
                   $i++;
@@ -339,8 +339,8 @@ class Profile_User extends CommonDBTM {
       echo "</table>";
 
       if ($canedit) {
-         openArrowMassive("entityuser_form$rand", true);
-         closeArrowMassive('delete', $LANG['buttons'][6]);
+         Html::openArrowMassives("entityuser_form$rand", true);
+         Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
          echo "</form>";
       }
       echo "</div>";
@@ -357,7 +357,7 @@ class Profile_User extends CommonDBTM {
       global $DB,$LANG,$CFG_GLPI;
 
       $ID      = $prof->fields['id'];
-      $canedit = haveRight("user","w");
+      $canedit = Session::haveRight("user", "w");
 
       if (!$prof->can($ID,'r')) {
          return false;
@@ -414,11 +414,11 @@ class Profile_User extends CommonDBTM {
                      echo "</table>";
 
                      if ($canedit_entity) {
-                        openArrowMassive("profileuser_form".$rand."_$temp", true);
+                        Html::openArrowMassives("profileuser_form".$rand."_$temp", true);
                         Dropdown::show('Entity', array('entity' => $_SESSION['glpiactiveentities']));
                         echo "&nbsp;<input type='submit' name='moveentity' value='".
                               $LANG['buttons'][20]."' class='submit'>&nbsp;";
-                        closeArrowMassive('delete', $LANG['buttons'][6]);
+                        Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
                      }
                      echo "</div></form></td></tr>\n";
                   }
@@ -433,13 +433,13 @@ class Profile_User extends CommonDBTM {
                   echo "<a href=\"javascript:showHideDiv('entity$temp$rand','imgcat$temp', '".
                          GLPI_ROOT."/pics/folder.png','".GLPI_ROOT."/pics/folder-open.png');\">";
                   echo "<img alt='' name='imgcat$temp' src=\"".GLPI_ROOT."/pics/folder.png\">&nbsp;";
-                  echo "<strong>".Dropdown::getDropdownName('glpi_entities', $data["entity"]).
-                        "</strong>";
+                  echo "<span class='b'>".Dropdown::getDropdownName('glpi_entities', $data["entity"]).
+                        "</span>";
                   echo "</a></td></tr>\n";
 
-                  echo "<tr><td>";
+                  echo "<tr class='tab_bg_2'><td>";
                   echo "<form name='profileuser_form".$rand."_$temp' id='profileuser_form".$rand.
-                         "_$temp' method='post' action='".getItemTypeFormURL(__CLASS__)."'>";
+                         "_$temp' method='post' action='".Toolbox::getItemTypeFormURL(__CLASS__)."'>";
                   echo "<div class='center' id='entity$temp$rand' style='display:none;'>\n";
                   echo "<table class='tab_cadre_fixe'>\n";
                }
@@ -467,7 +467,7 @@ class Profile_User extends CommonDBTM {
                                                            $data["realname"], $data["firstname"], 1);
 
                if ($data["is_dynamic"] || $data["is_recursive"]) {
-                  echo "<strong>&nbsp;(";
+                  echo "<span class='b'>&nbsp;(";
                   if ($data["is_dynamic"]) {
                      echo "D";
                   }
@@ -477,7 +477,7 @@ class Profile_User extends CommonDBTM {
                   if ($data["is_recursive"]) {
                      echo "R";
                   }
-                  echo ")</strong>";
+                  echo ")</span>";
                }
                echo "</td>\n";
                $i++;
@@ -488,7 +488,7 @@ class Profile_User extends CommonDBTM {
                   if ($canedit_entity) {
                      echo "<td width='10'>&nbsp;</td>";
                   }
-                  echo "<td class='tab_bg_1'>".DROPDOWN_EMPTY_VALUE."</td>";
+                  echo "<td class='tab_bg_1'>".Dropdown::EMPTY_VALUE."</td>";
                   $i++;
                }
             }
@@ -496,17 +496,17 @@ class Profile_User extends CommonDBTM {
             if ($i!=0) {
                echo "</table>\n";
                if ($canedit_entity) {
-                  openArrowMassive("profileuser_form".$rand."_$temp", true);
+                  Html::openArrowMassives("profileuser_form".$rand."_$temp", true);
                   Dropdown::show('Entity', array('entity' => $_SESSION['glpiactiveentities']));
                   echo "&nbsp;<input type='submit' name='moveentity' value='".
                                $LANG['buttons'][20]."' class='submit'>&nbsp;";
-                  closeArrowMassive('delete', $LANG['buttons'][6]);
+                  Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
                }
                echo "</div></form></td></tr>\n";
             }
 
          } else {
-            echo "<tr><td class='tab_bg_1 center'>".$LANG['profiles'][33]."</td></tr>\n";
+            echo "<tr class='tab_bg_2'><td class='center'>".$LANG['profiles'][33]."</td></tr>\n";
          }
       }
       echo "</table></div>\n";
@@ -577,6 +577,15 @@ class Profile_User extends CommonDBTM {
    }
 
 
+   /**
+    * retrieve the entities allowed to a user for a profile
+    *
+    * @param $users_id     Integer  ID of the user
+    * @param $profiles_id  Integer  ID of the profile
+    * @param $child        Boolean  when true, include child entity when recursive right
+    *
+    * @return Array of entity ID
+    */
    static function getEntitiesForProfileByUser($users_id, $profiles_id, $child=false) {
       global $DB;
 
@@ -708,7 +717,7 @@ class Profile_User extends CommonDBTM {
       $changes[1] = '';
       $changes[2] = addslashes($this->getName());
       Log::history($this->fields['users_id'], 'User', $changes, get_class($this),
-                   HISTORY_ADD_SUBITEM);
+                   Log::HISTORY_ADD_SUBITEM);
    }
 
 
@@ -721,7 +730,72 @@ class Profile_User extends CommonDBTM {
       $changes[1] = addslashes($this->getName());
       $changes[2] = '';
       Log::history($this->fields['users_id'], 'User', $changes, get_class($this),
-                   HISTORY_DELETE_SUBITEM);
+                   Log::HISTORY_DELETE_SUBITEM);
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         $nb = 0;
+         switch ($item->getType()) {
+            case 'Entity' :
+               if (Session::haveRight('user', 'r')) {
+                  if ($_SESSION['glpishow_count_on_tabs']) {
+                     // Keep this ? (only approx. as count deleted users)
+                     $nb = countElementsInTable($this->getTable(),
+                                                "entities_id = '".$item->getID()."'");
+                  }
+                  return self::createTabEntry($LANG['Menu'][14], $nb);
+               }
+               break;
+
+            case 'Profile' :
+               if (Session::haveRight('user', 'r')) {
+                  if ($_SESSION['glpishow_count_on_tabs']) {
+                     // Keep this ? (only approx. as count deleted users)
+                     $nb = countElementsInTable($this->getTable(),
+                                                "profiles_id = '".$item->getID()."'".
+                                                getEntitiesRestrictRequest('AND',
+                                                                           'glpi_profiles_users',
+                                                                           'entities_id',
+                                                                           $_SESSION['glpiactiveentities'],
+                                                                           true));
+                  }
+                  return self::createTabEntry($LANG['Menu'][14], $nb);
+               }
+               break;
+
+            case 'User' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  $nb = countElementsInTable($this->getTable(),
+                                             "users_id = '".$item->getID()."'");
+               }
+               return self::createTabEntry($LANG['users'][14], $nb);
+
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      switch ($item->getType()) {
+         case 'Entity' :
+            self::showForEntity($item);
+            break;
+
+         case 'Profile' :
+            self::showForProfile($item);
+            break;
+
+         case 'User' :
+            self::showForUser($item);
+            break;
+      }
+      return true;
    }
 
 }
