@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: reservationitem.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: reservationitem.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,10 +39,13 @@ if (!defined('GLPI_ROOT')) {
 /// Reservation item class
 class ReservationItem extends CommonDBTM {
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['Menu'][17];
+      if ($nb>1) {
+         return $LANG['reservation'][10];
+      }
+      return $LANG['reservation'][1];
    }
 
 
@@ -130,7 +133,7 @@ class ReservationItem extends CommonDBTM {
       $tab[70]['name']  = $LANG['common'][34];
 
       $tab[71]['table'] = 'glpi_groups';
-      $tab[71]['field'] = 'name';
+      $tab[71]['field'] = 'completename';
       $tab[71]['name']  = $LANG['common'][35];
 
       $tab[19]['table']         = 'reservation_types';
@@ -157,20 +160,16 @@ class ReservationItem extends CommonDBTM {
    }
 
 
-   static function showActivationFormForItem($itemtype, $items_id) {
+   static function showActivationFormForItem(CommonDBTM $item) {
       global $CFG_GLPI, $LANG;
 
-      if (!haveRight("reservation_central","w")) {
+      if (!Session::haveRight("reservation_central","w")) {
          return false;
       }
-      if (class_exists($itemtype)) {
-         $item = new $itemtype();
-         if (!$item->getFromDB($items_id)) {
-            return false;
-         }
+      if ($item->getID()) {
          // Recursive type case => need entity right
          if ($item->isRecursive()) {
-            if (!haveAccessToEntity($item->fields["entities_id"])) {
+            if (!Session::haveAccessToEntity($item->fields["entities_id"])) {
                return false;
             }
          }
@@ -179,13 +178,14 @@ class ReservationItem extends CommonDBTM {
          return false;
       }
 
-      $ri = new ReservationItem;
+      $ri = new ReservationItem();
 
-      echo "<div><form method='post' name=form action='".getItemTypeFormURL('ReservationItem')."'>";
+      echo "<div><form method='post' name=form action='".
+                  Toolbox::getItemTypeFormURL('ReservationItem')."'>";
       echo "<table class='tab_cadre_fixe'>";
       echo "<tr><th>".$LANG['reservation'][9]."</th></tr>";
       echo "<tr class='tab_bg_1'>";
-      if ($ri->getFromDBbyItem($itemtype,$items_id)) {
+      if ($ri->getFromDBbyItem($item->getType(),$item->getID())) {
          echo "<td class='center'>";
          //Switch reservation state
          echo "<input type='hidden' name='id' value='".$ri->fields['id']."'>";
@@ -200,13 +200,13 @@ class ReservationItem extends CommonDBTM {
          }
          echo "<span class='small_space'>";
          echo "<input type='submit' name='delete' value=\"".$LANG['reservation'][6]."\"
-               class='submit' ".addConfirmationOnAction(array($LANG['reservation'][38],
-                                                              $LANG['reservation'][39])).">";
+               class='submit' ".Html::addConfirmationOnAction(array($LANG['reservation'][38],
+                                                                    $LANG['reservation'][39])).">";
          echo "</span></td>";
       } else {
          echo "<td class='center'>";
-         echo "<input type='hidden' name='items_id' value='$items_id'>";
-         echo "<input type='hidden' name='itemtype' value='$itemtype'>";
+         echo "<input type='hidden' name='items_id' value='".$item->getID()."'>";
+         echo "<input type='hidden' name='itemtype' value='".$item->getType()."'>";
          echo "<input type='hidden' name='entities_id' value='".$item->getEntityID()."'>";
          echo "<input type='hidden' name='is_recursive' value='".$item->isRecursive()."'>";
          echo "<input type='submit' name='add' value=\"".$LANG['reservation'][7]."\" class='submit'>";
@@ -219,17 +219,16 @@ class ReservationItem extends CommonDBTM {
    function showForm($ID, $options=array()) {
       global $LANG;
 
-      if (!haveRight("reservation_central","w")) {
+      if (!Session::haveRight("reservation_central","w")) {
          return false;
       }
 
-      $r = new ReservationItem;
+      $r = new ReservationItem();
 
       if ($r->getFromDB($ID)) {
          $type = $r->fields["itemtype"];
          $name = NOT_AVAILABLE;
-         if (class_exists($r->fields["itemtype"])) {
-            $item = new $r->fields["itemtype"]();
+         if ($item = getItemForItemtype($r->fields["itemtype"])) {
             $type = $item->getTypeName();
             if ($item->getFromDB($r->fields["items_id"])) {
                $name = $item->getName();
@@ -265,23 +264,22 @@ class ReservationItem extends CommonDBTM {
    static function showListSimple() {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight("reservation_helpdesk","1")) {
+      if (!Session::haveRight("reservation_helpdesk","1")) {
          return false;
       }
 
-      $ri = new ReservationItem;
+      $ri = new ReservationItem();
       $ok = false;
-      $showentity = isMultiEntitiesMode();
+      $showentity = Session::isMultiEntitiesMode();
 
       echo "<div class='center'><form name='form' method='get' action='reservation.form.php'>";
       echo "<table class='tab_cadre'>";
       echo "<tr><th colspan='".($showentity?"5":"4")."'>".$LANG['reservation'][1]."</th></tr>\n";
 
       foreach ($CFG_GLPI["reservation_types"] as $itemtype) {
-         if (!class_exists($itemtype)) {
+         if (!($item = getItemForItemtype($itemtype))) {
             continue;
          }
-         $item = new $itemtype();
          $itemtable = getTableForItemType($itemtype);
          $query = "SELECT `glpi_reservationitems`.`id`,
                           `glpi_reservationitems`.`comment`,
@@ -403,7 +401,7 @@ class ReservationItem extends CommonDBTM {
       }
 
       foreach ($items_infos as $entity => $items) {
-         $resitem = new ReservationItem;
+         $resitem = new ReservationItem();
          if (NotificationEvent::raiseEvent("alert", new Reservation(),
                                            array('entities_id' => $entity,
                                                  'items'       => $items))) {
@@ -414,8 +412,8 @@ class ReservationItem extends CommonDBTM {
                $task->log(Dropdown::getDropdownName("glpi_entities",
                                                     $entity).":  $message\n");
             } else {
-               addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
-                                                                 $entity).":  $message");
+               Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                          $entity).":  $message");
             }
 
             $alert = new Alert();
@@ -432,8 +430,9 @@ class ReservationItem extends CommonDBTM {
                $task->log(Dropdown::getDropdownName("glpi_entities", $entity).
                           ":  Send reservationitem alert failed\n");
             } else {
-               addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity).
-                                       ":  Send reservationitem alert failed", false, ERROR);
+               Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity).
+                                                  ":  Send reservationitem alert failed",
+                                                false, ERROR);
             }
          }
       }
@@ -451,7 +450,7 @@ class ReservationItem extends CommonDBTM {
       $resa->fields['reservationitems_id'] = $this->getField('id');
       $resa->fields['begin']               = $_SESSION['glpi_currenttime'];
       $resa->fields['end']                 = $_SESSION['glpi_currenttime'];
-      $resa->fields['users_id']            = getLoginUserID();
+      $resa->fields['users_id']            = Session::getLoginUserID();
       $resa->fields['comment']             = '';
 
       NotificationEvent::debugEvent($resa);
