@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rule.class.php 17964 2012-03-21 09:46:22Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -85,6 +85,7 @@ class Rule extends CommonDBTM {
    const PATTERN_EXISTS          = 8;
    const PATTERN_DOES_NOT_EXISTS = 9;
    const PATTERN_FIND            = 10;
+   const PATTERN_UNDER           = 11;
 
    const AND_MATCHING = "AND";
    const OR_MATCHING  = "OR";
@@ -99,13 +100,23 @@ class Rule extends CommonDBTM {
    }
 
 
+   static function getTypeName($nb=0) {
+      global $LANG;
+
+      if ($nb>1) {
+         return $LANG['rulesengine'][17];
+      }
+      return Toolbox::ucfirst($LANG['log'][65]);
+   }
+
+
    function canCreate() {
-      return haveRight($this->right, 'w');
+      return Session::haveRight($this->right, 'w');
    }
 
 
    function canView() {
-      return haveRight($this->right, 'r');
+      return Session::haveRight($this->right, 'r');
    }
 
 
@@ -114,7 +125,7 @@ class Rule extends CommonDBTM {
    }
 
 
-   function post_getEmpty () {
+   function post_getEmpty() {
       $this->fields['is_active'] = 0;
    }
 
@@ -223,11 +234,11 @@ class Rule extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;:&nbsp;</td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
       echo "<td>".$LANG['joblist'][6]."&nbsp;:&nbsp;</td>";
       echo "<td>";
-      autocompletionTextField($this, "description");
+      Html::autocompletionTextField($this, "description");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -247,7 +258,7 @@ class Rule extends CommonDBTM {
 
       if (!$this->isNewID($ID)) {
          echo "<br>".$LANG['common'][26]."&nbsp;:&nbsp;";
-         echo ($this->fields["date_mod"] ? convDateTime($this->fields["date_mod"])
+         echo ($this->fields["date_mod"] ? Html::convDateTime($this->fields["date_mod"])
                                          : $LANG['setup'][307]);
       }
       echo"</td></tr>\n";
@@ -317,12 +328,12 @@ class Rule extends CommonDBTM {
       } else if ($ret=$this->getFromDB($ID)) {
 
          if ($withactions) {
-            $RuleAction    = new $this->ruleactionclass;
+            $RuleAction    = new $this->ruleactionclass();
             $this->actions = $RuleAction->getRuleActions($ID);
          }
 
          if ($withcriterias) {
-            $RuleCriterias   = new $this->rulecriteriaclass;
+            $RuleCriterias   = new $this->rulecriteriaclass();
             $this->criterias = $RuleCriterias->getRuleCriterias($ID);
          }
 
@@ -399,20 +410,20 @@ class Rule extends CommonDBTM {
          $canedit = false;
          $style   = "class='tab_cadre'";
       }
-      $this->getTitleAction(getItemTypeFormURL(get_class($this)));
+      $this->getTitleAction(Toolbox::getItemTypeFormURL(get_class($this)));
 
       if (($this->maxActionsCount()==0 || sizeof($this->actions) < $this->maxActionsCount())
           && $canedit) {
 
          echo "<form name='actionsaddform' method='post' action='".
-                getItemTypeFormURL(get_class($this))."'>\n";
+                Toolbox::getItemTypeFormURL(get_class($this))."'>\n";
          $this->addActionForm($rules_id);
          echo "</form>";
       }
 
       if ($canedit) {
          echo "<form name='actionsform' id='actionsform' method='post' action='".
-                getItemTypeFormURL(get_class($this))."'>\n";
+                Toolbox::getItemTypeFormURL(get_class($this))."'>\n";
       }
       echo "<div class='spaced'>";
       echo "<table $style>";
@@ -436,9 +447,9 @@ class Rule extends CommonDBTM {
       echo "</table>\n";
 
       if ($canedit && $nb>0) {
-         openArrowMassive("actionsform", true);
+         Html::openArrowMassives("actionsform", true);
          echo "<input type='hidden' name='".$this->rules_id_field."' value='$rules_id'>";
-         closeArrowMassive('delete_action', $LANG['buttons'][6]);
+         Html::closeArrowMassives(array('delete_action' => $LANG['buttons'][6]));
       }
       if ($canedit) {
          echo "</form>";
@@ -530,13 +541,13 @@ class Rule extends CommonDBTM {
       global $CFG_GLPI, $LANG;
 
       $canedit = $this->can($rules_id, "w");
-      $this->getTitleCriteria(getItemTypeFormURL(get_class($this)));
+      $this->getTitleCriteria(Toolbox::getItemTypeFormURL(get_class($this)));
 
       if (($this->maxCriteriasCount()==0 || sizeof($this->criterias) < $this->maxCriteriasCount())
           && $canedit) {
 
          echo "<form name='criteriasaddform' method='post' action='".
-                getItemTypeFormURL(get_class($this))."'>\n";
+                Toolbox::getItemTypeFormURL(get_class($this))."'>\n";
          $this->addCriteriaForm($rules_id);
          echo "</form>";
       }
@@ -544,7 +555,7 @@ class Rule extends CommonDBTM {
       echo "<div class='spaced'>";
 
       echo "<form name='criteriasform' id='criteriasform' method='post' action='".
-             getItemTypeFormURL(get_class($this))."'>\n";
+             Toolbox::getItemTypeFormURL(get_class($this))."'>\n";
       echo "<table class='tab_cadre_fixe'>";
       echo "<tr><th colspan='".($canedit?" 4 ":"3")."'>" . $LANG['rulesengine'][6] . "</th></tr>\n";
 
@@ -565,9 +576,9 @@ class Rule extends CommonDBTM {
       echo "</table>\n";
 
       if ($canedit && $maxsize>0) {
-         openArrowMassive("criteriasform", true);
+         Html::openArrowMassives("criteriasform", true);
          echo "<input type='hidden' name='".$this->rules_id_field."' value='$rules_id'>";
-         closeArrowMassive('delete_criteria', $LANG['buttons'][6]);
+         Html::closeArrowMassives(array('delete_criteria' => $LANG['buttons'][6]));
       }
       echo "</form></div>\n";
    }
@@ -593,16 +604,16 @@ class Rule extends CommonDBTM {
                       'rand'     => $rand,
                       'sub_type' => $this->getType());
 
-      ajaxUpdateItemOnSelectEvent("dropdown_criteria$rand", "criteria_span",
-                                  $CFG_GLPI["root_doc"]."/ajax/rulecriteria.php", $params, false);
+      Ajax::updateItemOnSelectEvent("dropdown_criteria$rand", "criteria_span",
+                                    $CFG_GLPI["root_doc"]."/ajax/rulecriteria.php", $params);
 
       if ($this->specific_parameters) {
          $itemtype = get_class($this).'Parameter';
          echo "<img alt='' title=\"".$LANG['rulesengine'][140]."\" src='".$CFG_GLPI["root_doc"].
                 "/pics/add_dropdown.png' style='cursor:pointer; margin-left:2px;'
-                onClick=\"var w = window.open('".getItemTypeFormURL($itemtype)."?popup=1&amp;rand=".
-                $params['rand']."' ,'glpipopup', 'height=400, "."width=1000, top=100, left=100, ".
-                "scrollbars=yes' );w.focus();\">";
+                onClick=\"var w = window.open('".Toolbox::getItemTypeFormURL($itemtype).
+                "?popup=1&amp;rand=".$params['rand']."' ,'glpipopup', 'height=400, ".
+                "width=1000, top=100, left=100, scrollbars=yes' );w.focus();\">";
       }
 
       return key($items);
@@ -661,8 +672,8 @@ class Rule extends CommonDBTM {
       $params = array('field'    => '__VALUE__',
                       'sub_type' => $this->getType());
 
-      ajaxUpdateItemOnSelectEvent("dropdown_field$rand", "action_span",
-                                  $CFG_GLPI["root_doc"]."/ajax/ruleaction.php", $params, false);
+      Ajax::updateItemOnSelectEvent("dropdown_field$rand", "action_span",
+                                    $CFG_GLPI["root_doc"]."/ajax/ruleaction.php", $params);
 
       return $value;
    }
@@ -773,7 +784,7 @@ class Rule extends CommonDBTM {
             $hook_params["ruleid"]   = $this->fields["id"];
             $hook_params["input"]    = $input;
             $hook_params["output"]   = $output;
-            doHook("rule_matched", $hook_params);
+            Plugin::doHook("rule_matched", $hook_params);
             $output["_rule_process"] = true;
             unset($output["_no_rule_matches"]);
          }
@@ -969,6 +980,7 @@ class Rule extends CommonDBTM {
                   if ($action->fields["action_type"] == "append_regex_result") {
                      $res = (isset($params[$action->fields["field"]])
                              ?$params[$action->fields["field"]]:"");
+
                   } else {
                      $res = "";
                   }
@@ -998,15 +1010,15 @@ class Rule extends CommonDBTM {
       // Delete a rule and all associated criterias and actions
       if (!empty($this->ruleactionclass)) {
          $sql = "DELETE
-               FROM `".getTableForItemType($this->ruleactionclass)."`
-               WHERE `".$this->rules_id_field."` = '".$this->fields['id']."'";
+                 FROM `".getTableForItemType($this->ruleactionclass)."`
+                 WHERE `".$this->rules_id_field."` = '".$this->fields['id']."'";
          $DB->query($sql);
       }
 
       if (!empty($this->rulecriteriaclass)) {
          $sql = "DELETE
-               FROM `".getTableForItemType($this->rulecriteriaclass)."`
-               WHERE `".$this->rules_id_field."` = '".$this->fields['id']."'";
+                 FROM `".getTableForItemType($this->rulecriteriaclass)."`
+                 WHERE `".$this->rules_id_field."` = '".$this->fields['id']."'";
          $DB->query($sql);
       }
    }
@@ -1023,14 +1035,14 @@ class Rule extends CommonDBTM {
    function showMinimalForm($target, $first=false, $last=false, $display_entities=false) {
       global $LANG, $CFG_GLPI;
 
-      $canedit = haveRight($this->right, "w") && !$display_entities;
+      $canedit = Session::haveRight($this->right, "w") && !$display_entities;
       echo "<tr class='tab_bg_1'>";
 
       if ($canedit) {
          echo "<td width='10'>";
          $sel = "";
 
-         if (isset ($_GET["select"]) && $_GET["select"] == "all") {
+         if (isset($_GET["select"]) && $_GET["select"] == "all") {
             $sel = "checked";
          }
 
@@ -1044,7 +1056,7 @@ class Rule extends CommonDBTM {
       echo "<td>".$this->getLink()."&nbsp;";
 
       if (!empty($this->fields["comment"])) {
-         showToolTip($this->fields["comment"]);
+         Html::showToolTip($this->fields["comment"]);
       }
       echo "</td>";
       echo "<td>".$this->fields["description"]."</td>";
@@ -1053,7 +1065,7 @@ class Rule extends CommonDBTM {
       if ($display_entities) {
          $rec = '';
          if ($this->maybeRecursive() && $this->fields['is_recursive']) {
-            $rec =' <b>(R)</b>';
+            $rec =' <span class="b">&nbsp;(R)</span>';
          }
          echo "<td>".Dropdown::getDropdownName('glpi_entities', $this->fields['entities_id'])."$rec</td>";
       }
@@ -1123,7 +1135,7 @@ class Rule extends CommonDBTM {
          echo "<td width='10'>";
          $sel = "";
 
-         if (isset ($_GET["select"]) && $_GET["select"] == "all") {
+         if (isset($_GET["select"]) && $_GET["select"] == "all") {
             $sel = "checked";
          }
 
@@ -1160,7 +1172,7 @@ class Rule extends CommonDBTM {
       //Process the rule
       $this->process($input, $output, $params, false);
 
-      $criteria = new $this->rulecriteriaclass;
+      $criteria = new $this->rulecriteriaclass();
 
       echo "<div class='spaced'>";
       echo "<table class='tab_cadrehov'>";
@@ -1180,7 +1192,7 @@ class Rule extends CommonDBTM {
          if ($criteria->fields['condition'] != self::PATTERN_FIND) {
             echo "<td class='b'>".Dropdown::getYesNo($criteria_result["result"])."</td></tr>\n";
          } else {
-            echo "<td class='b'>".DROPDOWN_EMPTY_VALUE."</td></tr>\n";
+            echo "<td class='b'>".Dropdown::EMPTY_VALUE."</td></tr>\n";
          }
       }
       echo "</table></div>";
@@ -1209,7 +1221,7 @@ class Rule extends CommonDBTM {
          echo "<tr class='tab_bg_2'>";
          echo "<td>".$LANG['rulesengine'][85]."</td>";
          echo "<td>";
-         printCleanArray($this->regex_results[0]);
+         Html::printCleanArray($this->regex_results[0]);
          echo "</td></tr>\n";
       }
       echo "</tr>\n";
@@ -1230,7 +1242,7 @@ class Rule extends CommonDBTM {
          echo "<td width='10'>";
          $sel = "";
 
-         if (isset ($_GET["select"]) && $_GET["select"] == "all") {
+         if (isset($_GET["select"]) && $_GET["select"] == "all") {
             $sel = "checked";
          }
 
@@ -1256,7 +1268,8 @@ class Rule extends CommonDBTM {
    function getMinimalCriteriaText($fields) {
 
       $text  = "<td>" . $this->getCriteriaName($fields["criteria"]) . "</td>";
-      $text .= "<td>" . RuleCriteria::getConditionByID($fields["condition"], get_class($this))."</td>";
+      $text .= "<td>" . RuleCriteria::getConditionByID($fields["condition"], get_class($this),
+                                                       $fields["criteria"])."</td>";
       $text .= "<td>" . $this->getCriteriaDisplayPattern($fields["criteria"], $fields["condition"],
                                                          $fields["pattern"]) . "</td>";
       return $text;
@@ -1298,7 +1311,9 @@ class Rule extends CommonDBTM {
           || $condition == self::PATTERN_FIND) {
           return $LANG['choice'][1];
 
-      } else if ($condition==self::PATTERN_IS || $condition==self::PATTERN_IS_NOT) {
+      } else if (in_array($condition, array(self::PATTERN_IS,
+                                            self::PATTERN_IS_NOT,
+                                            self::PATTERN_UNDER))) {
          $crit = $this->getCriteria($ID);
 
          if (isset($crit['type'])) {
@@ -1311,8 +1326,10 @@ class Rule extends CommonDBTM {
                   $addentity = "";
                   if ($this->isEntityAssign()) {
                      $itemtype = getItemTypeForTable($crit["table"]);
-                     $item     = new $itemtype();
-                     if ($item->isEntityAssign() && $item->getFromDB($pattern)) {
+                     $item     = getItemForItemtype($itemtype);
+                     if ($item
+                         && $item->isEntityAssign()
+                         && $item->getFromDB($pattern)) {
                         $addentity = '&nbsp;('.Dropdown::getDropdownName('glpi_entities',
                                                                          $item->getEntityID()).')';
                      }
@@ -1324,8 +1341,7 @@ class Rule extends CommonDBTM {
                   return getUserName($pattern);
 
                case "dropdown_tracking_itemtype" :
-                  if (class_exists($pattern)) {
-                     $item = new $pattern();
+                  if ($item = getItemForItemtype($pattern)) {
                      return $item->getTypeName();
                   }
                   if (empty($pattern)) {
@@ -1356,6 +1372,7 @@ class Rule extends CommonDBTM {
 
    /**
     * Used to get specific criteria patterns
+    *
     * @param $ID the given criteria
     * @param $condition condition used
     * @param $pattern the pattern
@@ -1383,7 +1400,9 @@ class Rule extends CommonDBTM {
       $tested  = false;
 
       if (isset($crit['type'])
-          && ($test || $condition == self::PATTERN_IS || $condition == self::PATTERN_IS_NOT)) {
+          && ($test || in_array($condition, array(self::PATTERN_IS,
+                                                  self::PATTERN_IS_NOT,
+                                                  self::PATTERN_UNDER)))) {
 
          switch ($crit['type']) {
             case "yesonly" :
@@ -1410,7 +1429,8 @@ class Rule extends CommonDBTM {
                break;
 
             case "dropdown_tracking_itemtype" :
-               Dropdown::dropdownTypes($name, 0 ,array_keys(Ticket::getAllTypesForHelpdesk()));
+               Dropdown::dropdownTypes($name, 0 ,
+                                       array_keys(Ticket::getAllTypesForHelpdesk()));
                $display = true;
                break;
 
@@ -1430,7 +1450,7 @@ class Rule extends CommonDBTM {
                break;
 
             case "dropdown_tickettype" :
-               Ticket::dropdownType($name, $value);
+               Ticket::dropdownType($name, array('value' => $value));
                $display = true;
                break;
          }
@@ -1448,9 +1468,9 @@ class Rule extends CommonDBTM {
 
       if (!$display) {
          $rc = new $this->rulecriteriaclass();
-         autocompletionTextField($rc, "pattern", array('name'  => $name,
-                                                       'value' => $value,
-                                                       'size'  => 70));
+         Html::autocompletionTextField($rc, "pattern", array('name'  => $name,
+                                                             'value' => $value,
+                                                             'size'  => 70));
       }
    }
 
@@ -1496,6 +1516,9 @@ class Rule extends CommonDBTM {
             case "dropdown_priority" :
                return Ticket::getPriorityName($value);
 
+            case "dropdown_tickettype" :
+               return Ticket::getTicketTypeName($value);
+
             case "dropdown_management" :
                return Dropdown::getGlobalSwitch($value);
 
@@ -1518,7 +1541,9 @@ class Rule extends CommonDBTM {
    function getCriteriaValue($ID, $condition, $value) {
       global $LANG;
 
-      if ($condition!=self::PATTERN_IS && $condition!=self::PATTERN_IS_NOT) {
+      if (!in_array($condition, array(self::PATTERN_IS,
+                                      self::PATTERN_IS_NOT,
+                                      self::PATTERN_UNDER,))) {
          $crit = $this->getCriteria($ID);
          if (isset($crit['type'])) {
 
@@ -1690,8 +1715,8 @@ class Rule extends CommonDBTM {
                       'entity_restrict' => $p['entity_restrict']);
 
       $default  = "<select name='".$p['name']."' id='dropdown_".$p['name'].$rand."'>";
-      $default .= "<option value='0'>".DROPDOWN_EMPTY_VALUE."</option></select>";
-      ajaxDropdown($use_ajax, "/ajax/dropdownRules.php", $params, $default, $rand);
+      $default .= "<option value='0'>".Dropdown::EMPTY_VALUE."</option></select>";
+      Ajax::dropdown($use_ajax, "/ajax/dropdownRules.php", $params, $default, $rand);
 
       return $rand;
    }
@@ -1709,8 +1734,7 @@ class Rule extends CommonDBTM {
 
    static function getActionsByType($sub_type) {
 
-      if (class_exists($sub_type)) {
-         $rule = new $sub_type();
+      if ($rule = getItemForItemtype($sub_type)) {
          return $rule->getActions();
       }
       return array();
@@ -1743,7 +1767,7 @@ class Rule extends CommonDBTM {
       }
 
       foreach ($DB->request($query) as $rule) {
-         $affect_rule = new Rule;
+         $affect_rule = new Rule();
          $affect_rule->getRuleWithCriteriasAndActions($rule["id"], 0, 1);
          $rules[] = $affect_rule;
       }
@@ -1754,23 +1778,23 @@ class Rule extends CommonDBTM {
    function showNewRuleForm($ID) {
       global $LANG;
 
-      echo "<form method='post' action='".getItemTypeFormURL('Entity')."'>";
+      echo "<form method='post' action='".Toolbox::getItemTypeFormURL('Entity')."'>";
       echo "<table class='tab_cadre_fixe'>";
       echo "<tr><th colspan='2'>" . $this->getTitle() . "</th></tr>\n";
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16] . "&nbsp;:&nbsp;";
-      autocompletionTextField($this, "name", array('value' => '',
-                                                   'size'  => 33));
+      Html::autocompletionTextField($this, "name", array('value' => '',
+                                                         'size'  => 33));
       echo "&nbsp;&nbsp;&nbsp;".$LANG['joblist'][6] . "&nbsp;:&nbsp;";
-      autocompletionTextField($this, "description", array('value' => '',
-                                                          'size'  => 33));
+      Html::autocompletionTextField($this, "description", array('value' => '',
+                                                                'size'  => 33));
       echo "&nbsp;&nbsp;&nbsp;".$LANG['rulesengine'][9] . "&nbsp;:&nbsp;";
       $this->dropdownRulesMatch("match", self::AND_MATCHING);
       echo "</td><td class='tab_bg_2 center'>";
       echo "<input type=hidden name='sub_type' value='".get_class($this)."'>";
       echo "<input type=hidden name='entities_id' value='-1'>";
       echo "<input type=hidden name='affectentity' value='$ID'>";
-      echo "<input type=hidden name='_method' value='addRule'>";
+      echo "<input type=hidden name='_method' value='AddRule'>";
       echo "<input type='submit' name='execute' value=\"".$LANG['buttons'][8]."\" class='submit'>";
       echo "</td></tr>\n";
       echo "</table></form>";
@@ -1780,7 +1804,7 @@ class Rule extends CommonDBTM {
    function showAndAddRuleForm($item) {
       global $LANG;
 
-      $canedit = haveRight($this->right, "w");
+      $canedit = Session::haveRight($this->right, "w");
 
       if ($canedit && $item->getType()=='Entity') {
          $this->showNewRuleForm($item->getField('id'));
@@ -1794,7 +1818,7 @@ class Rule extends CommonDBTM {
 
       echo "<div class='spaced'>";
 
-      if (empty ($rules)) {
+      if (empty($rules)) {
          echo "<table class='tab_cadre_fixehov'>";
          echo "<tr><th>" . $LANG['search'][15] . "</th>";
          echo "</tr>\n";
@@ -1804,7 +1828,7 @@ class Rule extends CommonDBTM {
          if ($canedit) {
             $formname = $item->getType()."_".$this->getType()."_form";
             echo "\n<form name='$formname' id='$formname' method='post' ".
-                   "action='".getItemTypeSearchURL(get_class($this))."'>";
+                   "action='".Toolbox::getItemTypeSearchURL(get_class($this))."'>";
          }
          echo "<table class='tab_cadre_fixehov'><tr>";
 
@@ -1815,17 +1839,17 @@ class Rule extends CommonDBTM {
          echo "<th>" . $LANG['joblist'][6] . "</th>";
          echo "<th>" . $LANG['common'][60] . "</th>";
          echo "</tr>\n";
-         initNavigateListItems(get_class($this), $item->getTypeName()."=".$item->getName());
+         Session::initNavigateListItems(get_class($this), $item->getTypeName()."=".$item->getName());
 
          foreach ($rules as $rule) {
-            addToNavigateListItems(get_class($this), $rule->fields["id"]);
+            Session::addToNavigateListItems(get_class($this), $rule->fields["id"]);
             echo "<tr class='tab_bg_1'>";
 
             if ($canedit) {
                echo "<td width='10'>";
                echo "<input type='checkbox' name='item[" . $rule->fields["id"] . "]' value='1'>";
                echo "</td>";
-               echo "<td><a href='".getItemTypeFormURL(get_class($this))."?id=" .
+               echo "<td><a href='".Toolbox::getItemTypeFormURL(get_class($this))."?id=" .
                       $rule->fields["id"] . "&amp;onglet=1'>" .$rule->fields["name"] ."</a></td>";
 
             } else {
@@ -1839,9 +1863,9 @@ class Rule extends CommonDBTM {
          echo "</table>\n";
 
          if ($canedit) {
-            openArrowMassive($formname, true);
+            Html::openArrowMassives($formname, true);
             echo "<input type='hidden' name='action' value='delete'>";
-            closeArrowMassive('massiveaction', $LANG['buttons'][6]);
+            Html::closeArrowMassives(array('massiveaction' => $LANG['buttons'][6]));
             echo "</form>";
          }
       }
@@ -1850,13 +1874,11 @@ class Rule extends CommonDBTM {
 
 
    function defineTabs($options=array()) {
-      global $LANG;
 
-      $ong[1] = $LANG['title'][26];
+      $ong = array();
+      $this->addStandardTab(__CLASS__, $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
-      if ($this->fields['id'] > 0) {
-         $ong[12] = $LANG['title'][38];
-      }
       return $ong;
    }
 
@@ -1902,6 +1924,8 @@ class Rule extends CommonDBTM {
       return false;
    }
 
+
+
    /**
     * Clean Rule with Action or Criteria linked to an item
     *
@@ -1911,9 +1935,9 @@ class Rule extends CommonDBTM {
     * @param $table string (glpi_ruleactions, glpi_rulescriterias or glpi_slalevelcriterias)
     * @param $valfield string (value or pattern)
     * @param $fieldfield string (criteria of field)
-    */
-   private static function cleanForItemActionOrCriteria($item, $field,
-                                                        $ruleitem, $table, $valfield, $fieldfield) {
+   **/
+   private static function cleanForItemActionOrCriteria($item, $field, $ruleitem, $table,
+                                                        $valfield, $fieldfield) {
       global $DB, $LANG;
 
       $fieldid = getForeignKeyFieldForTable($ruleitem->getTable());
@@ -1943,22 +1967,24 @@ class Rule extends CommonDBTM {
                   $input['id'] = $data[$fieldid];
                   $ruleitem->update($input);
                }
-               addMessageAfterRedirect($LANG['rulesengine'][150], true);
+               Session::addMessageAfterRedirect($LANG['rulesengine'][150], true);
             }
          }
       }
    }
 
+
    /**
     * Clean Rule with Action is assign to an item
     *
     * @param $item Object
     * @param $field string name (default is FK to item)
-    */
+   **/
    static function cleanForItemAction($item, $field='') {
 
       self::cleanForItemActionOrCriteria($item, $field,
                                          new self(), 'glpi_ruleactions', 'value', 'field');
+
       self::cleanForItemActionOrCriteria($item, $field,
                                          new SlaLevel(), 'glpi_slalevelactions', 'value', 'field');
    }
@@ -1969,12 +1995,102 @@ class Rule extends CommonDBTM {
     *
     * @param $item Object
     * @param $field string name (default is FK to item)
-    */
+   **/
    static function cleanForItemCriteria($item, $field='') {
 
       self::cleanForItemActionOrCriteria($item, $field,
                                          new self(), 'glpi_rulecriterias', 'pattern', 'criteria');
    }
-}
 
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case 'Entity' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  $types = array();
+                  $collection = new RuleRightCollection();
+                  if ($collection->canList()) {
+                     $types[] = 'RuleRight';
+                  }
+                  $collection = new RuleOcsCollection();
+                  if ($collection->canList()) {
+                     $types[] = 'RuleOcs';
+                  }
+                  $collection = new RuleMailCollectorCollection();
+                  if ($collection->canList()) {
+                     $types[] = 'RuleMailCollector';
+                  }
+                  $nb=0;
+                  if (count($types)) {
+                     $nb = countElementsInTable(array('glpi_rules','glpi_ruleactions'),
+                                                "`glpi_ruleactions`.`rules_id` = `glpi_rules`.`id`
+                                                AND `glpi_rules`.`sub_type` IN ('".implode("','",$types)."')
+                                                AND `glpi_ruleactions`.`field` = 'entities_id'
+                                                AND `glpi_ruleactions`.`value` = '".$item->getID()."'");
+                  }
+
+                  return self::createTabEntry($LANG['rulesengine'][17],$nb);
+               }
+               return $this->getTypeName(2);
+
+            case 'SLA' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry($LANG['rulesengine'][17],
+                                              countElementsInTable('glpi_ruleactions',
+                                                                   "`field` = 'slas_id'
+                                                                    AND `value` = '".$item->getID()."'"));
+               }
+               return $this->getTypeName(2);
+
+            default:
+               if ($item instanceof Rule) {
+                  return $this->getTypeName(1);
+               }
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType() == 'Entity') {
+         $collection = new RuleRightCollection();
+         if ($collection->canList()) {
+            $ldaprule = new RuleRight();
+            $ldaprule->showAndAddRuleForm($item);
+         }
+
+         $collection = new RuleOcsCollection();
+         if ($collection->canList()) {
+            $ocsrule = new RuleOcs();
+            $ocsrule->showAndAddRuleForm($item);
+         }
+
+         $collection = new RuleMailCollectorCollection();
+         if ($collection->canList()) {
+            $mailcollector = new RuleMailCollector();
+            $mailcollector->showAndAddRuleForm($item);
+         }
+      } else if ($item->getType() == 'SLA') {
+         $rule = new RuleTicket();
+         $rule->showAndAddRuleForm($item);
+
+      } else if ($item->getType() == 'SlaLevel') {
+         $rule = new RuleTicket();
+         $item->getRuleWithCriteriasAndActions($item->getID(), 0, 1);
+         $item->showActionsList($item->getID());
+
+      } else if ($item instanceof Rule) {
+         $item->getRuleWithCriteriasAndActions($item->getID(), 1, 1);
+         $item->showCriteriasList($item->getID());
+         $item->showActionsList($item->getID());
+      }
+
+      return true;
+   }
+
+}
 ?>
