@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleaction.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ruleaction.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -52,17 +52,20 @@ class RuleAction extends CommonDBChild {
     *
     * @return Title of the rule
    **/
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['rulesengine'][7];
+      if ($nb>1) {
+         return $LANG['rulesengine'][7];
+      }
+      return $LANG['rulesengine'][30];
    }
 
 
    function getName($with_comment=0) {
 
-      $rule = new $this->itemtype ();
-      return html_clean($rule->getMinimalActionText($this->fields));
+      $rule = new $this->itemtype();
+      return Html::clean($rule->getMinimalActionText($this->fields));
    }
 
 
@@ -109,7 +112,7 @@ class RuleAction extends CommonDBChild {
 
       $rules_actions = array();
       while ($rule = $DB->fetch_assoc($result)) {
-         $tmp = new RuleAction;
+         $tmp = new RuleAction();
          $tmp->fields     = $rule;
          $rules_actions[] = $tmp;
       }
@@ -229,7 +232,7 @@ class RuleAction extends CommonDBChild {
          //If a regex value is used, then always display an autocompletiontextfield
          case "regex_result" :
          case "append_regex_result" :
-            autocompletionTextField($this, "value");
+            Html::autocompletionTextField($this, "value");
             break;
 
          default :
@@ -243,6 +246,11 @@ class RuleAction extends CommonDBChild {
                      $display = true;
                      break;
 
+                  case "dropdown_tickettype" :
+                     Ticket::dropdownType('value');
+                     $display = true;
+                     break;
+
                   case "dropdown_assign" :
                      User::dropdown(array('name'  => 'value',
                                           'right' => 'own_ticket'));
@@ -301,7 +309,7 @@ class RuleAction extends CommonDBChild {
                      break;
 
                   default :
-                     $rule = new $options["sub_type"];
+                     $rule = new $options["sub_type"]();
                      $display = $rule->displayAdditionalRuleAction($actions[$options["field"]],
                                                                    $options);
                      break;
@@ -309,11 +317,10 @@ class RuleAction extends CommonDBChild {
             }
 
             if (!$display) {
-               autocompletionTextField($this, "value");
+               Html::autocompletionTextField($this, "value");
             }
       }
    }
 
 }
-
-?>
+?>
\ No newline at end of file
