@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecollection.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rulecollection.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -67,12 +67,12 @@ class RuleCollection extends CommonDBTM {
 
 
    function canCreate() {
-      return haveRight($this->right, 'w');
+      return Session::haveRight($this->right, 'w');
    }
 
 
    function canView() {
-      return haveRight($this->right, 'r');
+      return Session::haveRight($this->right, 'r');
    }
 
 
@@ -252,7 +252,7 @@ class RuleCollection extends CommonDBTM {
 
       $name = $this->getRuleClassName();
       if ($name !=  '') {
-         return new $name ();
+         return new $name();
       }
       return null;
    }
@@ -345,12 +345,11 @@ class RuleCollection extends CommonDBTM {
     * Show the list of rules
     *
     * @param $target
-    * @param $tab
     * @param $options
     *
     * @return nothing
    **/
-   function showListRules($target, $tab=0, $options=array()) {
+   function showListRules($target, $options=array()) {
       global $CFG_GLPI, $LANG;
 
       $p['inherited'] = true;
@@ -367,7 +366,7 @@ class RuleCollection extends CommonDBTM {
                            && ($p['inherited'] || $p['childrens']));
 
       // Do not know what it is ?
-      $canedit = (haveRight($this->right, "w") && !$display_entities);
+      $canedit = (Session::haveRight($this->right, "w") && !$display_entities);
 
       $nb = $this->getCollectionSize($p['inherited']);
       $p['start'] = (isset($options["start"]) ? $options["start"] : 0);
@@ -379,7 +378,7 @@ class RuleCollection extends CommonDBTM {
       $p['limit'] = $_SESSION['glpilist_limit'];
       $this->getCollectionPart($p);
 
-      printAjaxPager('', $p['start'], $nb);
+      Html::printAjaxPager('', $p['start'], $nb);
 
       echo "<form name='ruleactions_form' id='ruleactions_form' method='post'action='".$target."'>";
       echo "\n<div class='spaced'>";
@@ -405,20 +404,20 @@ class RuleCollection extends CommonDBTM {
 
       if (count($this->RuleList->list)) {
          $ruletype = $this->RuleList->list[0]->getType();
-         initNavigateListItems($ruletype);
+         Session::initNavigateListItems($ruletype);
       }
 
       for ($i=$p['start'],$j=0 ; isset($this->RuleList->list[$j]) ; $i++,$j++) {
          $this->RuleList->list[$j]->showMinimalForm($target, $i==0, $i==$nb-1, $display_entities);
-         addToNavigateListItems($ruletype, $this->RuleList->list[$j]->fields['id']);
+         Session::addToNavigateListItems($ruletype, $this->RuleList->list[$j]->fields['id']);
       }
       echo "</table>\n";
 
       if ($canedit && $nb>0) {
-         openArrowMassive("ruleactions_form", true);
+         Html::openArrowMassives("ruleactions_form", true);
 
          echo "<select name='massiveaction' id='massiveaction'>";
-         echo "<option value='-1' selected>".DROPDOWN_EMPTY_VALUE."</option>";
+         echo "<option value='-1' selected>".Dropdown::EMPTY_VALUE."</option>";
          echo "<option value='delete'>".$LANG['buttons'][6]."</option>";
 
          if ($this->orderby=="ranking") {
@@ -432,19 +431,20 @@ class RuleCollection extends CommonDBTM {
                          'sub_type'        => $this->getRuleClassName(),
                          'entity_restrict' => $this->entity);
 
-         ajaxUpdateItemOnSelectEvent("massiveaction", "show_massiveaction",
-                                     $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveAction.php",
-                                     $params);
+         Ajax::updateItemOnSelectEvent("massiveaction", "show_massiveaction",
+                                       $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveAction.php",
+                                       $params);
 
          echo "<span id='show_massiveaction'>&nbsp;</span>\n";
 
          if ($this->can_replay_rules) {
-            echo "</td>"; // close td of openArrowMassive
+            echo "</td>"; // close td of Html::openArrowMassives
             echo "<td><input type='submit' name='replay_rule' value='" . $LANG['rulesengine'][76] .
                        "' class='submit'></td>";
-            echo "<td>"; // open td for closeArrowMassive
+            echo "<td>"; // open td for Html::closeArrowMassives
          }
-         closeArrowMassive();
+         $options = array();
+         Html::closeArrowMassives($options);
       }
 
       echo "</div></form>";
@@ -565,7 +565,7 @@ class RuleCollection extends CommonDBTM {
    function moveRule($ID, $ref_ID, $type='after') {
       global $DB;
 
-      $ruleDescription = new Rule;
+      $ruleDescription = new Rule();
 
       // Get actual ranking of Rule to move
       $ruleDescription->getFromDB($ID);
@@ -674,7 +674,8 @@ class RuleCollection extends CommonDBTM {
             }
 
             if ($this->use_output_rule_process_as_next_input) {
-               $input = $output;
+               $output = $this->prepareInputDataForProcess($output, $params);
+               $input  = $output;
             }
          }
       }
@@ -919,8 +920,8 @@ class RuleCollection extends CommonDBTM {
       echo "<table class='tab_cadrehov'>";
       echo "<tr><th colspan='2'>" . $LANG['rulesengine'][81] . "</th></tr>\n";
       echo "<tr class='tab_bg_1'>";
-      echo "<td colspan='2' class='center'>".$LANG['rulesengine'][41]."&nbsp;:&nbsp;<strong> ".
-             Dropdown::getYesNo($global_result)."</strong></td>";
+      echo "<td colspan='2' class='center'>".$LANG['rulesengine'][41]."&nbsp;:&nbsp;<span class='b'>".
+             Dropdown::getYesNo($global_result)."</span></td>";
 
       $output = $this->preProcessPreviewResults($output);
 
@@ -975,8 +976,8 @@ class RuleCollection extends CommonDBTM {
       if (($check_dictionnary_type && in_array($itemtype, $CFG_GLPI["dictionnary_types"]))
           || !$check_dictionnary_type) {
 
-         if (class_exists($typeclass)) {
-            return new $typeclass();
+         if ($item = getItemForItemtype($typeclass)) {
+            return $item;
          }
          return NULL;
       }
@@ -1008,12 +1009,85 @@ class RuleCollection extends CommonDBTM {
                       AND `glpi_rules`.`is_active` = '1'";
 
       foreach ($DB->request($query) as $param) {
-             $params[] = utf8_strtolower($param["criteria"]);
+             $params[] = Toolbox::strtolower($param["criteria"]);
       }
       return $params;
    }
 
 
-}
+   /**
+    * For tabs management : force isNewItem
+    *
+    * @since version 0.83
+   **/
+   function isNewItem() {
+      return false;
+   }
 
+
+   function defineTabs($options=array()) {
+      global $LANG;
+
+      $ong = array();
+      $this->addStandardTab(__CLASS__, $ong, $options);
+      $ong['no_all_tab'] = true;
+      return $ong;
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if ($item instanceof RuleCollection){
+         $ong = array();
+         if ($item->showInheritedTab()) {
+            $ong[1] = $LANG['rulesengine'][20].' : '.
+                      Dropdown::getDropdownName('glpi_entities', $_SESSION['glpiactive_entity']);
+         }
+         $title = $LANG['rulesengine'][17];
+         if ($item->isRuleRecursive()) {
+            $title = $LANG['rulesengine'][23].' : '.
+                     Dropdown::getDropdownName('glpi_entities', $_SESSION['glpiactive_entity']);
+         }
+         $ong[2] = $title;
+         if ($item->showChildrensTab()) {
+            $ong[3] = $LANG['rulesengine'][21];
+         }
+         return $ong;
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+      global $CFG_GLPI;
+
+      if ($item instanceof RuleCollection) {
+         $options = $_POST;
+         switch ($tabnum) {
+            case 1:
+               $options['inherited'] = 1;
+               break;
+
+            case 2:
+               $options['inherited'] = 0;
+               break;
+
+            case 3 :
+               $options['inherited'] = 0;
+               $options['childrens'] = 1;
+               break;
+         }
+         if ($item->isRuleEntityAssigned()) {
+            $item->setEntity($_SESSION['glpiactive_entity']);
+         }
+         $item->title();
+         $item->showEngineSummary();
+         $item->showListRules($_POST['target'], $options);
+         return true;
+      }
+      return false;
+   }
+
+}
 ?>
\ No newline at end of file
