@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecriteria.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rulecriteria.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -53,17 +53,20 @@ class RuleCriteria extends CommonDBChild {
     *
     * @return Title of the rule
    **/
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['rulesengine'][6];
+      if ($nb>1) {
+         return $LANG['rulesengine'][6];
+      }
+      return $LANG['rulesengine'][16];
    }
 
 
    function getName($with_comment=0) {
 
-      $rule = new $this->itemtype ();
-      return html_clean($rule->getMinimalCriteriaText($this->fields));
+      $rule = new $this->itemtype();
+      return Html::clean($rule->getMinimalCriteriaText($this->fields));
    }
 
 
@@ -120,55 +123,6 @@ class RuleCriteria extends CommonDBChild {
    }
 
 
-   /**
-    * Return a value associated with a pattern associated to a criteria to compare it
-    *
-    * @param $condition condition used
-    * @param $initValue the pattern
-   **/
-   function getValueToMatch($condition, &$initValue) {
-      global $LANG;
-
-      $type = $this->getType();
-
-      if (!empty($type)
-          && ($condition!=Rule::PATTERN_IS && $condition!=Rule::PATTERN_IS_NOT)) {
-
-         switch ($this->getType()) {
-            case "dropdown" :
-               return Dropdown::getDropdownName($this->getTable(), $initValue);
-
-            case "dropdown_users" :
-               return getUserName($initValue);
-
-            case "dropdown_tracking_itemtype" :
-               if (class_exists($initValue)) {
-                  $item = new $initValue();
-                  return $item->getTypeName();
-               } else {
-                  if (empty($initValue)) {
-                     return $LANG['help'][30];
-                  }
-               }
-               break;
-
-            case "dropdown_urgency" :
-               return Ticket::getUrgencyName($initValue);
-
-            case "dropdown_impact" :
-               return Ticket::getImpactName($initValue);
-
-            case "dropdown_priority" :
-               return Ticket::getPriorityName($initValue);
-
-            case "dropdown_tickettype" :
-               return Ticket::getTicketTypeName($initValue);
-         }
-      }
-      return $initValue;
-   }
-
-
    /**
     * Try to match a definied rule
     *
@@ -193,7 +147,7 @@ class RuleCriteria extends CommonDBChild {
 
       // Input are slashed protected, not output.
       if (is_array($field)) {
-         $field = stripslashes_deep($field);
+         $field = Toolbox::stripslashes_deep($field);
       } else {
          // Trim for remove keyboard errors
          $field = stripslashes(trim($field));
@@ -203,8 +157,8 @@ class RuleCriteria extends CommonDBChild {
 
       if ($condition != Rule::REGEX_MATCH && $condition != Rule::REGEX_NOT_MATCH) {
          //Perform comparison with fields in lower case
-         $field   = utf8_strtolower($field);
-         $pattern = utf8_strtolower($pattern);
+         $field   = Toolbox::strtolower($field);
+         $pattern = Toolbox::strtolower($pattern);
       }
 
       switch ($condition) {
@@ -234,6 +188,14 @@ class RuleCriteria extends CommonDBChild {
             }
             return false;
 
+         case Rule::PATTERN_UNDER :
+            $table  = getTableNameForForeignKeyField($criteria);
+            $values = getSonsOf($table, $pattern);
+            if (isset($values[$field])) {
+               return true;
+            }
+            return false;
+
          case Rule::PATTERN_END :
             $value = "/".$pattern."$/";
             if (preg_match($value, $field) > 0) {
@@ -278,7 +240,7 @@ class RuleCriteria extends CommonDBChild {
          case Rule::REGEX_MATCH :
             $results = array();
             // Permit use < and >
-            $pattern = unclean_cross_side_scripting_deep($pattern);
+            $pattern = Toolbox::unclean_cross_side_scripting_deep($pattern);
             if (preg_match($pattern."i",$field,$results)>0) {
                // Drop $result[0] : complete match result
                array_shift($results);
@@ -291,7 +253,7 @@ class RuleCriteria extends CommonDBChild {
 
          case Rule::REGEX_NOT_MATCH :
             // Permit use < and >
-            $pattern = unclean_cross_side_scripting_deep($pattern);
+            $pattern = Toolbox::unclean_cross_side_scripting_deep($pattern);
             if (preg_match($pattern."i", $field) == 0) {
                $criterias_results[$criteria] = $pattern;
                return true;
@@ -310,12 +272,13 @@ class RuleCriteria extends CommonDBChild {
     *
     * @param $ID condition's ID
     * @param $itemtype itemtype
+    * @param $criterion
     *
     * @return condition's label
    **/
-   static function getConditionByID($ID, $itemtype) {
+   static function getConditionByID($ID, $itemtype, $criterion='') {
 
-      $conditions = self::getConditions($itemtype);
+      $conditions = self::getConditions($itemtype, $criterion);
       if (isset($conditions[$ID])) {
          return $conditions[$ID];
       }
@@ -324,14 +287,17 @@ class RuleCriteria extends CommonDBChild {
 
 
    /**
+    * @param $itemtype itemtype
+    * @param $criterion
     *
+    * @return array of criteria
    **/
-   static function getConditions($itemtype, $criterion = '') {
+   static function getConditions($itemtype, $criterion='') {
       global $LANG;
 
       $criteria =  array(Rule::PATTERN_IS              => $LANG['rulesengine'][0],
                          Rule::PATTERN_IS_NOT          => $LANG['rulesengine'][1],
-                         Rule::PATTERN_CONTAIN         => $LANG['rulesengine'][2],
+                         Rule::PATTERN_CONTAIN         => $LANG['search'][2],
                          Rule::PATTERN_NOT_CONTAIN     => $LANG['rulesengine'][3],
                          Rule::PATTERN_BEGIN           => $LANG['rulesengine'][4],
                          Rule::PATTERN_END             => $LANG['rulesengine'][5],
@@ -345,6 +311,17 @@ class RuleCriteria extends CommonDBChild {
       foreach ($extra_criteria as $key => $value) {
          $criteria[$key] = $value;
       }
+      /// Add Under criteria if tree dropdown table used
+      $item = new $itemtype();
+      $crit = $item->getCriteria($criterion);
+
+      if (isset($crit['type']) && $crit['type'] == 'dropdown') {
+         $crititemtype = getItemtypeForTable($crit['table']);
+         $item         = new $crititemtype();
+         if ($item instanceof CommonTreeDropdown) {
+            $criteria[Rule::PATTERN_UNDER] = $LANG['search'][3];
+         }
+      }
 
       return $criteria;
    }
