@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: ruledictionnarysoftwarecollection.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ruledictionnarysoftwarecollection.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -53,12 +53,14 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
 
       //Init cache system values
       $this->initCache("glpi_rulecachesoftwares", array("name"         => "old_value",
-                                                        "manufacturer" => "manufacturer"),
+                                                        "manufacturer" => "manufacturer",
+                                                        "entities_id"  => "entities_id"),
                        array("name"                => "new_value",
                              "version"             => "version",
                              "manufacturer"        => "new_manufacturer",
                              "is_helpdesk_visible" => "is_helpdesk_visible",
-                             "_ignore_ocs_import"  => "ignore_ocs_import"));
+                             "_ignore_ocs_import"  => "ignore_ocs_import",
+                             "new_entities_id"     => "new_entities_id"));
    }
 
 
@@ -95,7 +97,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
       echo "<tr><th colspan='2' class='b'>" . $LANG['rulesengine'][95] . "</th</tr>\n";
       echo "<tr><td class='tab_bg_2 center'>" . $LANG['rulesengine'][96] . "</td>";
       echo "<td class='tab_bg_2 center'>";
-      Dropdown::show('Manufacturer', array('name'=>'manufacturer'));
+      Dropdown::show('Manufacturer', array('name' => 'manufacturer'));
       echo "</td></tr>\n";
 
       echo "<tr><td class='tab_bg_2 center' colspan='2'>";
@@ -121,7 +123,8 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          //Select all the differents software
          $sql = "SELECT DISTINCT `glpi_softwares`.`name`,
                         `glpi_manufacturers`.`name` AS manufacturer,
-                        `glpi_softwares`.`manufacturers_id` AS manufacturers_id
+                        `glpi_softwares`.`manufacturers_id` AS manufacturers_id,
+                        `glpi_softwares`.`entities_id` AS entities_id
                  FROM `glpi_softwares`
                  LEFT JOIN `glpi_manufacturers`
                      ON (`glpi_manufacturers`.`id` = `glpi_softwares`.`manufacturers_id`)";
@@ -130,7 +133,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          $sql .= "WHERE `glpi_softwares`.`is_deleted` = '0'
                         AND `glpi_softwares`.`is_template` = '0' ";
 
-         if (isset ($params['manufacturer']) && $params['manufacturer'] > 0) {
+         if (isset($params['manufacturer']) && $params['manufacturer'] > 0) {
             $sql .= " AND `manufacturers_id` = '" . $params['manufacturer'] . "'";
          }
          if ($offset) {
@@ -147,24 +150,25 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
                   echo date("H:i:s") . " replayRulesOnExistingDB : $i/$nb (" .
                        round(memory_get_usage() / (1024 * 1024), 2) . " Mo)\n";
                } else {
-                  changeProgressBarPosition($i, $nb, "$i / $nb");
+                  Html::changeProgressBarPosition($i, $nb, "$i / $nb");
                }
             }
 
             //If manufacturer is set, then first run the manufacturer's dictionnary
-            if (isset ($input["manufacturer"])) {
+            if (isset($input["manufacturer"])) {
                $input["manufacturer"] = Manufacturer::processName($input["manufacturer"]);
             }
 
             //Replay software dictionnary rules
-            $input    = addslashes_deep($input);
+            $input    = Toolbox::addslashes_deep($input);
             $res_rule = $this->processAllRules($input, array(), array());
-            $res_rule = addslashes_deep($res_rule);
+            $res_rule = Toolbox::addslashes_deep($res_rule);
 
-            //If the software's name or version has changed
+            ///TODO Walid : verify my correction for parentheses
             if ((isset($res_rule["name"]) && $res_rule["name"] != $input["name"])
-                || (isset($res_rule["version"]))
-                && $res_rule["version"] != '') {
+                || (isset($res_rule["version"]) && $res_rule["version"] != '')
+                || (isset($res_rule['new_entities_id'])
+                    && $res_rule['new_entities_id'] != $input['entities_id'])) {
 
                $IDs = array();
                //Find all the softwares in the database with the same name and manufacturer
@@ -195,7 +199,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          if (isCommandLine()) {
             echo "replayRulesOnExistingDB : $i/$nb               \n";
          } else {
-            changeProgressBarPosition($i, $nb, "$i / $nb");
+            Html::changeProgressBarPosition($i, $nb, "$i / $nb");
          }
 
       } else {
@@ -239,7 +243,10 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          if ($DB->numrows($res_soft)) {
             $soft = $DB->fetch_array($res_soft);
             //For each software
-            $this->replayDictionnaryOnOneSoftware($new_softs, $res_rule, $ID, $soft["entities_id"],
+            $this->replayDictionnaryOnOneSoftware($new_softs, $res_rule, $ID,
+                                                  (isset($res_rule['new_entities_id'])
+                                                      ?$res_rule['new_entities_id']
+                                                      :$soft["entities_id"]),
                                                   (isset($soft["name"]) ? $soft["name"] : ''),
                                                   (isset($soft["manufacturer"])
                                                          ? $soft["manufacturer"] : ''),
@@ -268,29 +275,42 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
 
       $input["name"]         = $name;
       $input["manufacturer"] = $manufacturer;
-      $input                 = addslashes_deep($input);
+      $input                 = Toolbox::addslashes_deep($input);
 
-      if (empty ($res_rule)) {
+      if (empty($res_rule)) {
          $res_rule = $this->processAllRules($input, array(), array());
-         $res_rule = addslashes_deep($res_rule);
+         $res_rule = Toolbox::addslashes_deep($res_rule);
       }
-     $soft = new Software;
+      $soft = new Software();
 
-      //Software's name has changed
-      if (isset ($res_rule["name"]) && $res_rule["name"] != $name) {
-         if (isset ($res_rule["manufacturer"])) {
+      ///TODO walid : check parentheses + params for getSonsOf + comment (parent or child ?)
+      //Software's name has changed or entity
+      if ((isset($res_rule["name"]) && $res_rule["name"] != $name)
+            //Entity has changed, and new entity is a parent of the current one
+          || (!isset($res_rule["name"])
+              && isset($res_rule['new_entities_id'])
+              && in_array($res_rule['new_entities_id'],
+                          getAncestorsOf('glpi_entities', $entity)))) {
+
+         if (isset($res_rule["name"])) {
+            $new_name = $res_rule["name"];
+         } else {
+            $new_name = $name;
+         }
+
+         if (isset($res_rule["manufacturer"])) {
             $manufacturer = Dropdown::getDropdownName("glpi_manufacturers",
                                                       $res_rule["manufacturer"]);
          }
 
          //New software not already present in this entity
-         if (!isset ($new_softs[$entity][$res_rule["name"]])) {
+         if (!isset($new_softs[$entity][$new_name])) {
             // create new software or restore it from trash
-            $new_software_id = $soft->addOrRestoreFromTrash($res_rule["name"], $manufacturer,
-                                                            $entity);
-            $new_softs[$entity][$res_rule["name"]] = $new_software_id;
+            $new_software_id = $soft->addOrRestoreFromTrash($new_name, $manufacturer,
+                                                            $entity, '', true);
+            $new_softs[$entity][$new_name] = $new_software_id;
          } else {
-            $new_software_id = $new_softs[$entity][$res_rule["name"]];
+            $new_software_id = $new_softs[$entity][$new_name];
          }
          // Move licenses to new software
          $this->moveLicenses($ID, $new_software_id);
@@ -319,7 +339,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          $input["version"] = addslashes($version["name"]);
          $old_version_name = $input["version"];
 
-         if (isset ($res_rule["version"]) && $res_rule["version"] != '') {
+         if (isset($res_rule["version"]) && $res_rule["version"] != '') {
             $new_version_name = $res_rule["version"];
          } else {
             $new_version_name = $version["name"];
@@ -357,7 +377,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
                           HAVING `cpt` = '0'
                           ORDER BY `cpt`");
 
-         $software = new Software;
+         $software = new Software();
          while ($soft = $DB->fetch_array($res_countsoftinstall)) {
             $software->putInTrash($soft["id"], $LANG['rulesengine'][87]);
          }
@@ -404,7 +424,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
                         SET `softwareversions_id_use` = '$new_versionID'
                         WHERE `softwareversions_id_use` = '$version_id'");
             //Delete old version
-            $old_version = new SoftwareVersion;
+            $old_version = new SoftwareVersion();
             $old_version->delete(array("id" => $version_id));
          }
       }
