@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleimportcomputer.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ruleimportcomputer.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -51,12 +51,12 @@ class RuleImportComputer extends Rule {
 
 
    function canCreate() {
-      return haveRight('rule_ocs', 'w');
+      return Session::haveRight('rule_ocs', 'w');
    }
 
 
    function canView() {
-      return haveRight('rule_ocs', 'r');
+      return Session::haveRight('rule_ocs', 'r');
    }
 
 
@@ -265,7 +265,7 @@ class RuleImportComputer extends Rule {
                   if (!isset($input[$criterion]) || $input[$criterion] == '') {
                      $continue = false;
                   } else  {
-                  $complex_criterias[] = $crit;
+                     $complex_criterias[] = $crit;
                   }
                }
             }
@@ -293,6 +293,7 @@ class RuleImportComputer extends Rule {
          $where_entity = $input['entities_id'];
       }
 
+      // Search computer, in entity, not already linked
       $sql_where = "`glpi_ocslinks`.`computers_id` IS NULL
                     AND `glpi_computers`.`entities_id` IN ($where_entity)
                     AND `glpi_computers`.`is_template` = '0' ";
@@ -301,6 +302,7 @@ class RuleImportComputer extends Rule {
                    LEFT JOIN `glpi_ocslinks`
                           ON (`glpi_computers`.`id` = `glpi_ocslinks`.`computers_id`)";
 
+      // TODO : why don't take care of Rule match attribute ?
       $needport = false;
       foreach ($complex_criterias as $criteria) {
          switch ($criteria->fields['criteria']) {
@@ -341,17 +343,17 @@ class RuleImportComputer extends Rule {
 
             case 'model' :
                // search for model, don't create it if not found
-               $options = array('manufacturer' => $input['manufacturer']);
-               $mid = Dropdown::importExternal('ComputerModel', $input['model'], -1,
-                                               $options, '', false);
-               $sql_where .= " AND `glpi_computers`.`computermodels_id`='$mid'";
+               $options    = array('manufacturer' => $input['manufacturer']);
+               $mid        = Dropdown::importExternal('ComputerModel', $input['model'], -1,
+                                                      $options, '', false);
+               $sql_where .= " AND `glpi_computers`.`computermodels_id` = '$mid'";
                break;
 
             case 'manufacturer' :
                // search for manufacturer, don't create it if not found
-               $mid = Dropdown::importExternal('Manufacturer', $input['manufacturer'], -1,
-                                               array(), '', false);
-               $sql_where .= " AND `glpi_computers`.`manufacturers_id`='$mid'";
+               $mid        = Dropdown::importExternal('Manufacturer', $input['manufacturer'], -1,
+                                                      array(), '', false);
+               $sql_where .= " AND `glpi_computers`.`manufacturers_id` = '$mid'";
                break;
 
             case 'states_id' :
