@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleticket.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ruleticket.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -51,12 +51,12 @@ class RuleTicket extends Rule {
 
 
    function canCreate() {
-      return haveRight('entity_rule_ticket', 'w');
+      return Session::haveRight('entity_rule_ticket', 'w');
    }
 
 
    function canView() {
-      return haveRight('entity_rule_ticket', 'r');
+      return Session::haveRight('entity_rule_ticket', 'r');
    }
 
 
@@ -199,11 +199,11 @@ class RuleTicket extends Rule {
       $criterias['content']['name']      = $LANG['joblist'][6];
       $criterias['content']['linkfield'] = 'content';
 
-      $criterias['ticketcategories_id']['table']     = 'glpi_ticketcategories';
-      $criterias['ticketcategories_id']['field']     = 'name';
-      $criterias['ticketcategories_id']['name']      = $LANG['common'][36];
-      $criterias['ticketcategories_id']['linkfield'] = 'ticketcategories_id';
-      $criterias['ticketcategories_id']['type']      = 'dropdown';
+      $criterias['itilcategories_id']['table']     = 'glpi_itilcategories';
+      $criterias['itilcategories_id']['field']     = 'name';
+      $criterias['itilcategories_id']['name']      = $LANG['common'][36];
+      $criterias['itilcategories_id']['linkfield'] = 'itilcategories_id';
+      $criterias['itilcategories_id']['type']      = 'dropdown';
 
       $criterias['type']['table']     = 'glpi_tickets';
       $criterias['type']['field']     = 'type';
@@ -225,7 +225,7 @@ class RuleTicket extends Rule {
       $criterias['users_locations']['type']      = 'dropdown';
 
       $criterias['_groups_id_requester']['table']     = 'glpi_groups';
-      $criterias['_groups_id_requester']['field']     = 'name';
+      $criterias['_groups_id_requester']['field']     = 'completename';
       $criterias['_groups_id_requester']['name']      = $LANG['job'][4]." - ".$LANG['common'][35];
       $criterias['_groups_id_requester']['linkfield'] = '_groups_id_requester';
       $criterias['_groups_id_requester']['type']      = 'dropdown';
@@ -237,29 +237,29 @@ class RuleTicket extends Rule {
       $criterias['_users_id_assign']['type']      = 'dropdown_users';
 
       $criterias['_groups_id_assign']['table']     = 'glpi_groups';
-      $criterias['_groups_id_assign']['field']     = 'name';
+      $criterias['_groups_id_assign']['field']     = 'completename';
       $criterias['_groups_id_assign']['name']      = $LANG['job'][5]." - ".$LANG['common'][35];
       $criterias['_groups_id_assign']['linkfield'] = '_groups_id_assign';
       $criterias['_groups_id_assign']['type']      = 'dropdown';
 
-      $criterias['_users_id_observer']['table']     = 'glpi_users';
-      $criterias['_users_id_observer']['field']     = 'name';
-      $criterias['_users_id_observer']['name']      = $LANG['common'][104]." - ".$LANG['job'][6];
-      $criterias['_users_id_observer']['linkfield'] = '_users_id_assign';
-      $criterias['_users_id_observer']['type']      = 'dropdown_users';
-
-      $criterias['_groups_id_observer']['table']     = 'glpi_groups';
-      $criterias['_groups_id_observer']['field']     = 'name';
-      $criterias['_groups_id_observer']['name']      = $LANG['common'][104]." - ".$LANG['common'][35];
-      $criterias['_groups_id_observer']['linkfield'] = '_groups_id_observer';
-      $criterias['_groups_id_observer']['type']      = 'dropdown';
-
       $criterias['suppliers_id_assign']['table']     = 'glpi_suppliers';
       $criterias['suppliers_id_assign']['field']     = 'name';
       $criterias['suppliers_id_assign']['name']      = $LANG['job'][5]." - ".$LANG['financial'][26];
       $criterias['suppliers_id_assign']['linkfield'] = 'suppliers_id_assign';
       $criterias['suppliers_id_assign']['type']      = 'dropdown';
 
+      $criterias['_users_id_observer']['table']     = 'glpi_users';
+      $criterias['_users_id_observer']['field']     = 'name';
+      $criterias['_users_id_observer']['name']      = $LANG['common'][104]." - ".$LANG['common'][34];
+      $criterias['_users_id_observer']['linkfield'] = '_users_id_observer';
+      $criterias['_users_id_observer']['type']      = 'dropdown_users';
+
+      $criterias['_groups_id_observer']['table']     = 'glpi_groups';
+      $criterias['_groups_id_observer']['field']     = 'completename';
+      $criterias['_groups_id_observer']['name']      = $LANG['common'][104]." - ".$LANG['common'][35];
+      $criterias['_groups_id_observer']['linkfield'] = '_groups_id_observer';
+      $criterias['_groups_id_observer']['type']      = 'dropdown';
+
       $criterias['requesttypes_id']['table']     = 'glpi_requesttypes';
       $criterias['requesttypes_id']['field']     = 'name';
       $criterias['requesttypes_id']['name']      = $LANG['job'][44];
@@ -292,6 +292,11 @@ class RuleTicket extends Rule {
       $criterias['_mailgate']['name']      = $LANG['mailgate'][0];
       $criterias['_mailgate']['linkfield'] = '_mailgate';
       $criterias['_mailgate']['type']      = 'dropdown';
+
+      $criterias['_x-priority']['name']  = $LANG['mailing'][132].' : X-Priority';
+      $criterias['_x-priority']['table'] = '';
+      $criterias['_x-priority']['type']  = 'text';
+
       return $criterias;
    }
 
@@ -300,9 +305,14 @@ class RuleTicket extends Rule {
       global $LANG;
 
       $actions = array();
-      $actions['ticketcategories_id']['name']  = $LANG['common'][36];
-      $actions['ticketcategories_id']['type']  = 'dropdown';
-      $actions['ticketcategories_id']['table'] = 'glpi_ticketcategories';
+      $actions['itilcategories_id']['name']  = $LANG['common'][36];
+      $actions['itilcategories_id']['type']  = 'dropdown';
+      $actions['itilcategories_id']['table'] = 'glpi_itilcategories';
+
+      $actions['type']['name']      = $LANG['common'][17];
+      $actions['type']['table']     = 'glpi_tickets';
+      $actions['type']['type']      = 'dropdown_tickettype';
+
 
       $actions['_users_id_requester']['name'] = $LANG['job'][4]." - ".$LANG['common'][34];
       $actions['_users_id_requester']['type'] = 'dropdown_users';
@@ -318,19 +328,17 @@ class RuleTicket extends Rule {
       $actions['_groups_id_assign']['name']  = $LANG['job'][5]." - ".$LANG['common'][35];
       $actions['_groups_id_assign']['type']  = 'dropdown';
 
-      $actions['_users_id_observer']['name'] = $LANG['common'][104]." - ".$LANG['job'][6];
+      $actions['suppliers_id_assign']['table'] = 'glpi_suppliers';
+      $actions['suppliers_id_assign']['name']  = $LANG['job'][5]." - ".$LANG['financial'][26];
+      $actions['suppliers_id_assign']['type']  = 'dropdown';
+
+      $actions['_users_id_observer']['name'] = $LANG['common'][104]." - ".$LANG['common'][34];
       $actions['_users_id_observer']['type'] = 'dropdown_users';
 
       $actions['_groups_id_observer']['table'] = 'glpi_groups';
       $actions['_groups_id_observer']['name']  = $LANG['common'][104]." - ".$LANG['common'][35];
       $actions['_groups_id_observer']['type']  = 'dropdown';
 
-
-      $actions['suppliers_id_assign']['table'] = 'glpi_suppliers';
-      $actions['suppliers_id_assign']['name']  = $LANG['job'][5]." - ".$LANG['financial'][26];
-      $actions['suppliers_id_assign']['type']  = 'dropdown';
-
-
       $actions['urgency']['name'] = $LANG['joblist'][29];
       $actions['urgency']['type'] = 'dropdown_urgency';
 
