@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: slalevel.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: slalevel.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -43,7 +43,7 @@ class SlaLevel extends RuleTicket {
    protected $ruleactionclass   = 'SlaLevelAction';
    // No criteria
    protected $rulecriteriaclass = '';
-
+   
    public $right='sla';
 
    /**
@@ -54,21 +54,26 @@ class SlaLevel extends RuleTicket {
    }
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['sla'][15];
+      }
       return $LANG['sla'][6];
    }
 
    function cleanDBonPurge() {
       global $DB;
 
+
       parent::cleanDBOnPurge();
 
       $sql = "DELETE
               FROM `glpi_slalevels_tickets`
               WHERE `".$this->rules_id_field."` = '".$this->fields['id']."'";
       $DB->query($sql);
+
    }
 
    function showForSLA(SLA $sla) {
@@ -84,7 +89,7 @@ class SlaLevel extends RuleTicket {
 
       $rand=mt_rand();
       echo "<form name='slalevel_form$rand' id='slalevel_form$rand' method='post' action='";
-      echo getItemTypeFormURL(__CLASS__)."'>";
+      echo Toolbox::getItemTypeFormURL(__CLASS__)."'>";
 
       if ($canedit) {
          echo "<div class='center first-bloc'>";
@@ -122,11 +127,11 @@ class SlaLevel extends RuleTicket {
             echo "<th>".$LANG['sla'][3]."</th>";
             echo "<th>".$LANG['common'][60]."</th>";
             echo "</tr>";
-            initNavigateListItems('SlaLevel',$LANG['sla'][1]." - ".$sla->getName());
+            Session::initNavigateListItems('SlaLevel', $LANG['sla'][1]." - ".$sla->getName());
 
             while ($data = $DB->fetch_array($result)) {
 
-               addToNavigateListItems('SlaLevel',$data["id"]);
+               Session::addToNavigateListItems('SlaLevel',$data["id"]);
 
                echo "<tr class='tab_bg_2'>";
                echo "<td width='10'>";
@@ -139,7 +144,7 @@ class SlaLevel extends RuleTicket {
 
                echo "<td>";
                if ($canedit) {
-                  echo "<a href='".getItemTypeFormURL('SlaLevel')."?id=".$data["id"]."'>";
+                  echo "<a href='".Toolbox::getItemTypeFormURL('SlaLevel')."?id=".$data["id"]."'>";
                }
                   echo $data["name"];
                   if (empty($data["name"])) {
@@ -149,7 +154,9 @@ class SlaLevel extends RuleTicket {
                   echo "</a>";
                }
                echo "</td>";
-               echo "<td>".($data["execution_time"]<>0?timestampToString($data["execution_time"],false):$LANG['sla'][5])."</td>";
+               echo "<td>".($data["execution_time"]<>0?Html::timestampToString($data["execution_time"],
+                                                                               false)
+                                                      :$LANG['sla'][5])."</td>";
                echo "<td>".Dropdown::getYesNo($data["is_active"])."</td>";
                echo "</tr>";
                echo "<tr class='tab_bg_1'><td colspan='4'>";
@@ -158,8 +165,8 @@ class SlaLevel extends RuleTicket {
                echo "</td></tr>";
             }
 
-            openArrowMassive("slalevel_form$rand",true);
-            closeArrowMassive('delete', $LANG['buttons'][6]);
+            Html::openArrowMassives("slalevel_form$rand",true);
+            Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
 
             echo "</table></div>";
          }
@@ -207,7 +214,7 @@ class SlaLevel extends RuleTicket {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this,"name");
+      Html::autocompletionTextField($this,"name");
       echo "</td>";
       echo "<td>".$LANG['common'][60]."&nbsp;:</td>";
       echo "<td>";
@@ -266,21 +273,21 @@ class SlaLevel extends RuleTicket {
          $possible_values=array();
          for ($i=1 ; $i<24 ; $i++) {
             if (!in_array($i*HOUR_TIMESTAMP,$p['used'])) {
-               $possible_values[$i*HOUR_TIMESTAMP]='+ '.$i." ".$LANG['job'][21];
+               $possible_values[$i*HOUR_TIMESTAMP]='+ '.$i." ".Toolbox::ucfirst($LANG['gmt'][1]);
             }
             if (!in_array(-$i*HOUR_TIMESTAMP,$p['used'])) {
                if ($p['max_time'] >= $i*HOUR_TIMESTAMP) {
-                  $possible_values[-$i*HOUR_TIMESTAMP]='- '.$i." ".$LANG['job'][21];
+                  $possible_values[-$i*HOUR_TIMESTAMP]='- '.$i." ".Toolbox::ucfirst($LANG['gmt'][1]);
                }
             }
          }
          for ($i=1 ; $i<30 ; $i++) {
             if (!in_array($i*DAY_TIMESTAMP,$p['used'])) {
-               $possible_values[$i*DAY_TIMESTAMP]='+ '.$i." ".$LANG['stats'][31];
+               $possible_values[$i*DAY_TIMESTAMP]='+ '.$i." ".Toolbox::ucfirst($LANG['calendar'][12]);
             }
             if (!in_array(-$i*DAY_TIMESTAMP,$p['used'])) {
                if ($p['max_time'] >= $i*DAY_TIMESTAMP) {
-                  $possible_values[-$i*DAY_TIMESTAMP]='- '.$i." ".$LANG['stats'][31];
+                  $possible_values[-$i*DAY_TIMESTAMP]='- '.$i." ".Toolbox::ucfirst($LANG['calendar'][12]);
                }
             }
          }
@@ -368,6 +375,34 @@ class SlaLevel extends RuleTicket {
       return 0;
    }
 
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case 'SLA' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry(self::getTypeName(2),
+                                              countElementsInTable($this->getTable(),
+                                                                   "slas_id = '".$item->getID()."'"));
+               }
+               return self::getTypeName(2);
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='SLA') {
+         $slalevel = new self();
+         $slalevel->showForSLA($item);
+      }
+      return true;
+   }
+
 }
 
 ?>
