@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: software.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: software.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -47,20 +47,48 @@ class Software extends CommonDBTM {
    protected $forward_entity_to = array('Infocom', 'ReservationItem', 'SoftwareVersion');
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['Menu'][4];
+      }
       return $LANG['help'][31];
    }
 
 
    function canCreate() {
-      return haveRight('software', 'w');
+      return Session::haveRight('software', 'w');
    }
 
 
    function canView() {
-      return haveRight('software', 'r');
+      return Session::haveRight('software', 'r');
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case __CLASS__ :
+               if ($item->isRecursive() && $item->can($item->fields['id'],'w')) {
+                  return $LANG['software'][47];
+               }
+               break;
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType() == __CLASS__) {
+         $item->showMergeCandidates();
+      }
+      return true;
    }
 
 
@@ -68,46 +96,26 @@ class Software extends CommonDBTM {
       global $LANG, $CFG_GLPI;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         $ong[1] = $LANG['software'][5]."/".$LANG['software'][11];
-         if (empty ($withtemplate)) {
-            $ong[2] = $LANG['software'][19];
-         }
-         if (haveRight("contract","r") || haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
+      $this->addStandardTab('SoftwareVersion', $ong, $options);
+      $this->addStandardTab('SoftwareLicense', $ong, $options);
+      $this->addStandardTab('Computer_SoftwareVersion', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Reservation', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
+      $this->addStandardTab(__CLASS__, $ong, $options);
 
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            if (haveRight("show_all_ticket","1")) {
-               $ong[6] = $LANG['title'][28];
-            }
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-            if (haveRight("reservation_central", "r")) {
-               $ong[11] = $LANG['Menu'][17];
-            }
-            $ong[12] = $LANG['title'][38];
-            if ($this->isRecursive() && $this->can($this->fields['id'],'w')) {
-               $ong[21] = $LANG['software'][47];
-            }
-         }
-      } else { // New item
-         $ong[1]=$LANG['title'][26];
-      }
       return $ong;
    }
 
 
    function prepareInputForUpdate($input) {
 
-      if (isset ($input['is_update']) && ! $input['is_update']) {
+      if (isset($input['is_update']) && !$input['is_update']) {
          $input['softwares_id'] = 0;
       }
       return $input;
@@ -116,7 +124,7 @@ class Software extends CommonDBTM {
 
    function prepareInputForAdd($input) {
 
-      if (isset ($input['is_update']) && !$input['is_update']) {
+      if (isset($input['is_update']) && !$input['is_update']) {
          $input['softwares_id'] = 0;
       }
 
@@ -221,12 +229,6 @@ class Software extends CommonDBTM {
    function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
-      // Show Software or blank form
-
-      if (!haveRight("software", "r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -239,16 +241,16 @@ class Software extends CommonDBTM {
       if (isset($options['withtemplate']) && $options['withtemplate'] == 2) {
          $template   = "newcomp";
          $datestring = $LANG['computers'][14] . "&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else if (isset($options['withtemplate']) && $options['withtemplate'] == 1) {
          $template   = "newtemplate";
          $datestring = $LANG['computers'][14] . "&nbsp;: ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
 
       } else {
          $datestring = $LANG['common'][26] . "&nbsp;: ";
-         $date       = convDateTime($this->fields["date_mod"]);
+         $date       = Html::convDateTime($this->fields["date_mod"]);
          $template   = false;
       }
 
@@ -258,7 +260,7 @@ class Software extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>" . $LANG['common'][16] . "&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
       echo "<td>" . $LANG['common'][5] . " / ".$LANG['software'][6]."&nbsp;:</td><td>";
       Dropdown::show('Manufacturer', array('value' => $this->fields["manufacturers_id"]));
@@ -284,23 +286,32 @@ class Software extends CommonDBTM {
       Dropdown::showYesNo('is_helpdesk_visible',$this->fields['is_helpdesk_visible']);
       echo "</td></tr>\n";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
+      echo "</td>";
+      echo "<td rowspan='5' class='middle'>".$LANG['common'][25] . "&nbsp;: </td>";
+      echo "<td class='center middle' rowspan='5'>";
+      echo "<textarea cols='45' rows='8' name='comment' >".$this->fields["comment"]."</textarea>";
+      echo "</td></tr>\n";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td >" . $LANG['common'][34] . "&nbsp;:</td>";
       echo "<td >";
       User::dropdown(array('value'  => $this->fields["users_id"],
                            'entity' => $this->fields["entities_id"],
                            'right'  => 'all'));
-      echo "</td><td colspan='2'>";
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>" . $LANG['common'][35] . "&nbsp;:</td><td>";
-      Dropdown::show('Group', array('value'  => $this->fields["groups_id"],
-                                    'entity' => $this->fields["entities_id"]));
-      echo "</td>";
-      echo "<td rowspan='3' class='middle'>".$LANG['common'][25] . "&nbsp;: </td>";
-      echo "<td class='center middle' rowspan='3'>";
-      echo "<textarea cols='45' rows='5' name='comment' >".$this->fields["comment"]."</textarea>";
+      Dropdown::show('Group', array('value'     => $this->fields["groups_id"],
+                                    'entity'    => $this->fields["entities_id"],
+                                    'condition' => '`is_itemgroup`'));
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -315,7 +326,7 @@ class Software extends CommonDBTM {
 
       // UPDATE
       echo "<tr class='tab_bg_1'>";
-      echo "<td>" . $LANG['software'][29] . "&nbsp;:</td><td colspan='3'>";
+      echo "<td>" . $LANG['software'][29] . "&nbsp;:</td><td>";
       Dropdown::showYesNo("is_update", $this->fields['is_update']);
       echo "&nbsp;" . $LANG['pager'][2] . "&nbsp;";
       Dropdown::show('Software', array('value' => $this->fields["softwares_id"]));
@@ -391,13 +402,20 @@ class Software extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[70]['table'] = 'glpi_users';
       $tab[70]['field'] = 'name';
       $tab[70]['name']  = $LANG['common'][34];
 
-      $tab[71]['table'] = 'glpi_groups';
-      $tab[71]['field'] = 'name';
-      $tab[71]['name']  = $LANG['common'][35];
+      $tab[71]['table']     = 'glpi_groups';
+      $tab[71]['field']     = 'completename';
+      $tab[71]['name']      = $LANG['common'][35];
+      $tab[71]['condition'] = '`is_itemgroup`';
 
       $tab[61]['table']    = $this->getTable();
       $tab[61]['field']    = 'is_helpdesk_visible';
@@ -421,7 +439,8 @@ class Software extends CommonDBTM {
                                         'condition'  => "AND NEWTABLE.`is_deleted` = '0'
                                                          AND NEWTABLE.`is_template` = '0'",
                                         'beforejoin' => array('table' => 'glpi_softwareversions',
-                                                         'joinparams' => array('jointype' => 'child')));
+                                                              'joinparams'
+                                                                      => array('jointype' => 'child')));
 
 
       $tab[86]['table']         = $this->getTable();
@@ -440,7 +459,7 @@ class Software extends CommonDBTM {
       $tab[5]['joinparams']    = array('jointype' => 'child');
 
       $tab[31]['table']         = 'glpi_states';
-      $tab[31]['field']         = 'name';
+      $tab[31]['field']         = 'completename';
       $tab[31]['name']          = $LANG['state'][0];
       $tab[31]['forcegroupby']  = true;
       $tab[31]['massiveaction'] = false;
@@ -458,7 +477,7 @@ class Software extends CommonDBTM {
 
       $tab[4]['table']        = 'glpi_operatingsystems';
       $tab[4]['field']        = 'name';
-      $tab[4]['name']         = $LANG['setup'][5]." - ".$LANG['software'][5];
+      $tab[4]['name']         = $LANG['computers'][9]." - ".$LANG['software'][5];
       $tab[4]['forcegroupby'] = true;
       $tab[4]['joinparams']   = array('beforejoin'
                                         => array('table'      => 'glpi_softwareversions',
@@ -551,9 +570,9 @@ class Software extends CommonDBTM {
                       'myname'          => $myname,
                       'entity_restrict' => $entity_restrict);
 
-      $default = "<select name='$myname'><option value='0'>".DROPDOWN_EMPTY_VALUE." </option>
+      $default = "<select name='$myname'><option value='0'>".Dropdown::EMPTY_VALUE." </option>
                   </select>";
-      ajaxDropdown($use_ajax, "/ajax/dropdownSelectSoftware.php", $params, $default, $rand);
+      Ajax::dropdown($use_ajax, "/ajax/dropdownSelectSoftware.php", $params, $default, $rand);
 
       return $rand;
    }
@@ -585,9 +604,9 @@ class Software extends CommonDBTM {
                       'myname'          => $myname,
                       'entity_restrict' => $entity_restrict);
 
-      $default = "<select name='$myname'><option value='0'>".DROPDOWN_EMPTY_VALUE." </option>
+      $default = "<select name='$myname'><option value='0'>".Dropdown::EMPTY_VALUE." </option>
                   </select>";
-      ajaxDropdown($use_ajax, "/ajax/dropdownSelectSoftwareLicense.php", $params, $default, $rand);
+      Ajax::dropdown($use_ajax, "/ajax/dropdownSelectSoftwareLicense.php", $params, $default, $rand);
 
       return $rand;
    }
@@ -600,10 +619,11 @@ class Software extends CommonDBTM {
     * @param manufacturer the software's manufacturer
     * @param entity the entity in which the software must be added
     * @param comment
+    * @param is_recursive must the software be recursive (boolean)
     *
     * @return the software's ID
    **/
-   function addSoftware($name, $manufacturer, $entity, $comment = '') {
+   function addSoftware($name, $manufacturer, $entity, $comment='', $is_recursive=false) {
       global $DB, $CFG_GLPI;
 
       $manufacturer_id = 0;
@@ -625,6 +645,7 @@ class Software extends CommonDBTM {
          $input["name"]                = $name;
          $input["manufacturers_id"]    = $manufacturer_id;
          $input["entities_id"]         = $entity;
+         $input["is_recursive"]        = ($is_recursive ? 1 : 0);
          // No comment
          $input["is_helpdesk_visible"] = $CFG_GLPI["default_software_helpdesk_visible"];
 
@@ -632,7 +653,7 @@ class Software extends CommonDBTM {
          $softcatrule = new RuleSoftwareCategoryCollection();
          $result      = $softcatrule->processAllRules(null, null, $input);
 
-         if (!empty ($result) && isset ($result["softwarecategories_id"])) {
+         if (!empty($result) && isset($result["softwarecategories_id"])) {
             $input["softwarecategories_id"] = $result["softwarecategories_id"];
          } else {
             $input["softwarecategories_id"] = 0;
@@ -651,8 +672,9 @@ class Software extends CommonDBTM {
     * @param manufacturer the software's manufacturer
     * @param entity the entity in which the software must be added
     * @param comment comment
+    * @param is_recursive must the software be recursive (boolean)
    */
-   function addOrRestoreFromTrash($name, $manufacturer, $entity, $comment='') {
+   function addOrRestoreFromTrash($name, $manufacturer, $entity, $comment='', $is_recursive=false) {
       global $DB;
 
       //Look for the software by his name in GLPI for a specific entity
@@ -661,7 +683,6 @@ class Software extends CommonDBTM {
                        WHERE `name` = '$name'
                              AND `is_template` = '0'
                              AND `entities_id` = '$entity'";
-
       $result_search = $DB->query($query_search);
 
       if ($DB->numrows($result_search) > 0) {
@@ -679,7 +700,7 @@ class Software extends CommonDBTM {
       }
 
       if (!$ID) {
-         $ID = $this->addSoftware($name, $manufacturer, $entity, $comment);
+         $ID = $this->addSoftware($name, $manufacturer, $entity, $comment, $is_recursive);
       }
       return $ID;
    }
@@ -769,7 +790,7 @@ class Software extends CommonDBTM {
       $req = $DB->request($sql);
 
       if ($req->numrows()) {
-         $link = getItemTypeFormURL('Software');
+         $link = Toolbox::getItemTypeFormURL('Software');
          echo "<form method='post' name='mergesoftware_form$rand' id='mergesoftware_form$rand'
                 action='".$link."'>";
          echo "<table class='tab_cadre_fixehov'><tr><th>&nbsp;</th>";
@@ -788,9 +809,9 @@ class Software extends CommonDBTM {
          }
          echo "</table>\n";
 
-         openArrowMassive("mergesoftware_form$rand", true);
+         Html::openArrowMassives("mergesoftware_form$rand", true);
          echo "<input type='hidden' name='id' value='$ID'>";
-         closeArrowMassive('mergesoftware', $LANG['software'][48]);
+         Html::closeArrowMassives(array('mergesoftware' => $LANG['software'][48]));
 
          echo "</form>";
 
@@ -817,7 +838,7 @@ class Software extends CommonDBTM {
       echo "<div class='center'>";
       echo "<table class='tab_cadrehov'><tr><th>".$LANG['software'][47]."</th></tr>";
       echo "<tr class='tab_bg_2'><td>";
-      createProgressBar($LANG['rulesengine'][90]);
+      Html::createProgressBar($LANG['rulesengine'][90]);
       echo "</td></tr></table></div>\n";
 
       $item = array_keys($item);
@@ -868,7 +889,7 @@ class Software extends CommonDBTM {
             if ($DB->query($sql)) {
                $i++;
             }
-            changeProgressBarPosition($i,$nb+1);
+            Html::changeProgressBarPosition($i, $nb+1);
          }
       }
 
@@ -888,7 +909,7 @@ class Software extends CommonDBTM {
             $soft->putInTrash($old, $LANG['software'][49]);
          }
       }
-      changeProgressBarPosition($i,$nb+1,$LANG['rulesengine'][91]);
+      Html::changeProgressBarPosition($i, $nb+1, $LANG['rulesengine'][91]);
       return $i==($nb+1);
    }
 
