@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: softwarelicense.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: softwarelicense.class.php 18025 2012-03-27 09:00:32Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -47,20 +47,23 @@ class SoftwareLicense extends CommonDBTM {
    protected $forward_entity_to = array('Infocom');
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['software'][11];
+      if ($nb>1) {
+         return $LANG['software'][11];
+      }
+      return $LANG['software'][12];
    }
 
 
    function canCreate() {
-      return haveRight('software', 'w');
+      return Session::haveRight('software', 'w');
    }
 
 
    function canView() {
-      return haveRight('software', 'r');
+      return Session::haveRight('software', 'r');
    }
 
 
@@ -79,7 +82,7 @@ class SoftwareLicense extends CommonDBTM {
    function prepareInputForAdd($input) {
 
       // Unset to set to default using mysql default value
-      if (empty ($input['expire'])) {
+      if (empty($input['expire'])) {
          unset ($input['expire']);
       }
 
@@ -93,7 +96,7 @@ class SoftwareLicense extends CommonDBTM {
       $itemtype = 'Software';
       $dupid    = $this->fields["softwares_id"];
 
-      if (isset ($this->input["_duplicate_license"])) {
+      if (isset($this->input["_duplicate_license"])) {
          $itemtype = 'SoftwareLicense';
          $dupid    = $this->input["_duplicate_license"];
       }
@@ -107,18 +110,12 @@ class SoftwareLicense extends CommonDBTM {
    function defineTabs($options=array()) {
       global $LANG;
 
-      $ong[1] = $LANG['title'][26];
-      if ($this->fields['id'] > 0) {
-         $ong[2] = $LANG['Menu'][0];
-
-         if (haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-         if (haveRight("document","r")) {
-            $ong[5]=$LANG['Menu'][27];
-         }
-         $ong[12] = $LANG['title'][38];
-      }
+      $ong = array();
+      $this->addStandardTab('Computer_SoftwareLicense', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
       return $ong;
    }
 
@@ -141,7 +138,7 @@ class SoftwareLicense extends CommonDBTM {
          $softwares_id = $options['softwares_id'];
       }
 
-      if (!haveRight("software","w")) {
+      if (!Session::haveRight("software","w")) {
          return false;
       }
 
@@ -152,9 +149,10 @@ class SoftwareLicense extends CommonDBTM {
          $this->check(-1,'w');
          $this->fields['softwares_id'] = $softwares_id;
          $this->fields['number']       = 1;
-         $soft = new Software();
+         $soft                         = new Software();
          if ($soft->getFromDB($softwares_id)
-             && in_array($_SESSION['glpiactive_entity'], getAncestorsOf('glpi_entities', $soft->getEntityID()))) {
+             && in_array($_SESSION['glpiactive_entity'], getAncestorsOf('glpi_entities',
+                                                                        $soft->getEntityID()))) {
             $options['entities_id'] = $soft->getEntityID();
          }
       }
@@ -182,11 +180,11 @@ class SoftwareLicense extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this,"name");
+      Html::autocompletionTextField($this,"name");
       echo "</td>";
       echo "<td>".$LANG['common'][19]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this,"serial");
+      Html::autocompletionTextField($this,"serial");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -198,7 +196,7 @@ class SoftwareLicense extends CommonDBTM {
       echo "</td>";
       echo "<td>".$LANG['common'][20]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this,"otherserial");
+      Html::autocompletionTextField($this,"otherserial");
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -223,14 +221,14 @@ class SoftwareLicense extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['software'][32]."&nbsp;:</td>";
       echo "<td>";
-      showDateFormItem('expire', $this->fields["expire"]);
+      Html::showDateFormItem('expire', $this->fields["expire"]);
       Alert::displayLastAlert('SoftwareLicense', $ID);
       echo "</td></tr>\n";
 
       if ($ID>0) {
          echo "<tr class='tab_bg_1'>";
          echo "<td>".$LANG['common'][26]."&nbsp;: </td>";
-         echo "<td>".($this->fields["date_mod"] ? convDateTime($this->fields["date_mod"])
+         echo "<td>".($this->fields["date_mod"] ? Html::convDateTime($this->fields["date_mod"])
                                                 : $LANG['setup'][307]);
          echo "</td></tr>";
       }
@@ -361,7 +359,8 @@ class SoftwareLicense extends CommonDBTM {
 
          foreach ($DB->request($query) as $license) {
             $name     = $license['softname'].' - '.$license['name'].' - '.$license['serial'];
-            $message .= $LANG['mailing'][51]." ".$name.": ".convDate($license["expire"])."<br>\n";
+            $message .= $LANG['mailing'][51]." ".$name.": ".Html::convDate($license["expire"]).
+                        "<br>\n";
             $items[$license['id']] = $license;
          }
 
@@ -375,8 +374,9 @@ class SoftwareLicense extends CommonDBTM {
                   $task->log(Dropdown::getDropdownName("glpi_entities", $entity)." :  $message\n");
                    $task->addVolume(1);
                 } else {
-                  addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
-                                                                    $entity)." :  $message");
+                  Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                             $entity).
+                                                    " :  $message");
                }
 
                $input["type"]     = Alert::END;
@@ -394,8 +394,10 @@ class SoftwareLicense extends CommonDBTM {
                   $task->log(Dropdown::getDropdownName("glpi_entities", $entity).
                              " : Send licenses alert failed\n");
                } else {
-                  addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity).
-                                          " : Send licenses alert failed",false,ERROR);
+                  Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                             $entity).
+                                                      " : Send licenses alert failed",
+                                                   false, ERROR);
                }
             }
          }
@@ -474,7 +476,7 @@ class SoftwareLicense extends CommonDBTM {
       global $DB, $CFG_GLPI, $LANG;
 
       $softwares_id = $software->getField('id');
-      $license  = new SoftwareLicense;
+      $license  = new SoftwareLicense();
       $computer = new Computer();
 
       if (!$software->can($softwares_id,"r")) {
@@ -502,8 +504,9 @@ class SoftwareLicense extends CommonDBTM {
 
 
       // Righ type is enough. Can add a License on a software we have Read access
-      $canedit = haveRight("software", "w");
-
+      $canedit = Session::haveRight("software", "w");
+      $showmassiveactions = count(Dropdown::getMassiveActions(__CLASS__));
+      
       // Total Number of events
       $number = countElementsInTable("glpi_softwarelicenses",
                                      "glpi_softwarelicenses.softwares_id = $softwares_id " .
@@ -511,7 +514,8 @@ class SoftwareLicense extends CommonDBTM {
                                                                      '', '', true));
       echo "<div class='spaced'>";
 
-      initNavigateListItems('SoftwareLicense', $LANG['help'][31] ." = ". $software->fields["name"]);
+      Session::initNavigateListItems('SoftwareLicense',
+                                     $LANG['help'][31] ." = ". $software->fields["name"]);
 
       if ($number < 1) {
          echo "<table class='tab_cadre_fixe'>";
@@ -529,7 +533,7 @@ class SoftwareLicense extends CommonDBTM {
       }
 
       // Display the pager
-      printAjaxPager($LANG['software'][11], $start, $number);
+      Html::printAjaxPager($LANG['software'][11], $start, $number);
 
       $rand = mt_rand();
       $query = "SELECT `glpi_softwarelicenses`.*,
@@ -554,7 +558,7 @@ class SoftwareLicense extends CommonDBTM {
 
       if ($result=$DB->query($query)) {
          if ($DB->numrows($result)) {
-            if ($canedit) {
+            if ($showmassiveactions) {
                echo "<form method='post' name='massiveactionlicense_form$rand' id='".
                       "massiveactionlicense_form$rand' action=\"".$CFG_GLPI["root_doc"].
                       "/front/massiveaction.php\">";
@@ -602,7 +606,7 @@ class SoftwareLicense extends CommonDBTM {
 
             $tot_assoc = 0;
             for ($tot=0 ; $data=$DB->fetch_assoc($result) ; ) {
-               addToNavigateListItems('SoftwareLicense', $data['id']);
+               Session::addToNavigateListItems('SoftwareLicense', $data['id']);
                echo "<tr class='tab_bg_2'>";
 
                if ($license->can($data['id'], "w")) {
@@ -626,7 +630,7 @@ class SoftwareLicense extends CommonDBTM {
                echo "<td>".$data['typename']."</td>";
                echo "<td>".$data['buyname']."</td>";
                echo "<td>".$data['usename']."</td>";
-               echo "<td class='center'>".convDate($data['expire'])."</td>";
+               echo "<td class='center'>".Html::convDate($data['expire'])."</td>";
                echo "</tr>";
 
                if ($data['number']<0) {
@@ -652,11 +656,12 @@ class SoftwareLicense extends CommonDBTM {
             echo "</td></tr>";
             echo "</table>\n";
 
-            if ($canedit) {
-               openArrowMassive("massiveactionlicense_form$rand", true);
+            if ($showmassiveactions) {
+               Html::openArrowMassives("massiveactionlicense_form$rand", true);
                Dropdown::showForMassiveAction('SoftwareLicense', 0,
                                               array('softwares_id' => $softwares_id));
-               closeArrowMassive();
+               $options = array();
+               Html::closeArrowMassives($options);
 
                echo "</form>";
             }
@@ -699,6 +704,32 @@ class SoftwareLicense extends CommonDBTM {
                    'softwares_id' => $LANG['help'][31]);
    }
 
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         switch ($item->getType()) {
+            case 'Software' :
+               if ($_SESSION['glpishow_count_on_tabs']) {
+                  return self::createTabEntry(self::getTypeName(2),
+                                              self::countForSoftware($item->getID()));
+               }
+               return self::getTypeName(2);
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      if ($item->getType()=='Software') {
+         self::showForSoftware($item);
+      }
+      return true;
+   }
+
 }
 
 ?>
