@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: supplier.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: supplier.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -44,13 +44,14 @@ class Supplier extends CommonDBTM {
    // From CommonDBTM
    public $dohistory = true;
 
-/**
- * Name of the type
- *
- * @param $nb : number of item in the type
- *
- * @return $LANG
-**/
+
+   /**
+    * Name of the type
+    *
+    * @param $nb : number of item in the type
+    *
+    * @return $LANG
+   **/
    static function getTypeName($nb=0) {
       global $LANG;
 
@@ -62,19 +63,19 @@ class Supplier extends CommonDBTM {
 
 
    function canCreate() {
-      return haveRight('contact_enterprise', 'w');
+      return Session::haveRight('contact_enterprise', 'w');
    }
 
 
    function canView() {
-      return haveRight('contact_enterprise', 'r');
+      return Session::haveRight('contact_enterprise', 'r');
    }
 
 
    function cleanDBonPurge() {
       global $DB;
 
-      $job = new Ticket;
+      $job = new Ticket();
 
       $cs = new Contract_Supplier();
       $cs->cleanDBonItemDelete($this->getType(), $this->fields['id']);
@@ -91,33 +92,14 @@ class Supplier extends CommonDBTM {
       global $LANG,$CFG_GLPI;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         if (haveRight("contact_enterprise","r")) {
-            $ong[1] = $LANG['Menu'][22];
-         }
-         if (haveRight("contract","r")) {
-            $ong[4] = $LANG['Menu'][25];
-         }
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-            $ong[15] = $LANG['common'][96];
-         }
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-         if (haveRight("show_all_ticket","1")) {
-            $ong[6] = $LANG['title'][28];
-         }
-         if (haveRight("link","r")) {
-            $ong[7] = $LANG['title'][34];
-         }
-         if (haveRight("notes","r")) {
-            $ong[10] = $LANG['title'][37];
-         }
-         $ong[12] = $LANG['title'][38];
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('Contact_Supplier', $ong, $options);
+      $this->addStandardTab('Contract_Supplier', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
       return $ong;
    }
@@ -133,14 +115,9 @@ class Supplier extends CommonDBTM {
     *
     *@return Nothing (display)
    **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI,$LANG;
 
-      // Show Supplier or blank form
-      if (!haveRight("contact_enterprise","r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -154,7 +131,7 @@ class Supplier extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
       echo "<td>".$LANG['financial'][79]."&nbsp;:</td>";
       echo "<td>";
@@ -164,7 +141,7 @@ class Supplier extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['help'][35]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "phonenumber");
+      Html::autocompletionTextField($this, "phonenumber");
       echo "</td>";
       echo "<td rowspan='8' class='middle right'>".$LANG['common'][25]."&nbsp;:</td>";
       echo "<td class='center middle' rowspan='8'>";
@@ -174,19 +151,19 @@ class Supplier extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][30]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "fax");
+      Html::autocompletionTextField($this, "fax");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][45]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "website");
+      Html::autocompletionTextField($this, "website");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['setup'][14]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "email");
+      Html::autocompletionTextField($this, "email");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
@@ -198,21 +175,21 @@ class Supplier extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][100]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "postcode", array('size' => 10));
+      Html::autocompletionTextField($this, "postcode", array('size' => 10));
       echo "&nbsp;&nbsp;".$LANG['financial'][101]."&nbsp;:&nbsp;";
-      autocompletionTextField($this, "town", array('size' => 23));
+      Html::autocompletionTextField($this, "town", array('size' => 23));
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][102]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "state");
+      Html::autocompletionTextField($this, "state");
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['financial'][103]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "country");
+      Html::autocompletionTextField($this, "country");
       echo "</td></tr>";
 
       $this->showFormButtons($options);
@@ -398,12 +375,13 @@ class Supplier extends CommonDBTM {
 
       $used = array();
       if ($number) {
-         initNavigateListItems('Contact', $LANG['financial'][26]." = ".$this->fields['name']);
+         Session::initNavigateListItems('Contact',
+                                        $LANG['financial'][26]." = ".$this->fields['name']);
 
          while ($data=$DB->fetch_array($result)) {
             $ID                = $data["ID_ent"];
             $used[$data["id"]] = $data["id"];
-            addToNavigateListItems('Contact',$data["id"]);
+            Session::addToNavigateListItems('Contact',$data["id"]);
 
             echo "<tr class='tab_bg_1".($data["is_deleted"]?"_2":"")."'>";
             echo "<td class='center'>";
@@ -425,7 +403,7 @@ class Supplier extends CommonDBTM {
             if ($canedit) {
                echo "<a href='".$CFG_GLPI["root_doc"].
                      "/front/contact.form.php?deletecontactsupplier=1&amp;id=$ID&amp;contacts_id=".
-                     $data["id"]."'><img src='".$CFG_GLPI["root_doc"]."/pics/delete2.png' alt='".
+                     $data["id"]."'><img src='".$CFG_GLPI["root_doc"]."/pics/delete.png' alt='".
                      $LANG['buttons'][6]."'></a>";
             } else {
                echo "&nbsp;";
@@ -494,7 +472,7 @@ class Supplier extends CommonDBTM {
 
       echo "<div class='spaced'><table class='tab_cadre_fixe'>";
       echo "<tr><th colspan='2'>";
-      printPagerForm();
+      Html::printPagerForm();
       echo "</th><th colspan='3'>";
       if ($DB->numrows($result)==0) {
          echo $LANG['document'][13];
@@ -513,10 +491,9 @@ class Supplier extends CommonDBTM {
       for ($i=0 ; $i < $number ; $i++) {
          $itemtype = $DB->result($result, $i, "itemtype");
 
-         if (!class_exists($itemtype)) {
+         if (!($item = getItemForItemtype($itemtype))) {
             continue;
          }
-         $item = new $itemtype();
 
          if ($item->canView()) {
             $linktype  = $itemtype;
@@ -565,7 +542,7 @@ class Supplier extends CommonDBTM {
                echo "<tr class='tab_bg_1'>";
                echo "<td class='center'>".$item->getTypeName($nb)."&nbsp;:&nbsp;$nb</td>";
                echo "<td class='center' colspan='2'>";
-               echo "<a href='". getItemTypeSearchURL($linktype) . "?" .
+               echo "<a href='". Toolbox::getItemTypeSearchURL($linktype) . "?" .
                       rawurlencode("contains[0]") . "=" . rawurlencode('$$$$'.$instID) . "&" .
                       rawurlencode("field[0]") . "=53&sort=80&order=ASC&is_deleted=0&start=0". "'>" .
                       $LANG['reports'][57]."</a></td>";
@@ -578,7 +555,7 @@ class Supplier extends CommonDBTM {
                   if ($_SESSION["glpiis_ids_visible"] || empty($data["name"])) {
                      $ID = " (".$data["id"].")";
                   }
-                  $link = getItemTypeFormURL($linktype);
+                  $link = Toolbox::getItemTypeFormURL($linktype);
                   $name = "<a href=\"".$link."?id=".$data[$linkfield]."\">".$data["name"]."$ID</a>";
 
                   echo "<tr class='tab_bg_1'>";
@@ -617,7 +594,7 @@ class Supplier extends CommonDBTM {
       global $DB, $CFG_GLPI, $LANG;
 
       $ID = $this->fields['id'];
-      if (!haveRight("contract","r") || !$this->can($ID,'r')) {
+      if (!Session::haveRight("contract","r") || !$this->can($ID,'r')) {
          return false;
       }
       $canedit = $this->can($ID,'w');
@@ -665,24 +642,23 @@ class Supplier extends CommonDBTM {
          $assocID    = $data["assocID"];
 
          echo "<tr class='tab_bg_1".($data["is_deleted"]?"_2":"")."'>";
-         echo "<td class='center'>
-               <a href='".$CFG_GLPI["root_doc"]."/front/contract.form.php?id=$cID'>";
-         echo "<strong>".$data["name"];
+         echo "<td class='center b'>
+               <a href='".$CFG_GLPI["root_doc"]."/front/contract.form.php?id=$cID'>".$data["name"];
 
          if ($_SESSION["glpiis_ids_visible"] || empty($data["name"])) {
             echo " (".$data["id"].")";
          }
 
-         echo "</strong></a></td>";
+         echo "</a></td>";
          echo "<td class='center'>".Dropdown::getDropdownName("glpi_entities", $data["entity"]);
          echo "</td><td class='center'>".$data["num"]."</td>";
          echo "<td class='center'>".
                 Dropdown::getDropdownName("glpi_contracttypes",$data["contracttypes_id"])."</td>";
-         echo "<td class='center'>".convDate($data["begin_date"])."</td>";
+         echo "<td class='center'>".Html::convDate($data["begin_date"])."</td>";
          echo "<td class='center'>".$data["duration"]." ".$LANG['financial'][57];
 
          if ($data["begin_date"]!='' && !empty($data["begin_date"])) {
-            echo " -> ".getWarrantyExpir($data["begin_date"], $data["duration"]);
+            echo " -> ".Infocom::getWarrantyExpir($data["begin_date"], $data["duration"]);
          }
          echo "</td>";
          echo "<td class='tab_bg_2 center'>";
@@ -690,7 +666,7 @@ class Supplier extends CommonDBTM {
          if ($canedit) {
             echo "<a href='".$CFG_GLPI["root_doc"]."/front/contract.form.php?deletecontractsupplier=".
                    "1&amp;id=$assocID&amp;contracts_id=$cID'>";
-            echo "<img src='".$CFG_GLPI["root_doc"]."/pics/delete2.png' alt='".
+            echo "<img src='".$CFG_GLPI["root_doc"]."/pics/delete.png' alt='".
                    $LANG['buttons'][6]."'></a>";
          } else {
             echo "&nbsp;";
