@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ticketfollowup.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ticketfollowup.class.php 17472 2012-02-14 07:57:31Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -63,23 +63,23 @@ class TicketFollowup  extends CommonDBTM {
 
    function canCreate() {
 
-      return (haveRight('global_add_followups', 1)
-              || haveRight('add_followups', 1)
-              || haveRight('own_ticket', 1));
+      return (Session::haveRight('global_add_followups', 1)
+              || Session::haveRight('add_followups', 1)
+              || Session::haveRight('own_ticket', 1));
    }
 
 
    function canView() {
 
-      return (haveRight('observe_ticket', 1)
-              || haveRight('show_full_ticket', 1)
-              || haveRight('own_ticket', 1));
+      return (Session::haveRight('observe_ticket', 1)
+              || Session::haveRight('show_full_ticket', 1)
+              || Session::haveRight('own_ticket', 1));
    }
 
 
    function canDelete() {
 
-      return (haveRight('delete_followups', 1));
+      return (Session::haveRight('delete_followups', 1));
    }
 
 
@@ -95,7 +95,7 @@ class TicketFollowup  extends CommonDBTM {
          return false;
       }
 
-      if (haveRight('delete_followups',1)) {
+      if (Session::haveRight('delete_followups',1)) {
          return true;
       }
 
@@ -114,13 +114,13 @@ class TicketFollowup  extends CommonDBTM {
       if (!$ticket->can($this->getField('tickets_id'),'r')) {
          return false;
       }
-      if (haveRight('show_full_ticket', 1)) {
+      if (Session::haveRight('show_full_ticket', 1)) {
          return true;
       }
-      if (!$this->fields['is_private'] && haveRight('observe_ticket',1)) {
+      if (!$this->fields['is_private'] && Session::haveRight('observe_ticket',1)) {
          return true;
       }
-      if ($this->fields["users_id"] === getLoginUserID()) {
+      if ($this->fields["users_id"] === Session::getLoginUserID()) {
          return true;
       }
       return false;
@@ -149,7 +149,8 @@ class TicketFollowup  extends CommonDBTM {
    **/
    function canUpdateItem() {
 
-      if ($this->fields["users_id"]!=getLoginUserID() && !haveRight('update_followups',1)) {
+      if ($this->fields["users_id"]!=Session::getLoginUserID()
+          && !Session::haveRight('update_followups',1)) {
          return false;
       }
 
@@ -158,16 +159,41 @@ class TicketFollowup  extends CommonDBTM {
          return false;
       }
 
-      if ($this->fields["users_id"]===getLoginUserID()
-          && haveRight('update_own_followups',1)) {
+      if ($this->fields["users_id"]===Session::getLoginUserID()
+          && Session::haveRight('update_own_followups',1)) {
             return true;
 
       }
       // Only the technician
-      return (haveRight("update_followups","1")
-              || $ticket->isUser(Ticket::ASSIGN, getLoginUserID())
+      return (Session::haveRight("update_followups","1")
+              || $ticket->isUser(CommonITILObject::ASSIGN, Session::getLoginUserID())
               || (isset($_SESSION["glpigroups"])
-                  && $ticket->haveAGroup(Ticket::ASSIGN, $_SESSION['glpigroups'])));
+                  && $ticket->haveAGroup(CommonITILObject::ASSIGN, $_SESSION['glpigroups'])));
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if ($item->getType() == 'Ticket') {
+         if (Session::haveRight('observe_ticket','1')){
+            if ($_SESSION['glpishow_count_on_tabs']) {
+               return self::createTabEntry($LANG['mailing'][141],
+                                           countElementsInTable('glpi_ticketfollowups',
+                                                                "`tickets_id` = '".$item->getID()."'"));
+            }
+            return $LANG['mailing'][141];
+         }
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      $fup = new TicketFollowup();
+      $fup->showSummary($item);
+      return true;
    }
 
 
@@ -176,7 +202,8 @@ class TicketFollowup  extends CommonDBTM {
       if (isset($_SESSION['glpifollowup_private']) && $_SESSION['glpifollowup_private']) {
          $this->fields['is_private'] = 1;
       }
-      if (isset ($_SESSION["glpiname"])) {
+
+      if (isset($_SESSION["glpiname"])) {
          $this->fields['requesttypes_id'] = RequestType::getDefault('helpdesk');
       }
    }
@@ -193,7 +220,7 @@ class TicketFollowup  extends CommonDBTM {
       $changes[1] = '';
       $changes[2] = $this->fields['id'];
       Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
-                   HISTORY_DELETE_SUBITEM);
+                   Log::HISTORY_DELETE_SUBITEM);
 
       $options = array('followup_id' => $this->fields["id"], 
                         // Force is_private with data / not available
@@ -204,7 +231,7 @@ class TicketFollowup  extends CommonDBTM {
 
    function prepareInputForUpdate($input) {
 
-      if ($uid=getLoginUserID()) {
+      if ($uid=Session::getLoginUserID()) {
          $input["users_id"] = $uid;
       }
       return $input;
@@ -214,7 +241,7 @@ class TicketFollowup  extends CommonDBTM {
    function post_updateItem($history=1) {
       global $CFG_GLPI;
 
-      $job = new Ticket;
+      $job = new Ticket();
       $mailsend = false;
 
       if ($job->getFromDB($this->input["tickets_id"])) {
@@ -225,7 +252,7 @@ class TicketFollowup  extends CommonDBTM {
                 && (in_array("content",$this->updates)
                     || isset($this->input['_need_send_mail']))) {
                $options = array('followup_id' => $this->fields["id"],
-                                'is_private'  => $this->fields["is_private"]);
+                                'is_private'  => $this->fields['is_private']);
 
                NotificationEvent::raiseEvent("update_followup", $job, $options);
             }
@@ -235,7 +262,7 @@ class TicketFollowup  extends CommonDBTM {
          $changes[1] = '';
          $changes[2] = $this->fields['id'];
          Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
-                      HISTORY_UPDATE_SUBITEM);
+                      Log::HISTORY_UPDATE_SUBITEM);
       }
    }
 
@@ -243,8 +270,8 @@ class TicketFollowup  extends CommonDBTM {
    function prepareInputForAdd($input) {
       global $LANG;
 
-//      $input["_isadmin"] = haveRight("global_add_followups","1");
-      $input["_job"] = new Ticket;
+//      $input["_isadmin"] = Session::haveRight("global_add_followups","1");
+      $input["_job"] = new Ticket();
 
       if (!$input["_job"]->getFromDB($input["tickets_id"])) {
          return false;
@@ -274,7 +301,7 @@ class TicketFollowup  extends CommonDBTM {
       $input['_close'] = 0;
       unset($input["add"]);
 
-      if (!isset($input["users_id"]) && $uid=getLoginUserID()) {
+      if (!isset($input["users_id"]) && $uid=Session::getLoginUserID()) {
          $input["users_id"] = $uid;
       }
 //      if ($input["_isadmin"] && $input["_type"]!="update") {
@@ -283,9 +310,13 @@ class TicketFollowup  extends CommonDBTM {
       }
       unset($input["add_close"]);
 
+      if (!isset($input["is_private"])) {
+         $input['is_private'] = 0;
+      }
+
       if (isset($input["add_reopen"])) {
          if ($input["content"] == '') {
-            addMessageAfterRedirect($LANG['jobresolution'][5],false,ERROR);
+            Session::addMessageAfterRedirect($LANG['jobresolution'][5], false, ERROR);
             return false;
          }
          $input['_reopen'] = 1;
@@ -327,8 +358,8 @@ class TicketFollowup  extends CommonDBTM {
           && $this->input["_reopen"]
           && in_array($this->input["_job"]->fields["status"], array('solved', 'waiting'))) {
 
-         if ($this->input["_job"]->countUsers(Ticket::ASSIGN)>0
-             || $this->input["_job"]->countGroups(Ticket::ASSIGN)>0
+         if ($this->input["_job"]->countUsers(CommonITILObject::ASSIGN)>0
+             || $this->input["_job"]->countGroups(CommonITILObject::ASSIGN)>0
              || $this->input["_job"]->fields["suppliers_id_assign"]>0) {
 
             $update['status'] = 'assign';
@@ -344,7 +375,7 @@ class TicketFollowup  extends CommonDBTM {
 
       if ($donotif) {
          $options = array('followup_id' => $this->fields["id"],
-                          'is_private'  => $this->fields["is_private"]);
+                          'is_private'  => $this->fields['is_private']);
          NotificationEvent::raiseEvent("add_followup", $this->input["_job"], $options);
       }
 
@@ -353,7 +384,7 @@ class TicketFollowup  extends CommonDBTM {
       $changes[1] = '';
       $changes[2] = $this->fields['id'];
       Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
-                   HISTORY_ADD_SUBITEM);
+                   Log::HISTORY_ADD_SUBITEM);
    }
 
 
@@ -384,7 +415,7 @@ class TicketFollowup  extends CommonDBTM {
       }
 
       if ($with_comment) {
-         $name .= ' ('.convDateTime($this->fields['date']);
+         $name .= ' ('.Html::convDateTime($this->fields['date']);
          $name .= ', '.getUserName($this->fields['users_id']);
          $name .= ', '.($this->fields['is_private'] ? $LANG['common'][77] : $LANG['common'][76]);
          $name .= ')';
@@ -415,14 +446,15 @@ class TicketFollowup  extends CommonDBTM {
          echo "\n<script type='text/javascript' >\n";
          echo "function viewEditFollowup" . $ticket->fields['id'] . $this->fields["id"] . "$rand() {\n";
          $params = array('type'       => __CLASS__,
+                         'parenttype' => 'Ticket',
                          'tickets_id' => $this->fields["tickets_id"],
                          'id'         => $this->fields["id"]);
-         ajaxUpdateItemJsCode("viewfollowup" . $ticket->fields['id'] . "$rand",
-                              $CFG_GLPI["root_doc"]."/ajax/viewfollowup.php", $params, false);
+         Ajax::updateItemJsCode("viewfollowup" . $ticket->fields['id'] . "$rand",
+                                $CFG_GLPI["root_doc"]."/ajax/viewsubitem.php", $params);
          echo "};";
          echo "</script>\n";
       }
-      echo convDateTime($this->fields["date"]) . "</td>";
+      echo Html::convDateTime($this->fields["date"]) . "</td>";
       echo "<td class='left'>" . nl2br($this->fields["content"]) . "</td>";
 
       // echo "<td>&nbsp;</td>";
@@ -462,8 +494,8 @@ class TicketFollowup  extends CommonDBTM {
    function showForm($ID, $options=array()) {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (isset($options['ticket']) && !empty($options['ticket'])) {
-         $ticket = $options['ticket'];
+      if (isset($options['parent']) && !empty($options['parent'])) {
+         $ticket = $options['parent'];
       }
 
       if ($ID > 0) {
@@ -474,12 +506,12 @@ class TicketFollowup  extends CommonDBTM {
          $this->check(-1,'w',$input);
       }
 
-      $tech = (haveRight("global_add_followups", "1")
+      $tech = (Session::haveRight("global_add_followups", "1")
                // TODO there is no users_id_assign in glpi_tickets
-          //     || $ticket->fields["users_id_assign"] === getLoginUserID()
+          //     || $ticket->fields["users_id_assign"] === Session::getLoginUserID()
           )
                || (isset($_SESSION["glpigroups"])
-                   && $ticket->haveAGroup(Ticket::ASSIGN,$_SESSION['glpigroups']));
+                   && $ticket->haveAGroup(CommonITILObject::ASSIGN,$_SESSION['glpigroups']));
 
       if ($tech) {
          $this->showFormHeader($options);
@@ -490,7 +522,7 @@ class TicketFollowup  extends CommonDBTM {
                $this->fields["content"]."</textarea></td>";
          if ($this->fields["date"]) {
             echo "<td>".$LANG['common'][27]."&nbsp;:</td>";
-            echo "<td>".convDateTime($this->fields["date"]);
+            echo "<td>".Html::convDateTime($this->fields["date"]);
          } else {
             echo "<td colspan='2'>&nbsp;";
          }
@@ -528,82 +560,6 @@ class TicketFollowup  extends CommonDBTM {
    }
 
 
-   /*
-    * Form to update a followup to a ticket
-    *
-    * @param $ID integer : followup ID
-   function showUpdateForm() {
-      global $DB,$LANG,$CFG_GLPI;
-
-      $ID = $this->getField('id');
-
-      if (!$this->canUpdateItem()) {
-         return false;
-      }
-
-      echo "<div class='center'>";
-      echo "<table class='tab_cadre_fixe'>";
-      echo "<tr><th>".$LANG['job'][39]."</th></tr>";
-      echo "<tr class='tab_bg_2'><td>";
-      echo "<form method='post' action='".$this->getFormURL()."'>\n";
-
-      echo "<table width='100%'>";
-      echo "<tr class='tab_bg_2'><td width='50%'>";
-
-      echo "<table width='100%' bgcolor='#FFFFFF'>";
-      echo "<tr class='tab_bg_1'>";
-      echo "<td class='center' width='10%'>".$LANG['joblist'][6]."<br><br>".$LANG['common'][27].
-            "&nbsp;:<br>".convDateTime($this->fields["date"])."</td>";
-      echo "<td width='90%'>";
-      echo "<textarea name='content' cols='50' rows='6'>".$this->fields["content"]."</textarea>";
-      echo "</td></tr></table>";
-
-      echo "</td>";
-      echo "<td width='50%' class='top'>";
-
-      echo "<table width='100%'>";
-
-      echo "<tr><td>".$LANG['job'][45]."&nbsp;:</td>";
-      echo "<td>";
-      Dropdown::show('RequestType', array('value' => $this->fields["requesttypes_id"]));
-      echo "</td></tr>";
-
-      echo "<tr><td>".$LANG['common'][77]."&nbsp;:</td>";
-      echo "<td>";
-      Dropdown::showYesNo('is_private', $this->fields["is_private"]);
-      echo "</td></tr>";
-
-      echo "<tr><td>".$LANG['job'][31]."&nbsp;:</td><td>";
-      $hour = floor($this->fields["actiontime"]);
-      $minute = round(($this->fields["actiontime"]-$hour)*60,0);
-      Dropdown::showInteger('hour',$hour,0,100);
-      echo $LANG['job'][21]."&nbsp;&nbsp;";
-      Dropdown::showInteger('minute',$minute,0,59);
-      echo $LANG['job'][22];
-      echo "</tr>";
-
-      echo "<tr class='tab_bg_2'>";
-      echo "<td class='center' colspan='2'>";
-      echo "<table width='100%'><tr><td class='center'>";
-      echo "<input type='submit' name='update' value='".$LANG['buttons'][14]."' class='submit'>";
-      echo "</td><td class='center'>";
-      echo "<input type='submit' name='delete' value='".$LANG['buttons'][6]."' class='submit'>";
-      echo "</td></tr></table>";
-      echo "</td></tr>";
-
-      echo "</table>";
-      echo "</td></tr></table>";
-
-      echo "<input type='hidden' name='id' value='".$this->fields["id"]."'>";
-      echo "<input type='hidden' name='tickets_id' value='".$this->fields["tickets_id"]."'>";
-      echo "</form>";
-
-      echo "</td></tr>";
-      echo "</table>";
-      echo "</div>";
-   }
-*/
-
 
    /**
     * Show the current ticketfollowup summary
@@ -613,22 +569,23 @@ class TicketFollowup  extends CommonDBTM {
    function showSummary($ticket) {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight("observe_ticket", "1") && !haveRight("show_full_ticket", "1")) {
+      if (!Session::haveRight("observe_ticket", "1")
+          && !havSession::haveRighteRight("show_full_ticket", "1")) {
          return false;
       }
 
       $tID = $ticket->fields['id'];
 
       // Display existing Followups
-      $showprivate   = haveRight("show_full_ticket", "1");
-      $caneditall    = haveRight("update_followups", "1");
+      $showprivate   = Session::haveRight("show_full_ticket", "1");
+      $caneditall    = Session::haveRight("update_followups", "1");
       $tmp           = array('tickets_id' => $tID);
       $canadd        = $this->can(-1, 'w', $tmp);
 
       $RESTRICT = "";
       if (!$showprivate) {
          $RESTRICT = " AND (`is_private` = '0'
-                            OR `users_id` ='" . getLoginUserID() . "') ";
+                            OR `users_id` ='" . Session::getLoginUserID() . "') ";
       }
 
       $query = "SELECT `id`, `date`
@@ -647,10 +604,11 @@ class TicketFollowup  extends CommonDBTM {
          echo "<script type='text/javascript' >\n";
          echo "function viewAddFollowup" . $ticket->fields['id'] . "$rand() {\n";
          $params = array('type'       => __CLASS__,
+                         'parenttype' => 'Ticket',
                          'tickets_id' => $ticket->fields['id'],
                          'id'         => -1);
-         ajaxUpdateItemJsCode("viewfollowup" . $ticket->fields['id'] . "$rand",
-                              $CFG_GLPI["root_doc"]."/ajax/viewfollowup.php", $params, false);
+         Ajax::updateItemJsCode("viewfollowup" . $ticket->fields['id'] . "$rand",
+                                $CFG_GLPI["root_doc"]."/ajax/viewsubitem.php", $params);
          echo "};";
          echo "</script>\n";
          if ($ticket->fields["status"] != 'solved' && $ticket->fields["status"] != 'closed') {
@@ -687,12 +645,12 @@ class TicketFollowup  extends CommonDBTM {
       global $DB, $CFG_GLPI, $LANG;
 
       // Print Followups for a job
-      $showprivate = haveRight("show_full_ticket", "1");
+      $showprivate = Session::haveRight("show_full_ticket", "1");
 
       $RESTRICT = "";
       if (!$showprivate) {
          $RESTRICT = " AND (`is_private` = '0'
-                           OR `users_id` ='".getLoginUserID()."') ";
+                           OR `users_id` ='".Session::getLoginUserID()."') ";
       }
 
       // Get Number of Followups
@@ -711,9 +669,10 @@ class TicketFollowup  extends CommonDBTM {
 
          while ($data=$DB->fetch_array($result)) {
             $out .= "<tr class='tab_bg_3'>
-                     <td class='center'>".convDateTime($data["date"])."</td>
+                     <td class='center'>".Html::convDateTime($data["date"])."</td>
                      <td class='center'>".getUserName($data["users_id"],1)."</td>
-                     <td width='70%' class='b'>".resume_text($data["content"], $CFG_GLPI["cut"])."
+                     <td width='70%' class='b'>".Html::resume_text($data["content"],
+                                                                   $CFG_GLPI["cut"])."
                      </td></tr>";
          }
          $out .= "</table></div>";
