@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: ticketvalidation.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ticketvalidation.class.php 18014 2012-03-27 07:16:25Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -45,31 +45,35 @@ class TicketValidation  extends CommonDBChild {
    public $items_id = 'tickets_id';
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['validation'][8];
+      }
       return $LANG['validation'][0];
    }
 
 
    function canCreate() {
-      return haveRight('create_validation', 1);
+      return Session::haveRight('create_validation', 1);
    }
 
 
    function canView() {
-      return (haveRight('create_validation', 1)
-              || haveRight('validate_ticket', 1));
+      return (Session::haveRight('create_validation', 1)
+              || Session::haveRight('validate_ticket', 1));
    }
 
 
    function canUpdate() {
-      return (haveRight('validate_ticket', 1) || haveRight('create_validation', 1));
+      return (Session::haveRight('validate_ticket', 1)
+              || Session::haveRight('create_validation', 1));
    }
 
 
    function canDelete() {
-      return haveRight('create_validation', 1);
+      return Session::haveRight('create_validation', 1);
    }
 
 
@@ -80,8 +84,8 @@ class TicketValidation  extends CommonDBChild {
     */
    function canUpdateItem() {
 
-      if (!haveRight('create_validation', 1)
-          && ($this->fields["users_id_validate"] != getLoginUserID())) {
+      if (!Session::haveRight('create_validation', 1)
+          && ($this->fields["users_id_validate"] != Session::getLoginUserID())) {
          return false;
       }
 
@@ -95,59 +99,78 @@ class TicketValidation  extends CommonDBChild {
       $query = "SELECT `users_id_validate`
                 FROM `glpi_ticketvalidations`
                 WHERE `tickets_id` = '$tickets_id'
-                      AND users_id_validate='".getLoginUserID()."'";
+                      AND users_id_validate='".Session::getLoginUserID()."'";
       $result = $DB->query($query);
+
       if ($DB->numrows($result)) {
          return true;
       }
-
       return false;
    }
 
 
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (Session::haveRight('create_validation','1')
+          || Session::haveRight('validate_ticket','1')) {
+
+         if ($_SESSION['glpishow_count_on_tabs']) {
+            $restrict = "`tickets_id` = '".$item->getID()."'";
+            if (!Session::haveRight('create_validation','1')) {
+              $restrict .= " AND `users_id_validate` = '".Session::getLoginUserID()."' ";
+            }
+            return self::createTabEntry($LANG['validation'][8],
+                                        countElementsInTable('glpi_ticketvalidations', $restrict));
+         }
+         return $LANG['validation'][8];
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      $validation = new Ticketvalidation();
+      $validation->showSummary($item);
+      return true;
+   }
+
+
    function post_getEmpty() {
 
-      $this->fields["users_id"] = getLoginUserID();
+      $this->fields["users_id"] = Session::getLoginUserID();
       $this->fields["status"]   = 'waiting';
    }
 
 
-   function defineTabs($options=array()) {
-      global $LANG;
-
-      $ong = array();
-      $ong[1] = $LANG['title'][26];
-
-      return $ong;
-   }
-
-
    function prepareInputForAdd($input) {
 
       // Not attached to tickets -> not added
       if (!isset($input['tickets_id']) || $input['tickets_id'] <= 0) {
          return false;
-      } else {
+      }
 
 /*       if (strstr($job->fields["status"],"solved")
                   || strstr($job->fields["status"],"closed")) {
             return false;
          }*/
 
-         if (!isset($input['entities_id'])) { // Massive modif case
-            $job = new Ticket;
-            $job->getFromDB($input["tickets_id"]);
-
-            $input['entities_id'] = $job->fields["entities_id"];
-         }
-         $input["users_id"] = 0;
-         if (!isset($input['_auto_update'])) {
-            $input["users_id"] = getLoginUserID();
-         }
-         $input["submission_date"] = $_SESSION["glpi_currenttime"];
-         $input["status"] = 'waiting';
+      if (!isset($input['entities_id'])) { // Massive modif case
+         $job = new Ticket();
+         $job->getFromDB($input["tickets_id"]);
 
+         $input['entities_id'] = $job->fields["entities_id"];
       }
+
+      $input["users_id"] = 0;
+      if (!isset($input['_auto_update'])) {
+         $input["users_id"] = Session::getLoginUserID();
+      }
+
+      $input["submission_date"] = $_SESSION["glpi_currenttime"];
+      $input["status"]          = 'waiting';
+
       return $input;
    }
 
@@ -155,22 +178,30 @@ class TicketValidation  extends CommonDBChild {
    function post_addItem() {
       global $LANG,$CFG_GLPI;
 
-      $job = new Ticket;
+      $job      = new Ticket();
       $mailsend = false;
       if ($job->getFromDB($this->fields["tickets_id"])) {
          // Set global validation to waiting
          if ($job->fields['global_validation'] == 'accepted'
              || $job->fields['global_validation'] == 'none') {
-            $input['id'] = $this->fields["tickets_id"];
+            $input['id']                = $this->fields["tickets_id"];
             $input['global_validation'] = 'waiting';
 
             // to fix lastupdater
             if (isset($this->input['_auto_update'])) {
                $input['_auto_update'] = $this->input['_auto_update'];
             }
-
+            // to know update by rules
+            if (isset($this->input["_rule_process"])) {
+               $input['_rule_process'] = $this->input["_rule_process"];
+            }
+            // No update ticket notif on ticket add
+            if (isset($this->input["_ticket_add"])) {
+               $input['_disablenotif'] = true;
+            }
             $job->update($input);
          }
+
          if ($CFG_GLPI["use_mailing"]) {
             $options = array('validation_id'     => $this->fields["id"],
                              'validation_status' => $this->fields["status"]);
@@ -179,10 +210,11 @@ class TicketValidation  extends CommonDBChild {
          if ($mailsend) {
             $user = new User();
             $user->getFromDB($this->fields["users_id_validate"]);
-            if (!empty($user->fields["email"])) {
-               addMessageAfterRedirect($LANG['validation'][13]." ".$user->getName());
+            $email = $user->getDefaultEmail();
+            if (!empty($email)) {
+               Session::addMessageAfterRedirect($LANG['validation'][13]." ".$user->getName());
             } else {
-               addMessageAfterRedirect($LANG['validation'][23],false,ERROR);
+               Session::addMessageAfterRedirect($LANG['validation'][23], false, ERROR);
             }
          }
          // Add log entry in the ticket
@@ -191,7 +223,7 @@ class TicketValidation  extends CommonDBChild {
          $changes[2] = addslashes($LANG['validation'][13]." ".
                                   getUserName($this->fields["users_id_validate"]));
          Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
-                      HISTORY_LOG_SIMPLE_MESSAGE);
+                      Log::HISTORY_LOG_SIMPLE_MESSAGE);
       }
    }
 
@@ -199,13 +231,13 @@ class TicketValidation  extends CommonDBChild {
    function prepareInputForUpdate($input) {
       global $LANG;
 
-      $job = new Ticket;
+      $job = new Ticket();
       $forbid_fields = array();
 
-      if ($this->fields["users_id_validate"] == getLoginUserID()) {
+      if ($this->fields["users_id_validate"] == Session::getLoginUserID()) {
          if ($input["status"] == "rejected"
              && (!isset($input["comment_validation"]) || $input["comment_validation"] == '')) {
-            addMessageAfterRedirect($LANG['validation'][29],false,ERROR);
+            Session::addMessageAfterRedirect($LANG['validation'][29], false, ERROR);
             return false;
          }
          if ($input["status"] == "waiting") {
@@ -217,7 +249,7 @@ class TicketValidation  extends CommonDBChild {
          $forbid_fields = array('entities_id', 'users_id', 'tickets_id', 'users_id_validate',
                                 'comment_submission', 'submission_date');
 
-      } else if (haveRight('create_validation',1)) { // Update validation request
+      } else if (Session::haveRight('create_validation',1)) { // Update validation request
          $forbid_fields = array('entities_id', 'tickets_id', 'status', 'comment_validation',
                                 'validation_date');
       }
@@ -237,7 +269,7 @@ class TicketValidation  extends CommonDBChild {
    function post_updateItem($history=1) {
       global $LANG,$CFG_GLPI;
 
-      $job = new Ticket;
+      $job = new Ticket();
       $mailsend = false;
 
       $donotif = $CFG_GLPI["use_mailing"];
@@ -269,9 +301,7 @@ class TicketValidation  extends CommonDBChild {
 
          }
          Log::history($this->getField('tickets_id'), 'Ticket',  $changes, $this->getType(),
-                      HISTORY_LOG_SIMPLE_MESSAGE);
-
-
+                      Log::HISTORY_LOG_SIMPLE_MESSAGE);
 
          // Set global validation to accepted to define one
          if ($job->fields['global_validation'] == 'waiting'
@@ -295,7 +325,7 @@ class TicketValidation  extends CommonDBChild {
       $changes[2] = addslashes($LANG['validation'][30]." ".
                     getUserName($this->fields["users_id_validate"]));
       Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
-                   HISTORY_LOG_SIMPLE_MESSAGE);
+                   Log::HISTORY_LOG_SIMPLE_MESSAGE);
    }
 
 
@@ -423,7 +453,7 @@ class TicketValidation  extends CommonDBChild {
     * Get Ticket validation demands count
     *
     * @param $tickets_id ticket ID
-    */
+   **/
    static function getNumberValidationForTicket($tickets_id) {
       global $DB;
 
@@ -438,17 +468,19 @@ class TicketValidation  extends CommonDBChild {
       return false;
    }
 
+
    /**
     * Get Ticket validation demands count for a user
     *
     * @param $users_id User ID
-    */
+   **/
    static function getNumberTicketsToValidate($users_id) {
       global $DB;
 
       $query = "SELECT COUNT(`id`) AS 'total'
                 FROM `glpi_ticketvalidations`
-                WHERE `users_id_validate` = '$users_id' AND `status` = 'waiting'";
+                WHERE `users_id_validate` = '$users_id'
+                      AND `status` = 'waiting'";
 
       $result = $DB->query($query);
       if ($DB->numrows($result)) {
@@ -457,12 +489,13 @@ class TicketValidation  extends CommonDBChild {
       return false;
    }
 
+
    /**
     * Get the number of validations attached to a ticket having a specified status
     *
     * @param $tickets_id ticket ID
     * @param $status status
-    */
+   **/
    static function getTicketStatusNumber($tickets_id, $status) {
       global $DB;
 
@@ -481,7 +514,7 @@ class TicketValidation  extends CommonDBChild {
 
    /**
     * Form for Followup on Massive action
-    */
+   **/
    static function showFormMassiveAction() {
       global $LANG;
 
@@ -505,11 +538,12 @@ class TicketValidation  extends CommonDBChild {
    function showSummary($ticket) {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!haveRight('validate_ticket',1) && !haveRight('create_validation',1)) {
+      if (!Session::haveRight('validate_ticket',1)
+          && !Session::haveRight('create_validation',1)) {
          return false;
       }
       $tID = $ticket->fields['id'];
-      //$canadd = haveRight("create_validation", "1");
+      //$canadd = Session::haveRight("create_validation", "1");
 
       $tmp    = array('tickets_id' => $tID);
       $canadd = $this->can(-1,'w',$tmp);
@@ -521,10 +555,11 @@ class TicketValidation  extends CommonDBChild {
          echo "<script type='text/javascript' >\n";
          echo "function viewAddValidation" . $tID . "$rand() {\n";
          $params = array('type'       => __CLASS__,
+                         'parenttype' => 'Ticket',
                          'tickets_id' => $tID,
                          'id'         => -1);
-         ajaxUpdateItemJsCode("viewfollowup" . $tID . "$rand",
-                              $CFG_GLPI["root_doc"]."/ajax/viewfollowup.php", $params, false);
+         Ajax::updateItemJsCode("viewfollowup" . $tID . "$rand",
+                                $CFG_GLPI["root_doc"]."/ajax/viewsubitem.php", $params);
          echo "};";
          echo "</script>\n";
          if ($ticket->fields["status"] != 'solved' && $ticket->fields["status"] != 'closed') {
@@ -537,7 +572,7 @@ class TicketValidation  extends CommonDBChild {
                 FROM `".$this->getTable()."`
                 WHERE `tickets_id` = '".$ticket->getField('id')."'";
       if (!$canadd) {
-         $query .= " AND `users_id_validate` = '".getLoginUserID()."' ";
+         $query .= " AND `users_id_validate` = '".Session::getLoginUserID()."' ";
       }
       $query .= " ORDER BY submission_date DESC";
       $result = $DB->query($query);
@@ -562,12 +597,12 @@ class TicketValidation  extends CommonDBChild {
          }
          echo "</tr>";
 
-         initNavigateListItems('TicketValidation',
-                               $LANG['validation'][26]." = ".$ticket->fields['name']);
+         Session::initNavigateListItems('TicketValidation',
+                                        $LANG['validation'][26]." = ".$ticket->fields['name']);
 
          while ($row = $DB->fetch_assoc($result)) {
             $canedit = $this->can($row["id"],'w');
-            addToNavigateListItems('TicketValidation',$row["id"]);
+            Session::addToNavigateListItems('TicketValidation',$row["id"]);
             $bgcolor = $this->getStatusColor($row['status']);
             $status = $this->getStatus($row['status']);
 
@@ -580,10 +615,11 @@ class TicketValidation  extends CommonDBChild {
                echo "\n<script type='text/javascript' >\n";
                echo "function viewEditValidation" . $ticket->fields['id'] . $row["id"] . "$rand() {\n";
                $params = array('type'       => __CLASS__,
+                               'parenttype' => 'Ticket',
                                'tickets_id' => $this->fields["tickets_id"],
                                'id'         => $row["id"]);
-               ajaxUpdateItemJsCode("viewfollowup" . $ticket->fields['id'] . "$rand",
-                                    $CFG_GLPI["root_doc"]."/ajax/viewfollowup.php", $params, false);
+               Ajax::updateItemJsCode("viewfollowup" . $ticket->fields['id'] . "$rand",
+                                      $CFG_GLPI["root_doc"]."/ajax/viewsubitem.php", $params);
                echo "};";
                echo "</script>\n";
             }
@@ -594,15 +630,15 @@ class TicketValidation  extends CommonDBChild {
                 && !strstr($ticket->fields["status"], "solved")
                 && !strstr($ticket->fields["status"],"closed")) {
 
-               $link_validation = getItemTypeFormURL('TicketValidation');
-               echo "<td>". convDateTime($row["submission_date"])."</td>";
+               $link_validation = Toolbox::getItemTypeFormURL('TicketValidation');
+               echo "<td>". Html::convDateTime($row["submission_date"])."</td>";
             } else {
-               echo "<td>".convDateTime($row["submission_date"])."</a></td>";
+               echo "<td>".Html::convDateTime($row["submission_date"])."</a></td>";
             }
 
             echo "<td>".getUserName($row["users_id"])."</td>";
             echo "<td>".$row["comment_submission"]."</td>";
-            echo "<td>".convDateTime($row["validation_date"])."</td>";
+            echo "<td>".Html::convDateTime($row["validation_date"])."</td>";
             echo "<td>".getUserName($row["users_id_validate"])."</td>";
             echo "<td>".$row["comment_validation"]."</td>";
             echo "</tr>";
@@ -629,17 +665,17 @@ class TicketValidation  extends CommonDBChild {
       if ($ID>0) {
          $tickets_id = $this->fields["tickets_id"];
       } else {
-         $tickets_id = $options['ticket']->fields["id"];
+         $tickets_id = $options['parent']->fields["id"];
       }
       $ticket = new Ticket();
       if (!$ticket->getFromDB($tickets_id)) {
          return false;
       }
       // No update validation is answer set
-      $validation_admin = ($this->fields["users_id"] == getLoginUserID())
+      $validation_admin = ($this->fields["users_id"] == Session::getLoginUserID())
                           && $this->canCreate()
                           && $this->fields['status'] == 'waiting';
-      $validator = ($this->fields["users_id_validate"] == getLoginUserID());
+      $validator = ($this->fields["users_id_validate"] == Session::getLoginUserID());
 
       $options['colspan'] = 1;
 
