@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: index.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: index.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,8 +37,8 @@ define('GLPI_ROOT', '.');
 include (GLPI_ROOT . "/config/based_config.php");
 
 if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
-   include (GLPI_ROOT . "/inc/common.function.php");
-   glpi_header("install/install.php");
+   include_once (GLPI_ROOT . "/inc/autoload.function.php");
+   Html::redirect("install/install.php");
    die();
 
 } else {
@@ -83,7 +83,7 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
    echo "<body>";
    echo "<div id='contenulogin'>";
    echo "<div id='logo-login'>";
-   echo nl2br(unclean_cross_side_scripting_deep($CFG_GLPI['text_login']));
+   echo nl2br(Toolbox::unclean_cross_side_scripting_deep($CFG_GLPI['text_login']));
    echo "</div>";
 
    echo "<div id='boxlogin'>";
@@ -96,7 +96,7 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
 
    // redirect to ticket
    if (isset($_GET["redirect"])) {
-      manageRedirect($_GET["redirect"]);
+      Toolbox::manageRedirect($_GET["redirect"]);
       echo '<input type="hidden" name="redirect" value="'.$_GET['redirect'].'">';
    }
    echo "<fieldset>";
@@ -158,7 +158,7 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
 
    if (GLPI_DEMO_MODE) {
       echo "<div class='center'>";
-      getCountLogin();
+      Event::getCountLogin();
       echo "</div>";
    }
 
@@ -170,8 +170,8 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
 
 }
 // call cron
-if (! GLPI_DEMO_MODE) {
-   callCronForce();
+if (!GLPI_DEMO_MODE) {
+   CronTask::callCronForce();
 }
 
 echo "</body></html>";
