@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: install.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: install.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,14 +35,9 @@
 
 define('GLPI_ROOT', '..');
 
-include_once (GLPI_ROOT . "/config/define.php");
-include_once (GLPI_ROOT . "/config/based_config.php");
-include_once (GLPI_ROOT . "/inc/timer.class.php");
-include_once (GLPI_ROOT . "/inc/common.function.php");
+include_once (GLPI_ROOT . "/inc/autoload.function.php");
 include_once (GLPI_ROOT . "/inc/db.function.php");
-include_once (GLPI_ROOT . "/inc/dropdown.class.php");
-include_once (GLPI_ROOT . "/inc/display.function.php");
-
+Config::detectRootDoc();
 
 //Print a correct  Html header for application
 function header_html($etape) {
@@ -163,7 +158,7 @@ function step1($update) {
    echo "<h3>".$LANG['install'][5]."</h3>";
    echo "<table class='tab_check'>";
 
-   $error = commonCheckForUseGLPI();
+   $error = Toolbox::commonCheckForUseGLPI();
 
    echo "</table>";
    switch ($error) {
@@ -340,11 +335,11 @@ function step4 ($host, $user, $password, $databasename, $newdatabasename) {
    function fill_db() {
       global $LANG, $CFG_GLPI;
 
-      include_once (GLPI_ROOT . "/inc/dbmysql.class.php");
+      //include_once (GLPI_ROOT . "/inc/dbmysql.class.php");
       include_once (GLPI_CONFIG_DIR . "/config_db.php");
 
-      $DB = new DB;
-      if (!$DB->runFile(GLPI_ROOT ."/install/mysql/glpi-0.80.3-empty.sql")) {
+      $DB = new DB();
+      if (!$DB->runFile(GLPI_ROOT ."/install/mysql/glpi-0.83-empty.sql")) {
          echo "Errors occurred inserting default database";
       }
 
@@ -435,9 +430,8 @@ function step7() {
    global $LANG, $CFG_GLPI;
 
    require_once (GLPI_ROOT . "/inc/dbmysql.class.php");
-   require_once (GLPI_ROOT . "/inc/common.function.php");
    require_once (GLPI_CONFIG_DIR . "/config_db.php");
-   $DB = new DB;
+   $DB = new DB();
 
    $query = "UPDATE `glpi_configs`
              SET `url_base` = '".str_replace("/install/install.php", "", $_SERVER['HTTP_REFERER'])."'
@@ -504,10 +498,10 @@ function update1($host, $user, $password, $DBname) {
 
 // Use default session dir if not writable
 if (is_writable(GLPI_SESSION_DIR)) {
-   setGlpiSessionPath();
+   Session::setPath();
 }
 
-startGlpiSession();
+Session::start();
 error_reporting(0); // we want to check system before affraid the user.
 
 if (!isset($_SESSION["glpilanguage"]) || empty($_SESSION["glpilanguage"])) {
@@ -524,7 +518,7 @@ if (!isset($_POST["install"])) {
    $_SESSION = array();
 
    if (file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
-      glpi_header(GLPI_ROOT ."/index.php");
+      Html::redirect(GLPI_ROOT ."/index.php");
       die();
 
    } else {
@@ -558,12 +552,12 @@ if (!isset($_POST["install"])) {
          break;
 
       case "Etape_1" : // check ok, go import mysql settings.
-         $_SESSION['glpi_use_mode'] = DEBUG_MODE; // check system ok, we can use specific parameters for debug
-         $CFG_GLPI["debug_sql"]     = $CFG_GLPI["debug_vars"]=0;
-         $CFG_GLPI["use_log_in_files"]  = 1;
+         $_SESSION['glpi_use_mode']    = Session::DEBUG_MODE; // check system ok, we can use specific parameters for debug
+         $CFG_GLPI["debug_sql"]        = $CFG_GLPI["debug_vars"]=0;
+         $CFG_GLPI["use_log_in_files"] = 1;
          ini_set('display_errors', 'On');
          error_reporting(E_ALL | E_STRICT);
-         set_error_handler("userErrorHandlerDebug");
+         set_error_handler(array('Toolbox', 'userErrorHandlerDebug'));
 
          header_html($LANG['install'][77]." 1");
          step2($_POST["update"]);
