@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ldap_mass_sync.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ldap_mass_sync.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,21 +35,16 @@
 // Ensure current directory when run from crontab
 chdir(dirname($_SERVER["SCRIPT_FILENAME"]));
 
-if ($argv) {
-   for ($i=1 ; $i<count($argv) ; $i++) {
-      //To be able to use = in search filters, enter \= instead in command line
-      //Replace the \= by ° not to match the split function
-      $arg   = str_replace('\=','°',$argv[$i]);
-      $it    = explode("=",$arg);
+if (isset($_SERVER['argv'])) {
+   for ($i=1 ; $i<$_SERVER['argc'] ; $i++) {
+      $it = explode("=", $_SERVER['argv'][$i], 2);
       $it[0] = preg_replace('/^--/','',$it[0]);
 
-      //Replace the ° by = the find the good filter
-      $it           = str_replace('°','=',$it);
-      $_GET[$it[0]] = $it[1];
+      $_GET[$it[0]] = (isset($it[1]) ? $it[1] : true);
    }
 }
 
-if ((isset($argv) && in_array('help',$argv))
+if ((isset($_SERVER['argv']) && in_array('help', $_SERVER['argv']))
     || isset($_GET['help'])) {
    echo "Usage : php -q -f ldap_mass_sync.php [action=<option>]  [ldapservers_id=ID]\n";
    echo "Options values :\n";
@@ -97,7 +92,7 @@ if ($options['after-days']) {
    unset($options['after-days']);
 }
 
-if (!canUseLdap() || !countElementsInTable('glpi_authldaps')) {
+if (!Toolbox::canUseLdap() || !countElementsInTable('glpi_authldaps')) {
    echo "LDAP extension is not active or no LDAP directory defined";
 }
 
